@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -26,10 +25,6 @@
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 06, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -40,17 +35,17 @@ h5tbmake_table_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *name
                  hid_t_f *field_types, hsize_t_f *chunk_size, int_f *compress,
                  size_t_f *char_len_field_names,      /* field_names lengths */
                  size_t_f *max_char_size_field_names, /* char len of fields */
-                 char *    field_names)                   /* field_names */
+                 char     *field_names)                   /* field_names */
 {
-    char *  c_name  = NULL;
-    char *  c_name1 = NULL;
+    char   *c_name  = NULL;
+    char   *c_name1 = NULL;
     hsize_t num_elem;
     hsize_t i;
     hsize_t c_nfields      = (hsize_t)*nfields;
     size_t *c_field_offset = NULL;
-    hid_t * c_field_types  = NULL;
-    char ** c_field_names  = NULL;
-    char *  tmp            = NULL, *tmp_p;
+    hid_t  *c_field_types  = NULL;
+    char  **c_field_names  = NULL;
+    char   *tmp            = NULL, *tmp_p;
     int_f   ret_value      = 0;
 
     num_elem = (hsize_t)*nfields;
@@ -59,13 +54,13 @@ h5tbmake_table_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *name
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     if (NULL == (c_name1 = (char *)HD5f2cstring(name1, (size_t)*namelen1)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_field_offset = (size_t *)HDmalloc(sizeof(size_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_field_types = (hid_t *)HDmalloc(sizeof(hid_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_field_offset = (size_t *)malloc(sizeof(size_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_field_types = (hid_t *)malloc(sizeof(hid_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
 
     for (i = 0; i < num_elem; i++) {
         c_field_offset[i] = (size_t)field_offset[i];
@@ -75,21 +70,21 @@ h5tbmake_table_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *name
     /*
      * allocate array of character pointers
      */
-    if (NULL == (c_field_names = (char **)HDcalloc((size_t)num_elem, sizeof(char *))))
-        HGOTO_DONE(FAIL)
+    if (NULL == (c_field_names = (char **)calloc((size_t)num_elem, sizeof(char *))))
+        HGOTO_DONE(FAIL);
 
     /* copy data to long C string */
     if (NULL ==
         (tmp = (char *)HD5f2cstring(field_names, (size_t) * (max_char_size_field_names) * (size_t)num_elem)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     /*
      * move data from temporary buffer
      */
     tmp_p = tmp;
     for (i = 0; i < num_elem; i++) {
-        if (NULL == (c_field_names[i] = (char *)HDmalloc((size_t)char_len_field_names[i] + 1)))
-            HGOTO_DONE(FAIL)
-        HDmemcpy(c_field_names[i], tmp_p, (size_t)char_len_field_names[i]);
+        if (NULL == (c_field_names[i] = (char *)malloc((size_t)char_len_field_names[i] + 1)))
+            HGOTO_DONE(FAIL);
+        memcpy(c_field_names[i], tmp_p, (size_t)char_len_field_names[i]);
         c_field_names[i][char_len_field_names[i]] = '\0';
         tmp_p                                     = tmp_p + *max_char_size_field_names;
     } /* end for */
@@ -100,26 +95,26 @@ h5tbmake_table_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *name
     if (H5TBmake_table(c_name1, (hid_t)*loc_id, c_name, c_nfields, (hsize_t)*nrecords, (size_t)*type_size,
                        (const char **)c_field_names, c_field_offset, c_field_types, (hsize_t)*chunk_size,
                        NULL, *compress, NULL) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     if (c_name1)
-        HDfree(c_name1);
+        free(c_name1);
     if (c_field_names) {
         for (i = 0; i < num_elem; i++) {
             if (c_field_names[i])
-                HDfree(c_field_names[i]);
+                free(c_field_names[i]);
         } /* end for */
-        HDfree(c_field_names);
+        free(c_field_names);
     } /* end if */
     if (tmp)
-        HDfree(tmp);
+        free(tmp);
     if (c_field_offset)
-        HDfree(c_field_offset);
+        free(c_field_offset);
     if (c_field_types)
-        HDfree(c_field_types);
+        free(c_field_types);
 
     return ret_value;
 } /* end h5tbmake_table_c() */
@@ -131,10 +126,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: M. Scot Breitenfeld
- *
- * Date: Sept. 10, 2015
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -147,15 +138,15 @@ h5tbmake_table_ptr_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *
                      size_t_f *max_char_size_field_names, /* char len of fields */
                      char *field_names, void *data)       /* field_names */
 {
-    char *  c_name  = NULL;
-    char *  c_name1 = NULL;
+    char   *c_name  = NULL;
+    char   *c_name1 = NULL;
     hsize_t num_elem;
     hsize_t i;
     hsize_t c_nfields      = (hsize_t)*nfields;
     size_t *c_field_offset = NULL;
-    hid_t * c_field_types  = NULL;
-    char ** c_field_names  = NULL;
-    char *  tmp            = NULL, *tmp_p;
+    hid_t  *c_field_types  = NULL;
+    char  **c_field_names  = NULL;
+    char   *tmp            = NULL, *tmp_p;
     int_f   ret_value      = 0;
 
     num_elem = (hsize_t)*nfields;
@@ -164,13 +155,13 @@ h5tbmake_table_ptr_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     if (NULL == (c_name1 = (char *)HD5f2cstring(name1, (size_t)*namelen1)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_field_offset = (size_t *)HDmalloc(sizeof(size_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_field_types = (hid_t *)HDmalloc(sizeof(hid_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_field_offset = (size_t *)malloc(sizeof(size_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_field_types = (hid_t *)malloc(sizeof(hid_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
 
     for (i = 0; i < num_elem; i++) {
         c_field_offset[i] = (size_t)field_offset[i];
@@ -180,21 +171,21 @@ h5tbmake_table_ptr_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *
     /*
      * allocate array of character pointers
      */
-    if (NULL == (c_field_names = (char **)HDcalloc((size_t)num_elem, sizeof(char *))))
-        HGOTO_DONE(FAIL)
+    if (NULL == (c_field_names = (char **)calloc((size_t)num_elem, sizeof(char *))))
+        HGOTO_DONE(FAIL);
 
     /* copy data to long C string */
     if (NULL ==
         (tmp = (char *)HD5f2cstring(field_names, (size_t) * (max_char_size_field_names) * (size_t)num_elem)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     /*
      * move data from temporary buffer
      */
     tmp_p = tmp;
     for (i = 0; i < num_elem; i++) {
-        if (NULL == (c_field_names[i] = (char *)HDmalloc((size_t)char_len_field_names[i] + 1)))
-            HGOTO_DONE(FAIL)
-        HDmemcpy(c_field_names[i], tmp_p, (size_t)char_len_field_names[i]);
+        if (NULL == (c_field_names[i] = (char *)malloc((size_t)char_len_field_names[i] + 1)))
+            HGOTO_DONE(FAIL);
+        memcpy(c_field_names[i], tmp_p, (size_t)char_len_field_names[i]);
         c_field_names[i][char_len_field_names[i]] = '\0';
         tmp_p                                     = tmp_p + *max_char_size_field_names;
     } /* end for */
@@ -205,26 +196,26 @@ h5tbmake_table_ptr_c(size_t_f *namelen1, _fcd name1, hid_t_f *loc_id, size_t_f *
     if (H5TBmake_table(c_name1, (hid_t)*loc_id, c_name, c_nfields, (hsize_t)*nrecords, (size_t)*type_size,
                        (const char **)c_field_names, c_field_offset, c_field_types, (hsize_t)*chunk_size,
                        fill_data, *compress, data) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     if (c_name1)
-        HDfree(c_name1);
+        free(c_name1);
     if (c_field_names) {
         for (i = 0; i < num_elem; i++) {
             if (c_field_names[i])
-                HDfree(c_field_names[i]);
+                free(c_field_names[i]);
         } /* end for */
-        HDfree(c_field_names);
+        free(c_field_names);
     } /* end if */
     if (tmp)
-        HDfree(tmp);
+        free(tmp);
     if (c_field_offset)
-        HDfree(c_field_offset);
+        free(c_field_offset);
     if (c_field_types)
-        HDfree(c_field_types);
+        free(c_field_types);
 
     return ret_value;
 } /* end h5tbmake_table_c() */
@@ -236,10 +227,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: M. Scot Breitenfeld
- *
- * Date: Sept. 14, 2015
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -248,7 +235,7 @@ int_f
 h5tbread_table_c(hid_t_f *loc_id, _fcd name, size_t_f *namelen, hsize_t_f *nfields, size_t_f *dst_size,
                  size_t_f *dst_offset, size_t_f *dst_sizes, void *dst_buf)
 {
-    char *  c_name       = NULL;
+    char   *c_name       = NULL;
     size_t *c_dst_offset = NULL;
     size_t *c_dst_sizes  = NULL;
     hsize_t c_nfields    = (hsize_t)*nfields;
@@ -259,12 +246,12 @@ h5tbread_table_c(hid_t_f *loc_id, _fcd name, size_t_f *namelen, hsize_t_f *nfiel
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
-    if (NULL == (c_dst_offset = (size_t *)HDmalloc(sizeof(size_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_dst_sizes = (size_t *)HDmalloc(sizeof(size_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
+    if (NULL == (c_dst_offset = (size_t *)malloc(sizeof(size_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_dst_sizes = (size_t *)malloc(sizeof(size_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
 
     for (i = 0; i < c_nfields; i++) {
         c_dst_offset[i] = (size_t)dst_offset[i];
@@ -275,16 +262,16 @@ h5tbread_table_c(hid_t_f *loc_id, _fcd name, size_t_f *namelen, hsize_t_f *nfiel
      * call H5TBread_table function.
      */
     if (H5TBread_table((hid_t)*loc_id, c_name, (size_t)*dst_size, c_dst_offset, c_dst_sizes, dst_buf) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
 
     if (c_dst_offset)
-        HDfree(c_dst_offset);
+        free(c_dst_offset);
     if (c_dst_sizes)
-        HDfree(c_dst_sizes);
+        free(c_dst_sizes);
 
     return ret_value;
 } /* end h5tbmake_table_c() */
@@ -296,10 +283,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 12, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -308,8 +291,8 @@ int_f
 h5tbwrite_field_name_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *namelen1, _fcd field_name,
                        hsize_t_f *start, hsize_t_f *nrecords, size_t_f *type_size, void *buf)
 {
-    char * c_name         = NULL;
-    char * c_name1        = NULL;
+    char  *c_name         = NULL;
+    char  *c_name1        = NULL;
     size_t c_type_size[1] = {(size_t)*type_size};
     int_f  ret_value      = 0;
 
@@ -317,22 +300,22 @@ h5tbwrite_field_name_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     if (NULL == (c_name1 = (char *)HD5f2cstring(field_name, (size_t)*namelen1)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
     /*
      * call H5TBwrite_fields_name function.
      */
     if (H5TBwrite_fields_name((hid_t)*loc_id, c_name, c_name1, (hsize_t)*start, (hsize_t)*nrecords,
                               c_type_size[0], 0, c_type_size, buf) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     if (c_name1)
-        HDfree(c_name1);
+        free(c_name1);
 
     return ret_value;
 }
@@ -344,10 +327,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 12, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -356,8 +335,8 @@ int_f
 h5tbread_field_name_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *namelen1, _fcd field_name,
                       hsize_t_f *start, hsize_t_f *nrecords, size_t_f *type_size, void *buf)
 {
-    char * c_name         = NULL;
-    char * c_name1        = NULL;
+    char  *c_name         = NULL;
+    char  *c_name1        = NULL;
     size_t c_type_size[1] = {(size_t)*type_size};
     int_f  ret_value      = 0;
 
@@ -365,22 +344,22 @@ h5tbread_field_name_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *n
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     if (NULL == (c_name1 = (char *)HD5f2cstring(field_name, (size_t)*namelen1)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
     /*
      * call H5TBread_fields_name function.
      */
     if (H5TBread_fields_name((hid_t)*loc_id, c_name, c_name1, (hsize_t)*start, (hsize_t)*nrecords,
                              c_type_size[0], 0, c_type_size, buf) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     if (c_name1)
-        HDfree(c_name1);
+        free(c_name1);
 
     return ret_value;
 }
@@ -392,10 +371,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 12, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -404,7 +379,7 @@ int_f
 h5tbwrite_field_index_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *field_index, hsize_t_f *start,
                         hsize_t_f *nrecords, size_t_f *type_size, void *buf)
 {
-    char * c_name        = NULL;
+    char  *c_name        = NULL;
     size_t c_type_size   = *type_size;
     int    c_field_index = *field_index - 1; /* C zero based index */
     int_f  ret_value     = 0;
@@ -413,18 +388,18 @@ h5tbwrite_field_index_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *fi
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
     /*
      * call H5TBwrite_fields_name function.
      */
     if (H5TBwrite_fields_index((hid_t)*loc_id, c_name, (hsize_t)1, &c_field_index, (hsize_t)*start,
                                (hsize_t)*nrecords, c_type_size, 0, &c_type_size, buf) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
 
     return ret_value;
 }
@@ -436,10 +411,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 12, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -448,7 +419,7 @@ int_f
 h5tbread_field_index_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *field_index, hsize_t_f *start,
                        hsize_t_f *nrecords, size_t_f *type_size, void *buf)
 {
-    char * c_name        = NULL;
+    char  *c_name        = NULL;
     size_t c_type_size   = *type_size;
     int    c_field_index = *field_index - 1; /* C zero based index */
     int_f  ret_value     = 0;
@@ -457,18 +428,18 @@ h5tbread_field_index_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *fie
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
     /*
      * call H5TBread_fields_index function.
      */
     if (H5TBread_fields_index((hid_t)*loc_id, c_name, (hsize_t)1, &c_field_index, (hsize_t)*start,
                               (hsize_t)*nrecords, c_type_size, 0, &c_type_size, buf) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
 
     return ret_value;
 }
@@ -480,10 +451,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 13, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -500,22 +467,22 @@ h5tbinsert_field_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *name
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     if (NULL == (c_name1 = (char *)HD5f2cstring(field_name, (size_t)*namelen1)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     /*
      * call H5TBinsert_field function.
      */
 
     if (H5TBinsert_field((hid_t)*loc_id, c_name, c_name1, (hid_t)*field_type, (hsize_t)*position, NULL, buf) <
         0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     if (c_name1)
-        HDfree(c_name1);
+        free(c_name1);
 
     return ret_value;
 }
@@ -527,10 +494,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 13, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -546,21 +509,21 @@ h5tbdelete_field_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *name
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     if (NULL == (c_name1 = (char *)HD5f2cstring(field_name, (size_t)*namelen1)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
     /*
      * call H5TBinsert_field function.
      */
     if (H5TBdelete_field((hid_t)*loc_id, c_name, c_name1) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     if (c_name1)
-        HDfree(c_name1);
+        free(c_name1);
 
     return ret_value;
 }
@@ -572,10 +535,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 12, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -583,7 +542,7 @@ done:
 int_f
 h5tbget_table_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *nfields, hsize_t_f *nrecords)
 {
-    char *  c_name = NULL;
+    char   *c_name = NULL;
     hsize_t c_nfields;
     hsize_t c_nrecords;
     int_f   ret_value = 0;
@@ -592,20 +551,20 @@ h5tbget_table_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *n
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
     /*
      * call H5TBread_fields_index function.
      */
 
     if (H5TBget_table_info((hid_t)*loc_id, c_name, &c_nfields, &c_nrecords) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
     *nfields  = (hsize_t_f)c_nfields;
     *nrecords = (hsize_t_f)c_nrecords;
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
 
     return ret_value;
 }
@@ -617,10 +576,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: October 13, 2004
- *
  * Comments:
  *
  *-------------------------------------------------------------------------
@@ -634,14 +589,14 @@ h5tbget_field_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *n
                      size_t_f *maxlen_out)
 
 {
-    char *  c_name = NULL;
+    char   *c_name = NULL;
     hsize_t num_elem;
     hsize_t c_nfields       = *nfields;
     size_t *c_field_sizes   = NULL;
     size_t *c_field_offsets = NULL;
     size_t  c_type_size;
-    char ** c_field_names = NULL;
-    char *  tmp           = NULL, *tmp_p;
+    char  **c_field_names = NULL;
+    char   *tmp           = NULL, *tmp_p;
     hsize_t i;
     int_f   ret_value = 0;
     size_t  c_lenmax;
@@ -655,37 +610,37 @@ h5tbget_field_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *n
      * convert FORTRAN name to C name
      */
     if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_field_offsets = (size_t *)HDmalloc(sizeof(size_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_field_sizes = (size_t *)HDmalloc(sizeof(size_t) * (size_t)c_nfields)))
-        HGOTO_DONE(FAIL)
-    if (NULL == (c_field_names = (char **)HDcalloc((size_t)c_nfields, sizeof(char *))))
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_field_offsets = (size_t *)malloc(sizeof(size_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_field_sizes = (size_t *)malloc(sizeof(size_t) * (size_t)c_nfields)))
+        HGOTO_DONE(FAIL);
+    if (NULL == (c_field_names = (char **)calloc((size_t)c_nfields, sizeof(char *))))
+        HGOTO_DONE(FAIL);
 
     for (i = 0; i < c_nfields; i++)
-        if (NULL == (c_field_names[i] = (char *)HDmalloc(sizeof(char) * HLTB_MAX_FIELD_LEN)))
-            HGOTO_DONE(FAIL)
+        if (NULL == (c_field_names[i] = (char *)malloc(sizeof(char) * HLTB_MAX_FIELD_LEN)))
+            HGOTO_DONE(FAIL);
 
     /*
      * call H5TBget_field_info function.
      */
     if (H5TBget_field_info((hid_t)*loc_id, c_name, c_field_names, c_field_sizes, c_field_offsets,
                            &c_type_size) < 0)
-        HGOTO_DONE(FAIL)
+        HGOTO_DONE(FAIL);
 
     /* return values */
 
     /* names array */
-    if (NULL == (tmp = (char *)HDmalloc((c_lenmax * (size_t)c_nfields) + 1)))
-        HGOTO_DONE(FAIL)
+    if (NULL == (tmp = (char *)malloc((c_lenmax * (size_t)c_nfields) + 1)))
+        HGOTO_DONE(FAIL);
     tmp_p = tmp;
-    HDmemset(tmp, ' ', c_lenmax * (size_t)c_nfields);
+    memset(tmp, ' ', c_lenmax * (size_t)c_nfields);
     tmp[c_lenmax * c_nfields] = '\0';
     for (i = 0; i < c_nfields; i++) {
-        size_t field_name_len = HDstrlen(c_field_names[i]);
+        size_t field_name_len = strlen(c_field_names[i]);
 
-        HDmemcpy(tmp_p, c_field_names[i], field_name_len);
+        memcpy(tmp_p, c_field_names[i], field_name_len);
         namelen2[i] = (size_t_f)field_name_len;
         length      = MAX(length, strlen((c_field_names[i])));
         tmp_p       = tmp_p + c_lenmax;
@@ -703,19 +658,19 @@ h5tbget_field_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *n
 
 done:
     if (c_name)
-        HDfree(c_name);
+        free(c_name);
     if (c_field_names) {
         for (i = 0; i < num_elem; i++)
             if (c_field_names[i])
-                HDfree(c_field_names[i]);
-        HDfree(c_field_names);
+                free(c_field_names[i]);
+        free(c_field_names);
     } /* end if */
     if (tmp)
-        HDfree(tmp);
+        free(tmp);
     if (c_field_offsets)
-        HDfree(c_field_offsets);
+        free(c_field_offsets);
     if (c_field_sizes)
-        HDfree(c_field_sizes);
+        free(c_field_sizes);
 
     return ret_value;
 }
