@@ -70,8 +70,8 @@ static int H5__mpi_delete_cb(MPI_Comm comm, int keyval, void *attr_val, int *fla
 /*****************************/
 
 /* Library incompatible release versions, develop releases are incompatible by design */
-const unsigned VERS_RELEASE_EXCEPTIONS[]    = {0};
-const unsigned VERS_RELEASE_EXCEPTIONS_SIZE = 0;
+static const unsigned VERS_RELEASE_EXCEPTIONS[]    = {0};
+static const unsigned VERS_RELEASE_EXCEPTIONS_SIZE = 0;
 
 /* statically initialize block for pthread_once call used in initializing */
 /* the first global mutex                                                 */
@@ -115,7 +115,7 @@ H5_default_vfd_init(void)
      * it has of initializing the default VFD.
      */
     if (H5FD_sec2_init() == H5I_INVALID_HID) {
-        HGOTO_ERROR(H5E_FUNC, H5E_CANTINIT, FAIL, "unable to load default VFD ID")
+        HGOTO_ERROR(H5E_FUNC, H5E_CANTINIT, FAIL, "unable to load default VFD ID");
     }
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -145,7 +145,7 @@ H5_init_library(void)
 
     /* Run the library initialization routine, if it hasn't already run */
     if (H5_INIT_GLOBAL || H5_TERM_GLOBAL)
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
 
     /* Set the 'library initialized' flag as early as possible, to avoid
      * possible re-entrancy.
@@ -183,7 +183,7 @@ H5_init_library(void)
     /*
      * Make sure the package information is updated.
      */
-    HDmemset(&H5_debug_g, 0, sizeof H5_debug_g);
+    memset(&H5_debug_g, 0, sizeof H5_debug_g);
     H5_debug_g.pkg[H5_PKG_A].name  = "a";
     H5_debug_g.pkg[H5_PKG_AC].name = "ac";
     H5_debug_g.pkg[H5_PKG_B].name  = "b";
@@ -218,11 +218,11 @@ H5_init_library(void)
          * This must be entered before the library cleanup code so it's
          * executed in LIFO order (i.e., last).
          */
-        (void)HDatexit(H5TS_win32_process_exit);
+        (void)atexit(H5TS_win32_process_exit);
 #endif /* H5_HAVE_THREADSAFE && H5_HAVE_WIN_THREADS */
 
         /* Normal library termination code */
-        (void)HDatexit(H5_term_library);
+        (void)atexit(H5_term_library);
 
         H5_dont_atexit_g = TRUE;
     } /* end if */
@@ -243,33 +243,35 @@ H5_init_library(void)
      * The dataspace interface needs to be initialized so that future IDs for
      *   dataspaces work.
      */
-    /* clang-format off */
-    struct {
-        herr_t (*func)(void);
-        const char *descr;
-    } initializer[] = {
-        {H5E_init, "error"}
-    ,   {H5VL_init_phase1, "VOL"}
-    ,   {H5SL_init, "skip lists"}
-    ,   {H5FD_init, "VFD"}
-    ,   {H5_default_vfd_init, "default VFD"}
-    ,   {H5P_init_phase1, "property list"}
-    ,   {H5AC_init, "metadata caching"}
-    ,   {H5L_init, "link"}
-    ,   {H5S_init, "dataspace"}
-    ,   {H5PL_init, "plugins"}
-    /* Finish initializing interfaces that depend on the interfaces above */
-    ,   {H5P_init_phase2, "property list"}
-    ,   {H5VL_init_phase2, "VOL"}
-    };
+    {
+        /* clang-format off */
+        struct {
+            herr_t (*func)(void);
+            const char *descr;
+        } initializer[] = {
+            {H5E_init, "error"}
+        ,   {H5VL_init_phase1, "VOL"}
+        ,   {H5SL_init, "skip lists"}
+        ,   {H5FD_init, "VFD"}
+        ,   {H5_default_vfd_init, "default VFD"}
+        ,   {H5P_init_phase1, "property list"}
+        ,   {H5AC_init, "metadata caching"}
+        ,   {H5L_init, "link"}
+        ,   {H5S_init, "dataspace"}
+        ,   {H5PL_init, "plugins"}
+        /* Finish initializing interfaces that depend on the interfaces above */
+        ,   {H5P_init_phase2, "property list"}
+        ,   {H5VL_init_phase2, "VOL"}
+        };
 
-    for (i = 0; i < NELMTS(initializer); i++) {
-        if (initializer[i].func() < 0) {
-            HGOTO_ERROR(H5E_FUNC, H5E_CANTINIT, FAIL,
-                "unable to initialize %s interface", initializer[i].descr)
+        for (i = 0; i < NELMTS(initializer); i++) {
+            if (initializer[i].func() < 0) {
+                HGOTO_ERROR(H5E_FUNC, H5E_CANTINIT, FAIL,
+                    "unable to initialize %s interface", initializer[i].descr);
+            }
         }
+        /* clang-format on */
     }
-    /* clang-format on */
 
     /* Debugging? */
     H5__debug_mask("-all");
@@ -349,146 +351,148 @@ H5_term_library(void)
      * way that would necessitate some cleanup work in the other interface.
      */
 
-#define TERMINATOR(module, wait) {      \
-      .func = H5##module##_term_package \
-    , .name = #module                   \
-    , .completed = false                \
-    , .await_prior = wait               \
-    }
-
-    /*
-     * Termination is ordered by the `terminator` table so the "higher" level
-     * packages are shut down before "lower" level packages that they
-     * rely on:
-     */
-    struct {
-        int (*func)(void);       /* function to terminate the module; returns 0
-                                  * on success, >0 if termination was not
-                                  * completed and we should try to terminate
-                                  * some dependent modules, first.
-                                  */
-        const char *name;        /* name of the module */
-        hbool_t     completed;   /* true iff this terminator was already
-                                  * completed
-                                  */
-        const hbool_t await_prior;  /* true iff all prior terminators in the
-                                     * list must complete before this
-                                     * terminator is attempted
-                                     */
-    } terminator[] = {
-        /* Close the event sets first, so that all asynchronous operations
-         * complete before anything else attempts to shut down.
-         */
-        TERMINATOR(ES, false)
-        /* Do not attempt to close down package L until after event sets
-         * have finished closing down.
-         */
-    ,   TERMINATOR(L, true)
-        /* Close the "top" of various interfaces (IDs, etc) but don't shut
-         * down the whole interface yet, so that the object header messages
-         * get serialized correctly for entries in the metadata cache and the
-         * symbol table entry in the superblock gets serialized correctly, etc.
-         * all of which is performed in the 'F' shutdown.
-         *
-         * The tops of packages A, D, G, M, S, T do not need to wait for L
-         * or previous packages to finish closing down.
-         */
-    ,   TERMINATOR(A_top, false)
-    ,   TERMINATOR(D_top, false)
-    ,   TERMINATOR(G_top, false)
-    ,   TERMINATOR(M_top, false)
-    ,   TERMINATOR(S_top, false)
-    ,   TERMINATOR(T_top, false)
-        /* Don't shut down the file code until objects in files are shut down */
-    ,   TERMINATOR(F, true)
-        /* Don't shut down the property list code until all objects that might
-         * use property lists are shut down
-         */
-    ,   TERMINATOR(P, true)
-        /* Wait to shut down the "bottom" of various interfaces until the
-         * files are closed, so pieces of the file can be serialized
-         * correctly.
-         *
-         * Shut down the "bottom" of the attribute, dataset, group,
-         * reference, dataspace, and datatype interfaces, fully closing
-         * out the interfaces now.
-         */
-    ,   TERMINATOR(A, true)
-    ,   TERMINATOR(D, false)
-    ,   TERMINATOR(G, false)
-    ,   TERMINATOR(M, false)
-    ,   TERMINATOR(S, false)
-    ,   TERMINATOR(T, false)
-        /* Wait to shut down low-level packages like AC until after
-         * the preceding high-level packages have shut down.  This prevents
-         * low-level objects from closing "out from underneath" their
-         * reliant high-level objects.
-         */
-    ,   TERMINATOR(AC, true)
-        /* Shut down the "pluggable" interfaces, before the plugin framework */
-    ,   TERMINATOR(Z, false)
-    ,   TERMINATOR(FD, false)
-    ,   TERMINATOR(VL, false)
-        /* Don't shut down the plugin code until all "pluggable" interfaces
-         * (Z, FD, PL) are shut down
-         */
-    ,   TERMINATOR(PL, true)
-        /* Shut down the following packages in strictly the order given
-         * by the table.
-         */
-    ,   TERMINATOR(E, true)
-    ,   TERMINATOR(I, true)
-    ,   TERMINATOR(SL, true)
-    ,   TERMINATOR(FL, true)
-    ,   TERMINATOR(CX, true)
-    };
-
-    do {
-        pending = 0;
-        for (i = 0; i < NELMTS(terminator); i++) {
-            if (terminator[i].completed)
-                continue;
-            if (pending != 0 && terminator[i].await_prior)
-                break;
-            if (terminator[i].func() == 0) {
-                terminator[i].completed = true;
-                continue;
-            }
-
-            /* log a package when its terminator needs to be retried */
-            pending++;
-            nprinted = HDsnprintf(next, nleft, "%s%s",
-                (next != loop) ? "," : "", terminator[i].name);
-            if (nprinted < 0)
-                continue;
-            if ((size_t)nprinted >= nleft)
-                nprinted = HDsnprintf(next, nleft, "...");
-            if (nprinted < 0 || (size_t)nprinted >= nleft)
-                continue;
-            nleft -= (size_t)nprinted;
-            next += nprinted;
+    {
+#define TERMINATOR(module, wait) {          \
+          .func = H5##module##_term_package \
+        , .name = #module                   \
+        , .completed = false                \
+        , .await_prior = wait               \
         }
-    } while (pending && ntries++ < 100);
 
-    /* clang-format on */
+        /*
+         * Termination is ordered by the `terminator` table so the "higher" level
+         * packages are shut down before "lower" level packages that they
+         * rely on:
+         */
+        struct {
+            int (*func)(void);       /* function to terminate the module; returns 0
+                                      * on success, >0 if termination was not
+                                      * completed and we should try to terminate
+                                      * some dependent modules, first.
+                                      */
+            const char *name;        /* name of the module */
+            hbool_t     completed;   /* true iff this terminator was already
+                                      * completed
+                                      */
+            const hbool_t await_prior;  /* true iff all prior terminators in the
+                                         * list must complete before this
+                                         * terminator is attempted
+                                         */
+        } terminator[] = {
+            /* Close the event sets first, so that all asynchronous operations
+             * complete before anything else attempts to shut down.
+             */
+            TERMINATOR(ES, false)
+            /* Do not attempt to close down package L until after event sets
+             * have finished closing down.
+             */
+        ,   TERMINATOR(L, true)
+            /* Close the "top" of various interfaces (IDs, etc) but don't shut
+             * down the whole interface yet, so that the object header messages
+             * get serialized correctly for entries in the metadata cache and the
+             * symbol table entry in the superblock gets serialized correctly, etc.
+             * all of which is performed in the 'F' shutdown.
+             *
+             * The tops of packages A, D, G, M, S, T do not need to wait for L
+             * or previous packages to finish closing down.
+             */
+        ,   TERMINATOR(A_top, false)
+        ,   TERMINATOR(D_top, false)
+        ,   TERMINATOR(G_top, false)
+        ,   TERMINATOR(M_top, false)
+        ,   TERMINATOR(S_top, false)
+        ,   TERMINATOR(T_top, false)
+            /* Don't shut down the file code until objects in files are shut down */
+        ,   TERMINATOR(F, true)
+            /* Don't shut down the property list code until all objects that might
+             * use property lists are shut down
+             */
+        ,   TERMINATOR(P, true)
+            /* Wait to shut down the "bottom" of various interfaces until the
+             * files are closed, so pieces of the file can be serialized
+             * correctly.
+             *
+             * Shut down the "bottom" of the attribute, dataset, group,
+             * reference, dataspace, and datatype interfaces, fully closing
+             * out the interfaces now.
+             */
+        ,   TERMINATOR(A, true)
+        ,   TERMINATOR(D, false)
+        ,   TERMINATOR(G, false)
+        ,   TERMINATOR(M, false)
+        ,   TERMINATOR(S, false)
+        ,   TERMINATOR(T, false)
+            /* Wait to shut down low-level packages like AC until after
+             * the preceding high-level packages have shut down.  This prevents
+             * low-level objects from closing "out from underneath" their
+             * reliant high-level objects.
+             */
+        ,   TERMINATOR(AC, true)
+            /* Shut down the "pluggable" interfaces, before the plugin framework */
+        ,   TERMINATOR(Z, false)
+        ,   TERMINATOR(FD, false)
+        ,   TERMINATOR(VL, false)
+            /* Don't shut down the plugin code until all "pluggable" interfaces
+             * (Z, FD, PL) are shut down
+             */
+        ,   TERMINATOR(PL, true)
+            /* Shut down the following packages in strictly the order given
+             * by the table.
+             */
+        ,   TERMINATOR(E, true)
+        ,   TERMINATOR(I, true)
+        ,   TERMINATOR(SL, true)
+        ,   TERMINATOR(FL, true)
+        ,   TERMINATOR(CX, true)
+        };
 
-    if (pending) {
-        /* Only display the error message if the user is interested in them. */
-        if (func) {
-            HDfprintf(stderr, "HDF5: infinite loop closing library\n");
-            HDfprintf(stderr, "      %s\n", loop);
+        do {
+            pending = 0;
+            for (i = 0; i < NELMTS(terminator); i++) {
+                if (terminator[i].completed)
+                    continue;
+                if (pending != 0 && terminator[i].await_prior)
+                    break;
+                if (terminator[i].func() == 0) {
+                    terminator[i].completed = true;
+                    continue;
+                }
+
+                /* log a package when its terminator needs to be retried */
+                pending++;
+                nprinted = HDsnprintf(next, nleft, "%s%s",
+                    (next != loop) ? "," : "", terminator[i].name);
+                if (nprinted < 0)
+                    continue;
+                if ((size_t)nprinted >= nleft)
+                    nprinted = HDsnprintf(next, nleft, "...");
+                if (nprinted < 0 || (size_t)nprinted >= nleft)
+                    continue;
+                nleft -= (size_t)nprinted;
+                next += nprinted;
+            }
+        } while (pending && ntries++ < 100);
+
+        /* clang-format on */
+
+        if (pending) {
+            /* Only display the error message if the user is interested in them. */
+            if (func) {
+                fprintf(stderr, "HDF5: infinite loop closing library\n");
+                fprintf(stderr, "      %s\n", loop);
 #ifndef NDEBUG
-            HDabort();
-#endif    /* NDEBUG */
-        } /* end if */
-    }     /* end if */
+                HDabort();
+#endif        /* NDEBUG */
+            } /* end if */
+        }     /* end if */
+    }
 
     /* Free open debugging streams */
     while (H5_debug_g.open_stream) {
         H5_debug_open_stream_t *tmp_open_stream;
 
         tmp_open_stream = H5_debug_g.open_stream;
-        (void)HDfclose(H5_debug_g.open_stream->stream);
+        (void)fclose(H5_debug_g.open_stream->stream);
         H5_debug_g.open_stream = H5_debug_g.open_stream->next;
         (void)H5MM_free(tmp_open_stream);
     } /* end while */
@@ -572,7 +576,7 @@ H5garbage_collect(void)
 
     /* Call the garbage collection routines in the library */
     if (H5FL_garbage_coll() < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGC, FAIL, "can't garbage collect objects")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGC, FAIL, "can't garbage collect objects");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -618,7 +622,7 @@ H5set_free_list_limits(int reg_global_lim, int reg_list_lim, int arr_global_lim,
     /* Call the free list function to actually set the limits */
     if (H5FL_set_free_list_limits(reg_global_lim, reg_list_lim, arr_global_lim, arr_list_lim, blk_global_lim,
                                   blk_list_lim, blk_global_lim, blk_list_lim) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTSET, FAIL, "can't set garbage collection limits")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTSET, FAIL, "can't set garbage collection limits");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -641,9 +645,6 @@ done:
  * Return:    Success:    non-negative
  *        Failure:    negative
  *
- * Programmer:  Quincey Koziol
- *              Friday, March 6, 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -657,7 +658,7 @@ H5get_free_list_sizes(size_t *reg_size /*out*/, size_t *arr_size /*out*/, size_t
 
     /* Call the free list function to actually get the sizes */
     if (H5FL_get_free_list_sizes(reg_size, arr_size, blk_size, fac_size) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGET, FAIL, "can't get garbage collection sizes")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGET, FAIL, "can't get garbage collection sizes");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -696,7 +697,7 @@ H5__debug_mask(const char *s)
 
     while (s && *s) {
 
-        if (HDisalpha(*s) || '-' == *s || '+' == *s) {
+        if (isalpha(*s) || '-' == *s || '+' == *s) {
 
             /* Enable or Disable debugging? */
             if ('-' == *s) {
@@ -712,7 +713,7 @@ H5__debug_mask(const char *s)
             } /* end if */
 
             /* Get the name */
-            for (i = 0; HDisalpha(*s); i++, s++)
+            for (i = 0; isalpha(*s); i++, s++)
                 if (i < sizeof pkg_name)
                     pkg_name[i] = *s;
             pkg_name[MIN(sizeof(pkg_name) - 1, i)] = '\0';
@@ -741,11 +742,11 @@ H5__debug_mask(const char *s)
                     } /* end if */
                 }     /* end for */
                 if (i >= (size_t)H5_NPKGS)
-                    HDfprintf(stderr, "HDF5_DEBUG: ignored %s\n", pkg_name);
+                    fprintf(stderr, "HDF5_DEBUG: ignored %s\n", pkg_name);
             } /* end if-else */
         }
-        else if (HDisdigit(*s)) {
-            int                     fd = (int)HDstrtol(s, &rest, 0);
+        else if (isdigit(*s)) {
+            int                     fd = (int)strtol(s, &rest, 0);
             H5_debug_open_stream_t *open_stream;
 
             if ((stream = HDfdopen(fd, "w")) != NULL) {
@@ -753,7 +754,7 @@ H5__debug_mask(const char *s)
 
                 if (NULL ==
                     (open_stream = (H5_debug_open_stream_t *)H5MM_malloc(sizeof(H5_debug_open_stream_t)))) {
-                    (void)HDfclose(stream);
+                    (void)fclose(stream);
                     return;
                 } /* end if */
 
@@ -880,7 +881,7 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
 
     /* Don't check again, if we already have */
     if (checked)
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
 
     {
         const char *s; /* Environment string for disabling version check */
@@ -888,23 +889,23 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
         /* Allow different versions of the header files and library? */
         s = HDgetenv("HDF5_DISABLE_VERSION_CHECK");
 
-        if (s && HDisdigit(*s))
-            disable_version_check = (unsigned int)HDstrtol(s, NULL, 0);
+        if (s && isdigit(*s))
+            disable_version_check = (unsigned int)strtol(s, NULL, 0);
     }
 
     /* H5_VERS_MAJOR and H5_VERS_MINOR must match */
     if (H5_VERS_MAJOR != majnum || H5_VERS_MINOR != minnum) {
         switch (disable_version_check) {
             case 0:
-                HDfprintf(stderr, "%s%s", version_mismatch_warning,
-                          "You can, at your own risk, disable this warning by setting the environment\n"
-                          "variable 'HDF5_DISABLE_VERSION_CHECK' to a value of '1'.\n"
-                          "Setting it to 2 or higher will suppress the warning messages totally.\n");
+                fprintf(stderr, "%s%s", version_mismatch_warning,
+                        "You can, at your own risk, disable this warning by setting the environment\n"
+                        "variable 'HDF5_DISABLE_VERSION_CHECK' to a value of '1'.\n"
+                        "Setting it to 2 or higher will suppress the warning messages totally.\n");
                 /* Mention the versions we are referring to */
-                HDfprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum, relnum,
-                          (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
+                fprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum, relnum,
+                        (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
                 /* Show library settings if available */
-                HDfprintf(stderr, "%s", H5libhdf5_settings);
+                fprintf(stderr, "%s", H5libhdf5_settings);
 
                 /* Bail out now. */
                 HDfputs("Bye...\n", stderr);
@@ -912,16 +913,16 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
             case 1:
                 /* continue with a warning */
                 /* Note that the warning message is embedded in the format string.*/
-                HDfprintf(stderr,
-                          "%s'HDF5_DISABLE_VERSION_CHECK' "
-                          "environment variable is set to %d, application will\n"
-                          "continue at your own risk.\n",
-                          version_mismatch_warning, disable_version_check);
+                fprintf(stderr,
+                        "%s'HDF5_DISABLE_VERSION_CHECK' "
+                        "environment variable is set to %d, application will\n"
+                        "continue at your own risk.\n",
+                        version_mismatch_warning, disable_version_check);
                 /* Mention the versions we are referring to */
-                HDfprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum, relnum,
-                          (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
+                fprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum, relnum,
+                        (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
                 /* Show library settings if available */
-                HDfprintf(stderr, "%s", H5libhdf5_settings);
+                fprintf(stderr, "%s", H5libhdf5_settings);
                 break;
             default:
                 /* 2 or higher: continue silently */
@@ -938,15 +939,13 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
             if (VERS_RELEASE_EXCEPTIONS[i] == relnum || VERS_RELEASE_EXCEPTIONS[i] == H5_VERS_RELEASE) {
                 switch (disable_version_check) {
                     case 0:
-                        HDfprintf(
-                            stderr, "%s%s", release_mismatch_warning,
-                            "You can, at your own risk, disable this warning by setting the environment\n"
-                            "variable 'HDF5_DISABLE_VERSION_CHECK' to a value of '1'.\n"
-                            "Setting it to 2 or higher will suppress the warning messages totally.\n");
+                        fprintf(stderr, "%s%s", release_mismatch_warning,
+                                "You can, at your own risk, disable this warning by setting the environment\n"
+                                "variable 'HDF5_DISABLE_VERSION_CHECK' to a value of '1'.\n"
+                                "Setting it to 2 or higher will suppress the warning messages totally.\n");
                         /* Mention the versions we are referring to */
-                        HDfprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum,
-                                  relnum, (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR,
-                                  (unsigned)H5_VERS_RELEASE);
+                        fprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum, relnum,
+                                (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
 
                         /* Bail out now. */
                         HDfputs("Bye...\n", stderr);
@@ -954,15 +953,14 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
                     case 1:
                         /* continue with a warning */
                         /* Note that the warning message is embedded in the format string.*/
-                        HDfprintf(stderr,
-                                  "%s'HDF5_DISABLE_VERSION_CHECK' "
-                                  "environment variable is set to %d, application will\n"
-                                  "continue at your own risk.\n",
-                                  release_mismatch_warning, disable_version_check);
+                        fprintf(stderr,
+                                "%s'HDF5_DISABLE_VERSION_CHECK' "
+                                "environment variable is set to %d, application will\n"
+                                "continue at your own risk.\n",
+                                release_mismatch_warning, disable_version_check);
                         /* Mention the versions we are referring to */
-                        HDfprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum,
-                                  relnum, (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR,
-                                  (unsigned)H5_VERS_RELEASE);
+                        fprintf(stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n", majnum, minnum, relnum,
+                                (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
                         break;
                     default:
                         /* 2 or higher: continue silently */
@@ -995,11 +993,11 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
                     "variable 'HDF5_DISABLE_VERSION_CHECK' to a value of 1 "
                     "will suppress\nthis warning.\n",
                     stderr);
-            HDfprintf(stderr,
-                      "Library version information are:\n"
-                      "H5_VERS_MAJOR=%d, H5_VERS_MINOR=%d, H5_VERS_RELEASE=%d, "
-                      "H5_VERS_SUBRELEASE=%s,\nH5_VERS_INFO=%s\n",
-                      H5_VERS_MAJOR, H5_VERS_MINOR, H5_VERS_RELEASE, H5_VERS_SUBRELEASE, H5_VERS_INFO);
+            fprintf(stderr,
+                    "Library version information are:\n"
+                    "H5_VERS_MAJOR=%d, H5_VERS_MINOR=%d, H5_VERS_RELEASE=%d, "
+                    "H5_VERS_SUBRELEASE=%s,\nH5_VERS_INFO=%s\n",
+                    H5_VERS_MAJOR, H5_VERS_MINOR, H5_VERS_RELEASE, H5_VERS_SUBRELEASE, H5_VERS_INFO);
         } /* end if */
     }
 
@@ -1054,11 +1052,11 @@ H5atclose(H5_atclose_func_t func, void *ctx)
 
     /* Check arguments */
     if (NULL == func)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "NULL func pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "NULL func pointer");
 
     /* Allocate space for the 'atclose' node */
     if (NULL == (new_atclose = H5FL_MALLOC(H5_atclose_node_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "can't allocate 'atclose' node")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "can't allocate 'atclose' node");
 
     /* Set up 'atclose' node */
     new_atclose->func = func;
@@ -1122,7 +1120,7 @@ H5close(void)
  *
  *-------------------------------------------------------------------------
  */
-void *
+void *H5_ATTR_MALLOC
 H5allocate_memory(size_t size, hbool_t clear)
 {
     void *ret_value = NULL;
@@ -1255,7 +1253,7 @@ H5is_library_terminating(hbool_t *is_terminating /*out*/)
     FUNC_ENTER_API_NOINIT
     H5TRACE1("e", "x", is_terminating);
 
-    HDassert(is_terminating);
+    assert(is_terminating);
 
     if (is_terminating)
         *is_terminating = H5_TERM_GLOBAL;
