@@ -10,10 +10,8 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Quincey Koziol
- *              Thursday, February  3, 2005
- *
- * Purpose:	v2 B-tree testing functions.
+/*
+ * Purpose:     v2 B-tree testing functions
  *
  */
 
@@ -27,9 +25,12 @@
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"  /* Generic Functions			*/
-#include "H5B2pkg.h"    /* v2 B-trees				*/
-#include "H5Eprivate.h" /* Error handling		  	*/
+#include "H5private.h"   /* Generic Functions                        */
+#include "H5ACprivate.h" /* Metadata Cache                           */
+#include "H5B2pkg.h"     /* B-Trees (Version 2)                      */
+#include "H5Eprivate.h"  /* Error Handling                           */
+#include "H5Fprivate.h"  /* Files                                    */
+#include "H5FLprivate.h" /* Free Lists                               */
 
 /****************/
 /* Local Macros */
@@ -121,9 +122,6 @@ H5FL_DEFINE_STATIC(H5B2_test_ctx_t);
  * Return:	Success:	non-NULL
  *		Failure:	NULL
  *
- * Programmer:	Quincey Koziol
- *              Thursday, November 26, 2009
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -136,11 +134,11 @@ H5B2__test_crt_context(void *_f)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(f);
+    assert(f);
 
     /* Allocate callback context */
     if (NULL == (ctx = H5FL_MALLOC(H5B2_test_ctx_t)))
-        HGOTO_ERROR(H5E_BTREE, H5E_CANTALLOC, NULL, "can't allocate callback context")
+        HGOTO_ERROR(H5E_BTREE, H5E_CANTALLOC, NULL, "can't allocate callback context");
 
     /* Determine the size of lengths in the file */
     ctx->sizeof_size = H5F_SIZEOF_SIZE(f);
@@ -160,9 +158,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, November 26, 2009
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -173,7 +168,7 @@ H5B2__test_dst_context(void *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(ctx);
+    assert(ctx);
 
     /* Release callback context */
     ctx = H5FL_FREE(H5B2_test_ctx_t, ctx);
@@ -189,9 +184,6 @@ H5B2__test_dst_context(void *_ctx)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, February  3, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -213,9 +205,6 @@ H5B2__test_store(void *nrecord, const void *udata)
  *              =0 if rec1 == rec2
  *              >0 if rec1 > rec2
  *
- * Programmer:	Quincey Koziol
- *              Thursday, February  3, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -236,9 +225,6 @@ H5B2__test_compare(const void *rec1, const void *rec2, int *result)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, February  3, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -249,9 +235,9 @@ H5B2__test_encode(uint8_t *raw, const void *nrecord, void *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(ctx);
+    assert(ctx);
 
-    H5F_ENCODE_LENGTH_LEN(raw, *(const hsize_t *)nrecord, ctx->sizeof_size);
+    H5_ENCODE_LENGTH_LEN(raw, *(const hsize_t *)nrecord, ctx->sizeof_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5B2__test_encode() */
@@ -264,9 +250,6 @@ H5B2__test_encode(uint8_t *raw, const void *nrecord, void *_ctx)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Friday, February  4, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -277,9 +260,9 @@ H5B2__test_decode(const uint8_t *raw, void *nrecord, void *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(ctx);
+    assert(ctx);
 
-    H5F_DECODE_LENGTH_LEN(raw, *(hsize_t *)nrecord, ctx->sizeof_size);
+    H5_DECODE_LENGTH_LEN(raw, *(hsize_t *)nrecord, ctx->sizeof_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5B2__test_decode() */
@@ -292,9 +275,6 @@ H5B2__test_decode(const uint8_t *raw, void *nrecord, void *_ctx)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Friday, February  4, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -302,9 +282,9 @@ H5B2__test_debug(FILE *stream, int indent, int fwidth, const void *record, const
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(record);
+    assert(record);
 
-    HDfprintf(stream, "%*s%-*s %" PRIuHSIZE "\n", indent, "", fwidth, "Record:", *(const hsize_t *)record);
+    fprintf(stream, "%*s%-*s %" PRIuHSIZE "\n", indent, "", fwidth, "Record:", *(const hsize_t *)record);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5B2__test_debug() */
@@ -317,9 +297,6 @@ H5B2__test_debug(FILE *stream, int indent, int fwidth, const void *record, const
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Friday, December 25, 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -341,9 +318,6 @@ H5B2__test2_store(void *nrecord, const void *udata)
  *              =0 if rec1 == rec2
  *              >0 if rec1 > rec2
  *
- * Programmer:	Quincey Koziol
- *              Friday, December 25, 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -364,9 +338,6 @@ H5B2__test2_compare(const void *rec1, const void *rec2, int *result)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Friday, December 25, 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -377,10 +348,10 @@ H5B2__test2_encode(uint8_t *raw, const void *nrecord, void *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(ctx);
+    assert(ctx);
 
-    H5F_ENCODE_LENGTH_LEN(raw, ((const H5B2_test_rec_t *)nrecord)->key, ctx->sizeof_size);
-    H5F_ENCODE_LENGTH_LEN(raw, ((const H5B2_test_rec_t *)nrecord)->val, ctx->sizeof_size);
+    H5_ENCODE_LENGTH_LEN(raw, ((const H5B2_test_rec_t *)nrecord)->key, ctx->sizeof_size);
+    H5_ENCODE_LENGTH_LEN(raw, ((const H5B2_test_rec_t *)nrecord)->val, ctx->sizeof_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5B2__test2_encode() */
@@ -393,9 +364,6 @@ H5B2__test2_encode(uint8_t *raw, const void *nrecord, void *_ctx)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Friday, December 25, 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -406,10 +374,10 @@ H5B2__test2_decode(const uint8_t *raw, void *nrecord, void *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(ctx);
+    assert(ctx);
 
-    H5F_DECODE_LENGTH_LEN(raw, ((H5B2_test_rec_t *)nrecord)->key, ctx->sizeof_size);
-    H5F_DECODE_LENGTH_LEN(raw, ((H5B2_test_rec_t *)nrecord)->val, ctx->sizeof_size);
+    H5_DECODE_LENGTH_LEN(raw, ((H5B2_test_rec_t *)nrecord)->key, ctx->sizeof_size);
+    H5_DECODE_LENGTH_LEN(raw, ((H5B2_test_rec_t *)nrecord)->val, ctx->sizeof_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5B2__test2_decode() */
@@ -422,9 +390,6 @@ H5B2__test2_decode(const uint8_t *raw, void *nrecord, void *_ctx)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Friday, December 25, 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -432,10 +397,10 @@ H5B2__test2_debug(FILE *stream, int indent, int fwidth, const void *record, cons
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(record);
+    assert(record);
 
-    HDfprintf(stream, "%*s%-*s (%" PRIuHSIZE ", %" PRIuHSIZE ")\n", indent, "", fwidth,
-              "Record:", ((const H5B2_test_rec_t *)record)->key, ((const H5B2_test_rec_t *)record)->val);
+    fprintf(stream, "%*s%-*s (%" PRIuHSIZE ", %" PRIuHSIZE ")\n", indent, "", fwidth,
+            "Record:", ((const H5B2_test_rec_t *)record)->key, ((const H5B2_test_rec_t *)record)->val);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5B2__test2_debug() */
@@ -447,9 +412,6 @@ H5B2__test2_debug(FILE *stream, int indent, int fwidth, const void *record, cons
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *              Saturday, February 26, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -458,8 +420,8 @@ H5B2__get_root_addr_test(H5B2_t *bt2, haddr_t *root_addr)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Check arguments. */
-    HDassert(bt2);
-    HDassert(root_addr);
+    assert(bt2);
+    assert(root_addr);
 
     /* Get B-tree root addr */
     *root_addr = bt2->hdr->root.addr;
@@ -474,9 +436,6 @@ H5B2__get_root_addr_test(H5B2_t *bt2, haddr_t *root_addr)
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *              Thursday, August 31, 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -493,7 +452,7 @@ H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(bt2);
+    assert(bt2);
 
     /* Set the shared v2 B-tree header's file context for this operation */
     bt2->hdr->f = bt2->f;
@@ -513,7 +472,7 @@ H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
 
     /* Check for empty tree */
     if (0 == curr_node_ptr.node_nrec)
-        HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, FAIL, "B-tree has no records")
+        HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, FAIL, "B-tree has no records");
 
     /* Walk down B-tree to find record or leaf node where record is located */
     cmp = -1;
@@ -524,19 +483,19 @@ H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
         /* Lock B-tree current node */
         if (NULL == (internal = H5B2__protect_internal(hdr, parent, &curr_node_ptr, depth, FALSE,
                                                        H5AC__READ_ONLY_FLAG)))
-            HGOTO_ERROR(H5E_BTREE, H5E_CANTPROTECT, FAIL, "unable to load B-tree internal node")
+            HGOTO_ERROR(H5E_BTREE, H5E_CANTPROTECT, FAIL, "unable to load B-tree internal node");
 
         /* Unpin parent if necessary */
         if (parent) {
             if (parent != hdr && H5AC_unpin_entry(parent) < 0)
-                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry")
+                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry");
             parent = NULL;
         } /* end if */
 
         /* Locate node pointer for child */
         if (H5B2__locate_record(hdr->cls, internal->nrec, hdr->nat_off, internal->int_native, udata, &idx,
                                 &cmp) < 0)
-            HGOTO_ERROR(H5E_BTREE, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records")
+            HGOTO_ERROR(H5E_BTREE, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records");
 
         if (cmp > 0)
             idx++;
@@ -548,7 +507,7 @@ H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
             /* Unlock current node */
             if (H5AC_unprotect(hdr->f, H5AC_BT2_INT, curr_node_ptr.addr, internal,
                                (unsigned)(hdr->swmr_write ? H5AC__PIN_ENTRY_FLAG : H5AC__NO_FLAGS_SET)) < 0)
-                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node")
+                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node");
 
             /* Keep track of parent if necessary */
             if (hdr->swmr_write)
@@ -560,14 +519,14 @@ H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
         else {
             /* Unlock current node */
             if (H5AC_unprotect(hdr->f, H5AC_BT2_INT, curr_node_ptr.addr, internal, H5AC__NO_FLAGS_SET) < 0)
-                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node")
+                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node");
 
             /* Fill in information about the node */
             ninfo->depth = depth;
             ninfo->nrec  = curr_node_ptr.node_nrec;
 
             /* Indicate success */
-            HGOTO_DONE(SUCCEED)
+            HGOTO_DONE(SUCCEED);
         } /* end else */
 
         /* Decrement depth we're at in B-tree */
@@ -579,26 +538,26 @@ H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
 
         /* Lock B-tree leaf node */
         if (NULL == (leaf = H5B2__protect_leaf(hdr, parent, &curr_node_ptr, FALSE, H5AC__READ_ONLY_FLAG)))
-            HGOTO_ERROR(H5E_BTREE, H5E_CANTPROTECT, FAIL, "unable to protect B-tree leaf node")
+            HGOTO_ERROR(H5E_BTREE, H5E_CANTPROTECT, FAIL, "unable to protect B-tree leaf node");
 
         /* Unpin parent if necessary */
         if (parent) {
             if (parent != hdr && H5AC_unpin_entry(parent) < 0)
-                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry")
+                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry");
             parent = NULL;
         } /* end if */
 
         /* Locate record */
         if (H5B2__locate_record(hdr->cls, leaf->nrec, hdr->nat_off, leaf->leaf_native, udata, &idx, &cmp) < 0)
-            HGOTO_ERROR(H5E_BTREE, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records")
+            HGOTO_ERROR(H5E_BTREE, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records");
 
         /* Unlock current node */
         if (H5AC_unprotect(hdr->f, H5AC_BT2_LEAF, curr_node_ptr.addr, leaf, H5AC__NO_FLAGS_SET) < 0)
-            HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node")
+            HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node");
 
         /* Indicate the depth that the record was found */
         if (cmp != 0)
-            HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, FAIL, "record not in B-tree")
+            HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, FAIL, "record not in B-tree");
     } /* end block */
 
     /* Fill in information about the leaf node */
@@ -607,9 +566,9 @@ H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
 
 done:
     if (parent) {
-        HDassert(ret_value < 0);
+        assert(ret_value < 0);
         if (parent != hdr && H5AC_unpin_entry(parent) < 0)
-            HDONE_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry")
+            HDONE_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry");
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -627,9 +586,6 @@ done:
  *
  *              Failure:    -1
  *
- * Programmer:	Quincey Koziol
- *              Saturday, August 26, 2006
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -641,11 +597,11 @@ H5B2__get_node_depth_test(H5B2_t *bt2, void *udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(bt2);
+    assert(bt2);
 
     /* Get information abou the node */
     if (H5B2__get_node_info_test(bt2, udata, &ninfo) < 0)
-        HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, (-1), "error looking up node info")
+        HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, (-1), "error looking up node info");
 
     /* Set return value */
     ret_value = (int)ninfo.depth;
