@@ -152,9 +152,6 @@ static const H5C_log_class_t H5C_json_log_class_g = {"json",
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -166,22 +163,22 @@ H5C__json_write_log_message(H5C_log_json_udata_t *json_udata)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->outfile);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->outfile);
+    assert(json_udata->message);
 
     /* Write the log message and flush */
     n_chars = HDstrlen(json_udata->message);
-    if ((int)n_chars != HDfprintf(json_udata->outfile, "%s", json_udata->message))
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "error writing log message")
-    HDmemset((void *)(json_udata->message), 0, (size_t)(n_chars * sizeof(char)));
+    if ((int)n_chars != fprintf(json_udata->outfile, "%s", json_udata->message))
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "error writing log message");
+    memset((void *)(json_udata->message), 0, (size_t)(n_chars * sizeof(char)));
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C__json_write_log_message() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5C_log_json_set_up
+ * Function:    H5C__log_json_set_up
  *
  * Purpose:     Setup for metadata cache logging.
  *
@@ -199,36 +196,33 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_json_set_up(H5C_log_info_t *log_info, const char log_location[], int mpi_rank)
+H5C__log_json_set_up(H5C_log_info_t *log_info, const char log_location[], int mpi_rank)
 {
     H5C_log_json_udata_t *json_udata = NULL;
     char                 *file_name  = NULL;
     size_t                n_chars;
     herr_t                ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(log_info);
-    HDassert(log_location);
+    assert(log_info);
+    assert(log_location);
 
     /* Set up the class struct */
     log_info->cls = &H5C_json_log_class_g;
 
     /* Allocate memory for the JSON-specific data */
     if (NULL == (log_info->udata = H5MM_calloc(sizeof(H5C_log_json_udata_t))))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed");
     json_udata = (H5C_log_json_udata_t *)(log_info->udata);
 
     /* Allocate memory for the message buffer */
     if (NULL == (json_udata->message = (char *)H5MM_calloc(H5C_MAX_JSON_LOG_MSG_SIZE * sizeof(char))))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed");
 
     /* Possibly fix up the log file name.
      * The extra 39 characters are for adding the rank to the file name
@@ -240,7 +234,7 @@ H5C_log_json_set_up(H5C_log_info_t *log_info, const char log_location[], int mpi
     n_chars = 5 + 39 + 1 + HDstrlen(log_location) + 1;
     if (NULL == (file_name = (char *)H5MM_calloc(n_chars * sizeof(char))))
         HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL,
-                    "can't allocate memory for mdc log file name manipulation")
+                    "can't allocate memory for mdc log file name manipulation");
 
     /* Add the rank to the log file name when MPI is in use */
     if (-1 == mpi_rank)
@@ -249,8 +243,8 @@ H5C_log_json_set_up(H5C_log_info_t *log_info, const char log_location[], int mpi
         HDsnprintf(file_name, n_chars, "RANK_%d.%s", mpi_rank, log_location);
 
     /* Open log file and set it to be unbuffered */
-    if (NULL == (json_udata->outfile = HDfopen(file_name, "w")))
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "can't create mdc log file")
+    if (NULL == (json_udata->outfile = fopen(file_name, "w")))
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "can't create mdc log file");
     HDsetbuf(json_udata->outfile, NULL);
 
 done:
@@ -271,7 +265,7 @@ done:
     }
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5C_log_json_set_up() */
+} /* H5C__log_json_set_up() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5C__json_tear_down_logging
@@ -280,9 +274,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -294,7 +285,7 @@ H5C__json_tear_down_logging(H5C_log_info_t *log_info)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(log_info);
+    assert(log_info);
 
     /* Alias */
     json_udata = (H5C_log_json_udata_t *)(log_info->udata);
@@ -303,8 +294,8 @@ H5C__json_tear_down_logging(H5C_log_info_t *log_info)
     H5MM_xfree(json_udata->message);
 
     /* Close log file */
-    if (EOF == HDfclose(json_udata->outfile))
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "problem closing mdc log file")
+    if (EOF == fclose(json_udata->outfile))
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "problem closing mdc log file");
     json_udata->outfile = NULL;
 
     /* Fre the udata */
@@ -325,9 +316,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -339,8 +327,8 @@ H5C__json_write_start_log_msg(void *udata)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string (opens the JSON array) */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -355,7 +343,7 @@ H5C__json_write_start_log_msg(void *udata)
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -368,9 +356,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -382,8 +367,8 @@ H5C__json_write_stop_log_msg(void *udata)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string (closes the JSON array) */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -397,7 +382,7 @@ H5C__json_write_stop_log_msg(void *udata)
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -410,9 +395,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -424,8 +406,8 @@ H5C__json_write_create_cache_log_msg(void *udata, herr_t fxn_ret_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -439,7 +421,7 @@ H5C__json_write_create_cache_log_msg(void *udata, herr_t fxn_ret_value)
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -452,9 +434,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -466,8 +445,8 @@ H5C__json_write_destroy_cache_log_msg(void *udata)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -480,7 +459,7 @@ H5C__json_write_destroy_cache_log_msg(void *udata)
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -493,9 +472,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -507,8 +483,8 @@ H5C__json_write_evict_cache_log_msg(void *udata, herr_t fxn_ret_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -522,7 +498,7 @@ H5C__json_write_evict_cache_log_msg(void *udata, herr_t fxn_ret_value)
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -535,9 +511,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -549,8 +522,8 @@ H5C__json_write_expunge_entry_log_msg(void *udata, haddr_t address, int type_id,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -566,7 +539,7 @@ H5C__json_write_expunge_entry_log_msg(void *udata, haddr_t address, int type_id,
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -579,9 +552,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -593,8 +563,8 @@ H5C__json_write_flush_cache_log_msg(void *udata, herr_t fxn_ret_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -608,7 +578,7 @@ H5C__json_write_flush_cache_log_msg(void *udata, herr_t fxn_ret_value)
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -621,9 +591,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -636,8 +603,8 @@ H5C__json_write_insert_entry_log_msg(void *udata, haddr_t address, int type_id,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -656,7 +623,7 @@ H5C__json_write_insert_entry_log_msg(void *udata, haddr_t address, int type_id,
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -669,9 +636,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -683,9 +647,9 @@ H5C__json_write_mark_entry_dirty_log_msg(void *udata, const H5C_cache_entry_t *e
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -700,7 +664,7 @@ H5C__json_write_mark_entry_dirty_log_msg(void *udata, const H5C_cache_entry_t *e
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -713,9 +677,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -727,9 +688,9 @@ H5C__json_write_mark_entry_clean_log_msg(void *udata, const H5C_cache_entry_t *e
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -744,7 +705,7 @@ H5C__json_write_mark_entry_clean_log_msg(void *udata, const H5C_cache_entry_t *e
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -757,9 +718,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -772,9 +730,9 @@ H5C__json_write_mark_unserialized_entry_log_msg(void *udata, const H5C_cache_ent
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -789,7 +747,7 @@ H5C__json_write_mark_unserialized_entry_log_msg(void *udata, const H5C_cache_ent
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -802,9 +760,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -817,9 +772,9 @@ H5C__json_write_mark_serialized_entry_log_msg(void *udata, const H5C_cache_entry
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -834,7 +789,7 @@ H5C__json_write_mark_serialized_entry_log_msg(void *udata, const H5C_cache_entry
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -847,9 +802,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -862,8 +814,8 @@ H5C__json_write_move_entry_log_msg(void *udata, haddr_t old_addr, haddr_t new_ad
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -881,7 +833,7 @@ H5C__json_write_move_entry_log_msg(void *udata, haddr_t old_addr, haddr_t new_ad
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -894,9 +846,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -908,9 +857,9 @@ H5C__json_write_pin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry, h
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -925,7 +874,7 @@ H5C__json_write_pin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry, h
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -939,9 +888,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -954,10 +900,10 @@ H5C__json_write_create_fd_log_msg(void *udata, const H5C_cache_entry_t *parent,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(parent);
-    HDassert(child);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(parent);
+    assert(child);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -974,7 +920,7 @@ H5C__json_write_create_fd_log_msg(void *udata, const H5C_cache_entry_t *parent,
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -987,9 +933,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1003,9 +946,9 @@ H5C__json_write_protect_entry_log_msg(void *udata, const H5C_cache_entry_t *entr
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     if (H5C__READ_ONLY_FLAG == flags)
         HDstrcpy(rw_s, "READ");
@@ -1029,7 +972,7 @@ H5C__json_write_protect_entry_log_msg(void *udata, const H5C_cache_entry_t *entr
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1042,9 +985,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1057,9 +997,9 @@ H5C__json_write_resize_entry_log_msg(void *udata, const H5C_cache_entry_t *entry
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -1075,7 +1015,7 @@ H5C__json_write_resize_entry_log_msg(void *udata, const H5C_cache_entry_t *entry
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1088,9 +1028,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1102,9 +1039,9 @@ H5C__json_write_unpin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -1119,7 +1056,7 @@ H5C__json_write_unpin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry,
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1133,9 +1070,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1148,10 +1082,10 @@ H5C__json_write_destroy_fd_log_msg(void *udata, const H5C_cache_entry_t *parent,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(parent);
-    HDassert(child);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(parent);
+    assert(child);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -1168,7 +1102,7 @@ H5C__json_write_destroy_fd_log_msg(void *udata, const H5C_cache_entry_t *parent,
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1181,9 +1115,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1196,8 +1127,8 @@ H5C__json_write_unprotect_entry_log_msg(void *udata, haddr_t address, int type_i
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
+    assert(json_udata);
+    assert(json_udata->message);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -1214,7 +1145,7 @@ H5C__json_write_unprotect_entry_log_msg(void *udata, haddr_t address, int type_i
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1227,9 +1158,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1242,9 +1170,9 @@ H5C__json_write_set_cache_config_log_msg(void *udata, const H5AC_cache_config_t
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(config);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(config);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -1258,7 +1186,7 @@ H5C__json_write_set_cache_config_log_msg(void *udata, const H5AC_cache_config_t
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1271,9 +1199,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1285,9 +1210,9 @@ H5C__json_write_remove_entry_log_msg(void *udata, const H5C_cache_entry_t *entry
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(json_udata);
-    HDassert(json_udata->message);
-    HDassert(entry);
+    assert(json_udata);
+    assert(json_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(json_udata->message, H5C_MAX_JSON_LOG_MSG_SIZE, "\
@@ -1302,7 +1227,7 @@ H5C__json_write_remove_entry_log_msg(void *udata, const H5C_cache_entry_t *entry
 
     /* Write the log message to the file */
     if (H5C__json_write_log_message(json_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
