@@ -147,9 +147,6 @@ static const H5C_log_class_t H5C_trace_log_class_g = {"trace",
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -161,22 +158,22 @@ H5C__trace_write_log_message(H5C_log_trace_udata_t *trace_udata)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->outfile);
-    HDassert(trace_udata->message);
+    assert(trace_udata);
+    assert(trace_udata->outfile);
+    assert(trace_udata->message);
 
     /* Write the log message and flush */
     n_chars = HDstrlen(trace_udata->message);
-    if ((int)n_chars != HDfprintf(trace_udata->outfile, "%s", trace_udata->message))
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "error writing log message")
-    HDmemset((void *)(trace_udata->message), 0, (size_t)(n_chars * sizeof(char)));
+    if ((int)n_chars != fprintf(trace_udata->outfile, "%s", trace_udata->message))
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "error writing log message");
+    memset((void *)(trace_udata->message), 0, (size_t)(n_chars * sizeof(char)));
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C__trace_write_log_message() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5C_log_trace_set_up
+ * Function:    H5C__log_trace_set_up
  *
  * Purpose:     Setup for metadata cache logging.
  *
@@ -194,36 +191,33 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_trace_set_up(H5C_log_info_t *log_info, const char log_location[], int mpi_rank)
+H5C__log_trace_set_up(H5C_log_info_t *log_info, const char log_location[], int mpi_rank)
 {
     H5C_log_trace_udata_t *trace_udata = NULL;
     char                  *file_name   = NULL;
     size_t                 n_chars;
     herr_t                 ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(log_info);
-    HDassert(log_location);
+    assert(log_info);
+    assert(log_location);
 
     /* Set up the class struct */
     log_info->cls = &H5C_trace_log_class_g;
 
     /* Allocate memory for the JSON-specific data */
     if (NULL == (log_info->udata = H5MM_calloc(sizeof(H5C_log_trace_udata_t))))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed");
     trace_udata = (H5C_log_trace_udata_t *)(log_info->udata);
 
     /* Allocate memory for the message buffer */
     if (NULL == (trace_udata->message = (char *)H5MM_calloc(H5C_MAX_TRACE_LOG_MSG_SIZE * sizeof(char))))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "memory allocation failed");
 
     /* Possibly fix up the log file name.
      * The extra 39 characters are for adding the rank to the file name
@@ -235,7 +229,7 @@ H5C_log_trace_set_up(H5C_log_info_t *log_info, const char log_location[], int mp
     n_chars = HDstrlen(log_location) + 1 + 39 + 1;
     if (NULL == (file_name = (char *)H5MM_calloc(n_chars * sizeof(char))))
         HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL,
-                    "can't allocate memory for mdc log file name manipulation")
+                    "can't allocate memory for mdc log file name manipulation");
 
     /* Add the rank to the log file name when MPI is in use */
     if (-1 == mpi_rank)
@@ -244,12 +238,12 @@ H5C_log_trace_set_up(H5C_log_info_t *log_info, const char log_location[], int mp
         HDsnprintf(file_name, n_chars, "%s.%d", log_location, mpi_rank);
 
     /* Open log file and set it to be unbuffered */
-    if (NULL == (trace_udata->outfile = HDfopen(file_name, "w")))
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "can't create mdc log file")
+    if (NULL == (trace_udata->outfile = fopen(file_name, "w")))
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "can't create mdc log file");
     HDsetbuf(trace_udata->outfile, NULL);
 
     /* Write the header */
-    HDfprintf(trace_udata->outfile, "### HDF5 metadata cache trace file version 1 ###\n");
+    fprintf(trace_udata->outfile, "### HDF5 metadata cache trace file version 1 ###\n");
 
 done:
     if (file_name)
@@ -269,7 +263,7 @@ done:
     }
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5C_log_trace_set_up() */
+} /* H5C__log_trace_set_up() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5C__trace_tear_down_logging
@@ -278,9 +272,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -292,7 +283,7 @@ H5C__trace_tear_down_logging(H5C_log_info_t *log_info)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(log_info);
+    assert(log_info);
 
     /* Alias */
     trace_udata = (H5C_log_trace_udata_t *)(log_info->udata);
@@ -301,8 +292,8 @@ H5C__trace_tear_down_logging(H5C_log_info_t *log_info)
     H5MM_xfree(trace_udata->message);
 
     /* Close log file */
-    if (EOF == HDfclose(trace_udata->outfile))
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "problem closing mdc log file")
+    if (EOF == fclose(trace_udata->outfile))
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "problem closing mdc log file");
     trace_udata->outfile = NULL;
 
     /* Fre the udata */
@@ -323,9 +314,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -337,8 +325,8 @@ H5C__trace_write_expunge_entry_log_msg(void *udata, haddr_t address, int type_id
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
+    assert(trace_udata);
+    assert(trace_udata->message);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_expunge_entry 0x%lx %d %d\n",
@@ -346,7 +334,7 @@ H5C__trace_write_expunge_entry_log_msg(void *udata, haddr_t address, int type_id
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -359,9 +347,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -373,15 +358,15 @@ H5C__trace_write_flush_cache_log_msg(void *udata, herr_t fxn_ret_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
+    assert(trace_udata);
+    assert(trace_udata->message);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_flush %d\n", (int)fxn_ret_value);
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -394,9 +379,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -409,8 +391,8 @@ H5C__trace_write_insert_entry_log_msg(void *udata, haddr_t address, int type_id,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
+    assert(trace_udata);
+    assert(trace_udata->message);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_insert_entry 0x%lx %d 0x%x %d %d\n",
@@ -418,7 +400,7 @@ H5C__trace_write_insert_entry_log_msg(void *udata, haddr_t address, int type_id,
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -431,9 +413,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -445,9 +424,9 @@ H5C__trace_write_mark_entry_dirty_log_msg(void *udata, const H5C_cache_entry_t *
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_mark_entry_dirty 0x%lx %d\n",
@@ -455,7 +434,7 @@ H5C__trace_write_mark_entry_dirty_log_msg(void *udata, const H5C_cache_entry_t *
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -468,9 +447,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -482,9 +458,9 @@ H5C__trace_write_mark_entry_clean_log_msg(void *udata, const H5C_cache_entry_t *
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_mark_entry_clean 0x%lx %d\n",
@@ -492,7 +468,7 @@ H5C__trace_write_mark_entry_clean_log_msg(void *udata, const H5C_cache_entry_t *
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -505,9 +481,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -520,9 +493,9 @@ H5C__trace_write_mark_unserialized_entry_log_msg(void *udata, const H5C_cache_en
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_mark_entry_unserialized 0x%lx %d\n",
@@ -530,7 +503,7 @@ H5C__trace_write_mark_unserialized_entry_log_msg(void *udata, const H5C_cache_en
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -543,9 +516,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -558,9 +528,9 @@ H5C__trace_write_mark_serialized_entry_log_msg(void *udata, const H5C_cache_entr
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_mark_entry_serialized 0x%lx %d\n",
@@ -568,7 +538,7 @@ H5C__trace_write_mark_serialized_entry_log_msg(void *udata, const H5C_cache_entr
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -581,9 +551,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -596,8 +563,8 @@ H5C__trace_write_move_entry_log_msg(void *udata, haddr_t old_addr, haddr_t new_a
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
+    assert(trace_udata);
+    assert(trace_udata->message);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_move_entry 0x%lx 0x%lx %d %d\n",
@@ -605,7 +572,7 @@ H5C__trace_write_move_entry_log_msg(void *udata, haddr_t old_addr, haddr_t new_a
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -618,9 +585,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -632,9 +596,9 @@ H5C__trace_write_pin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_pin_protected_entry 0x%lx %d\n",
@@ -642,7 +606,7 @@ H5C__trace_write_pin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry,
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -656,9 +620,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -671,10 +632,10 @@ H5C__trace_write_create_fd_log_msg(void *udata, const H5C_cache_entry_t *parent,
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(parent);
-    HDassert(child);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(parent);
+    assert(child);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE,
@@ -683,7 +644,7 @@ H5C__trace_write_create_fd_log_msg(void *udata, const H5C_cache_entry_t *parent,
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -696,9 +657,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -711,9 +669,9 @@ H5C__trace_write_protect_entry_log_msg(void *udata, const H5C_cache_entry_t *ent
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_protect 0x%lx %d 0x%x %d %d\n",
@@ -721,7 +679,7 @@ H5C__trace_write_protect_entry_log_msg(void *udata, const H5C_cache_entry_t *ent
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -734,9 +692,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -749,9 +704,9 @@ H5C__trace_write_resize_entry_log_msg(void *udata, const H5C_cache_entry_t *entr
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_resize_entry 0x%lx %d %d\n",
@@ -759,7 +714,7 @@ H5C__trace_write_resize_entry_log_msg(void *udata, const H5C_cache_entry_t *entr
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -772,9 +727,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -786,9 +738,9 @@ H5C__trace_write_unpin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_unpin_entry 0x%lx %d\n",
@@ -796,7 +748,7 @@ H5C__trace_write_unpin_entry_log_msg(void *udata, const H5C_cache_entry_t *entry
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -810,9 +762,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -825,10 +774,10 @@ H5C__trace_write_destroy_fd_log_msg(void *udata, const H5C_cache_entry_t *parent
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(parent);
-    HDassert(child);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(parent);
+    assert(child);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE,
@@ -837,7 +786,7 @@ H5C__trace_write_destroy_fd_log_msg(void *udata, const H5C_cache_entry_t *parent
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -850,9 +799,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -865,8 +811,8 @@ H5C__trace_write_unprotect_entry_log_msg(void *udata, haddr_t address, int type_
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
+    assert(trace_udata);
+    assert(trace_udata->message);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_unprotect 0x%lx %d 0x%x %d\n",
@@ -874,7 +820,7 @@ H5C__trace_write_unprotect_entry_log_msg(void *udata, haddr_t address, int type_
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -887,9 +833,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -902,9 +845,9 @@ H5C__trace_write_set_cache_config_log_msg(void *udata, const H5AC_cache_config_t
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(config);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(config);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE,
@@ -924,7 +867,7 @@ H5C__trace_write_set_cache_config_log_msg(void *udata, const H5AC_cache_config_t
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -937,9 +880,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2018
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -951,9 +891,9 @@ H5C__trace_write_remove_entry_log_msg(void *udata, const H5C_cache_entry_t *entr
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(trace_udata);
-    HDassert(trace_udata->message);
-    HDassert(entry);
+    assert(trace_udata);
+    assert(trace_udata->message);
+    assert(entry);
 
     /* Create the log message string */
     HDsnprintf(trace_udata->message, H5C_MAX_TRACE_LOG_MSG_SIZE, "H5AC_remove_entry 0x%lx %d\n",
@@ -961,7 +901,7 @@ H5C__trace_write_remove_entry_log_msg(void *udata, const H5C_cache_entry_t *entr
 
     /* Write the log message to the file */
     if (H5C__trace_write_log_message(trace_udata) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message")
+        HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to emit log message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
