@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5Cquery.c
- *              May 30 2016
- *              Quincey Koziol
  *
  * Purpose:     Routines which query different components of the generic
  *              cache structure or entries.
@@ -70,9 +68,6 @@
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *		10/8/04
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -82,10 +77,10 @@ H5C_get_cache_auto_resize_config(const H5C_t *cache_ptr, H5C_auto_size_ctl_t *co
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
     if (config_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad config_ptr on entry.")
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad config_ptr on entry.");
 
     *config_ptr = cache_ptr->resize_ctl;
 
@@ -107,9 +102,6 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *		10/8/04
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -120,8 +112,8 @@ H5C_get_cache_size(const H5C_t *cache_ptr, size_t *max_size_ptr, size_t *min_cle
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
 
     if (max_size_ptr != NULL)
         *max_size_ptr = cache_ptr->max_cache_size;
@@ -156,8 +148,8 @@ H5C_get_cache_flush_in_progress(const H5C_t *cache_ptr, hbool_t *flush_in_progre
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
 
     if (flush_in_progress_ptr != NULL)
         *flush_in_progress_ptr = cache_ptr->flush_in_progress;
@@ -177,9 +169,6 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *		10/7/04
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -189,13 +178,13 @@ H5C_get_cache_hit_rate(const H5C_t *cache_ptr, double *hit_rate_ptr)
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
     if (hit_rate_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad hit_rate_ptr on entry.")
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad hit_rate_ptr on entry.");
 
-    HDassert(cache_ptr->cache_hits >= 0);
-    HDassert(cache_ptr->cache_accesses >= cache_ptr->cache_hits);
+    assert(cache_ptr->cache_hits >= 0);
+    assert(cache_ptr->cache_accesses >= cache_ptr->cache_hits);
 
     if (cache_ptr->cache_accesses > 0)
         *hit_rate_ptr = ((double)(cache_ptr->cache_hits)) / ((double)(cache_ptr->cache_accesses));
@@ -207,7 +196,6 @@ done:
 } /* H5C_get_cache_hit_rate() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_get_entry_status
  *
  * Purpose:     This function is used to determine whether the cache
@@ -223,9 +211,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  John Mainzer
- *              7/1/05
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -241,23 +226,17 @@ H5C_get_entry_status(const H5F_t *f, haddr_t addr, size_t *size_ptr, hbool_t *in
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
-
+    assert(f);
+    assert(f->shared);
     cache_ptr = f->shared->cache;
+    assert(cache_ptr != NULL);
+    assert(H5_addr_defined(addr));
+    assert(in_cache_ptr != NULL);
 
-    HDassert(cache_ptr != NULL);
-    HDassert(cache_ptr->magic == H5C__H5C_T_MAGIC);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(in_cache_ptr != NULL);
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
 
-    /* this test duplicates two of the above asserts, but we need an
-     * invocation of HGOTO_ERROR to keep the compiler happy.
-     */
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
-
-    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL)
+    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL);
 
     if (entry_ptr == NULL) {
         /* the entry doesn't exist in the cache -- report this
@@ -297,9 +276,6 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  John Mainzer
- *              7/27/07
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -309,11 +285,11 @@ H5C_get_evictions_enabled(const H5C_t *cache_ptr, hbool_t *evictions_enabled_ptr
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad cache_ptr on entry.");
 
     if (evictions_enabled_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad evictions_enabled_ptr on entry.")
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "Bad evictions_enabled_ptr on entry.");
 
     *evictions_enabled_ptr = cache_ptr->evictions_enabled;
 
@@ -331,9 +307,6 @@ done:
  *
  * Return:      NULL/non-NULL (can't fail)
  *
- * Programmer:  Quincey Koziol
- *              6/29/15
- *
  *-------------------------------------------------------------------------
  */
 void *
@@ -342,8 +315,7 @@ H5C_get_aux_ptr(const H5C_t *cache_ptr)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(cache_ptr);
-    HDassert(cache_ptr->magic == H5C__H5C_T_MAGIC);
+    assert(cache_ptr);
 
     FUNC_LEAVE_NOAPI(cache_ptr->aux_ptr)
 } /* H5C_get_aux_ptr() */
@@ -358,9 +330,6 @@ H5C_get_aux_ptr(const H5C_t *cache_ptr)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              9/8/15
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -373,17 +342,16 @@ H5C_get_entry_ring(const H5F_t *f, haddr_t addr, H5C_ring_t *ring)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
     cache_ptr = f->shared->cache;
-    HDassert(cache_ptr);
-    HDassert(cache_ptr->magic == H5C__H5C_T_MAGIC);
-    HDassert(H5F_addr_defined(addr));
+    assert(cache_ptr);
+    assert(H5_addr_defined(addr));
 
     /* Locate the entry at the address */
-    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL)
+    H5C__SEARCH_INDEX(cache_ptr, addr, entry_ptr, FAIL);
     if (entry_ptr == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_NOTFOUND, FAIL, "can't find entry in index")
+        HGOTO_ERROR(H5E_CACHE, H5E_NOTFOUND, FAIL, "can't find entry in index");
 
     /* Return the ring value */
     *ring = entry_ptr->ring;
@@ -399,8 +367,6 @@ done:
  *
  * Return:      SUCCEED on success, and FAIL on failure.
  *
- * Programmer:  Vailin Choi; March 2017
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -410,8 +376,8 @@ H5C_get_mdc_image_info(const H5C_t *cache_ptr, haddr_t *image_addr, hsize_t *ima
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    if ((cache_ptr == NULL) || (cache_ptr->magic != H5C__H5C_T_MAGIC))
-        HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "bad cache_ptr on entry")
+    if (cache_ptr == NULL)
+        HGOTO_ERROR(H5E_CACHE, H5E_BADVALUE, FAIL, "bad cache_ptr on entry");
 
     if (image_addr)
         *image_addr = cache_ptr->image_addr;
