@@ -13,11 +13,9 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5Ctag.c
- *              June 5 2016
- *              Quincey Koziol
  *
  * Purpose:     Functions in this file operate on tags for metadata
- *              cache entries.
+ *              cache entries
  *
  *-------------------------------------------------------------------------
  */
@@ -32,14 +30,14 @@
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"   /* Generic Functions			*/
-#include "H5ACprivate.h" /* Metadata cache                       */
-#include "H5Cpkg.h"      /* Cache				*/
-#include "H5CXprivate.h" /* API Contexts                         */
-#include "H5Eprivate.h"  /* Error handling		  	*/
-#include "H5Fpkg.h"      /* Files				*/
-#include "H5Iprivate.h"  /* IDs			  		*/
-#include "H5Pprivate.h"  /* Property lists                       */
+#include "H5private.h"   /* Generic Functions                        */
+#include "H5ACprivate.h" /* Metadata Cache                           */
+#include "H5Cpkg.h"      /* Cache                                    */
+#include "H5CXprivate.h" /* API Contexts                             */
+#include "H5Eprivate.h"  /* Error Handling                           */
+#include "H5Fpkg.h"      /* Files                                    */
+#include "H5FLprivate.h" /* Free Lists                               */
+#include "H5MMprivate.h" /* Memory management                        */
 
 /****************/
 /* Local Macros */
@@ -81,7 +79,9 @@ typedef struct {
 /********************/
 /* Local Prototypes */
 /********************/
+static herr_t H5C__iter_tagged_entries_real(H5C_t *cache, haddr_t tag, H5C_tag_iter_cb_t cb, void *cb_ctx);
 static herr_t H5C__mark_tagged_entries(H5C_t *cache, haddr_t tag);
+static herr_t H5C__flush_marked_entries(H5F_t *f);
 
 /*********************/
 /* Package Variables */
@@ -99,7 +99,6 @@ H5FL_EXTERN(H5C_tag_info_t);
 /*******************/
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_ignore_tags
  *
  * Purpose:     Override all assertion frameworks associated with making
@@ -115,9 +114,6 @@ H5FL_EXTERN(H5C_tag_info_t);
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Mike McGreevy
- *              December 1, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -126,8 +122,7 @@ H5C_ignore_tags(H5C_t *cache)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Assertions */
-    HDassert(cache != NULL);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache != NULL);
 
     /* Set variable to ignore tag values upon assignment */
     cache->ignore_tags = TRUE;
@@ -136,58 +131,48 @@ H5C_ignore_tags(H5C_t *cache)
 } /* H5C_ignore_tags */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_get_ignore_tags
  *
  * Purpose:     Retrieve the 'ignore_tags' field for the cache
  *
  * Return:      'ignore_tags' value (can't fail)
  *
- * Programmer:  Quincey Koziol
- *              April 30, 2016
- *
  *-------------------------------------------------------------------------
  */
-hbool_t
+H5_ATTR_PURE hbool_t
 H5C_get_ignore_tags(const H5C_t *cache)
 {
     FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity checks */
-    HDassert(cache);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache);
 
     /* Return ignore tag value */
     FUNC_LEAVE_NOAPI(cache->ignore_tags)
 } /* H5C_get_ignore_tags */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_get_num_objs_corked
  *
  * Purpose:     Retrieve the 'num_objs_corked' field for the cache
  *
  * Return:      'num_objs_corked' value (can't fail)
  *
- * Programmer:  Vailin Choi; Feb 2019
- *
  *-------------------------------------------------------------------------
  */
-uint32_t
+H5_ATTR_PURE uint32_t
 H5C_get_num_objs_corked(const H5C_t *cache)
 {
     FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity checks */
-    HDassert(cache);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache);
 
     /* Return value for num_objs_corked */
     FUNC_LEAVE_NOAPI(cache->num_objs_corked)
 } /* H5C_get_num_objs_corked */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__tag_entry
  *
  * Purpose:     Tags an entry with the provided tag (contained in the API context).
@@ -197,9 +182,6 @@ H5C_get_num_objs_corked(const H5C_t *cache)
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Mike McGreevy
- *              January 14, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -212,9 +194,8 @@ H5C__tag_entry(H5C_t *cache, H5C_cache_entry_t *entry)
     FUNC_ENTER_PACKAGE
 
     /* Assertions */
-    HDassert(cache != NULL);
-    HDassert(entry != NULL);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache != NULL);
+    assert(entry != NULL);
 
     /* Get the tag */
     tag = H5CX_get_tag();
@@ -227,14 +208,14 @@ H5C__tag_entry(H5C_t *cache, H5C_cache_entry_t *entry)
            arbitrarily set it to something for the sake of passing the tests.
            If the tag value is set, then we'll just let it get assigned without
            additional checking for correctness. */
-        if (!H5F_addr_defined(tag))
+        if (!H5_addr_defined(tag))
             tag = H5AC__IGNORE_TAG;
     }
 #ifdef H5C_DO_TAGGING_SANITY_CHECKS
     else {
         /* Perform some sanity checks to ensure that a correct tag is being applied */
         if (H5C_verify_tag(entry->type->id, tag) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "tag verification failed")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "tag verification failed");
     }
 #endif
 
@@ -245,7 +226,7 @@ H5C__tag_entry(H5C_t *cache, H5C_cache_entry_t *entry)
     if (NULL == tag_info) {
         /* Allocate new tag info struct */
         if (NULL == (tag_info = H5FL_CALLOC(H5C_tag_info_t)))
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "can't allocate tag info for cache entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTALLOC, FAIL, "can't allocate tag info for cache entry");
 
         /* Set the tag for all entries */
         tag_info->tag = tag;
@@ -254,12 +235,12 @@ H5C__tag_entry(H5C_t *cache, H5C_cache_entry_t *entry)
         HASH_ADD(hh, cache->tag_list, tag, sizeof(haddr_t), tag_info);
     }
     else
-        HDassert(tag_info->corked || (tag_info->entry_cnt > 0 && tag_info->head));
+        assert(tag_info->corked || (tag_info->entry_cnt > 0 && tag_info->head));
 
     /* Sanity check entry, to avoid double insertions, etc */
-    HDassert(entry->tl_next == NULL);
-    HDassert(entry->tl_prev == NULL);
-    HDassert(entry->tag_info == NULL);
+    assert(entry->tl_next == NULL);
+    assert(entry->tl_prev == NULL);
+    assert(entry->tag_info == NULL);
 
     /* Add the entry to the list for the tagged object */
     entry->tl_next  = tag_info->head;
@@ -274,7 +255,6 @@ done:
 } /* H5C__tag_entry */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__untag_entry
  *
  * Purpose:     Removes an entry from a tag list, possibly removing the tag
@@ -282,9 +262,6 @@ done:
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Quincey Koziol
- *              July 8, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -296,9 +273,8 @@ H5C__untag_entry(H5C_t *cache, H5C_cache_entry_t *entry)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Assertions */
-    HDassert(cache != NULL);
-    HDassert(entry != NULL);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache != NULL);
+    assert(entry != NULL);
 
     /* Get the entry's tag info struct */
     if (NULL != (tag_info = entry->tag_info)) {
@@ -319,30 +295,26 @@ H5C__untag_entry(H5C_t *cache, H5C_cache_entry_t *entry)
         /* Remove the tag info from the tag list, if there's no more entries with this tag */
         if (!tag_info->corked && 0 == tag_info->entry_cnt) {
             /* Sanity check */
-            HDassert(NULL == tag_info->head);
+            assert(NULL == tag_info->head);
 
             /* Release the tag info */
             HASH_DELETE(hh, cache->tag_list, tag_info);
             tag_info = H5FL_FREE(H5C_tag_info_t, tag_info);
         }
         else
-            HDassert(tag_info->corked || NULL != tag_info->head);
+            assert(tag_info->corked || NULL != tag_info->head);
     }
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C__untag_entry */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__iter_tagged_entries_real
  *
  * Purpose:     Iterate over tagged entries, making a callback for matches
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Quincey Koziol
- *              June 7, 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -355,8 +327,7 @@ H5C__iter_tagged_entries_real(H5C_t *cache, haddr_t tag, H5C_tag_iter_cb_t cb, v
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(cache != NULL);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache != NULL);
 
     /* Search the list of tagged object addresses in the cache */
     HASH_FIND(hh, cache->tag_list, &tag, sizeof(haddr_t), tag_info);
@@ -367,8 +338,8 @@ H5C__iter_tagged_entries_real(H5C_t *cache, haddr_t tag, H5C_tag_iter_cb_t cb, v
         H5C_cache_entry_t *next_entry; /* Pointer to next entry in hash bucket chain */
 
         /* Sanity check */
-        HDassert(tag_info->head);
-        HDassert(tag_info->entry_cnt > 0);
+        assert(tag_info->head);
+        assert(tag_info->entry_cnt > 0);
 
         /* Iterate over the entries for this tag */
         entry = tag_info->head;
@@ -378,7 +349,7 @@ H5C__iter_tagged_entries_real(H5C_t *cache, haddr_t tag, H5C_tag_iter_cb_t cb, v
 
             /* Make callback for entry */
             if ((cb)(entry, cb_ctx) != H5_ITER_CONT)
-                HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "tagged entry iteration callback failed")
+                HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "tagged entry iteration callback failed");
 
             /* Advance to next entry */
             entry = next_entry;
@@ -390,16 +361,12 @@ done:
 } /* H5C__iter_tagged_entries_real() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__iter_tagged_entries
  *
  * Purpose:     Iterate over tagged entries, making a callback for matches
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Quincey Koziol
- *              June 7, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -411,22 +378,21 @@ H5C__iter_tagged_entries(H5C_t *cache, haddr_t tag, hbool_t match_global, H5C_ta
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(cache != NULL);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache != NULL);
 
     /* Iterate over the entries for this tag */
     if (H5C__iter_tagged_entries_real(cache, tag, cb, cb_ctx) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "iteration of tagged entries failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "iteration of tagged entries failed");
 
     /* Check for iterating over global metadata */
     if (match_global) {
         /* Iterate over the entries for SOHM entries */
         if (H5C__iter_tagged_entries_real(cache, H5AC__SOHM_TAG, cb, cb_ctx) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "iteration of tagged entries failed")
+            HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "iteration of tagged entries failed");
 
         /* Iterate over the entries for global heap entries */
         if (H5C__iter_tagged_entries_real(cache, H5AC__GLOBALHEAP_TAG, cb, cb_ctx) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "iteration of tagged entries failed")
+            HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "iteration of tagged entries failed");
     } /* end if */
 
 done:
@@ -434,16 +400,12 @@ done:
 } /* H5C__iter_tagged_entries() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__evict_tagged_entries_cb
  *
  * Purpose:     Callback for evicting tagged entries
  *
  * Return:      H5_ITER_ERROR if error is detected, H5_ITER_CONT otherwise.
  *
- * Programmer:  Mike McGreevy
- *              August 19, 2010
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -456,14 +418,14 @@ H5C__evict_tagged_entries_cb(H5C_cache_entry_t *entry, void *_ctx)
     FUNC_ENTER_PACKAGE
 
     /* Santify checks */
-    HDassert(entry);
-    HDassert(ctx);
+    assert(entry);
+    assert(ctx);
 
     /* Attempt to evict entry */
     if (entry->is_protected)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, H5_ITER_ERROR, "Cannot evict protected entry")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, H5_ITER_ERROR, "Cannot evict protected entry");
     else if (entry->is_dirty)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, H5_ITER_ERROR, "Cannot evict dirty entry")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, H5_ITER_ERROR, "Cannot evict dirty entry");
     else if (entry->is_pinned)
         /* Can't evict at this time, but let's note that we hit a pinned
             entry and we'll loop back around again (as evicting other
@@ -474,7 +436,7 @@ H5C__evict_tagged_entries_cb(H5C_cache_entry_t *entry, void *_ctx)
         if (H5C__flush_single_entry(ctx->f, entry,
                                     H5C__FLUSH_INVALIDATE_FLAG | H5C__FLUSH_CLEAR_ONLY_FLAG |
                                         H5C__DEL_FROM_SLIST_ON_DESTROY_FLAG) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, H5_ITER_ERROR, "Entry eviction failed.")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, H5_ITER_ERROR, "Entry eviction failed.");
         ctx->evicted_entries_last_pass = TRUE;
     }
     else
@@ -485,16 +447,12 @@ done:
 } /* H5C__evict_tagged_entries_cb() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_evict_tagged_entries
  *
  * Purpose:     Evicts all entries with the specified tag from cache
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Mike McGreevy
- *              August 19, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -508,11 +466,10 @@ H5C_evict_tagged_entries(H5F_t *f, haddr_t tag, hbool_t match_global)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
     cache = f->shared->cache; /* Get cache pointer */
-    HDassert(cache != NULL);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache != NULL);
 
     /* Construct context for iterator callbacks */
     ctx.f = f;
@@ -526,7 +483,7 @@ H5C_evict_tagged_entries(H5F_t *f, haddr_t tag, hbool_t match_global)
 
         /* Iterate through entries in the cache */
         if (H5C__iter_tagged_entries(cache, tag, match_global, H5C__evict_tagged_entries_cb, &ctx) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "Iteration of tagged entries failed")
+            HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "Iteration of tagged entries failed");
 
         /* Keep doing this until we have stopped evicted entries */
     } while (TRUE == ctx.evicted_entries_last_pass);
@@ -557,23 +514,19 @@ H5C_evict_tagged_entries(H5F_t *f, haddr_t tag, hbool_t match_global)
      * ctx.skipped_pf_dirty_entries is TRUE.
      */
     if ((!ctx.skipped_pf_dirty_entries) && (ctx.pinned_entries_need_evicted))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "Pinned entries still need evicted?!")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "Pinned entries still need evicted?!");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_evict_tagged_entries() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__mark_tagged_entries_cb
  *
  * Purpose:     Callback to set the flush marker on dirty entries in the cache
  *
  * Return:      H5_ITER_CONT (can't fail)
  *
- * Programmer:  Mike McGreevy
- *              September 9, 2010
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -583,7 +536,7 @@ H5C__mark_tagged_entries_cb(H5C_cache_entry_t *entry, void H5_ATTR_UNUSED *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(entry);
+    assert(entry);
 
     /* We only want to set the flush marker on entries that
      * actually need flushed (i.e., dirty ones) */
@@ -594,7 +547,6 @@ H5C__mark_tagged_entries_cb(H5C_cache_entry_t *entry, void H5_ATTR_UNUSED *_ctx)
 } /* H5C__mark_tagged_entries_cb() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__mark_tagged_entries
  *
  * Purpose:     Set the flush marker on dirty entries in the cache that have
@@ -602,9 +554,6 @@ H5C__mark_tagged_entries_cb(H5C_cache_entry_t *entry, void H5_ATTR_UNUSED *_ctx)
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Mike McGreevy
- *              September 9, 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -616,32 +565,65 @@ H5C__mark_tagged_entries(H5C_t *cache, haddr_t tag)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(cache);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache);
 
     /* Iterate through hash table entries, marking those with specified tag, as
      * well as any major global entries which should always be flushed
      * when flushing based on tag value */
     if (H5C__iter_tagged_entries(cache, tag, TRUE, H5C__mark_tagged_entries_cb, NULL) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "Iteration of tagged entries failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "Iteration of tagged entries failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C__mark_tagged_entries() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5C__flush_marked_entries
+ *
+ * Purpose:     Flushes all marked entries in the cache.
+ *
+ * Return:      FAIL if error is detected, SUCCEED otherwise.
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5C__flush_marked_entries(H5F_t *f)
+{
+    herr_t ret_value = SUCCEED;
+
+    FUNC_ENTER_PACKAGE
+
+    /* Assertions */
+    assert(f != NULL);
+
+    /* Enable the slist, as it is needed in the flush */
+    if (H5C_set_slist_enabled(f->shared->cache, TRUE, FALSE) < 0)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "set slist enabled failed");
+
+    /* Flush all marked entries */
+    if (H5C_flush_cache(f, H5C__FLUSH_MARKED_ENTRIES_FLAG | H5C__FLUSH_IGNORE_PROTECTED_FLAG) < 0)
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "Can't flush cache");
+
+    /* Disable the slist.  Set the clear_slist parameter to TRUE
+     * since we called H5C_flush_cache() with the
+     * H5C__FLUSH_MARKED_ENTRIES_FLAG.
+     */
+    if (H5C_set_slist_enabled(f->shared->cache, FALSE, TRUE) < 0)
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "disable slist failed");
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* H5C__flush_marked_entries */
+
 #ifdef H5C_DO_TAGGING_SANITY_CHECKS
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_verify_tag
  *
  * Purpose:     Performs sanity checking on an entrytype/tag pair.
  *
  * Return:      SUCCEED or FAIL.
  *
- * Programmer:  Mike McGreevy
- *              January 14, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -655,10 +637,10 @@ H5C_verify_tag(int id, haddr_t tag)
      * types require certain tag values, so check that these
      * constraints are met. */
     if (tag == H5AC__IGNORE_TAG)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "cannot ignore a tag while doing verification.")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "cannot ignore a tag while doing verification.");
     else if (tag == H5AC__INVALID_TAG) {
         if (id != H5AC_PROXY_ENTRY_ID)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "no metadata tag provided")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "no metadata tag provided");
     } /* end else-if */
     else {
         /* Perform some sanity checks on tag value. Certain entry
@@ -668,32 +650,32 @@ H5C_verify_tag(int id, haddr_t tag)
         /* Superblock */
         if ((id == H5AC_SUPERBLOCK_ID) || (id == H5AC_DRVRINFO_ID)) {
             if (tag != H5AC__SUPERBLOCK_TAG)
-                HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "superblock not tagged with H5AC__SUPERBLOCK_TAG")
+                HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "superblock not tagged with H5AC__SUPERBLOCK_TAG");
         } /* end if */
         else {
             if (tag == H5AC__SUPERBLOCK_TAG)
                 HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL,
-                            "H5AC__SUPERBLOCK_TAG applied to non-superblock entry")
+                            "H5AC__SUPERBLOCK_TAG applied to non-superblock entry");
         } /* end else */
 
         /* Free Space Manager */
         if (tag == H5AC__FREESPACE_TAG && ((id != H5AC_FSPACE_HDR_ID) && (id != H5AC_FSPACE_SINFO_ID)))
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "H5AC__FREESPACE_TAG applied to non-freespace entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "H5AC__FREESPACE_TAG applied to non-freespace entry");
 
         /* SOHM */
         if ((id == H5AC_SOHM_TABLE_ID) || (id == H5AC_SOHM_LIST_ID))
             if (tag != H5AC__SOHM_TAG)
-                HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "sohm entry not tagged with H5AC__SOHM_TAG")
+                HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "sohm entry not tagged with H5AC__SOHM_TAG");
 
         /* Global Heap */
         if (id == H5AC_GHEAP_ID) {
             if (tag != H5AC__GLOBALHEAP_TAG)
-                HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "global heap not tagged with H5AC__GLOBALHEAP_TAG")
+                HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL, "global heap not tagged with H5AC__GLOBALHEAP_TAG");
         } /* end if */
         else {
             if (tag == H5AC__GLOBALHEAP_TAG)
                 HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, FAIL,
-                            "H5AC__GLOBALHEAP_TAG applied to non-globalheap entry")
+                            "H5AC__GLOBALHEAP_TAG applied to non-globalheap entry");
         } /* end else */
     }     /* end else */
 
@@ -703,16 +685,12 @@ done:
 #endif
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_flush_tagged_entries
  *
  * Purpose:     Flushes all entries with the specified tag to disk.
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Mike McGreevy
- *              August 19, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -725,26 +703,25 @@ H5C_flush_tagged_entries(H5F_t *f, haddr_t tag)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Assertions */
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     /* Get cache pointer */
     cache = f->shared->cache;
 
     /* Mark all entries with specified tag */
     if (H5C__mark_tagged_entries(cache, tag) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "Can't mark tagged entries")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "Can't mark tagged entries");
 
     /* Flush all marked entries */
     if (H5C__flush_marked_entries(f) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "Can't flush marked entries")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "Can't flush marked entries");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_flush_tagged_entries */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_retag_entries
  *
  * Purpose:     Searches through cache index for all entries with the
@@ -753,9 +730,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Mike McGreevy
- *              March 17, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -767,7 +741,7 @@ H5C_retag_entries(H5C_t *cache, haddr_t src_tag, haddr_t dest_tag)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity check */
-    HDassert(cache);
+    assert(cache);
 
     /* Remove tag info from tag list */
     HASH_FIND(hh, cache->tag_list, &src_tag, sizeof(haddr_t), tag_info);
@@ -786,7 +760,6 @@ H5C_retag_entries(H5C_t *cache, haddr_t src_tag, haddr_t dest_tag)
 } /* H5C_retag_entries() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C__expunge_tag_type_metadata_cb
  *
  * Purpose:     Expunge from the cache entries associated
@@ -794,9 +767,6 @@ H5C_retag_entries(H5C_t *cache, haddr_t src_tag, haddr_t dest_tag)
  *
  * Return:      H5_ITER_ERROR if error is detected, H5_ITER_CONT otherwise.
  *
- * Programmer:  Vailin Choi
- *		May 2016
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -809,20 +779,19 @@ H5C__expunge_tag_type_metadata_cb(H5C_cache_entry_t *entry, void *_ctx)
     FUNC_ENTER_PACKAGE
 
     /* Santify checks */
-    HDassert(entry);
-    HDassert(ctx);
+    assert(entry);
+    assert(ctx);
 
     /* Found one with the same tag and type id */
     if (entry->type->id == ctx->type_id)
         if (H5C_expunge_entry(ctx->f, entry->type, entry->addr, ctx->flags) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTEXPUNGE, H5_ITER_ERROR, "can't expunge entry")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTEXPUNGE, H5_ITER_ERROR, "can't expunge entry");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C__expunge_tag_type_metadata_cb() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_expunge_tag_type_metadata
  *
  * Purpose:     Search and expunge from the cache entries associated
@@ -830,9 +799,6 @@ done:
  *
  * Return:      FAIL if error is detected, SUCCEED otherwise.
  *
- * Programmer:  Vailin Choi
- *		May 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -846,11 +812,10 @@ H5C_expunge_tag_type_metadata(H5F_t *f, haddr_t tag, int type_id, unsigned flags
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
     cache = f->shared->cache; /* Get cache pointer */
-    HDassert(cache != NULL);
-    HDassert(cache->magic == H5C__H5C_T_MAGIC);
+    assert(cache != NULL);
 
     /* Construct context for iterator callbacks */
     ctx.f       = f;
@@ -859,23 +824,19 @@ H5C_expunge_tag_type_metadata(H5F_t *f, haddr_t tag, int type_id, unsigned flags
 
     /* Iterate through hash table entries, expunge those with specified tag and type id */
     if (H5C__iter_tagged_entries(cache, tag, FALSE, H5C__expunge_tag_type_metadata_cb, &ctx) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "Iteration of tagged entries failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_BADITER, FAIL, "Iteration of tagged entries failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_expunge_tag_type_metadata() */
 
 /*-------------------------------------------------------------------------
- *
  * Function:    H5C_get_tag()
  *
  * Purpose:     Get the tag for a metadata cache entry.
  *
  * Return:      SUCCEED (can't fail)
  *
- * Programmer:  Dana Robinson
- *              Fall 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -885,9 +846,9 @@ H5C_get_tag(const void *thing, haddr_t *tag)
 
     FUNC_ENTER_NOAPI_NOERR
 
-    HDassert(entry);
-    HDassert(entry->tag_info);
-    HDassert(tag);
+    assert(entry);
+    assert(entry->tag_info);
+    assert(tag);
 
     /* Return the tag */
     *tag = entry->tag_info->tag;
