@@ -157,7 +157,7 @@ const H5D_chunk_ops_t H5D_COPS_BTREE[1] = {{
 /*****************************/
 
 /* inherits B-tree like properties from H5B */
-H5B_class_t H5B_BTREE[1] = {{
+static H5B_class_t H5B_BTREE[1] = {{
     H5B_CHUNK_ID,            /*id			*/
     sizeof(H5D_btree_key_t), /*sizeof_nkey		*/
     H5D__btree_get_shared,   /*get_shared		*/
@@ -191,9 +191,6 @@ H5FL_DEFINE_STATIC(H5O_layout_chunk_t);
  *
  *		Failure:	Can't fail
  *
- * Programmer:	Quincey Koziol
- *		Monday, July  5, 2004
- *
  *-------------------------------------------------------------------------
  */
 static H5UC_t *
@@ -203,10 +200,10 @@ H5D__btree_get_shared(const H5F_t H5_ATTR_UNUSED *f, const void *_udata)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(udata);
-    HDassert(udata->storage);
-    HDassert(udata->storage->idx_type == H5D_CHUNK_IDX_BTREE);
-    HDassert(udata->storage->u.btree.shared);
+    assert(udata);
+    assert(udata->storage);
+    assert(udata->storage->idx_type == H5D_CHUNK_IDX_BTREE);
+    assert(udata->storage->u.btree.shared);
 
     /* Return the pointer to the ref-count object */
     FUNC_LEAVE_NOAPI(udata->storage->u.btree.shared)
@@ -225,9 +222,6 @@ H5D__btree_get_shared(const H5F_t H5_ATTR_UNUSED *f, const void *_udata)
  *
  * 		Failure:	Negative
  *
- * Programmer:	Robb Matzke
- *		Tuesday, October 14, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -243,16 +237,16 @@ H5D__btree_new_node(H5F_t H5_ATTR_NDEBUG_UNUSED *f, H5B_ins_t op, void *_lt_key,
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(lt_key);
-    HDassert(rt_key);
-    HDassert(udata);
-    HDassert(udata->common.layout->ndims > 0 && udata->common.layout->ndims < H5O_LAYOUT_NDIMS);
-    HDassert(addr_p);
+    assert(f);
+    assert(lt_key);
+    assert(rt_key);
+    assert(udata);
+    assert(udata->common.layout->ndims > 0 && udata->common.layout->ndims < H5O_LAYOUT_NDIMS);
+    assert(addr_p);
 
     /* Set address */
-    HDassert(H5F_addr_defined(udata->chunk_block.offset));
-    HDassert(udata->chunk_block.length > 0);
+    assert(H5_addr_defined(udata->chunk_block.offset));
+    assert(udata->chunk_block.length > 0);
     *addr_p = udata->chunk_block.offset;
 
     /*
@@ -272,7 +266,7 @@ H5D__btree_new_node(H5F_t H5_ATTR_NDEBUG_UNUSED *f, H5B_ins_t op, void *_lt_key,
         rt_key->nbytes      = 0;
         rt_key->filter_mask = 0;
         for (u = 0; u < udata->common.layout->ndims; u++) {
-            HDassert(udata->common.scaled[u] + 1 > udata->common.scaled[u]);
+            assert(udata->common.scaled[u] + 1 > udata->common.scaled[u]);
             rt_key->scaled[u] = udata->common.scaled[u] + 1;
         } /* end if */
     }     /* end if */
@@ -294,9 +288,6 @@ H5D__btree_new_node(H5F_t H5_ATTR_NDEBUG_UNUSED *f, H5B_ins_t op, void *_lt_key,
  *
  *		Failure:	FAIL (same as LT_KEY<RT_KEY)
  *
- * Programmer:	Robb Matzke
- *		Thursday, November  6, 1997
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -309,10 +300,10 @@ H5D__btree_cmp2(void *_lt_key, void *_udata, void *_rt_key)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(lt_key);
-    HDassert(rt_key);
-    HDassert(udata);
-    HDassert(udata->layout->ndims > 0 && udata->layout->ndims <= H5O_LAYOUT_NDIMS);
+    assert(lt_key);
+    assert(rt_key);
+    assert(udata);
+    assert(udata->layout->ndims > 0 && udata->layout->ndims <= H5O_LAYOUT_NDIMS);
 
     /* Compare the offsets but ignore the other fields */
     ret_value = H5VM_vector_cmp_u(udata->layout->ndims, lt_key->scaled, rt_key->scaled);
@@ -342,9 +333,6 @@ H5D__btree_cmp2(void *_lt_key, void *_udata, void *_rt_key)
  *
  *		Failure:	FAIL (same as UDATA < LT_KEY)
  *
- * Programmer:	Robb Matzke
- *		Wednesday, October  8, 1997
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -357,10 +345,10 @@ H5D__btree_cmp3(void *_lt_key, void *_udata, void *_rt_key)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(lt_key);
-    HDassert(rt_key);
-    HDassert(udata);
-    HDassert(udata->layout->ndims > 0 && udata->layout->ndims <= H5O_LAYOUT_NDIMS);
+    assert(lt_key);
+    assert(rt_key);
+    assert(udata);
+    assert(udata->layout->ndims > 0 && udata->layout->ndims <= H5O_LAYOUT_NDIMS);
 
     /* Special case for faster checks on 1-D chunks */
     /* (Checking for ndims==2 because last dimension is the datatype size) */
@@ -406,9 +394,6 @@ H5D__btree_cmp3(void *_lt_key, void *_udata, void *_rt_key)
  *              chunk returned through the UDATA argument, if *FOUND is true.
  *              Negative on failure.
  *
- * Programmer:	Robb Matzke
- *		Thursday, October  9, 1997
- *
  *-------------------------------------------------------------------------
  */
 static htri_t
@@ -422,21 +407,21 @@ H5D__btree_found(H5F_t H5_ATTR_UNUSED *f, haddr_t addr, const void *_lt_key, hbo
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(lt_key);
-    HDassert(found);
-    HDassert(udata);
+    assert(f);
+    assert(H5_addr_defined(addr));
+    assert(lt_key);
+    assert(found);
+    assert(udata);
 
     /* Is this *really* the requested chunk? */
     for (u = 0; u < udata->common.layout->ndims; u++)
         if (udata->common.scaled[u] >= (lt_key->scaled[u] + 1)) {
             *found = FALSE;
-            HGOTO_DONE(SUCCEED)
+            HGOTO_DONE(SUCCEED);
         }
 
     /* Initialize return values */
-    HDassert(lt_key->nbytes > 0);
+    assert(lt_key->nbytes > 0);
     udata->chunk_block.offset = addr;
     udata->chunk_block.length = lt_key->nbytes;
     udata->filter_mask        = lt_key->filter_mask;
@@ -454,9 +439,6 @@ done:
  * Return:	Success:	FALSE if they are not disjoint.
  *				TRUE if they are disjoint.
  *
- * Programmer:	Quincey Koziol
- *		Wednesday, May 6, 2015
- *
  * Note:	Assumes that the chunk offsets are scaled coordinates
  *
  *-------------------------------------------------------------------------
@@ -470,14 +452,14 @@ H5D__chunk_disjoint(unsigned n, const hsize_t *scaled1, const hsize_t *scaled2)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(n);
-    HDassert(scaled1);
-    HDassert(scaled2);
+    assert(n);
+    assert(scaled1);
+    assert(scaled2);
 
     /* Loop over two chunks, detecting disjointness and getting out quickly */
     for (u = 0; u < n; u++)
         if ((scaled1[u] + 1) <= scaled2[u] || (scaled2[u] + 1) <= scaled1[u])
-            HGOTO_DONE(TRUE)
+            HGOTO_DONE(TRUE);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -506,9 +488,6 @@ done:
  *
  *		Failure:	H5B_INS_ERROR
  *
- * Programmer:	Robb Matzke
- *		Thursday, October  9, 1997
- *
  *-------------------------------------------------------------------------
  */
 static H5B_ins_t
@@ -527,21 +506,21 @@ H5D__btree_insert(H5F_t H5_ATTR_NDEBUG_UNUSED *f, haddr_t H5_ATTR_NDEBUG_UNUSED
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(lt_key);
-    HDassert(lt_key_changed);
-    HDassert(md_key);
-    HDassert(udata);
-    HDassert(rt_key);
-    HDassert(new_node_p);
+    assert(f);
+    assert(H5_addr_defined(addr));
+    assert(lt_key);
+    assert(lt_key_changed);
+    assert(md_key);
+    assert(udata);
+    assert(rt_key);
+    assert(new_node_p);
 
     cmp = H5D__btree_cmp3(lt_key, udata, rt_key);
-    HDassert(cmp <= 0);
+    assert(cmp <= 0);
 
     if (cmp < 0) {
         /* Negative indices not supported yet */
-        HGOTO_ERROR(H5E_STORAGE, H5E_UNSUPPORTED, H5B_INS_ERROR, "internal error")
+        HGOTO_ERROR(H5E_STORAGE, H5E_UNSUPPORTED, H5B_INS_ERROR, "internal error");
     }
     else if (H5VM_vector_eq_u(udata->common.layout->ndims, udata->common.scaled, lt_key->scaled) &&
              lt_key->nbytes > 0) {
@@ -551,7 +530,7 @@ H5D__btree_insert(H5F_t H5_ATTR_NDEBUG_UNUSED *f, haddr_t H5_ATTR_NDEBUG_UNUSED
          */
         if (lt_key->nbytes != udata->chunk_block.length) {
             /* Set node's address (already re-allocated by main chunk routines) */
-            HDassert(H5F_addr_defined(udata->chunk_block.offset));
+            assert(H5_addr_defined(udata->chunk_block.offset));
             *new_node_p = udata->chunk_block.offset;
             H5_CHECKED_ASSIGN(lt_key->nbytes, uint32_t, udata->chunk_block.length, hsize_t);
             lt_key->filter_mask = udata->filter_mask;
@@ -560,12 +539,12 @@ H5D__btree_insert(H5F_t H5_ATTR_NDEBUG_UNUSED *f, haddr_t H5_ATTR_NDEBUG_UNUSED
         }
         else {
             /* Already have address in udata, from main chunk routines */
-            HDassert(H5F_addr_defined(udata->chunk_block.offset));
+            assert(H5_addr_defined(udata->chunk_block.offset));
             ret_value = H5B_INS_NOOP;
         }
     }
     else if (H5D__chunk_disjoint(udata->common.layout->ndims, lt_key->scaled, udata->common.scaled)) {
-        HDassert(H5D__chunk_disjoint(udata->common.layout->ndims, rt_key->scaled, udata->common.scaled));
+        assert(H5D__chunk_disjoint(udata->common.layout->ndims, rt_key->scaled, udata->common.scaled));
         /*
          * Split this node, inserting the new new node to the right of the
          * current node.  The MD_KEY is where the split occurs.
@@ -575,12 +554,12 @@ H5D__btree_insert(H5F_t H5_ATTR_NDEBUG_UNUSED *f, haddr_t H5_ATTR_NDEBUG_UNUSED
         for (u = 0; u < udata->common.layout->ndims; u++)
             md_key->scaled[u] = udata->common.scaled[u];
 
-        HDassert(H5F_addr_defined(udata->chunk_block.offset));
+        assert(H5_addr_defined(udata->chunk_block.offset));
         *new_node_p = udata->chunk_block.offset;
         ret_value   = H5B_INS_RIGHT;
     }
     else {
-        HGOTO_ERROR(H5E_IO, H5E_UNSUPPORTED, H5B_INS_ERROR, "internal error")
+        HGOTO_ERROR(H5E_IO, H5E_UNSUPPORTED, H5B_INS_ERROR, "internal error");
     }
 
 done:
@@ -594,9 +573,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:  Pedro Vicente
- * 		March 28, 2002
- *
  *-------------------------------------------------------------------------
  */
 static H5B_ins_t
@@ -612,7 +588,7 @@ H5D__btree_remove(H5F_t *f, haddr_t addr, void *_lt_key /*in,out */, hbool_t *lt
     /* Remove raw data chunk from file */
     H5_CHECK_OVERFLOW(lt_key->nbytes, uint32_t, hsize_t);
     if (H5MF_xfree(f, H5FD_MEM_DRAW, addr, (hsize_t)lt_key->nbytes) < 0)
-        HGOTO_ERROR(H5E_STORAGE, H5E_CANTFREE, H5B_INS_ERROR, "unable to free chunk")
+        HGOTO_ERROR(H5E_STORAGE, H5E_CANTFREE, H5B_INS_ERROR, "unable to free chunk");
 
     /* Mark keys as unchanged */
     *lt_key_changed = FALSE;
@@ -640,25 +616,25 @@ H5D__btree_decode_key(const H5B_shared_t *shared, const uint8_t *raw, void *_key
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(shared);
-    HDassert(raw);
-    HDassert(key);
+    assert(shared);
+    assert(raw);
+    assert(key);
     layout = (const H5O_layout_chunk_t *)shared->udata;
-    HDassert(layout);
+    assert(layout);
 
     if (layout->ndims > H5O_LAYOUT_NDIMS)
-        HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "bad number of dimensions")
+        HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "bad number of dimensions");
 
     UINT32DECODE(raw, key->nbytes);
     UINT32DECODE(raw, key->filter_mask);
     for (unsigned u = 0; u < layout->ndims; u++) {
         if (layout->dim[u] == 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "chunk size must be > 0, dim = %u ", u)
+            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "chunk size must be > 0, dim = %u ", u);
 
         /* Retrieve coordinate offset */
         UINT64DECODE(raw, tmp_offset);
         if (0 != (tmp_offset % layout->dim[u]))
-            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "bad coordinate offset")
+            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "bad coordinate offset");
 
         /* Convert to a scaled offset */
         key->scaled[u] = tmp_offset / layout->dim[u];
@@ -675,9 +651,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Friday, October 10, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -691,12 +664,12 @@ H5D__btree_encode_key(const H5B_shared_t *shared, uint8_t *raw, const void *_key
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(shared);
-    HDassert(raw);
-    HDassert(key);
+    assert(shared);
+    assert(raw);
+    assert(key);
     layout = (const H5O_layout_chunk_t *)shared->udata;
-    HDassert(layout);
-    HDassert(layout->ndims > 0 && layout->ndims <= H5O_LAYOUT_NDIMS);
+    assert(layout);
+    assert(layout->ndims > 0 && layout->ndims <= H5O_LAYOUT_NDIMS);
 
     /* encode */
     UINT32ENCODE(raw, key->nbytes);
@@ -717,9 +690,6 @@ H5D__btree_encode_key(const H5B_shared_t *shared, uint8_t *raw, const void *_key
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Thursday, April 16, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -731,13 +701,13 @@ H5D__btree_debug_key(FILE *stream, int indent, int fwidth, const void *_key, con
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(key);
+    assert(key);
 
-    HDfprintf(stream, "%*s%-*s %u bytes\n", indent, "", fwidth, "Chunk size:", (unsigned)key->nbytes);
-    HDfprintf(stream, "%*s%-*s 0x%08x\n", indent, "", fwidth, "Filter mask:", key->filter_mask);
-    HDfprintf(stream, "%*s%-*s {", indent, "", fwidth, "Logical offset:");
+    fprintf(stream, "%*s%-*s %u bytes\n", indent, "", fwidth, "Chunk size:", (unsigned)key->nbytes);
+    fprintf(stream, "%*s%-*s 0x%08x\n", indent, "", fwidth, "Filter mask:", key->filter_mask);
+    fprintf(stream, "%*s%-*s {", indent, "", fwidth, "Logical offset:");
     for (u = 0; u < udata->ndims; u++)
-        HDfprintf(stream, "%s%" PRIuHSIZE, u ? ", " : "", (key->scaled[u] * udata->common.layout->dim[u]));
+        fprintf(stream, "%s%" PRIuHSIZE, u ? ", " : "", (key->scaled[u] * udata->common.layout->dim[u]));
     HDfputs("}\n", stream);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
@@ -750,9 +720,6 @@ H5D__btree_debug_key(FILE *stream, int indent, int fwidth, const void *_key, con
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Thursday, May 7, 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -768,7 +735,7 @@ H5D__btree_shared_free(void *_shared)
 
     /* Chain up to the generic B-tree shared info free routine */
     if (H5B_shared_free(shared) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "can't free shared B-tree info")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "can't free shared B-tree info");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -781,9 +748,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Monday, September 27, 2004
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -803,17 +767,17 @@ H5D__btree_shared_create(const H5F_t *f, H5O_storage_chunk_t *store, const H5O_l
 
     /* Allocate & initialize global info for the shared structure */
     if (NULL == (shared = H5B_shared_new(f, H5B_BTREE, sizeof_rkey)))
-        HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "memory allocation failed for shared B-tree info")
+        HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "memory allocation failed for shared B-tree info");
 
     /* Set up the "local" information for this dataset's chunks */
     if (NULL == (my_layout = H5FL_MALLOC(H5O_layout_chunk_t)))
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "can't allocate chunk layout")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "can't allocate chunk layout");
     H5MM_memcpy(my_layout, layout, sizeof(H5O_layout_chunk_t));
     shared->udata = my_layout;
 
     /* Make shared B-tree info reference counted */
     if (NULL == (store->u.btree.shared = H5UC_create(shared, H5D__btree_shared_free)))
-        HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't create ref-count wrapper for shared B-tree info")
+        HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't create ref-count wrapper for shared B-tree info");
 
 done:
     if (ret_value < 0)
@@ -830,9 +794,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Monday, May 18, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -844,18 +805,18 @@ H5D__btree_idx_init(const H5D_chk_idx_info_t *idx_info, const H5S_t H5_ATTR_UNUS
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(H5F_addr_defined(dset_ohdr_addr));
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(H5_addr_defined(dset_ohdr_addr));
 
     idx_info->storage->u.btree.dset_ohdr_addr = dset_ohdr_addr;
 
     /* Allocate the shared structure */
     if (H5D__btree_shared_create(idx_info->f, idx_info->storage, idx_info->layout) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTINIT, FAIL, "can't create wrapper for shared B-tree info")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTINIT, FAIL, "can't create wrapper for shared B-tree info");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -874,9 +835,6 @@ done:
  * Return:	Non-negative on success (with the LAYOUT argument initialized
  *		and ready to write to an object header). Negative on failure.
  *
- * Programmer:	Robb Matzke
- *		Tuesday, October 21, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -888,12 +846,12 @@ H5D__btree_idx_create(const H5D_chk_idx_info_t *idx_info)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(!H5F_addr_defined(idx_info->storage->idx_addr));
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(!H5_addr_defined(idx_info->storage->idx_addr));
 
     /* Initialize "user" data for B-tree callbacks, etc. */
     udata.layout  = idx_info->layout;
@@ -901,7 +859,7 @@ H5D__btree_idx_create(const H5D_chk_idx_info_t *idx_info)
 
     /* Create the v1 B-tree for the chunk index */
     if (H5B_create(idx_info->f, H5B_BTREE, &udata, &(idx_info->storage->idx_addr) /*out*/) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't create B-tree")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't create B-tree");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -914,9 +872,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Thursday, January 15, 2009
- *
  *-------------------------------------------------------------------------
  */
 static hbool_t
@@ -925,9 +880,9 @@ H5D__btree_idx_is_space_alloc(const H5O_storage_chunk_t *storage)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(storage);
+    assert(storage);
 
-    FUNC_LEAVE_NOAPI((hbool_t)H5F_addr_defined(storage->idx_addr))
+    FUNC_LEAVE_NOAPI((hbool_t)H5_addr_defined(storage->idx_addr))
 } /* end H5D__btree_idx_is_space_alloc() */
 
 /*-------------------------------------------------------------------------
@@ -937,9 +892,6 @@ H5D__btree_idx_is_space_alloc(const H5O_storage_chunk_t *storage)
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Thursday, May 21, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -950,20 +902,20 @@ H5D__btree_idx_insert(const H5D_chk_idx_info_t *idx_info, H5D_chunk_ud_t *udata,
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(H5F_addr_defined(idx_info->storage->idx_addr));
-    HDassert(udata);
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(H5_addr_defined(idx_info->storage->idx_addr));
+    assert(udata);
 
     /*
      * Create the chunk it if it doesn't exist, or reallocate the chunk if
      * its size changed.
      */
     if (H5B_insert(idx_info->f, H5B_BTREE, idx_info->storage->idx_addr, udata) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "unable to allocate chunk")
+        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "unable to allocate chunk");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -978,9 +930,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Albert Cheng
- *              June 27, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -991,19 +940,19 @@ H5D__btree_idx_get_addr(const H5D_chk_idx_info_t *idx_info, H5D_chunk_ud_t *udat
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->layout->ndims > 0);
-    HDassert(idx_info->storage);
-    HDassert(H5F_addr_defined(idx_info->storage->idx_addr));
-    HDassert(udata);
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->layout->ndims > 0);
+    assert(idx_info->storage);
+    assert(H5_addr_defined(idx_info->storage->idx_addr));
+    assert(udata);
 
     /* Go get the chunk information from the B-tree */
     found = FALSE;
     if (H5B_find(idx_info->f, H5B_BTREE, idx_info->storage->idx_addr, &found, udata) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTFIND, FAIL, "can't check for chunk in B-tree")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTFIND, FAIL, "can't check for chunk in B-tree");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1019,9 +968,6 @@ done:
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, May 20, 2008
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1062,9 +1008,6 @@ H5D__btree_idx_iterate_cb(H5F_t H5_ATTR_UNUSED *f, const void *_lt_key, haddr_t
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, May 20, 2008
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1075,17 +1018,17 @@ H5D__btree_idx_iterate(const H5D_chk_idx_info_t *idx_info, H5D_chunk_cb_func_t c
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(H5F_addr_defined(idx_info->storage->idx_addr));
-    HDassert(chunk_cb);
-    HDassert(chunk_udata);
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(H5_addr_defined(idx_info->storage->idx_addr));
+    assert(chunk_cb);
+    assert(chunk_udata);
 
     /* Initialize userdata */
-    HDmemset(&udata, 0, sizeof udata);
+    memset(&udata, 0, sizeof udata);
     udata.common.layout  = idx_info->layout;
     udata.common.storage = idx_info->storage;
     udata.cb             = chunk_cb;
@@ -1106,9 +1049,6 @@ H5D__btree_idx_iterate(const H5D_chk_idx_info_t *idx_info, H5D_chunk_cb_func_t c
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Thursday, May 22, 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1118,19 +1058,19 @@ H5D__btree_idx_remove(const H5D_chk_idx_info_t *idx_info, H5D_chunk_common_ud_t
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(H5F_addr_defined(idx_info->storage->idx_addr));
-    HDassert(udata);
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(H5_addr_defined(idx_info->storage->idx_addr));
+    assert(udata);
 
     /* Remove the chunk from the v1 B-tree index and release the space for the
      * chunk (in the B-tree callback).
      */
     if (H5B_remove(idx_info->f, H5B_BTREE, idx_info->storage->idx_addr, udata) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTDELETE, FAIL, "unable to remove chunk entry")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTDELETE, FAIL, "unable to remove chunk entry");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1145,9 +1085,6 @@ done:
  * Return:	Success:	Non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, March 20, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1158,14 +1095,14 @@ H5D__btree_idx_delete(const H5D_chk_idx_info_t *idx_info)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
 
     /* Check if the index data structure has been allocated */
-    if (H5F_addr_defined(idx_info->storage->idx_addr)) {
+    if (H5_addr_defined(idx_info->storage->idx_addr)) {
         H5O_storage_chunk_t   tmp_storage; /* Local copy of storage info */
         H5D_chunk_common_ud_t udata;       /* User data for B-tree operations */
 
@@ -1174,22 +1111,22 @@ H5D__btree_idx_delete(const H5D_chk_idx_info_t *idx_info)
 
         /* Set up the shared structure */
         if (H5D__btree_shared_create(idx_info->f, &tmp_storage, idx_info->layout) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't create wrapper for shared B-tree info")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't create wrapper for shared B-tree info");
 
         /* Set up B-tree user data */
-        HDmemset(&udata, 0, sizeof udata);
+        memset(&udata, 0, sizeof udata);
         udata.layout  = idx_info->layout;
         udata.storage = &tmp_storage;
 
         /* Delete entire B-tree */
         if (H5B_delete(idx_info->f, H5B_BTREE, tmp_storage.idx_addr, &udata) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTDELETE, FAIL, "unable to delete chunk B-tree")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTDELETE, FAIL, "unable to delete chunk B-tree");
 
         /* Release the shared B-tree page */
         if (NULL == tmp_storage.u.btree.shared)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "ref-counted page nil")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "ref-counted page nil");
         if (H5UC_DEC(tmp_storage.u.btree.shared) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "unable to decrement ref-counted page")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "unable to decrement ref-counted page");
     } /* end if */
 
 done:
@@ -1203,9 +1140,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Thursday, May 29, 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1215,29 +1149,29 @@ H5D__btree_idx_copy_setup(const H5D_chk_idx_info_t *idx_info_src, const H5D_chk_
 
     FUNC_ENTER_PACKAGE_TAG(H5AC__COPIED_TAG)
 
-    HDassert(idx_info_src);
-    HDassert(idx_info_src->f);
-    HDassert(idx_info_src->pline);
-    HDassert(idx_info_src->layout);
-    HDassert(idx_info_src->storage);
-    HDassert(idx_info_dst);
-    HDassert(idx_info_dst->f);
-    HDassert(idx_info_dst->pline);
-    HDassert(idx_info_dst->layout);
-    HDassert(idx_info_dst->storage);
-    HDassert(!H5F_addr_defined(idx_info_dst->storage->idx_addr));
+    assert(idx_info_src);
+    assert(idx_info_src->f);
+    assert(idx_info_src->pline);
+    assert(idx_info_src->layout);
+    assert(idx_info_src->storage);
+    assert(idx_info_dst);
+    assert(idx_info_dst->f);
+    assert(idx_info_dst->pline);
+    assert(idx_info_dst->layout);
+    assert(idx_info_dst->storage);
+    assert(!H5_addr_defined(idx_info_dst->storage->idx_addr));
 
     /* Create shared B-tree info for each file */
     if (H5D__btree_shared_create(idx_info_src->f, idx_info_src->storage, idx_info_src->layout) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTINIT, FAIL, "can't create wrapper for source shared B-tree info")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTINIT, FAIL, "can't create wrapper for source shared B-tree info");
     if (H5D__btree_shared_create(idx_info_dst->f, idx_info_dst->storage, idx_info_dst->layout) < 0)
         HGOTO_ERROR(H5E_RESOURCE, H5E_CANTINIT, FAIL,
-                    "can't create wrapper for destination shared B-tree info")
+                    "can't create wrapper for destination shared B-tree info");
 
     /* Create the root of the B-tree that describes chunked storage in the dest. file */
     if (H5D__btree_idx_create(idx_info_dst) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_CANTINIT, FAIL, "unable to initialize chunked storage")
-    HDassert(H5F_addr_defined(idx_info_dst->storage->idx_addr));
+        HGOTO_ERROR(H5E_IO, H5E_CANTINIT, FAIL, "unable to initialize chunked storage");
+    assert(H5_addr_defined(idx_info_dst->storage->idx_addr));
 
 done:
     FUNC_LEAVE_NOAPI_TAG(ret_value)
@@ -1250,9 +1184,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Thursday, May 29, 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1262,14 +1193,14 @@ H5D__btree_idx_copy_shutdown(H5O_storage_chunk_t *storage_src, H5O_storage_chunk
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(storage_src);
-    HDassert(storage_dst);
+    assert(storage_src);
+    assert(storage_dst);
 
     /* Decrement refcount on shared B-tree info */
     if (H5UC_DEC(storage_src->u.btree.shared) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTDEC, FAIL, "unable to decrement ref-counted page")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTDEC, FAIL, "unable to decrement ref-counted page");
     if (H5UC_DEC(storage_dst->u.btree.shared) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTDEC, FAIL, "unable to decrement ref-counted page")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTDEC, FAIL, "unable to decrement ref-counted page");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1283,9 +1214,6 @@ done:
  * Return:      Success:        Non-negative
  *              Failure:        negative
  *
- * Programmer:  Vailin Choi
- *              June 8, 2007
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1298,21 +1226,21 @@ H5D__btree_idx_size(const H5D_chk_idx_info_t *idx_info, hsize_t *index_size)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(index_size);
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(index_size);
 
     /* Initialize B-tree node user-data */
-    HDmemset(&udata, 0, sizeof udata);
+    memset(&udata, 0, sizeof udata);
     udata.layout  = idx_info->layout;
     udata.storage = idx_info->storage;
 
     /* Get metadata information for B-tree */
     if (H5B_get_info(idx_info->f, H5B_BTREE, idx_info->storage->idx_addr, &bt_info, NULL, &udata) < 0)
-        HGOTO_ERROR(H5E_BTREE, H5E_CANTINIT, FAIL, "unable to iterate over chunk B-tree")
+        HGOTO_ERROR(H5E_BTREE, H5E_CANTINIT, FAIL, "unable to iterate over chunk B-tree");
 
     /* Set the size of the B-tree */
     *index_size = bt_info.size;
@@ -1328,9 +1256,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Thursday, January 15, 2009
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1338,7 +1263,7 @@ H5D__btree_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(storage);
+    assert(storage);
 
     /* Reset index info */
     if (reset_addr)
@@ -1355,9 +1280,6 @@ H5D__btree_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr)
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Thursday, January 15, 2009
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1365,10 +1287,10 @@ H5D__btree_idx_dump(const H5O_storage_chunk_t *storage, FILE *stream)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(storage);
-    HDassert(stream);
+    assert(storage);
+    assert(stream);
 
-    HDfprintf(stream, "    Address: %" PRIuHADDR "\n", storage->idx_addr);
+    fprintf(stream, "    Address: %" PRIuHADDR "\n", storage->idx_addr);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5D__btree_idx_dump() */
@@ -1380,9 +1302,6 @@ H5D__btree_idx_dump(const H5O_storage_chunk_t *storage, FILE *stream)
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Thursday, May 21, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1392,17 +1311,17 @@ H5D__btree_idx_dest(const H5D_chk_idx_info_t *idx_info)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
 
     /* Free the raw B-tree node buffer */
     if (NULL == idx_info->storage->u.btree.shared)
-        HGOTO_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "ref-counted page nil")
+        HGOTO_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "ref-counted page nil");
     if (H5UC_DEC(idx_info->storage->u.btree.shared) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "unable to decrement ref-counted page")
+        HGOTO_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "unable to decrement ref-counted page");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1415,9 +1334,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Thursday, April 16, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1434,18 +1350,18 @@ H5D_btree_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth, un
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Reset "fake" storage info */
-    HDmemset(&storage, 0, sizeof(storage));
+    memset(&storage, 0, sizeof(storage));
     storage.idx_type = H5D_CHUNK_IDX_BTREE;
 
     /* Reset "fake" layout info */
-    HDmemset(&layout, 0, sizeof(layout));
+    memset(&layout, 0, sizeof(layout));
     layout.ndims = ndims;
     for (u = 0; u < ndims; u++)
         layout.dim[u] = dim[u];
 
     /* Allocate the shared structure */
     if (H5D__btree_shared_create(f, &storage, &layout) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTINIT, FAIL, "can't create wrapper for shared B-tree info")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTINIT, FAIL, "can't create wrapper for shared B-tree info");
     shared_init = TRUE;
 
     /* Set up user data for callback */
@@ -1461,9 +1377,9 @@ done:
     if (shared_init) {
         /* Free the raw B-tree node buffer */
         if (NULL == storage.u.btree.shared)
-            HDONE_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "ref-counted shared info nil")
+            HDONE_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "ref-counted shared info nil");
         else if (H5UC_DEC(storage.u.btree.shared) < 0)
-            HDONE_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "unable to decrement ref-counted shared info")
+            HDONE_ERROR(H5E_IO, H5E_CANTFREE, FAIL, "unable to decrement ref-counted shared info");
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
