@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5Dfill.c
- *			Jun 19 2007
- *			Quincey Koziol
  *
  * Purpose:		Fill value operations for datasets
  *
@@ -104,7 +102,6 @@ H5FL_EXTERN(H5S_sel_iter_t);
     If "fill" parameter is NULL, use all zeros as fill value.
  EXAMPLES
  REVISION LOG
-    Raymond Lu - 20 March 2007
     If there's VL type of data, the address of the data is copied multiple
     times into the buffer, causing some trouble when the data is released.
     Instead, make multiple copies of fill value first, then do conversion
@@ -128,14 +125,14 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(fill_type);
-    HDassert(buf);
-    HDassert(buf_type);
-    HDassert(space);
+    assert(fill_type);
+    assert(buf);
+    assert(buf_type);
+    assert(space);
 
     /* Make sure the dataspace has an extent set (or is NULL) */
     if (!(H5S_has_extent(space)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "dataspace extent has not been set")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "dataspace extent has not been set");
 
     /* Get the memory datatype size */
     dst_type_size = H5T_get_size(buf_type);
@@ -146,15 +143,15 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
 
         /* Wrap the local buffer for elements */
         if (NULL == (elem_wb = H5WB_wrap(elem_buf, sizeof(elem_buf))))
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't wrap buffer")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't wrap buffer");
 
         /* Get a pointer to a buffer that's large enough for element */
         if (NULL == (elem_ptr = H5WB_actual_clear(elem_wb, dst_type_size)))
-            HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't get actual buffer")
+            HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't get actual buffer");
 
         /* Fill the selection in the memory buffer */
         if (H5S_select_fill(elem_ptr, dst_type_size, space, buf) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTENCODE, FAIL, "filling selection failed")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTENCODE, FAIL, "filling selection failed");
     } /* end if */
     else {
         H5T_path_t *tpath;         /* Conversion path information */
@@ -169,15 +166,16 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
 
         /* Set up type conversion function */
         if (NULL == (tpath = H5T_path_find(fill_type, buf_type)))
-            HGOTO_ERROR(H5E_DATASET, H5E_UNSUPPORTED, FAIL, "unable to convert between src and dest datatype")
+            HGOTO_ERROR(H5E_DATASET, H5E_UNSUPPORTED, FAIL,
+                        "unable to convert between src and dest datatype");
 
         /* Construct source & destination datatype IDs, if we will need them */
         if (!H5T_path_noop(tpath)) {
             if ((src_id = H5I_register(H5I_DATATYPE, H5T_copy(fill_type, H5T_COPY_ALL), FALSE)) < 0)
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTREGISTER, FAIL, "unable to register types for conversion")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTREGISTER, FAIL, "unable to register types for conversion");
 
             if ((dst_id = H5I_register(H5I_DATATYPE, H5T_copy(buf_type, H5T_COPY_ALL), FALSE)) < 0)
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTREGISTER, FAIL, "unable to register types for conversion")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTREGISTER, FAIL, "unable to register types for conversion");
         } /* end if */
 
         /* If there's VL type of data, make multiple copies of fill value first,
@@ -193,12 +191,12 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
 
             /* Allocate a temporary buffer */
             if (NULL == (tmp_buf = H5FL_BLK_MALLOC(type_conv, (size_t)nelmts * buf_size)))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
             /* Allocate a background buffer, if necessary */
             if (H5T_path_bkg(tpath) &&
                 NULL == (bkg_buf = H5FL_BLK_CALLOC(type_conv, (size_t)nelmts * buf_size)))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
             /* Replicate the file's fill value into the temporary buffer */
             H5VM_array_fill(tmp_buf, fill, src_type_size, (size_t)nelmts);
@@ -206,21 +204,21 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
             /* Convert from file's fill value into memory form */
             if (H5T_convert(tpath, src_id, dst_id, (size_t)nelmts, (size_t)0, (size_t)0, tmp_buf, bkg_buf) <
                 0)
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed");
 
             /* Allocate the chunk selection iterator */
             if (NULL == (mem_iter = H5FL_MALLOC(H5S_sel_iter_t)))
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "can't allocate memory selection iterator")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "can't allocate memory selection iterator");
 
             /* Create a selection iterator for scattering the elements to memory buffer */
             if (H5S_select_iter_init(mem_iter, space, dst_type_size, 0) < 0)
                 HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL,
-                            "unable to initialize memory selection information")
+                            "unable to initialize memory selection information");
             mem_iter_init = TRUE;
 
             /* Scatter the data into memory */
             if (H5D__scatter_mem(tmp_buf, mem_iter, (size_t)nelmts, buf /*out*/) < 0)
-                HGOTO_ERROR(H5E_DATASET, H5E_READERROR, FAIL, "scatter failed")
+                HGOTO_ERROR(H5E_DATASET, H5E_READERROR, FAIL, "scatter failed");
         } /* end if */
         else {
             const uint8_t *fill_buf; /* Buffer to use for writing fill values */
@@ -232,11 +230,11 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
 
                 /* Wrap the local buffer for elements */
                 if (NULL == (elem_wb = H5WB_wrap(elem_buf, sizeof(elem_buf))))
-                    HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't wrap buffer")
+                    HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't wrap buffer");
 
                 /* Get a pointer to a buffer that's large enough for element */
                 if (NULL == (elem_ptr = H5WB_actual(elem_wb, buf_size)))
-                    HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't get actual buffer")
+                    HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't get actual buffer");
 
                 /* Copy the user's data into the buffer for conversion */
                 H5MM_memcpy(elem_ptr, fill, src_type_size);
@@ -246,17 +244,17 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
                 if (H5T_path_bkg(tpath)) {
                     /* Wrap the local buffer for background elements */
                     if (NULL == (bkg_elem_wb = H5WB_wrap(bkg_elem_buf, sizeof(bkg_elem_buf))))
-                        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't wrap buffer")
+                        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't wrap buffer");
 
                     /* Get a pointer to a buffer that's large enough for element */
                     if (NULL == (bkg_ptr = H5WB_actual_clear(bkg_elem_wb, buf_size)))
-                        HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't get actual buffer")
+                        HGOTO_ERROR(H5E_DATASET, H5E_NOSPACE, FAIL, "can't get actual buffer");
                 } /* end if */
 
                 /* Perform datatype conversion */
                 if (H5T_convert(tpath, src_id, dst_id, (size_t)1, (size_t)0, (size_t)0, elem_ptr, bkg_ptr) <
                     0)
-                    HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed")
+                    HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed");
 
                 /* Point at element buffer */
                 fill_buf = (const uint8_t *)elem_ptr;
@@ -266,25 +264,25 @@ H5D__fill(const void *fill, const H5T_t *fill_type, void *buf, const H5T_t *buf_
 
             /* Fill the selection in the memory buffer */
             if (H5S_select_fill(fill_buf, dst_type_size, space, buf) < 0)
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTENCODE, FAIL, "filling selection failed")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTENCODE, FAIL, "filling selection failed");
         } /* end else */
     }     /* end else */
 
 done:
     if (mem_iter_init && H5S_SELECT_ITER_RELEASE(mem_iter) < 0)
-        HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't release selection iterator")
+        HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't release selection iterator");
     if (mem_iter)
         mem_iter = H5FL_FREE(H5S_sel_iter_t, mem_iter);
     if (src_id != (-1) && H5I_dec_ref(src_id) < 0)
-        HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID")
+        HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID");
     if (dst_id != (-1) && H5I_dec_ref(dst_id) < 0)
-        HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID")
+        HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID");
     if (tmp_buf)
         tmp_buf = H5FL_BLK_FREE(type_conv, tmp_buf);
     if (elem_wb && H5WB_unwrap(elem_wb) < 0)
-        HDONE_ERROR(H5E_ATTR, H5E_CLOSEERROR, FAIL, "can't close wrapped buffer")
+        HDONE_ERROR(H5E_ATTR, H5E_CLOSEERROR, FAIL, "can't close wrapped buffer");
     if (bkg_elem_wb && H5WB_unwrap(bkg_elem_wb) < 0)
-        HDONE_ERROR(H5E_ATTR, H5E_CLOSEERROR, FAIL, "can't close wrapped buffer")
+        HDONE_ERROR(H5E_ATTR, H5E_CLOSEERROR, FAIL, "can't close wrapped buffer");
     if (bkg_buf)
         bkg_buf = H5FL_BLK_FREE(type_conv, bkg_buf);
 
@@ -298,9 +296,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		June 21, 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -313,13 +308,13 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(fb_info);
-    HDassert(fill);
-    HDassert(dset_type);
-    HDassert(dset_type_id > 0);
+    assert(fb_info);
+    assert(fill);
+    assert(dset_type);
+    assert(dset_type_id > 0);
 
     /* Reset fill buffer information */
-    HDmemset(fb_info, 0, sizeof(*fb_info));
+    memset(fb_info, 0, sizeof(*fb_info));
 
     /* Cache constant information from the dataset */
     fb_info->fill            = fill;
@@ -336,22 +331,22 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
 
         /* Detect whether the datatype has a VL component */
         if ((has_vlen_type = H5T_detect_class(dset_type, H5T_VLEN, FALSE)) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "unable to detect vlen datatypes?")
+            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "unable to detect vlen datatypes?");
         fb_info->has_vlen_fill_type = (hbool_t)has_vlen_type;
 
         /* If necessary, convert fill value datatypes (which copies VL components, etc.) */
         if (fb_info->has_vlen_fill_type) {
             /* Create temporary datatype for conversion operation */
             if (NULL == (fb_info->mem_type = H5T_copy(dset_type, H5T_COPY_TRANSIENT)))
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTCOPY, FAIL, "unable to copy file datatype")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTCOPY, FAIL, "unable to copy file datatype");
             if ((fb_info->mem_tid = H5I_register(H5I_DATATYPE, fb_info->mem_type, FALSE)) < 0)
-                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, FAIL, "unable to register memory datatype")
+                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, FAIL, "unable to register memory datatype");
 
             /* Retrieve sizes of memory & file datatypes */
             fb_info->mem_elmt_size = H5T_get_size(fb_info->mem_type);
-            HDassert(fb_info->mem_elmt_size > 0);
+            assert(fb_info->mem_elmt_size > 0);
             fb_info->file_elmt_size = H5T_get_size(dset_type);
-            HDassert(fb_info->file_elmt_size == (size_t)fill->size);
+            assert(fb_info->file_elmt_size == (size_t)fill->size);
 
             /* If fill value is not library default, use it to set the element size */
             fb_info->max_elmt_size = MAX(fb_info->mem_elmt_size, fb_info->file_elmt_size);
@@ -361,7 +356,7 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
                 fb_info->elmts_per_buf = MIN(total_nelmts, MAX(1, (max_buf_size / fb_info->max_elmt_size)));
             else
                 fb_info->elmts_per_buf = max_buf_size / fb_info->max_elmt_size;
-            HDassert(fb_info->elmts_per_buf > 0);
+            assert(fb_info->elmts_per_buf > 0);
 
             /* Compute the buffer size to use */
             fb_info->fill_buf_size = MIN(max_buf_size, (fb_info->elmts_per_buf * fb_info->max_elmt_size));
@@ -377,18 +372,18 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
                 else
                     fb_info->fill_buf = H5FL_BLK_MALLOC(non_zero_fill, fb_info->fill_buf_size);
                 if (NULL == fb_info->fill_buf)
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for fill buffer")
+                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for fill buffer");
             } /* end else */
 
             /* Get the datatype conversion path for this operation */
             if (NULL == (fb_info->fill_to_mem_tpath = H5T_path_find(dset_type, fb_info->mem_type)))
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL,
-                            "unable to convert between src and dst datatypes")
+                            "unable to convert between src and dst datatypes");
 
             /* Get the inverse datatype conversion path for this operation */
             if (NULL == (fb_info->mem_to_dset_tpath = H5T_path_find(fb_info->mem_type, dset_type)))
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL,
-                            "unable to convert between src and dst datatypes")
+                            "unable to convert between src and dst datatypes");
 
             /* Check if we need to allocate a background buffer */
             if (H5T_path_bkg(fb_info->fill_to_mem_tpath) || H5T_path_bkg(fb_info->mem_to_dset_tpath)) {
@@ -401,12 +396,12 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
 
                 /* Allocate the background buffer */
                 if (NULL == (fb_info->bkg_buf = H5FL_BLK_MALLOC(type_conv, fb_info->bkg_buf_size)))
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
             } /* end if */
         }     /* end if */
         else {
             /* If fill value is not library default, use it to set the element size */
-            HDassert(fill->size >= 0);
+            assert(fill->size >= 0);
             fb_info->max_elmt_size = fb_info->file_elmt_size = fb_info->mem_elmt_size = (size_t)fill->size;
 
             /* Compute the number of elements that fit within a buffer to write */
@@ -414,7 +409,7 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
                 fb_info->elmts_per_buf = MIN(total_nelmts, MAX(1, (max_buf_size / fb_info->max_elmt_size)));
             else
                 fb_info->elmts_per_buf = max_buf_size / fb_info->max_elmt_size;
-            HDassert(fb_info->elmts_per_buf > 0);
+            assert(fb_info->elmts_per_buf > 0);
 
             /* Compute the buffer size to use */
             fb_info->fill_buf_size = MIN(max_buf_size, fb_info->elmts_per_buf * fb_info->max_elmt_size);
@@ -430,7 +425,7 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
                 else
                     fb_info->fill_buf = H5FL_BLK_MALLOC(non_zero_fill, fb_info->fill_buf_size);
                 if (NULL == fb_info->fill_buf)
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for fill buffer")
+                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for fill buffer");
             } /* end else */
 
             /* Replicate the fill value into the cached buffer */
@@ -440,14 +435,14 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
     else { /* Fill the buffer with the default fill value */
         /* Retrieve size of elements */
         fb_info->max_elmt_size = fb_info->file_elmt_size = fb_info->mem_elmt_size = H5T_get_size(dset_type);
-        HDassert(fb_info->max_elmt_size > 0);
+        assert(fb_info->max_elmt_size > 0);
 
         /* Compute the number of elements that fit within a buffer to write */
         if (total_nelmts > 0)
             fb_info->elmts_per_buf = MIN(total_nelmts, MAX(1, (max_buf_size / fb_info->max_elmt_size)));
         else
             fb_info->elmts_per_buf = max_buf_size / fb_info->max_elmt_size;
-        HDassert(fb_info->elmts_per_buf > 0);
+        assert(fb_info->elmts_per_buf > 0);
 
         /* Compute the buffer size to use */
         fb_info->fill_buf_size = MIN(max_buf_size, (fb_info->elmts_per_buf * fb_info->max_elmt_size));
@@ -457,19 +452,19 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
             fb_info->fill_buf            = caller_fill_buf;
             fb_info->use_caller_fill_buf = TRUE;
 
-            HDmemset(fb_info->fill_buf, 0, fb_info->fill_buf_size);
+            memset(fb_info->fill_buf, 0, fb_info->fill_buf_size);
         } /* end if */
         else {
             if (alloc_func) {
                 fb_info->fill_buf = alloc_func(fb_info->fill_buf_size, alloc_info);
 
-                HDmemset(fb_info->fill_buf, 0, fb_info->fill_buf_size);
+                memset(fb_info->fill_buf, 0, fb_info->fill_buf_size);
             } /* end if */
             else {
                 htri_t buf_avail = H5FL_BLK_AVAIL(
                     zero_fill,
                     fb_info->fill_buf_size); /* Check if there is an already zeroed out buffer available */
-                HDassert(buf_avail != FAIL);
+                assert(buf_avail != FAIL);
 
                 /* Allocate temporary buffer (zeroing it if no buffer is available) */
                 if (!buf_avail)
@@ -478,7 +473,7 @@ H5D__fill_init(H5D_fill_buf_info_t *fb_info, void *caller_fill_buf, H5MM_allocat
                     fb_info->fill_buf = H5FL_BLK_MALLOC(zero_fill, fb_info->fill_buf_size);
             } /* end else */
             if (fb_info->fill_buf == NULL)
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for fill buffer")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for fill buffer");
         } /* end else */
     }     /* end else */
 
@@ -486,7 +481,7 @@ done:
     /* Cleanup on error */
     if (ret_value < 0)
         if (H5D__fill_term(fb_info) < 0)
-            HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't release fill buffer info")
+            HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't release fill buffer info");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5D__fill_init() */
@@ -498,9 +493,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		June 21, 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -512,21 +504,21 @@ H5D__fill_refill_vl(H5D_fill_buf_info_t *fb_info, size_t nelmts)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(fb_info);
-    HDassert(fb_info->has_vlen_fill_type);
-    HDassert(fb_info->fill_buf);
+    assert(fb_info);
+    assert(fb_info->has_vlen_fill_type);
+    assert(fb_info->fill_buf);
 
     /* Make a copy of the (disk-based) fill value into the buffer */
     H5MM_memcpy(fb_info->fill_buf, fb_info->fill->buf, fb_info->file_elmt_size);
 
     /* Reset first element of background buffer, if necessary */
     if (H5T_path_bkg(fb_info->fill_to_mem_tpath))
-        HDmemset(fb_info->bkg_buf, 0, fb_info->max_elmt_size);
+        memset(fb_info->bkg_buf, 0, fb_info->max_elmt_size);
 
     /* Type convert the dataset buffer, to copy any VL components */
     if (H5T_convert(fb_info->fill_to_mem_tpath, fb_info->file_tid, fb_info->mem_tid, (size_t)1, (size_t)0,
                     (size_t)0, fb_info->fill_buf, fb_info->bkg_buf) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed");
 
     /* Replicate the fill value into the cached buffer */
     if (nelmts > 1)
@@ -535,7 +527,7 @@ H5D__fill_refill_vl(H5D_fill_buf_info_t *fb_info, size_t nelmts)
 
     /* Reset the entire background buffer, if necessary */
     if (H5T_path_bkg(fb_info->mem_to_dset_tpath))
-        HDmemset(fb_info->bkg_buf, 0, fb_info->bkg_buf_size);
+        memset(fb_info->bkg_buf, 0, fb_info->bkg_buf_size);
 
     /* Make a copy of the fill buffer so we can free dynamic elements after conversion */
     if (fb_info->fill_alloc_func)
@@ -543,25 +535,25 @@ H5D__fill_refill_vl(H5D_fill_buf_info_t *fb_info, size_t nelmts)
     else
         buf = H5FL_BLK_MALLOC(non_zero_fill, fb_info->fill_buf_size);
     if (!buf)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "memory allocation failed for temporary fill buffer")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "memory allocation failed for temporary fill buffer");
 
     H5MM_memcpy(buf, fb_info->fill_buf, fb_info->fill_buf_size);
 
     /* Type convert the dataset buffer, to copy any VL components */
     if (H5T_convert(fb_info->mem_to_dset_tpath, fb_info->mem_tid, fb_info->file_tid, nelmts, (size_t)0,
                     (size_t)0, fb_info->fill_buf, fb_info->bkg_buf) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTCONVERT, FAIL, "data type conversion failed");
 
 done:
     if (buf) {
         /* Free dynamically allocated VL elements in fill buffer */
         if (fb_info->fill->type) {
             if (H5T_vlen_reclaim_elmt(buf, fb_info->fill->type) < 0)
-                HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "can't reclaim vlen element")
+                HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "can't reclaim vlen element");
         } /* end if */
         else {
             if (H5T_vlen_reclaim_elmt(buf, fb_info->mem_type) < 0)
-                HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "can't reclaim vlen element")
+                HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "can't reclaim vlen element");
         } /* end else */
 
         /* Free temporary fill buffer */
@@ -581,9 +573,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		June 22, 2007
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -592,8 +581,8 @@ H5D__fill_release(H5D_fill_buf_info_t *fb_info)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(fb_info);
-    HDassert(fb_info->fill);
+    assert(fb_info);
+    assert(fb_info->fill);
 
     /* Free the buffer for fill values */
     if (!fb_info->use_caller_fill_buf && fb_info->fill_buf) {
@@ -618,9 +607,6 @@ H5D__fill_release(H5D_fill_buf_info_t *fb_info)
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		June 21, 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -629,7 +615,7 @@ H5D__fill_term(H5D_fill_buf_info_t *fb_info)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(fb_info);
+    assert(fb_info);
 
     /* Free the buffer for fill values */
     H5D__fill_release(fb_info);
