@@ -10,17 +10,16 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer: 	Vailin Choi
- *	       	September 2010
- *
+/*
  * Purpose:	Implicit (Non Index) chunked I/O functions.
- *		This is used when the dataset is:
- *			extendible but with fixed max. dims
- *			with early allocation
- *			without filter
- *		The chunk coordinate is mapped into the actual disk addresses
- *		for the chunk without indexing.
  *
+ *          This is used when the dataset is:
+ *			- extendible but with fixed max. dims
+ *			- with early allocation
+ *			- without filter
+ *
+ *          The chunk coordinate is mapped into the actual disk addresses
+ *          for the chunk without indexing.
  */
 
 /****************/
@@ -105,8 +104,6 @@ const H5D_chunk_ops_t H5D_COPS_NONE[1] = {{
  * Return:	Non-negative on success
  *		Negative on failure.
  *
- * Programmer:	Vailin Choi; September 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -119,22 +116,22 @@ H5D__none_idx_create(const H5D_chk_idx_info_t *idx_info)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->pline->nused == 0); /* Shouldn't have filter defined on entering here */
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(idx_info->layout->max_nchunks);
-    HDassert(!H5F_addr_defined(idx_info->storage->idx_addr)); /* address of data shouldn't be defined */
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->pline->nused == 0); /* Shouldn't have filter defined on entering here */
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(idx_info->layout->max_nchunks);
+    assert(!H5_addr_defined(idx_info->storage->idx_addr)); /* address of data shouldn't be defined */
 
     /* Calculate size of max dataset chunks */
     nbytes = idx_info->layout->max_nchunks * idx_info->layout->size;
 
     /* Allocate space for max dataset chunks */
     addr = H5MF_alloc(idx_info->f, H5FD_MEM_DRAW, nbytes);
-    if (!H5F_addr_defined(addr))
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "file allocation failed")
+    if (!H5_addr_defined(addr))
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTALLOC, FAIL, "file allocation failed");
 
     /* This is the address of the dataset chunks */
     idx_info->storage->idx_addr = addr;
@@ -150,8 +147,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi; September 2010
- *
  *-------------------------------------------------------------------------
  */
 static hbool_t
@@ -160,9 +155,9 @@ H5D__none_idx_is_space_alloc(const H5O_storage_chunk_t *storage)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(storage);
+    assert(storage);
 
-    FUNC_LEAVE_NOAPI((hbool_t)H5F_addr_defined(storage->idx_addr))
+    FUNC_LEAVE_NOAPI((hbool_t)H5_addr_defined(storage->idx_addr))
 } /* end H5D__none_idx_is_space_alloc() */
 
 /*-------------------------------------------------------------------------
@@ -173,8 +168,6 @@ H5D__none_idx_is_space_alloc(const H5O_storage_chunk_t *storage)
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi; Sept 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -183,14 +176,14 @@ H5D__none_idx_get_addr(const H5D_chk_idx_info_t *idx_info, H5D_chunk_ud_t *udata
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(idx_info->pline->nused == 0);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(udata);
-    HDassert(H5F_addr_defined(idx_info->storage->idx_addr));
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(idx_info->pline->nused == 0);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(udata);
+    assert(H5_addr_defined(idx_info->storage->idx_addr));
 
     /* Calculate the index of this chunk */
     udata->chunk_idx = H5VM_array_offset_pre((idx_info->layout->ndims - 1), idx_info->layout->max_down_chunks,
@@ -214,8 +207,6 @@ H5D__none_idx_get_addr(const H5D_chk_idx_info_t *idx_info, H5D_chunk_ud_t *udata
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi; September 2010
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -231,23 +222,23 @@ H5D__none_idx_iterate(const H5D_chk_idx_info_t *idx_info, H5D_chunk_cb_func_t ch
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(!idx_info->pline->nused);
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(chunk_cb);
-    HDassert(chunk_udata);
-    HDassert(H5F_addr_defined(idx_info->storage->idx_addr));
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(!idx_info->pline->nused);
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(chunk_cb);
+    assert(chunk_udata);
+    assert(H5_addr_defined(idx_info->storage->idx_addr));
 
     /* Initialize generic chunk record */
-    HDmemset(&chunk_rec, 0, sizeof(chunk_rec));
+    memset(&chunk_rec, 0, sizeof(chunk_rec));
     chunk_rec.nbytes      = idx_info->layout->size;
     chunk_rec.filter_mask = 0;
 
     ndims = idx_info->layout->ndims - 1;
-    HDassert(ndims > 0);
+    assert(ndims > 0);
 
     /* Iterate over all the chunks in the dataset's dataspace */
     for (u = 0; u < idx_info->layout->nchunks && ret_value == H5_ITER_CONT; u++) {
@@ -260,7 +251,7 @@ H5D__none_idx_iterate(const H5D_chk_idx_info_t *idx_info, H5D_chunk_cb_func_t ch
         /* Make "generic chunk" callback */
         if ((ret_value = (*chunk_cb)(&chunk_rec, chunk_udata)) < 0)
             HGOTO_ERROR(H5E_DATASET, H5E_CALLBACK, H5_ITER_ERROR,
-                        "failure in generic chunk iterator callback")
+                        "failure in generic chunk iterator callback");
 
         /* Update coordinates of chunk in dataset */
         curr_dim = (int)(ndims - 1);
@@ -294,8 +285,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi; Sept 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -317,8 +306,6 @@ H5D__none_idx_remove(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info,
  * Return:	Success:	Non-negative
  *		Failure:	negative
  *
- * Programmer:	Vailin Choi; Sept 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -330,18 +317,18 @@ H5D__none_idx_delete(const H5D_chk_idx_info_t *idx_info)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(idx_info);
-    HDassert(idx_info->f);
-    HDassert(idx_info->pline);
-    HDassert(!idx_info->pline->nused); /* Shouldn't have filter defined on entering here */
-    HDassert(idx_info->layout);
-    HDassert(idx_info->storage);
-    HDassert(H5F_addr_defined(idx_info->storage->idx_addr)); /* should be defined */
+    assert(idx_info);
+    assert(idx_info->f);
+    assert(idx_info->pline);
+    assert(!idx_info->pline->nused); /* Shouldn't have filter defined on entering here */
+    assert(idx_info->layout);
+    assert(idx_info->storage);
+    assert(H5_addr_defined(idx_info->storage->idx_addr)); /* should be defined */
 
     /* chunk size * max # of chunks */
     nbytes = idx_info->layout->max_nchunks * idx_info->layout->size;
     if (H5MF_xfree(idx_info->f, H5FD_MEM_DRAW, idx_info->storage->idx_addr, nbytes) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, H5_ITER_ERROR, "unable to free dataset chunks")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTFREE, H5_ITER_ERROR, "unable to free dataset chunks");
 
     idx_info->storage->idx_addr = HADDR_UNDEF;
 
@@ -356,8 +343,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi; Sept 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -369,27 +354,27 @@ H5D__none_idx_copy_setup(const H5D_chk_idx_info_t H5_ATTR_NDEBUG_UNUSED *idx_inf
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(idx_info_src);
-    HDassert(idx_info_src->f);
-    HDassert(idx_info_src->pline);
-    HDassert(!idx_info_src->pline->nused);
-    HDassert(idx_info_src->layout);
-    HDassert(idx_info_src->storage);
-    HDassert(H5F_addr_defined(idx_info_src->storage->idx_addr));
+    assert(idx_info_src);
+    assert(idx_info_src->f);
+    assert(idx_info_src->pline);
+    assert(!idx_info_src->pline->nused);
+    assert(idx_info_src->layout);
+    assert(idx_info_src->storage);
+    assert(H5_addr_defined(idx_info_src->storage->idx_addr));
 
-    HDassert(idx_info_dst);
-    HDassert(idx_info_dst->f);
-    HDassert(idx_info_dst->pline);
-    HDassert(!idx_info_dst->pline->nused);
-    HDassert(idx_info_dst->layout);
-    HDassert(idx_info_dst->storage);
+    assert(idx_info_dst);
+    assert(idx_info_dst->f);
+    assert(idx_info_dst->pline);
+    assert(!idx_info_dst->pline->nused);
+    assert(idx_info_dst->layout);
+    assert(idx_info_dst->storage);
 
     /* Set copied metadata tag */
-    H5_BEGIN_TAG(H5AC__COPIED_TAG);
+    H5_BEGIN_TAG(H5AC__COPIED_TAG)
 
     /* Allocate dataset chunks in the dest. file */
     if (H5D__none_idx_create(idx_info_dst) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize chunked storage")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize chunked storage");
 
     /* Reset metadata tag */
     H5_END_TAG
@@ -406,8 +391,6 @@ done:
  * Return:      Success:        Non-negative
  *              Failure:        negative
  *
- * Programmer:	Vailin Choi; Sept 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -416,7 +399,7 @@ H5D__none_idx_size(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info, hsize_t *i
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(index_size);
+    assert(index_size);
 
     *index_size = 0;
 
@@ -430,8 +413,6 @@ H5D__none_idx_size(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info, hsize_t *i
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi; Sept 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -440,7 +421,7 @@ H5D__none_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(storage);
+    assert(storage);
 
     /* Reset index info */
     if (reset_addr)
@@ -456,8 +437,6 @@ H5D__none_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr)
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi; September 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -466,10 +445,10 @@ H5D__none_idx_dump(const H5O_storage_chunk_t *storage, FILE *stream)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(storage);
-    HDassert(stream);
+    assert(storage);
+    assert(stream);
 
-    HDfprintf(stream, "    Address: %" PRIuHADDR "\n", storage->idx_addr);
+    fprintf(stream, "    Address: %" PRIuHADDR "\n", storage->idx_addr);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5D__none_idx_dump() */
