@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5EA.c
- *			Jun 17 2008
- *			Quincey Koziol
  *
  * Purpose:		Implements an "extensible array" for storing elements
  *                      in an array whose high bounds can extend and shrink.
@@ -97,7 +95,7 @@ const H5EA_class_t *const H5EA_client_class_g[] = {
 H5FL_DEFINE_STATIC(H5EA_t);
 
 /* Declare a PQ free list to manage the element */
-H5FL_BLK_DEFINE(ea_native_elmt);
+H5FL_BLK_DEFINE_STATIC(ea_native_elmt);
 
 /*-------------------------------------------------------------------------
  * Function:	H5EA__new
@@ -107,9 +105,6 @@ H5FL_BLK_DEFINE(ea_native_elmt);
  * Return:	Pointer to earray wrapper success
  *              NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Oct 10 2016
- *
  *-------------------------------------------------------------------------
  */
 static H5EA_t *
@@ -122,30 +117,30 @@ H5EA__new(H5F_t *f, haddr_t ea_addr, hbool_t from_open, void *ctx_udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(ea_addr));
+    assert(f);
+    assert(H5_addr_defined(ea_addr));
 
     /* Allocate extensible array wrapper */
     if (NULL == (ea = H5FL_CALLOC(H5EA_t)))
-        HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL, "memory allocation failed for extensible array info")
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL, "memory allocation failed for extensible array info");
 
     /* Lock the array header into memory */
     if (NULL == (hdr = H5EA__hdr_protect(f, ea_addr, ctx_udata, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, NULL, "unable to load extensible array header")
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, NULL, "unable to load extensible array header");
 
     /* Check for pending array deletion */
     if (from_open && hdr->pending_delete)
-        HGOTO_ERROR(H5E_EARRAY, H5E_CANTOPENOBJ, NULL, "can't open extensible array pending deletion")
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTOPENOBJ, NULL, "can't open extensible array pending deletion");
 
     /* Point extensible array wrapper at header and bump it's ref count */
     ea->hdr = hdr;
     if (H5EA__hdr_incr(ea->hdr) < 0)
-        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header")
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header");
 
     /* Increment # of files using this array header */
     if (H5EA__hdr_fuse_incr(ea->hdr) < 0)
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTINC, NULL,
-                    "can't increment file reference count on shared array header")
+                    "can't increment file reference count on shared array header");
 
     /* Set file pointer for this array open context */
     ea->f = f;
@@ -156,10 +151,10 @@ H5EA__new(H5F_t *f, haddr_t ea_addr, hbool_t from_open, void *ctx_udata)
 done:
 
     if (hdr && H5EA__hdr_unprotect(hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, NULL, "unable to release extensible array header")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, NULL, "unable to release extensible array header");
     if (!ret_value)
         if (ea && H5EA_close(ea) < 0)
-            HDONE_ERROR(H5E_EARRAY, H5E_CLOSEERROR, NULL, "unable to close extensible array")
+            HDONE_ERROR(H5E_EARRAY, H5E_CLOSEERROR, NULL, "unable to close extensible array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA__new() */
@@ -172,9 +167,6 @@ done:
  * Return:	Pointer to earray wrapper on success
  *              NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Jun 17 2008
- *
  *-------------------------------------------------------------------------
  */
 H5EA_t *
@@ -187,20 +179,20 @@ H5EA_create(H5F_t *f, const H5EA_create_t *cparam, void *ctx_udata)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(cparam);
+    assert(f);
+    assert(cparam);
 
     /* H5EA interface sanity check */
     HDcompile_assert(H5EA_NUM_CLS_ID == NELMTS(H5EA_client_class_g));
 
     /* Create extensible array header */
     if (HADDR_UNDEF == (ea_addr = H5EA__hdr_create(f, cparam, ctx_udata)))
-        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINIT, NULL, "can't create extensible array header")
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINIT, NULL, "can't create extensible array header");
 
     /* Allocate and initialize new extensible array wrapper */
     if (NULL == (ea = H5EA__new(f, ea_addr, FALSE, ctx_udata)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTINIT, NULL,
-                    "allocation and/or initialization failed for extensible array wrapper")
+                    "allocation and/or initialization failed for extensible array wrapper");
 
     /* Set the return value */
     ret_value = ea;
@@ -208,7 +200,7 @@ H5EA_create(H5F_t *f, const H5EA_create_t *cparam, void *ctx_udata)
 done:
     if (!ret_value)
         if (ea && H5EA_close(ea) < 0)
-            HDONE_ERROR(H5E_EARRAY, H5E_CLOSEERROR, NULL, "unable to close extensible array")
+            HDONE_ERROR(H5E_EARRAY, H5E_CLOSEERROR, NULL, "unable to close extensible array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA_create() */
@@ -221,9 +213,6 @@ done:
  * Return:	Pointer to array wrapper on success
  *              NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Aug 28 2008
- *
  *-------------------------------------------------------------------------
  */
 H5EA_t *
@@ -235,13 +224,13 @@ H5EA_open(H5F_t *f, haddr_t ea_addr, void *ctx_udata)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(ea_addr));
+    assert(f);
+    assert(H5_addr_defined(ea_addr));
 
     /* Allocate and initialize new extensible array wrapper */
     if (NULL == (ea = H5EA__new(f, ea_addr, TRUE, ctx_udata)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTINIT, NULL,
-                    "allocation and/or initialization failed for extensible array wrapper")
+                    "allocation and/or initialization failed for extensible array wrapper");
 
     /* Set the return value */
     ret_value = ea;
@@ -249,7 +238,7 @@ H5EA_open(H5F_t *f, haddr_t ea_addr, void *ctx_udata)
 done:
     if (!ret_value)
         if (ea && H5EA_close(ea) < 0)
-            HDONE_ERROR(H5E_EARRAY, H5E_CLOSEERROR, NULL, "unable to close extensible array")
+            HDONE_ERROR(H5E_EARRAY, H5E_CLOSEERROR, NULL, "unable to close extensible array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA_open() */
@@ -261,9 +250,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug 21 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -272,8 +258,8 @@ H5EA_get_nelmts(const H5EA_t *ea, hsize_t *nelmts)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(nelmts);
+    assert(ea);
+    assert(nelmts);
 
     /* Retrieve the max. index set */
     *nelmts = ea->hdr->stats.stored.max_idx_set;
@@ -288,9 +274,6 @@ H5EA_get_nelmts(const H5EA_t *ea, hsize_t *nelmts)
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug 21 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -299,9 +282,9 @@ H5EA_get_addr(const H5EA_t *ea, haddr_t *addr)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(ea->hdr);
-    HDassert(addr);
+    assert(ea);
+    assert(ea->hdr);
+    assert(addr);
 
     /* Retrieve the address of the extensible array's header */
     *addr = ea->hdr->addr;
@@ -317,9 +300,6 @@ H5EA_get_addr(const H5EA_t *ea, haddr_t *addr)
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep  9 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -341,14 +321,14 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(hdr);
-    HDassert(thing);
-    HDassert(thing_elmt_buf);
-    HDassert(thing_unprot_func);
+    assert(ea);
+    assert(hdr);
+    assert(thing);
+    assert(thing_elmt_buf);
+    assert(thing_unprot_func);
 
     /* only the H5AC__READ_ONLY_FLAG may be set in thing_acc */
-    HDassert((thing_acc & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
+    assert((thing_acc & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
 
     /* Set the shared array header's file context for this operation */
     hdr->f = ea->f;
@@ -360,24 +340,24 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
     *thing_unprot_func = (H5EA__unprotect_func_t)NULL;
 
     /* Check if we should create the index block */
-    if (!H5F_addr_defined(hdr->idx_blk_addr)) {
+    if (!H5_addr_defined(hdr->idx_blk_addr)) {
         /* Check if we are allowed to create the thing */
         if (0 == (thing_acc & H5AC__READ_ONLY_FLAG)) { /* i.e. r/w access */
             /* Create the index block */
             hdr->idx_blk_addr = H5EA__iblock_create(hdr, &stats_changed);
-            if (!H5F_addr_defined(hdr->idx_blk_addr))
-                HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL, "unable to create index block")
+            if (!H5_addr_defined(hdr->idx_blk_addr))
+                HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL, "unable to create index block");
             hdr_dirty = TRUE;
         } /* end if */
         else
-            HGOTO_DONE(SUCCEED)
+            HGOTO_DONE(SUCCEED);
     } /* end if */
 
     /* Protect index block */
     if (NULL == (iblock = H5EA__iblock_protect(hdr, thing_acc)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL,
                     "unable to protect extensible array index block, address = %llu",
-                    (unsigned long long)hdr->idx_blk_addr)
+                    (unsigned long long)hdr->idx_blk_addr);
 
     /* Check if element is in index block */
     if (idx < hdr->cparam.idx_blk_elmts) {
@@ -403,10 +383,10 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
             /* Compute the data block index in index block */
             dblk_idx = (size_t)(hdr->sblk_info[sblk_idx].start_dblk +
                                 (elmt_idx / hdr->sblk_info[sblk_idx].dblk_nelmts));
-            HDassert(dblk_idx < iblock->ndblk_addrs);
+            assert(dblk_idx < iblock->ndblk_addrs);
 
             /* Check if the data block has been allocated on disk yet */
-            if (!H5F_addr_defined(iblock->dblk_addrs[dblk_idx])) {
+            if (!H5_addr_defined(iblock->dblk_addrs[dblk_idx])) {
                 /* Check if we are allowed to create the thing */
                 if (0 == (thing_acc & H5AC__READ_ONLY_FLAG)) { /* i.e. r/w access */
                     haddr_t dblk_addr;                         /* Address of data block created */
@@ -417,16 +397,16 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                                (dblk_idx * hdr->sblk_info[sblk_idx].dblk_nelmts);
                     dblk_addr = H5EA__dblock_create(hdr, iblock, &stats_changed, dblk_off,
                                                     hdr->sblk_info[sblk_idx].dblk_nelmts);
-                    if (!H5F_addr_defined(dblk_addr))
+                    if (!H5_addr_defined(dblk_addr))
                         HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL,
-                                    "unable to create extensible array data block")
+                                    "unable to create extensible array data block");
 
                     /* Set data block address in index block */
                     iblock->dblk_addrs[dblk_idx] = dblk_addr;
                     iblock_cache_flags |= H5AC__DIRTIED_FLAG;
                 } /* end if */
                 else
-                    HGOTO_DONE(SUCCEED)
+                    HGOTO_DONE(SUCCEED);
             } /* end if */
 
             /* Protect data block */
@@ -434,7 +414,7 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                                                        hdr->sblk_info[sblk_idx].dblk_nelmts, thing_acc)))
                 HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL,
                             "unable to protect extensible array data block, address = %llu",
-                            (unsigned long long)iblock->dblk_addrs[dblk_idx])
+                            (unsigned long long)iblock->dblk_addrs[dblk_idx]);
 
             /* Adjust index to offset in data block */
             elmt_idx %= hdr->sblk_info[sblk_idx].dblk_nelmts;
@@ -445,7 +425,7 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                     HGOTO_ERROR(
                         H5E_EARRAY, H5E_CANTDEPEND, FAIL,
                         "unable to create flush dependency between data block and header, index = %llu",
-                        (unsigned long long)idx)
+                        (unsigned long long)idx);
                 dblock->has_hdr_depend = TRUE;
             } /* end if */
 
@@ -462,23 +442,23 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
             sblk_off = sblk_idx - iblock->nsblks;
 
             /* Check if the super block has been allocated on disk yet */
-            if (!H5F_addr_defined(iblock->sblk_addrs[sblk_off])) {
+            if (!H5_addr_defined(iblock->sblk_addrs[sblk_off])) {
                 /* Check if we are allowed to create the thing */
                 if (0 == (thing_acc & H5AC__READ_ONLY_FLAG)) { /* i.e. r/w access */
                     haddr_t sblk_addr;                         /* Address of data block created */
 
                     /* Create super block */
                     sblk_addr = H5EA__sblock_create(hdr, iblock, &stats_changed, sblk_idx);
-                    if (!H5F_addr_defined(sblk_addr))
+                    if (!H5_addr_defined(sblk_addr))
                         HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL,
-                                    "unable to create extensible array super block")
+                                    "unable to create extensible array super block");
 
                     /* Set super block address in index block */
                     iblock->sblk_addrs[sblk_off] = sblk_addr;
                     iblock_cache_flags |= H5AC__DIRTIED_FLAG;
                 } /* end if */
                 else
-                    HGOTO_DONE(SUCCEED)
+                    HGOTO_DONE(SUCCEED);
             } /* end if */
 
             /* Protect super block */
@@ -486,14 +466,14 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                                                        thing_acc)))
                 HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL,
                             "unable to protect extensible array super block, address = %llu",
-                            (unsigned long long)iblock->sblk_addrs[sblk_off])
+                            (unsigned long long)iblock->sblk_addrs[sblk_off]);
 
             /* Compute the data block index in super block */
             dblk_idx = (size_t)(elmt_idx / sblock->dblk_nelmts);
-            HDassert(dblk_idx < sblock->ndblks);
+            assert(dblk_idx < sblock->ndblks);
 
             /* Check if the data block has been allocated on disk yet */
-            if (!H5F_addr_defined(sblock->dblk_addrs[dblk_idx])) {
+            if (!H5_addr_defined(sblock->dblk_addrs[dblk_idx])) {
                 /* Check if we are allowed to create the thing */
                 if (0 == (thing_acc & H5AC__READ_ONLY_FLAG)) { /* i.e. r/w access */
                     haddr_t dblk_addr;                         /* Address of data block created */
@@ -504,9 +484,9 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                                (dblk_idx * hdr->sblk_info[sblk_idx].dblk_nelmts);
                     dblk_addr =
                         H5EA__dblock_create(hdr, sblock, &stats_changed, dblk_off, sblock->dblk_nelmts);
-                    if (!H5F_addr_defined(dblk_addr))
+                    if (!H5_addr_defined(dblk_addr))
                         HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL,
-                                    "unable to create extensible array data block")
+                                    "unable to create extensible array data block");
 
                     /* Set data block address in index block */
                     sblock->dblk_addrs[dblk_idx] = dblk_addr;
@@ -520,12 +500,12 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                                 H5E_EARRAY, H5E_CANTDEPEND, FAIL,
                                 "unable to create flush dependency between super block and header, address "
                                 "= %llu",
-                                (unsigned long long)sblock->addr)
+                                (unsigned long long)sblock->addr);
                         sblock->has_hdr_depend = TRUE;
                     } /* end if */
                 }     /* end if */
                 else
-                    HGOTO_DONE(SUCCEED)
+                    HGOTO_DONE(SUCCEED);
             } /* end if */
 
             /* Adjust index to offset in data block */
@@ -556,21 +536,21 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                     if (0 == (thing_acc & H5AC__READ_ONLY_FLAG)) { /* i.e. r/w access */
                         /* Create the data block page */
                         if (H5EA__dblk_page_create(hdr, sblock, dblk_page_addr) < 0)
-                            HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL, "unable to create data block page")
+                            HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL, "unable to create data block page");
 
                         /* Mark data block page as initialized in super block */
                         H5VM_bit_set(sblock->page_init, page_init_idx, TRUE);
                         sblock_cache_flags |= H5AC__DIRTIED_FLAG;
                     } /* end if */
                     else
-                        HGOTO_DONE(SUCCEED)
+                        HGOTO_DONE(SUCCEED);
                 } /* end if */
 
                 /* Protect data block page */
                 if (NULL == (dblk_page = H5EA__dblk_page_protect(hdr, sblock, dblk_page_addr, thing_acc)))
                     HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL,
                                 "unable to protect extensible array data block page, address = %llu",
-                                (unsigned long long)dblk_page_addr)
+                                (unsigned long long)dblk_page_addr);
 
                 /* Check if there is already a dependency on the header */
                 if (will_extend && !dblk_page->has_hdr_depend) {
@@ -578,7 +558,7 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                         HGOTO_ERROR(H5E_EARRAY, H5E_CANTDEPEND, FAIL,
                                     "unable to create flush dependency between data block page and header, "
                                     "index = %llu",
-                                    (unsigned long long)idx)
+                                    (unsigned long long)idx);
                     dblk_page->has_hdr_depend = TRUE;
                 } /* end if */
 
@@ -594,7 +574,7 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                                                            sblock->dblk_nelmts, thing_acc)))
                     HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL,
                                 "unable to protect extensible array data block, address = %llu",
-                                (unsigned long long)sblock->dblk_addrs[dblk_idx])
+                                (unsigned long long)sblock->dblk_addrs[dblk_idx]);
 
                 /* Check if there is already a dependency on the header */
                 if (will_extend && !dblock->has_hdr_depend) {
@@ -602,7 +582,7 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
                         HGOTO_ERROR(
                             H5E_EARRAY, H5E_CANTDEPEND, FAIL,
                             "unable to create flush dependency between data block and header, index = %llu",
-                            (unsigned long long)idx)
+                            (unsigned long long)idx);
                     dblock->has_hdr_depend = TRUE;
                 } /* end if */
 
@@ -616,8 +596,8 @@ H5EA__lookup_elmt(const H5EA_t *ea, hsize_t idx, hbool_t will_extend, unsigned t
     }         /* end else */
 
     /* Sanity checks */
-    HDassert(*thing != NULL);
-    HDassert(*thing_unprot_func != NULL);
+    assert(*thing != NULL);
+    assert(*thing_unprot_func != NULL);
 
 done:
     /* Reset 'thing' info on error */
@@ -636,18 +616,19 @@ done:
     if (hdr_dirty)
         if (H5EA__hdr_modified(hdr) < 0)
             HDONE_ERROR(H5E_EARRAY, H5E_CANTMARKDIRTY, FAIL,
-                        "unable to mark extensible array header as modified")
+                        "unable to mark extensible array header as modified");
 
     /* Release resources */
     if (iblock && *thing != iblock && H5EA__iblock_unprotect(iblock, iblock_cache_flags) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array index block")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array index block");
     /* (Note: super blocks don't contain elements, so don't have a '*thing != sblock' check) */
     if (sblock && H5EA__sblock_unprotect(sblock, sblock_cache_flags) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array super block")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array super block");
     if (dblock && *thing != dblock && H5EA__dblock_unprotect(dblock, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array data block")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array data block");
     if (dblk_page && *thing != dblk_page && H5EA__dblk_page_unprotect(dblk_page, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array data block page")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL,
+                    "unable to release extensible array data block page");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA__lookup_elmt() */
@@ -659,9 +640,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep  9 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -679,8 +657,8 @@ H5EA_set(const H5EA_t *ea, hsize_t idx, const void *elmt)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(hdr);
+    assert(ea);
+    assert(hdr);
 
     /* Set the shared array header's file context for this operation */
     hdr->f = ea->f;
@@ -689,12 +667,12 @@ H5EA_set(const H5EA_t *ea, hsize_t idx, const void *elmt)
     will_extend = (idx >= hdr->stats.stored.max_idx_set);
     if (H5EA__lookup_elmt(ea, idx, will_extend, H5AC__NO_FLAGS_SET, &thing, &thing_elmt_buf, &thing_elmt_idx,
                           &thing_unprot_func) < 0)
-        HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL, "unable to protect array metadata")
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL, "unable to protect array metadata");
 
     /* Sanity check */
-    HDassert(thing);
-    HDassert(thing_elmt_buf);
-    HDassert(thing_unprot_func);
+    assert(thing);
+    assert(thing_elmt_buf);
+    assert(thing_unprot_func);
 
     /* Set element in thing's element buffer */
     H5MM_memcpy(thing_elmt_buf + (hdr->cparam.cls->nat_elmt_size * thing_elmt_idx), elmt,
@@ -707,13 +685,13 @@ H5EA_set(const H5EA_t *ea, hsize_t idx, const void *elmt)
         hdr->stats.stored.max_idx_set = idx + 1;
         if (H5EA__hdr_modified(hdr) < 0)
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTMARKDIRTY, FAIL,
-                        "unable to mark extensible array header as modified")
+                        "unable to mark extensible array header as modified");
     }
 
 done:
     /* Release resources */
     if (thing && (thing_unprot_func)(thing, thing_cache_flags) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array metadata")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array metadata");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA_set() */
@@ -725,9 +703,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep 11 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -742,14 +717,14 @@ H5EA_get(const H5EA_t *ea, hsize_t idx, void *elmt)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(hdr);
+    assert(ea);
+    assert(hdr);
 
     /* Check for element beyond max. element in array */
     if (idx >= hdr->stats.stored.max_idx_set) {
         /* Call the class's 'fill' callback */
         if ((hdr->cparam.cls->fill)(elmt, (size_t)1) < 0)
-            HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value")
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value");
     } /* end if */
     else {
         uint8_t *thing_elmt_buf; /* Pointer to the element buffer for the array metadata */
@@ -761,13 +736,13 @@ H5EA_get(const H5EA_t *ea, hsize_t idx, void *elmt)
         /* Look up the array metadata containing the element we want to set */
         if (H5EA__lookup_elmt(ea, idx, FALSE, H5AC__READ_ONLY_FLAG, &thing, &thing_elmt_buf, &thing_elmt_idx,
                               &thing_unprot_func) < 0)
-            HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL, "unable to protect array metadata")
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL, "unable to protect array metadata");
 
         /* Check if the thing holding the element has been created yet */
         if (NULL == thing) {
             /* Call the class's 'fill' callback */
             if ((hdr->cparam.cls->fill)(elmt, (size_t)1) < 0)
-                HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value")
+                HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value");
         } /* end if */
         else
             /* Get element from thing's element buffer */
@@ -778,7 +753,7 @@ H5EA_get(const H5EA_t *ea, hsize_t idx, void *elmt)
 done:
     /* Release thing */
     if (thing && (thing_unprot_func)(thing, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array metadata")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array metadata");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA_get() */
@@ -791,9 +766,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		May 27 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -805,9 +777,9 @@ H5EA_depend(H5EA_t *ea, H5AC_proxy_entry_t *parent)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(hdr);
-    HDassert(parent);
+    assert(ea);
+    assert(hdr);
+    assert(parent);
 
     /*
      * Check to see if a flush dependency between the extensible array
@@ -816,14 +788,14 @@ H5EA_depend(H5EA_t *ea, H5AC_proxy_entry_t *parent)
      */
     if (NULL == hdr->parent) {
         /* Sanity check */
-        HDassert(hdr->top_proxy);
+        assert(hdr->top_proxy);
 
         /* Set the shared array header's file context for this operation */
         hdr->f = ea->f;
 
         /* Add the extensible array as a child of the parent (proxy) */
         if (H5AC_proxy_entry_add_child(parent, hdr->f, hdr->top_proxy) < 0)
-            HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, FAIL, "unable to add extensible array as child of proxy")
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, FAIL, "unable to add extensible array as child of proxy");
         hdr->parent = parent;
     }
 
@@ -838,9 +810,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug 21 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -853,7 +822,7 @@ H5EA_close(H5EA_t *ea)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(ea);
+    assert(ea);
 
     /* Close the header, if it was set */
     if (ea->hdr) {
@@ -886,19 +855,19 @@ H5EA_close(H5EA_t *ea)
                 /* Check the header's status in the metadata cache */
                 if (H5AC_get_entry_status(ea->f, ea_addr, &hdr_status) < 0)
                     HGOTO_ERROR(H5E_EARRAY, H5E_CANTGET, FAIL,
-                                "unable to check metadata cache status for extensible array header")
+                                "unable to check metadata cache status for extensible array header");
 
                 /* Sanity checks on header */
-                HDassert(hdr_status & H5AC_ES__IN_CACHE);
-                HDassert(hdr_status & H5AC_ES__IS_PINNED);
-                HDassert(!(hdr_status & H5AC_ES__IS_PROTECTED));
+                assert(hdr_status & H5AC_ES__IN_CACHE);
+                assert(hdr_status & H5AC_ES__IS_PINNED);
+                assert(!(hdr_status & H5AC_ES__IS_PROTECTED));
             }
 #endif /* NDEBUG */
 
             /* Lock the array header into memory */
             /* (OK to pass in NULL for callback context, since we know the header must be in the cache) */
             if (NULL == (hdr = H5EA__hdr_protect(ea->f, ea_addr, NULL, H5AC__NO_FLAGS_SET)))
-                HGOTO_ERROR(H5E_EARRAY, H5E_CANTLOAD, FAIL, "unable to load extensible array header")
+                HGOTO_ERROR(H5E_EARRAY, H5E_CANTLOAD, FAIL, "unable to load extensible array header");
 
             /* Set the shared array header's file context for this operation */
             hdr->f = ea->f;
@@ -909,11 +878,11 @@ H5EA_close(H5EA_t *ea)
              */
             if (H5EA__hdr_decr(ea->hdr) < 0)
                 HGOTO_ERROR(H5E_EARRAY, H5E_CANTDEC, FAIL,
-                            "can't decrement reference count on shared array header")
+                            "can't decrement reference count on shared array header");
 
             /* Delete array, starting with header (unprotects header) */
             if (H5EA__hdr_delete(hdr) < 0)
-                HGOTO_ERROR(H5E_EARRAY, H5E_CANTDELETE, FAIL, "unable to delete extensible array")
+                HGOTO_ERROR(H5E_EARRAY, H5E_CANTDELETE, FAIL, "unable to delete extensible array");
         } /* end if */
         else {
             /* Decrement the reference count on the array header */
@@ -922,7 +891,7 @@ H5EA_close(H5EA_t *ea)
              */
             if (H5EA__hdr_decr(ea->hdr) < 0)
                 HGOTO_ERROR(H5E_EARRAY, H5E_CANTDEC, FAIL,
-                            "can't decrement reference count on shared array header")
+                            "can't decrement reference count on shared array header");
         } /* end else */
     }     /* end if */
 
@@ -940,9 +909,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug 28 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -954,13 +920,13 @@ H5EA_delete(H5F_t *f, haddr_t ea_addr, void *ctx_udata)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(ea_addr));
+    assert(f);
+    assert(H5_addr_defined(ea_addr));
 
     /* Lock the array header into memory */
     if (NULL == (hdr = H5EA__hdr_protect(f, ea_addr, ctx_udata, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL,
-                    "unable to protect extensible array header, address = %llu", (unsigned long long)ea_addr)
+                    "unable to protect extensible array header, address = %llu", (unsigned long long)ea_addr);
 
     /* Check for files using shared array header */
     if (hdr->file_rc)
@@ -971,14 +937,14 @@ H5EA_delete(H5F_t *f, haddr_t ea_addr, void *ctx_udata)
 
         /* Delete array now, starting with header (unprotects header) */
         if (H5EA__hdr_delete(hdr) < 0)
-            HGOTO_ERROR(H5E_EARRAY, H5E_CANTDELETE, FAIL, "unable to delete extensible array")
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTDELETE, FAIL, "unable to delete extensible array");
         hdr = NULL;
     }
 
 done:
     /* Unprotect the header if an error occurred */
     if (hdr && H5EA__hdr_unprotect(hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array header")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array header");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA_delete() */
@@ -991,8 +957,6 @@ done:
  *
  * Return:      H5_ITER_CONT/H5_ITER_ERROR
  *
- * Programmer:  Vailin Choi; Feb 2015
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1005,20 +969,20 @@ H5EA_iterate(H5EA_t *ea, H5EA_operator_t op, void *udata)
     FUNC_ENTER_NOAPI(H5_ITER_ERROR)
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(op);
-    HDassert(udata);
+    assert(ea);
+    assert(op);
+    assert(udata);
 
     /* Allocate space for a native array element */
     if (NULL == (elmt = H5FL_BLK_MALLOC(ea_native_elmt, ea->hdr->cparam.cls->nat_elmt_size)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, H5_ITER_ERROR,
-                    "memory allocation failed for extensible array element")
+                    "memory allocation failed for extensible array element");
 
     /* Iterate over all elements in array */
     for (u = 0; u < ea->hdr->stats.stored.max_idx_set && ret_value == H5_ITER_CONT; u++) {
         /* Get array element */
         if (H5EA_get(ea, u, elmt) < 0)
-            HGOTO_ERROR(H5E_EARRAY, H5E_CANTGET, H5_ITER_ERROR, "unable to delete fixed array")
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTGET, H5_ITER_ERROR, "unable to delete fixed array");
 
         /* Make callback */
         if ((ret_value = (*op)(u, elmt, udata)) < 0) {
@@ -1052,8 +1016,8 @@ H5EA_patch_file(H5EA_t *ea, H5F_t *f)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(ea);
-    HDassert(f);
+    assert(ea);
+    assert(f);
 
     if (ea->f != f || ea->hdr->f != f)
         ea->f = ea->hdr->f = f;
