@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -14,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5EAiblock.c
- *			Sep  9 2008
- *			Quincey Koziol
  *
  * Purpose:		Index block routines for extensible arrays.
  *
@@ -86,9 +83,6 @@ H5FL_SEQ_DEFINE_STATIC(haddr_t);
  *
  * Return:	Non-NULL pointer to index block on success/NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  9 2008
- *
  *-------------------------------------------------------------------------
  */
 H5EA_iblock_t *
@@ -100,16 +94,16 @@ H5EA__iblock_alloc(H5EA_hdr_t *hdr)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Allocate memory for the index block */
     if (NULL == (iblock = H5FL_CALLOC(H5EA_iblock_t)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL,
-                    "memory allocation failed for extensible array index block")
+                    "memory allocation failed for extensible array index block");
 
     /* Share common array information */
     if (H5EA__hdr_incr(hdr) < 0)
-        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header")
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header");
     iblock->hdr = hdr;
 
     /* Set non-zero internal fields */
@@ -126,19 +120,19 @@ H5EA__iblock_alloc(H5EA_hdr_t *hdr)
             (iblock->elmts = H5FL_BLK_MALLOC(
                  idx_blk_elmt_buf, (size_t)(hdr->cparam.idx_blk_elmts * hdr->cparam.cls->nat_elmt_size))))
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL,
-                        "memory allocation failed for index block data element buffer")
+                        "memory allocation failed for index block data element buffer");
 
     /* Allocate buffer for data block addresses in index block */
     if (iblock->ndblk_addrs > 0)
         if (NULL == (iblock->dblk_addrs = H5FL_SEQ_MALLOC(haddr_t, iblock->ndblk_addrs)))
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL,
-                        "memory allocation failed for index block data block addresses")
+                        "memory allocation failed for index block data block addresses");
 
     /* Allocate buffer for super block addresses in index block */
     if (iblock->nsblk_addrs > 0)
         if (NULL == (iblock->sblk_addrs = H5FL_SEQ_MALLOC(haddr_t, iblock->nsblk_addrs)))
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL,
-                        "memory allocation failed for index block super block addresses")
+                        "memory allocation failed for index block super block addresses");
 
     /* Set the return value */
     ret_value = iblock;
@@ -146,7 +140,7 @@ H5EA__iblock_alloc(H5EA_hdr_t *hdr)
 done:
     if (!ret_value)
         if (iblock && H5EA__iblock_dest(iblock) < 0)
-            HDONE_ERROR(H5E_EARRAY, H5E_CANTFREE, NULL, "unable to destroy extensible array index block")
+            HDONE_ERROR(H5E_EARRAY, H5E_CANTFREE, NULL, "unable to destroy extensible array index block");
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA__iblock_alloc() */
 
@@ -157,9 +151,6 @@ done:
  *
  * Return:	Valid file address on success/HADDR_UNDEF on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  9 2008
- *
  *-------------------------------------------------------------------------
  */
 haddr_t
@@ -173,13 +164,13 @@ H5EA__iblock_create(H5EA_hdr_t *hdr, hbool_t *stats_changed)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(hdr);
-    HDassert(stats_changed);
+    assert(hdr);
+    assert(stats_changed);
 
     /* Allocate the index block */
     if (NULL == (iblock = H5EA__iblock_alloc(hdr)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, HADDR_UNDEF,
-                    "memory allocation failed for extensible array index block")
+                    "memory allocation failed for extensible array index block");
 
     /* Set size of index block on disk */
     iblock->size = H5EA_IBLOCK_SIZE(iblock);
@@ -187,7 +178,7 @@ H5EA__iblock_create(H5EA_hdr_t *hdr, hbool_t *stats_changed)
     /* Allocate space for the index block on disk */
     if (HADDR_UNDEF == (iblock_addr = H5MF_alloc(hdr->f, H5FD_MEM_EARRAY_IBLOCK, (hsize_t)iblock->size)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, HADDR_UNDEF,
-                    "file allocation failed for extensible array index block")
+                    "file allocation failed for extensible array index block");
     iblock->addr = iblock_addr;
 
     /* Clear any elements in index block to fill value */
@@ -195,7 +186,7 @@ H5EA__iblock_create(H5EA_hdr_t *hdr, hbool_t *stats_changed)
         /* Call the class's 'fill' callback */
         if ((hdr->cparam.cls->fill)(iblock->elmts, (size_t)hdr->cparam.idx_blk_elmts) < 0)
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, HADDR_UNDEF,
-                        "can't set extensible array index block elements to class's fill value")
+                        "can't set extensible array index block elements to class's fill value");
     } /* end if */
 
     /* Reset any data block addresses in the index block */
@@ -217,20 +208,20 @@ H5EA__iblock_create(H5EA_hdr_t *hdr, hbool_t *stats_changed)
     /* Cache the new extensible array index block */
     if (H5AC_insert_entry(hdr->f, H5AC_EARRAY_IBLOCK, iblock_addr, iblock, H5AC__NO_FLAGS_SET) < 0)
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTINSERT, HADDR_UNDEF,
-                    "can't add extensible array index block to cache")
+                    "can't add extensible array index block to cache");
     inserted = TRUE;
 
     /* Add index block as child of 'top' proxy */
     if (hdr->top_proxy) {
         if (H5AC_proxy_entry_add_child(hdr->top_proxy, hdr->f, iblock) < 0)
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, HADDR_UNDEF,
-                        "unable to add extensible array entry as child of array proxy")
+                        "unable to add extensible array entry as child of array proxy");
         iblock->top_proxy = hdr->top_proxy;
     } /* end if */
 
     /* Update extensible array index block statistics */
-    HDassert(0 == hdr->stats.computed.nindex_blks);
-    HDassert(0 == hdr->stats.computed.index_blk_size);
+    assert(0 == hdr->stats.computed.nindex_blks);
+    assert(0 == hdr->stats.computed.index_blk_size);
     hdr->stats.computed.nindex_blks    = 1;
     hdr->stats.computed.index_blk_size = iblock->size;
 
@@ -244,24 +235,24 @@ H5EA__iblock_create(H5EA_hdr_t *hdr, hbool_t *stats_changed)
     ret_value = iblock_addr;
 
 done:
-    if (!H5F_addr_defined(ret_value))
+    if (!H5_addr_defined(ret_value))
         if (iblock) {
             /* Remove from cache, if inserted */
             if (inserted)
                 if (H5AC_remove_entry(iblock) < 0)
                     HDONE_ERROR(H5E_EARRAY, H5E_CANTREMOVE, HADDR_UNDEF,
-                                "unable to remove extensible array index block from cache")
+                                "unable to remove extensible array index block from cache");
 
             /* Release index block's disk space */
-            if (H5F_addr_defined(iblock->addr) &&
+            if (H5_addr_defined(iblock->addr) &&
                 H5MF_xfree(hdr->f, H5FD_MEM_EARRAY_IBLOCK, iblock->addr, (hsize_t)iblock->size) < 0)
                 HDONE_ERROR(H5E_EARRAY, H5E_CANTFREE, HADDR_UNDEF,
-                            "unable to release file space for extensible array index block")
+                            "unable to release file space for extensible array index block");
 
             /* Destroy index block */
             if (H5EA__iblock_dest(iblock) < 0)
                 HDONE_ERROR(H5E_EARRAY, H5E_CANTFREE, HADDR_UNDEF,
-                            "unable to destroy extensible array index block")
+                            "unable to destroy extensible array index block");
         } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -274,9 +265,6 @@ done:
  *
  * Return:	Non-NULL pointer to index block on success/NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  9 2008
- *
  *-------------------------------------------------------------------------
  */
 H5EA_iblock_t *
@@ -288,24 +276,24 @@ H5EA__iblock_protect(H5EA_hdr_t *hdr, unsigned flags)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(hdr);
+    assert(hdr);
 
     /* only the H5AC__READ_ONLY_FLAG may be set */
-    HDassert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
+    assert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
 
     /* Protect the index block */
     if (NULL ==
         (iblock = (H5EA_iblock_t *)H5AC_protect(hdr->f, H5AC_EARRAY_IBLOCK, hdr->idx_blk_addr, hdr, flags)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, NULL,
                     "unable to protect extensible array index block, address = %llu",
-                    (unsigned long long)hdr->idx_blk_addr)
+                    (unsigned long long)hdr->idx_blk_addr);
 
     /* Create top proxy, if it doesn't exist */
     if (hdr->top_proxy && NULL == iblock->top_proxy) {
         /* Add index block as child of 'top' proxy */
         if (H5AC_proxy_entry_add_child(hdr->top_proxy, hdr->f, iblock) < 0)
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, NULL,
-                        "unable to add extensible array entry as child of array proxy")
+                        "unable to add extensible array entry as child of array proxy");
         iblock->top_proxy = hdr->top_proxy;
     } /* end if */
 
@@ -320,7 +308,7 @@ done:
             H5AC_unprotect(hdr->f, H5AC_EARRAY_IBLOCK, iblock->addr, iblock, H5AC__NO_FLAGS_SET) < 0)
             HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, NULL,
                         "unable to unprotect extensible array index block, address = %llu",
-                        (unsigned long long)iblock->addr)
+                        (unsigned long long)iblock->addr);
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -333,9 +321,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  9 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -346,13 +331,13 @@ H5EA__iblock_unprotect(H5EA_iblock_t *iblock, unsigned cache_flags)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(iblock);
+    assert(iblock);
 
     /* Unprotect the index block */
     if (H5AC_unprotect(iblock->hdr->f, H5AC_EARRAY_IBLOCK, iblock->addr, iblock, cache_flags) < 0)
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL,
                     "unable to unprotect extensible array index block, address = %llu",
-                    (unsigned long long)iblock->addr)
+                    (unsigned long long)iblock->addr);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -365,9 +350,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep  9 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -379,14 +361,14 @@ H5EA__iblock_delete(H5EA_hdr_t *hdr)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(hdr);
-    HDassert(H5F_addr_defined(hdr->idx_blk_addr));
+    assert(hdr);
+    assert(H5_addr_defined(hdr->idx_blk_addr));
 
     /* Protect index block */
     if (NULL == (iblock = H5EA__iblock_protect(hdr, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, FAIL,
                     "unable to protect extensible array index block, address = %llu",
-                    (unsigned long long)hdr->idx_blk_addr)
+                    (unsigned long long)hdr->idx_blk_addr);
 
     /* Check for index block having data block pointers */
     if (iblock->ndblk_addrs > 0) {
@@ -398,12 +380,12 @@ H5EA__iblock_delete(H5EA_hdr_t *hdr)
         sblk_idx = dblk_idx = 0;
         for (u = 0; u < iblock->ndblk_addrs; u++) {
             /* Check for data block existing */
-            if (H5F_addr_defined(iblock->dblk_addrs[u])) {
+            if (H5_addr_defined(iblock->dblk_addrs[u])) {
                 /* Delete data block */
                 if (H5EA__dblock_delete(hdr, iblock, iblock->dblk_addrs[u],
                                         hdr->sblk_info[sblk_idx].dblk_nelmts) < 0)
                     HGOTO_ERROR(H5E_EARRAY, H5E_CANTDELETE, FAIL,
-                                "unable to delete extensible array data block")
+                                "unable to delete extensible array data block");
                 iblock->dblk_addrs[u] = HADDR_UNDEF;
             } /* end if */
 
@@ -425,12 +407,12 @@ H5EA__iblock_delete(H5EA_hdr_t *hdr)
         /* Iterate over super blocks */
         for (u = 0; u < iblock->nsblk_addrs; u++) {
             /* Check for data block existing */
-            if (H5F_addr_defined(iblock->sblk_addrs[u])) {
+            if (H5_addr_defined(iblock->sblk_addrs[u])) {
                 /* Delete super block */
                 if (H5EA__sblock_delete(hdr, iblock, iblock->sblk_addrs[u], (unsigned)(u + iblock->nsblks)) <
                     0)
                     HGOTO_ERROR(H5E_EARRAY, H5E_CANTDELETE, FAIL,
-                                "unable to delete extensible array super block")
+                                "unable to delete extensible array super block");
                 iblock->sblk_addrs[u] = HADDR_UNDEF;
             }
         }
@@ -440,7 +422,7 @@ done:
     /* Finished deleting index block in metadata cache */
     if (iblock && H5EA__iblock_unprotect(iblock, H5AC__DIRTIED_FLAG | H5AC__DELETED_FLAG |
                                                      H5AC__FREE_FILE_SPACE_FLAG) < 0)
-        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array index block")
+        HDONE_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array index block");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5EA__iblock_delete() */
@@ -452,9 +434,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep 11 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -465,21 +444,21 @@ H5EA__iblock_dest(H5EA_iblock_t *iblock)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(iblock);
+    assert(iblock);
 
     /* Check if shared header field has been initialized */
     if (iblock->hdr) {
         /* Check if we've got elements in the index block */
         if (iblock->elmts) {
             /* Free buffer for index block elements */
-            HDassert(iblock->hdr->cparam.idx_blk_elmts > 0);
+            assert(iblock->hdr->cparam.idx_blk_elmts > 0);
             iblock->elmts = H5FL_BLK_FREE(idx_blk_elmt_buf, iblock->elmts);
         } /* end if */
 
         /* Check if we've got data block addresses in the index block */
         if (iblock->dblk_addrs) {
             /* Free buffer for index block data block addresses */
-            HDassert(iblock->ndblk_addrs > 0);
+            assert(iblock->ndblk_addrs > 0);
             iblock->dblk_addrs  = H5FL_SEQ_FREE(haddr_t, iblock->dblk_addrs);
             iblock->ndblk_addrs = 0;
         } /* end if */
@@ -487,7 +466,7 @@ H5EA__iblock_dest(H5EA_iblock_t *iblock)
         /* Check if we've got super block addresses in the index block */
         if (iblock->sblk_addrs) {
             /* Free buffer for index block super block addresses */
-            HDassert(iblock->nsblk_addrs > 0);
+            assert(iblock->nsblk_addrs > 0);
             iblock->sblk_addrs  = H5FL_SEQ_FREE(haddr_t, iblock->sblk_addrs);
             iblock->nsblk_addrs = 0;
         } /* end if */
@@ -495,12 +474,12 @@ H5EA__iblock_dest(H5EA_iblock_t *iblock)
         /* Decrement reference count on shared info */
         if (H5EA__hdr_decr(iblock->hdr) < 0)
             HGOTO_ERROR(H5E_EARRAY, H5E_CANTDEC, FAIL,
-                        "can't decrement reference count on shared array header")
+                        "can't decrement reference count on shared array header");
         iblock->hdr = NULL;
     } /* end if */
 
     /* Sanity check */
-    HDassert(NULL == iblock->top_proxy);
+    assert(NULL == iblock->top_proxy);
 
     /* Free the index block itself */
     iblock = H5FL_FREE(H5EA_iblock_t, iblock);
