@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5ESint.c
- *              Apr  8 2020
- *              Quincey Koziol
  *
  * Purpose:     Internal "event set" routines for managing asynchronous
  *                      operations.
@@ -141,7 +139,7 @@ H5ES_init(void)
 
     /* Initialize the ID group for the event set IDs */
     if (H5I_register_type(H5I_EVENTSET_CLS) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINIT, FAIL, "unable to initialize interface")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINIT, FAIL, "unable to initialize interface");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -156,9 +154,6 @@ done:
  *                          affect other interfaces; zero otherwise.
  *              Failure:    Negative
  *
- * Programmer:  Quincey Koziol
- *              Monday, April 6, 2020
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -181,9 +176,6 @@ H5ES_term_package(void)
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, April 6, 2020
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -195,7 +187,7 @@ H5ES__close_cb(void *_es, void H5_ATTR_UNUSED **rt)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
+    assert(es);
 
     /* Close the event set object */
     if (H5ES__close(es) < 0)
@@ -213,9 +205,6 @@ done:
  * Return:      Success:    Pointer to an event set struct
  *              Failure:    NULL
  *
- * Programmer:  Quincey Koziol
- *              Wednesday, April 8, 2020
- *
  *-------------------------------------------------------------------------
  */
 H5ES_t *
@@ -228,7 +217,7 @@ H5ES__create(void)
 
     /* Allocate space for new event set */
     if (NULL == (es = H5FL_CALLOC(H5ES_t)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, NULL, "can't allocate event set object")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, NULL, "can't allocate event set object");
 
     /* Set the return value */
     ret_value = es;
@@ -236,7 +225,7 @@ H5ES__create(void)
 done:
     if (!ret_value)
         if (es && H5ES__close(es) < 0)
-            HDONE_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, NULL, "unable to free event set")
+            HDONE_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, NULL, "unable to free event set");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5ES__create() */
@@ -248,9 +237,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Friday, December 11, 2020
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -264,11 +250,11 @@ H5ES__insert(H5ES_t *es, H5VL_t *connector, void *request_token, const char *app
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
+    assert(es);
 
     /* Create new event */
     if (NULL == (ev = H5ES__event_new(connector, request_token)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTCREATE, FAIL, "can't create event object")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTCREATE, FAIL, "can't create event object");
 
     /* Copy the app source information */
     /* The 'app_func' & 'app_file' strings are statically allocated (by the compiler)
@@ -291,9 +277,9 @@ H5ES__insert(H5ES_t *es, H5VL_t *connector, void *request_token, const char *app
      * there's no need to duplicate it.
      */
     ev->op_info.api_name = caller;
-    HDassert(ev->op_info.api_args == NULL);
+    assert(ev->op_info.api_args == NULL);
     if (api_args && NULL == (ev->op_info.api_args = H5MM_xstrdup(api_args)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, FAIL, "can't copy API routine arguments")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, FAIL, "can't copy API routine arguments");
 
     /* Append fully initialized event onto the event set's 'active' list */
     H5ES__list_append(&es->active, ev);
@@ -302,7 +288,7 @@ H5ES__insert(H5ES_t *es, H5VL_t *connector, void *request_token, const char *app
     /* Invoke the event set's 'insert' callback, if present */
     if (es->ins_func)
         if ((es->ins_func)(&ev->op_info, es->ins_ctx) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CALLBACK, FAIL, "'insert' callback for event set failed")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CALLBACK, FAIL, "'insert' callback for event set failed");
 
 done:
     /* Release resources on error */
@@ -311,7 +297,7 @@ done:
             if (ev_inserted)
                 H5ES__list_remove(&es->active, ev);
             if (H5ES__event_free(ev) < 0)
-                HDONE_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, FAIL, "unable to release event")
+                HDONE_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, FAIL, "unable to release event");
         }
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -324,9 +310,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Wednesday, April 8, 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -345,51 +328,51 @@ H5ES_insert(hid_t es_id, H5VL_t *connector, void *token, const char *caller, con
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(connector);
-    HDassert(token);
-    HDassert(caller);
-    HDassert(caller_args);
+    assert(connector);
+    assert(token);
+    assert(caller);
+    assert(caller_args);
 
     /* Get event set */
     if (NULL == (es = (H5ES_t *)H5I_object_verify(es_id, H5I_EVENTSET)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an event set")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an event set");
 
     /* Check for errors in event set */
     if (es->err_occurred)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINSERT, FAIL, "event set has failed operations")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINSERT, FAIL, "event set has failed operations");
 
     /* Start working on the API routines arguments */
-    HDva_start(ap, caller_args);
+    va_start(ap, caller_args);
     arg_started = TRUE;
 
     /* Copy the app source information */
-    (void)HDva_arg(ap, char *); /* Toss the 'app_file' parameter name */
-    app_file = HDva_arg(ap, char *);
-    (void)HDva_arg(ap, char *); /* Toss the 'app_func' parameter name */
-    app_func = HDva_arg(ap, char *);
-    (void)HDva_arg(ap, char *); /* Toss the 'app_line' parameter name */
-    app_line = HDva_arg(ap, unsigned);
+    (void)va_arg(ap, char *); /* Toss the 'app_file' parameter name */
+    app_file = va_arg(ap, char *);
+    (void)va_arg(ap, char *); /* Toss the 'app_func' parameter name */
+    app_func = va_arg(ap, char *);
+    (void)va_arg(ap, char *); /* Toss the 'app_line' parameter name */
+    app_line = va_arg(ap, unsigned);
 
     /* Create the string for the API routine's arguments */
     if (NULL == (rs = H5RS_create(NULL)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, FAIL, "can't allocate ref-counted string")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, FAIL, "can't allocate ref-counted string");
 
     /* Copy the string for the API routine's arguments */
     /* (skip the six characters from the app's file, function and line # arguments) */
-    HDassert(0 == HDstrncmp(caller_args, "*s*sIu", 6));
+    assert(0 == HDstrncmp(caller_args, "*s*sIu", 6));
     if (H5_trace_args(rs, caller_args + 6, ap) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTSET, FAIL, "can't create formatted API arguments")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTSET, FAIL, "can't create formatted API arguments");
     if (NULL == (api_args = H5RS_get_str(rs)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTGET, FAIL, "can't get pointer to formatted API arguments")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTGET, FAIL, "can't get pointer to formatted API arguments");
 
     /* Insert the operation into the event set */
     if (H5ES__insert(es, connector, token, app_file, app_func, app_line, caller, api_args) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINSERT, FAIL, "event set has failed operations")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINSERT, FAIL, "event set has failed operations");
 
 done:
     /* Clean up */
     if (arg_started)
-        HDva_end(ap);
+        va_end(ap);
     if (rs)
         H5RS_decr(rs);
 
@@ -403,9 +386,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Friday, December 11, 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -416,13 +396,13 @@ H5ES__insert_request(H5ES_t *es, H5VL_t *connector, void *token)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
-    HDassert(connector);
-    HDassert(token);
+    assert(es);
+    assert(connector);
+    assert(token);
 
     /* Insert an 'anonymous' operation into the event set */
     if (H5ES__insert(es, connector, token, NULL, NULL, 0, NULL, NULL) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINSERT, FAIL, "event set has failed operations")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTINSERT, FAIL, "event set has failed operations");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -436,9 +416,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Neil Fortner
- *              Tuesday, November 23, 2021
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -450,9 +427,9 @@ H5ES__get_requests_cb(H5ES_event_t *ev, void *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(ev);
-    HDassert(ctx);
-    HDassert(ctx->i < ctx->array_len);
+    assert(ev);
+    assert(ctx);
+    assert(ctx->i < ctx->array_len);
 
     /* Get the connector ID for the event */
     if (ctx->connector_ids)
@@ -476,9 +453,6 @@ H5ES__get_requests_cb(H5ES_event_t *ev, void *_ctx)
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Neil Fortner
- *              Tuesday, November 23, 2021
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -490,9 +464,9 @@ H5ES__get_requests(H5ES_t *es, H5_iter_order_t order, hid_t *connector_ids, void
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
-    HDassert(array_len > 0);
-    HDassert(requests || connector_ids);
+    assert(es);
+    assert(array_len > 0);
+    assert(requests || connector_ids);
 
     /* Set up context for iterator callbacks */
     ctx.connector_ids = connector_ids;
@@ -502,7 +476,7 @@ H5ES__get_requests(H5ES_t *es, H5_iter_order_t order, hid_t *connector_ids, void
 
     /* Iterate over the events in the set */
     if (H5ES__list_iterate(&es->active, order, H5ES__get_requests_cb, &ctx) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -515,9 +489,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Thursday, October 15, 2020
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -526,9 +497,9 @@ H5ES__handle_fail(H5ES_t *es, H5ES_event_t *ev)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(es);
-    HDassert(es->active.head);
-    HDassert(ev);
+    assert(es);
+    assert(es->active.head);
+    assert(ev);
 
     /* Set error flag for event set */
     es->err_occurred = TRUE;
@@ -549,9 +520,6 @@ H5ES__handle_fail(H5ES_t *es, H5ES_event_t *ev)
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Friday, December 11, 2020
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -564,10 +532,10 @@ H5ES__op_complete(H5ES_t *es, H5ES_event_t *ev, H5VL_request_status_t ev_status)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
-    HDassert(ev);
-    HDassert(H5VL_REQUEST_STATUS_SUCCEED == ev_status || H5VL_REQUEST_STATUS_FAIL == ev_status ||
-             H5VL_REQUEST_STATUS_CANCELED == ev_status);
+    assert(es);
+    assert(ev);
+    assert(H5VL_REQUEST_STATUS_SUCCEED == ev_status || H5VL_REQUEST_STATUS_FAIL == ev_status ||
+           H5VL_REQUEST_STATUS_CANCELED == ev_status);
 
     /* Handle each form of event completion */
     if (H5VL_REQUEST_STATUS_SUCCEED == ev_status || H5VL_REQUEST_STATUS_CANCELED == ev_status) {
@@ -588,19 +556,19 @@ H5ES__op_complete(H5ES_t *es, H5ES_event_t *ev, H5VL_request_status_t ev_status)
                 /* Retrieve the execution time info */
                 if (H5VL_request_specific(ev->request, &vol_cb_args) < 0)
                     HGOTO_ERROR(H5E_EVENTSET, H5E_CANTGET, FAIL,
-                                "unable to retrieve execution time info for operation")
+                                "unable to retrieve execution time info for operation");
             }
             else
                 /* Translate status */
                 op_status = H5ES_STATUS_CANCELED;
 
             if ((es->comp_func)(&ev->op_info, op_status, H5I_INVALID_HID, es->comp_ctx) < 0)
-                HGOTO_ERROR(H5E_EVENTSET, H5E_CALLBACK, FAIL, "'complete' callback for event set failed")
+                HGOTO_ERROR(H5E_EVENTSET, H5E_CALLBACK, FAIL, "'complete' callback for event set failed");
         } /* end if */
 
         /* Event success or cancellation */
         if (H5ES__event_completed(ev, &es->active) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, FAIL, "unable to release completed event")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, FAIL, "unable to release completed event");
     } /* end if */
     else if (H5VL_REQUEST_STATUS_FAIL == ev_status) {
         /* Invoke the event set's 'complete' callback, if present */
@@ -611,21 +579,21 @@ H5ES__op_complete(H5ES_t *es, H5ES_event_t *ev, H5VL_request_status_t ev_status)
 
             /* Retrieve the error stack for the operation */
             if (H5VL_request_specific(ev->request, &vol_cb_args) < 0)
-                HGOTO_ERROR(H5E_EVENTSET, H5E_CANTGET, FAIL, "unable to retrieve error stack for operation")
+                HGOTO_ERROR(H5E_EVENTSET, H5E_CANTGET, FAIL, "unable to retrieve error stack for operation");
 
             /* Set values */
             err_stack_id = vol_cb_args.args.get_err_stack.err_stack_id;
 
             if ((es->comp_func)(&ev->op_info, H5ES_STATUS_FAIL, err_stack_id, es->comp_ctx) < 0)
-                HGOTO_ERROR(H5E_EVENTSET, H5E_CALLBACK, FAIL, "'complete' callback for event set failed")
+                HGOTO_ERROR(H5E_EVENTSET, H5E_CALLBACK, FAIL, "'complete' callback for event set failed");
         } /* end if */
 
         /* Handle failure */
         if (H5ES__handle_fail(es, ev) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTSET, FAIL, "unable to handle failed event")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTSET, FAIL, "unable to handle failed event");
     } /* end else-if */
     else
-        HGOTO_ERROR(H5E_EVENTSET, H5E_BADVALUE, FAIL, "unknown event status?!?")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_BADVALUE, FAIL, "unknown event status?!?");
 
 done:
     /* Clean up */
@@ -644,9 +612,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Sunday, November 7, 2020
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -660,14 +625,14 @@ H5ES__wait_cb(H5ES_event_t *ev, void *_ctx)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(ev);
-    HDassert(ctx);
+    assert(ev);
+    assert(ctx);
 
     /* Wait on the request */
     if (ctx->timeout != H5ES_WAIT_NONE && ctx->timeout != H5ES_WAIT_FOREVER)
         start_time = H5_now_usec();
     if (H5VL_request_wait(ev->request, ctx->timeout, &ev_status) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTWAIT, H5_ITER_ERROR, "unable to test operation")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTWAIT, H5_ITER_ERROR, "unable to test operation");
     if (ctx->timeout != H5ES_WAIT_NONE && ctx->timeout != H5ES_WAIT_FOREVER)
         elapsed_time = H5_now_usec() - start_time;
 
@@ -675,7 +640,7 @@ H5ES__wait_cb(H5ES_event_t *ev, void *_ctx)
     if (ev_status == H5VL_REQUEST_STATUS_FAIL) {
         /* Handle event completion */
         if (H5ES__op_complete(ctx->es, ev, ev_status) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event");
 
         /* Record the error */
         *ctx->op_failed = TRUE;
@@ -686,15 +651,15 @@ H5ES__wait_cb(H5ES_event_t *ev, void *_ctx)
     else if (ev_status == H5VL_REQUEST_STATUS_SUCCEED || ev_status == H5VL_REQUEST_STATUS_CANCELED) {
         /* Handle event completion */
         if (H5ES__op_complete(ctx->es, ev, ev_status) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event");
     } /* end else-if */
     else if (ev_status == H5VL_REQUEST_STATUS_CANT_CANCEL)
         /* Should never get a status of 'can't cancel' back from test / wait operation */
         HGOTO_ERROR(H5E_EVENTSET, H5E_BADVALUE, H5_ITER_ERROR,
-                    "received \"can't cancel\" status for operation")
+                    "received \"can't cancel\" status for operation");
     else {
         /* Sanity check */
-        HDassert(ev_status == H5VL_REQUEST_STATUS_IN_PROGRESS);
+        assert(ev_status == H5VL_REQUEST_STATUS_IN_PROGRESS);
 
         /* Increment "in progress operation" counter */
         (*ctx->num_in_progress)++;
@@ -722,9 +687,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, July 13, 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -736,9 +698,9 @@ H5ES__wait(H5ES_t *es, uint64_t timeout, size_t *num_in_progress, hbool_t *op_fa
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
-    HDassert(num_in_progress);
-    HDassert(op_failed);
+    assert(es);
+    assert(num_in_progress);
+    assert(op_failed);
 
     /* Set user's parameters to known values */
     *num_in_progress = 0;
@@ -752,7 +714,7 @@ H5ES__wait(H5ES_t *es, uint64_t timeout, size_t *num_in_progress, hbool_t *op_fa
 
     /* Iterate over the events in the set, waiting for them to complete */
     if (H5ES__list_iterate(&es->active, H5_ITER_NATIVE, H5ES__wait_cb, &ctx) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -765,9 +727,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Thursday, December 10, 2020
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -780,18 +739,18 @@ H5ES__cancel_cb(H5ES_event_t *ev, void *_ctx)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(ev);
-    HDassert(ctx);
+    assert(ev);
+    assert(ctx);
 
     /* Attempt to cancel the request */
     if (H5VL_request_cancel(ev->request, &ev_status) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTCANCEL, H5_ITER_ERROR, "unable to cancel operation")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTCANCEL, H5_ITER_ERROR, "unable to cancel operation");
 
     /* Check for status values that indicate we should break out of the loop */
     if (ev_status == H5VL_REQUEST_STATUS_FAIL) {
         /* Handle event completion */
         if (H5ES__op_complete(ctx->es, ev, ev_status) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTSET, H5_ITER_ERROR, "unable to handle failed event")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTSET, H5_ITER_ERROR, "unable to handle failed event");
 
         /* Record the error */
         *ctx->op_failed = TRUE;
@@ -805,7 +764,7 @@ H5ES__cancel_cb(H5ES_event_t *ev, void *_ctx)
 
         /* Handle event completion */
         if (H5ES__op_complete(ctx->es, ev, ev_status) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event");
     } /* end else-if */
     else if (ev_status == H5VL_REQUEST_STATUS_CANT_CANCEL || ev_status == H5VL_REQUEST_STATUS_IN_PROGRESS) {
         /* Increment "not canceled" counter */
@@ -813,11 +772,11 @@ H5ES__cancel_cb(H5ES_event_t *ev, void *_ctx)
     } /* end else-if */
     else {
         /* Sanity check */
-        HDassert(ev_status == H5VL_REQUEST_STATUS_CANCELED);
+        assert(ev_status == H5VL_REQUEST_STATUS_CANCELED);
 
         /* Handle event completion */
         if (H5ES__op_complete(ctx->es, ev, ev_status) < 0)
-            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event")
+            HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release completed event");
     } /* end else */
 
 done:
@@ -831,9 +790,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Thursday, December 10, 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -845,9 +801,9 @@ H5ES__cancel(H5ES_t *es, size_t *num_not_canceled, hbool_t *op_failed)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
-    HDassert(num_not_canceled);
-    HDassert(op_failed);
+    assert(es);
+    assert(num_not_canceled);
+    assert(op_failed);
 
     /* Set user's parameters to known values */
     *num_not_canceled = 0;
@@ -860,7 +816,7 @@ H5ES__cancel(H5ES_t *es, size_t *num_not_canceled, hbool_t *op_failed)
 
     /* Iterate over the events in the set, attempting to cancel them */
     if (H5ES__list_iterate(&es->active, H5_ITER_NATIVE, H5ES__cancel_cb, &ctx) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -873,9 +829,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, November 11, 2020
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -888,8 +841,8 @@ H5ES__get_err_info_cb(H5ES_event_t *ev, void *_ctx)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(ev);
-    HDassert(ctx);
+    assert(ev);
+    assert(ctx);
 
     /* Copy operation info for event */
     /* The 'app_func_name', 'app_file_name', and 'api_name' strings are statically allocated (by the compiler)
@@ -897,13 +850,13 @@ H5ES__get_err_info_cb(H5ES_event_t *ev, void *_ctx)
      * here, when they are given back to the user.
      */
     if (NULL == (ctx->curr_err_info->api_name = H5MM_xstrdup(ev->op_info.api_name)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 API routine name")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 API routine name");
     if (NULL == (ctx->curr_err_info->api_args = H5MM_xstrdup(ev->op_info.api_args)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 API routine arguments")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 API routine arguments");
     if (NULL == (ctx->curr_err_info->app_file_name = H5MM_xstrdup(ev->op_info.app_file_name)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 application file name")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 application file name");
     if (NULL == (ctx->curr_err_info->app_func_name = H5MM_xstrdup(ev->op_info.app_func_name)))
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 application function name")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTALLOC, H5_ITER_ERROR, "can't copy HDF5 application function name");
     ctx->curr_err_info->app_line_num = ev->op_info.app_line_num;
     ctx->curr_err_info->op_ins_count = ev->op_info.op_ins_count;
     ctx->curr_err_info->op_ins_ts    = ev->op_info.op_ins_ts;
@@ -916,7 +869,7 @@ H5ES__get_err_info_cb(H5ES_event_t *ev, void *_ctx)
 
     /* Get error stack for event */
     if (H5VL_request_specific(ev->request, &vol_cb_args) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTGET, H5_ITER_ERROR, "unable to retrieve error stack for operation")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTGET, H5_ITER_ERROR, "unable to retrieve error stack for operation");
 
     /* Set value */
     ctx->curr_err_info->err_stack_id = vol_cb_args.args.get_err_stack.err_stack_id;
@@ -926,7 +879,7 @@ H5ES__get_err_info_cb(H5ES_event_t *ev, void *_ctx)
 
     /* Free event node */
     if (H5ES__event_free(ev) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release failed event")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release failed event");
 
     /* Advance to next element of err_info[] array */
     ctx->curr_err++;
@@ -947,9 +900,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Friday, November 6, 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -961,10 +911,10 @@ H5ES__get_err_info(H5ES_t *es, size_t num_err_info, H5ES_err_info_t err_info[],
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
-    HDassert(num_err_info);
-    HDassert(err_info);
-    HDassert(num_cleared);
+    assert(es);
+    assert(num_err_info);
+    assert(err_info);
+    assert(num_cleared);
 
     /* Set up context for iterator callbacks */
     ctx.es            = es;
@@ -974,7 +924,7 @@ H5ES__get_err_info(H5ES_t *es, size_t num_err_info, H5ES_err_info_t err_info[],
 
     /* Iterate over the failed events in the set, copying their error info */
     if (H5ES__list_iterate(&es->failed, H5_ITER_NATIVE, H5ES__get_err_info_cb, &ctx) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed");
 
     /* Set # of failed events cleared from event set's failed list */
     *num_cleared = ctx.curr_err;
@@ -990,9 +940,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, November 11, 2020
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1004,15 +951,15 @@ H5ES__close_failed_cb(H5ES_event_t *ev, void *_ctx)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(ev);
-    HDassert(es);
+    assert(ev);
+    assert(es);
 
     /* Remove event from event set's failed list */
     H5ES__list_remove(&es->failed, ev);
 
     /* Free event node */
     if (H5ES__event_free(ev) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release failed event")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_CANTRELEASE, H5_ITER_ERROR, "unable to release failed event");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1025,9 +972,6 @@ done:
  *
  * Return:      SUCCEED / FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, April 6, 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1038,17 +982,17 @@ H5ES__close(H5ES_t *es)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(es);
+    assert(es);
 
     /* Fail if active operations still present */
     if (H5ES__list_count(&es->active) > 0)
         HGOTO_ERROR(
             H5E_EVENTSET, H5E_CANTCLOSEOBJ, FAIL,
-            "can't close event set while unfinished operations are present (i.e. wait on event set first)")
+            "can't close event set while unfinished operations are present (i.e. wait on event set first)");
 
     /* Iterate over the failed events in the set, releasing them */
     if (H5ES__list_iterate(&es->failed, H5_ITER_NATIVE, H5ES__close_failed_cb, (void *)es) < 0)
-        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed")
+        HGOTO_ERROR(H5E_EVENTSET, H5E_BADITER, FAIL, "iteration failed");
 
     /* Release the event set */
     es = H5FL_FREE(H5ES_t, es);
