@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5FA.c
- *              April 2009
- *              Vailin Choi
  *
  * Purpose:     Implements a Fixed Array for storing elements
  *              of datasets with fixed dimensions.
@@ -96,9 +94,6 @@ H5FL_BLK_DEFINE(fa_native_elmt);
  * Return:	Pointer to farray wrapper success
  *              NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Oct 17 2016
- *
  *-------------------------------------------------------------------------
  */
 static H5FA_t *
@@ -111,30 +106,30 @@ H5FA__new(H5F_t *f, haddr_t fa_addr, hbool_t from_open, void *ctx_udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fa_addr));
+    assert(f);
+    assert(H5_addr_defined(fa_addr));
 
     /* Allocate fixed array wrapper */
     if (NULL == (fa = H5FL_CALLOC(H5FA_t)))
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTALLOC, NULL, "memory allocation failed for fixed array info")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTALLOC, NULL, "memory allocation failed for fixed array info");
 
     /* Lock the array header into memory */
     if (NULL == (hdr = H5FA__hdr_protect(f, fa_addr, ctx_udata, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, NULL, "unable to load fixed array header")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, NULL, "unable to load fixed array header");
 
     /* Check for pending array deletion */
     if (from_open && hdr->pending_delete)
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTOPENOBJ, NULL, "can't open fixed array pending deletion")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTOPENOBJ, NULL, "can't open fixed array pending deletion");
 
     /* Point fixed array wrapper at header and bump it's ref count */
     fa->hdr = hdr;
     if (H5FA__hdr_incr(fa->hdr) < 0)
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header");
 
     /* Increment # of files using this array header */
     if (H5FA__hdr_fuse_incr(fa->hdr) < 0)
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTINC, NULL,
-                    "can't increment file reference count on shared array header")
+                    "can't increment file reference count on shared array header");
 
     /* Set file pointer for this array open context */
     fa->f = f;
@@ -144,10 +139,10 @@ H5FA__new(H5F_t *f, haddr_t fa_addr, hbool_t from_open, void *ctx_udata)
 
 done:
     if (hdr && H5FA__hdr_unprotect(hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, NULL, "unable to release fixed array header")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, NULL, "unable to release fixed array header");
     if (!ret_value)
         if (fa && H5FA_close(fa) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array")
+            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA__new() */
@@ -160,9 +155,6 @@ done:
  * Return:      Pointer to fixed array wrapper on success
  *              NULL on failure
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 H5FA_t *
@@ -175,20 +167,20 @@ H5FA_create(H5F_t *f, const H5FA_create_t *cparam, void *ctx_udata)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(cparam);
+    assert(f);
+    assert(cparam);
 
     /* H5FA interface sanity check */
     HDcompile_assert(H5FA_NUM_CLS_ID == NELMTS(H5FA_client_class_g));
 
     /* Create fixed array header */
     if (HADDR_UNDEF == (fa_addr = H5FA__hdr_create(f, cparam, ctx_udata)))
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL, "can't create fixed array header")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL, "can't create fixed array header");
 
     /* Allocate and initialize new fixed array wrapper */
     if (NULL == (fa = H5FA__new(f, fa_addr, FALSE, ctx_udata)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL,
-                    "allocation and/or initialization failed for fixed array wrapper")
+                    "allocation and/or initialization failed for fixed array wrapper");
 
     /* Set the return value */
     ret_value = fa;
@@ -196,7 +188,7 @@ H5FA_create(H5F_t *f, const H5FA_create_t *cparam, void *ctx_udata)
 done:
     if (!ret_value)
         if (fa && H5FA_close(fa) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array")
+            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_create() */
@@ -209,9 +201,6 @@ done:
  * Return:      Pointer to array wrapper on success
  *              NULL on failure
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 H5FA_t *
@@ -223,13 +212,13 @@ H5FA_open(H5F_t *f, haddr_t fa_addr, void *ctx_udata)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fa_addr));
+    assert(f);
+    assert(H5_addr_defined(fa_addr));
 
     /* Allocate and initialize new fixed array wrapper */
     if (NULL == (fa = H5FA__new(f, fa_addr, TRUE, ctx_udata)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL,
-                    "allocation and/or initialization failed for fixed array wrapper")
+                    "allocation and/or initialization failed for fixed array wrapper");
 
     /* Set the return value */
     ret_value = fa;
@@ -237,7 +226,7 @@ H5FA_open(H5F_t *f, haddr_t fa_addr, void *ctx_udata)
 done:
     if (!ret_value)
         if (fa && H5FA_close(fa) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array")
+            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_open() */
@@ -249,9 +238,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -260,8 +246,8 @@ H5FA_get_nelmts(const H5FA_t *fa, hsize_t *nelmts)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(nelmts);
+    assert(fa);
+    assert(nelmts);
 
     /* Retrieve the current number of elements in the fixed array */
     *nelmts = fa->hdr->stats.nelmts;
@@ -276,9 +262,6 @@ H5FA_get_nelmts(const H5FA_t *fa, hsize_t *nelmts)
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -287,9 +270,9 @@ H5FA_get_addr(const H5FA_t *fa, haddr_t *addr)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(fa->hdr);
-    HDassert(addr);
+    assert(fa);
+    assert(fa->hdr);
+    assert(addr);
 
     /* Retrieve the address of the fixed array's header */
     *addr = fa->hdr->addr;
@@ -304,9 +287,6 @@ H5FA_get_addr(const H5FA_t *fa, haddr_t *addr)
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -324,27 +304,27 @@ H5FA_set(const H5FA_t *fa, hsize_t idx, const void *elmt)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(fa->hdr);
+    assert(fa);
+    assert(fa->hdr);
 
     /* Set the shared array header's file context for this operation */
     hdr->f = fa->f;
 
     /* Check if we need to create the fixed array data block */
-    if (!H5F_addr_defined(hdr->dblk_addr)) {
+    if (!H5_addr_defined(hdr->dblk_addr)) {
         /* Create the data block */
         hdr->dblk_addr = H5FA__dblock_create(hdr, &hdr_dirty);
-        if (!H5F_addr_defined(hdr->dblk_addr))
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create fixed array data block")
+        if (!H5_addr_defined(hdr->dblk_addr))
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create fixed array data block");
     }
 
-    HDassert(idx < hdr->cparam.nelmts);
+    assert(idx < hdr->cparam.nelmts);
 
     /* Protect data block */
     if (NULL == (dblock = H5FA__dblock_protect(hdr, hdr->dblk_addr, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                     "unable to protect fixed array data block, address = %llu",
-                    (unsigned long long)hdr->dblk_addr)
+                    (unsigned long long)hdr->dblk_addr);
 
     /* Check for paging data block */
     if (!dblock->npages) {
@@ -377,7 +357,7 @@ H5FA_set(const H5FA_t *fa, hsize_t idx, const void *elmt)
         if (!H5VM_bit_get(dblock->dblk_page_init, page_idx)) {
             /* Create the data block page */
             if (H5FA__dblk_page_create(hdr, dblk_page_addr, dblk_page_nelmts) < 0)
-                HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create data block page")
+                HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create data block page");
 
             /* Mark data block page as initialized in data block */
             H5VM_bit_set(dblock->dblk_page_init, page_idx, TRUE);
@@ -389,7 +369,7 @@ H5FA_set(const H5FA_t *fa, hsize_t idx, const void *elmt)
             (dblk_page = H5FA__dblk_page_protect(hdr, dblk_page_addr, dblk_page_nelmts, H5AC__NO_FLAGS_SET)))
             HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                         "unable to protect fixed array data block page, address = %llu",
-                        (unsigned long long)dblk_page_addr)
+                        (unsigned long long)dblk_page_addr);
 
         /* Set the element in the data block page */
         H5MM_memcpy(((uint8_t *)dblk_page->elmts) + (hdr->cparam.cls->nat_elmt_size * elmt_idx), elmt,
@@ -401,13 +381,13 @@ done:
     /* Check for header modified */
     if (hdr_dirty)
         if (H5FA__hdr_modified(hdr) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CANTMARKDIRTY, FAIL, "unable to mark fixed array header as modified")
+            HDONE_ERROR(H5E_FARRAY, H5E_CANTMARKDIRTY, FAIL, "unable to mark fixed array header as modified");
 
     /* Release resources */
     if (dblock && H5FA__dblock_unprotect(dblock, dblock_cache_flags) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block");
     if (dblk_page && H5FA__dblk_page_unprotect(dblk_page, dblk_page_cache_flags) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_set() */
@@ -419,9 +399,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -435,25 +412,25 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(fa->hdr);
+    assert(fa);
+    assert(fa->hdr);
 
     /* Set the shared array header's file context for this operation */
     hdr->f = fa->f;
 
     /* Check if the fixed array data block has been allocated on disk yet */
-    if (!H5F_addr_defined(hdr->dblk_addr)) {
+    if (!H5_addr_defined(hdr->dblk_addr)) {
         /* Call the class's 'fill' callback */
         if ((hdr->cparam.cls->fill)(elmt, (size_t)1) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value");
     } /* end if */
     else {
         /* Get the data block */
-        HDassert(H5F_addr_defined(hdr->dblk_addr));
+        assert(H5_addr_defined(hdr->dblk_addr));
         if (NULL == (dblock = H5FA__dblock_protect(hdr, hdr->dblk_addr, H5AC__READ_ONLY_FLAG)))
             HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                         "unable to protect fixed array data block, address = %llu",
-                        (unsigned long long)hdr->dblk_addr)
+                        (unsigned long long)hdr->dblk_addr);
 
         /* Check for paged data block */
         if (!dblock->npages)
@@ -470,10 +447,10 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
             if (!H5VM_bit_get(dblock->dblk_page_init, page_idx)) {
                 /* Call the class's 'fill' callback */
                 if ((hdr->cparam.cls->fill)(elmt, (size_t)1) < 0)
-                    HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value")
+                    HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value");
 
                 /* We've retrieved the value, leave now */
-                HGOTO_DONE(SUCCEED)
+                HGOTO_DONE(SUCCEED);
             }                             /* end if */
             else {                        /* get the page */
                 size_t  dblk_page_nelmts; /* # of elements in a data block page */
@@ -498,7 +475,7 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
                                                                  H5AC__READ_ONLY_FLAG)))
                     HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                                 "unable to protect fixed array data block page, address = %llu",
-                                (unsigned long long)dblk_page_addr)
+                                (unsigned long long)dblk_page_addr);
 
                 /* Retrieve element from data block */
                 H5MM_memcpy(elmt, ((uint8_t *)dblk_page->elmts) + (hdr->cparam.cls->nat_elmt_size * elmt_idx),
@@ -509,9 +486,9 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
 
 done:
     if (dblock && H5FA__dblock_unprotect(dblock, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block");
     if (dblk_page && H5FA__dblk_page_unprotect(dblk_page, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_get() */
@@ -523,9 +500,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -538,7 +512,7 @@ H5FA_close(H5FA_t *fa)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
+    assert(fa);
 
     /* Close the header if it was set */
     if (fa->hdr) {
@@ -571,19 +545,19 @@ H5FA_close(H5FA_t *fa)
                 /* Check the header's status in the metadata cache */
                 if (H5AC_get_entry_status(fa->f, fa_addr, &hdr_status) < 0)
                     HGOTO_ERROR(H5E_FARRAY, H5E_CANTGET, FAIL,
-                                "unable to check metadata cache status for fixed array header")
+                                "unable to check metadata cache status for fixed array header");
 
                 /* Sanity checks on header */
-                HDassert(hdr_status & H5AC_ES__IN_CACHE);
-                HDassert(hdr_status & H5AC_ES__IS_PINNED);
-                HDassert(!(hdr_status & H5AC_ES__IS_PROTECTED));
+                assert(hdr_status & H5AC_ES__IN_CACHE);
+                assert(hdr_status & H5AC_ES__IS_PINNED);
+                assert(!(hdr_status & H5AC_ES__IS_PROTECTED));
             }
 #endif /* NDEBUG */
 
             /* Lock the array header into memory */
             /* (OK to pass in NULL for callback context, since we know the header must be in the cache) */
             if (NULL == (hdr = H5FA__hdr_protect(fa->f, fa_addr, NULL, H5AC__NO_FLAGS_SET)))
-                HGOTO_ERROR(H5E_FARRAY, H5E_CANTLOAD, FAIL, "unable to load fixed array header")
+                HGOTO_ERROR(H5E_FARRAY, H5E_CANTLOAD, FAIL, "unable to load fixed array header");
 
             /* Set the shared array header's file context for this operation */
             hdr->f = fa->f;
@@ -594,11 +568,11 @@ H5FA_close(H5FA_t *fa)
              */
             if (H5FA__hdr_decr(fa->hdr) < 0)
                 HGOTO_ERROR(H5E_FARRAY, H5E_CANTDEC, FAIL,
-                            "can't decrement reference count on shared array header")
+                            "can't decrement reference count on shared array header");
 
             /* Delete array, starting with header (unprotects header) */
             if (H5FA__hdr_delete(hdr) < 0)
-                HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array")
+                HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array");
         } /* end if */
         else {
             /* Decrement the reference count on the array header */
@@ -607,7 +581,7 @@ H5FA_close(H5FA_t *fa)
              */
             if (H5FA__hdr_decr(fa->hdr) < 0)
                 HGOTO_ERROR(H5E_FARRAY, H5E_CANTDEC, FAIL,
-                            "can't decrement reference count on shared array header")
+                            "can't decrement reference count on shared array header");
         } /* end else */
     }     /* end if */
 
@@ -625,9 +599,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -639,13 +610,13 @@ H5FA_delete(H5F_t *f, haddr_t fa_addr, void *ctx_udata)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fa_addr));
+    assert(f);
+    assert(H5_addr_defined(fa_addr));
 
     /* Lock the array header into memory */
     if (NULL == (hdr = H5FA__hdr_protect(f, fa_addr, ctx_udata, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL, "unable to protect fixed array header, address = %llu",
-                    (unsigned long long)fa_addr)
+                    (unsigned long long)fa_addr);
 
     /* Check for files using shared array header */
     if (hdr->file_rc)
@@ -656,14 +627,14 @@ H5FA_delete(H5F_t *f, haddr_t fa_addr, void *ctx_udata)
 
         /* Delete array now, starting with header (unprotects header) */
         if (H5FA__hdr_delete(hdr) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array");
         hdr = NULL;
     }
 
 done:
     /* Unprotect the header if an error occurred */
     if (hdr && H5FA__hdr_unprotect(hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array header")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array header");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_delete() */
@@ -678,9 +649,6 @@ done:
  *
  * Return:      H5_ITER_CONT/H5_ITER_ERROR
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -693,20 +661,20 @@ H5FA_iterate(H5FA_t *fa, H5FA_operator_t op, void *udata)
     FUNC_ENTER_NOAPI(H5_ITER_ERROR)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(op);
-    HDassert(udata);
+    assert(fa);
+    assert(op);
+    assert(udata);
 
     /* Allocate space for a native array element */
     if (NULL == (elmt = H5FL_BLK_MALLOC(fa_native_elmt, fa->hdr->cparam.cls->nat_elmt_size)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTALLOC, H5_ITER_ERROR,
-                    "memory allocation failed for fixed array element")
+                    "memory allocation failed for fixed array element");
 
     /* Iterate over all elements in array */
     for (u = 0; u < fa->hdr->stats.nelmts && ret_value == H5_ITER_CONT; u++) {
         /* Get array element */
         if (H5FA_get(fa, u, elmt) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTGET, H5_ITER_ERROR, "unable to delete fixed array")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTGET, H5_ITER_ERROR, "unable to delete fixed array");
 
         /* Invoke callback */
         if ((ret_value = (*op)(u, elmt, udata)) < 0) {
@@ -730,9 +698,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -744,9 +709,9 @@ H5FA_depend(H5FA_t *fa, H5AC_proxy_entry_t *parent)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(hdr);
-    HDassert(parent);
+    assert(fa);
+    assert(hdr);
+    assert(parent);
 
     /*
      * Check to see if a flush dependency between the fixed array
@@ -755,14 +720,14 @@ H5FA_depend(H5FA_t *fa, H5AC_proxy_entry_t *parent)
      */
     if (NULL == hdr->parent) {
         /* Sanity check */
-        HDassert(hdr->top_proxy);
+        assert(hdr->top_proxy);
 
         /* Set the shared array header's file context for this operation */
         hdr->f = fa->f;
 
         /* Add the fixed array as a child of the parent (proxy) */
         if (H5AC_proxy_entry_add_child(parent, hdr->f, hdr->top_proxy) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "unable to add fixed array as child of proxy")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "unable to add fixed array as child of proxy");
         hdr->parent = parent;
     }
 
@@ -788,8 +753,8 @@ H5FA_patch_file(H5FA_t *fa, H5F_t *f)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(f);
+    assert(fa);
+    assert(f);
 
     if (fa->f != f || fa->hdr->f != f)
         fa->f = fa->hdr->f = f;
