@@ -19,11 +19,12 @@
 /* This source code file is part of the H5FD driver module */
 #include "H5FDdrvr_module.h"
 
-#include "H5private.h"      /* Generic Functions           */
-#include "H5Eprivate.h"     /* Error handling              */
-#include "H5FDprivate.h"    /* File drivers                */
-#include "H5FDonion.h"      /* Onion file driver           */
-#include "H5FDonion_priv.h" /* Onion file driver internals */
+#include "H5private.h"      /* Generic Functions                        */
+#include "H5Eprivate.h"     /* Error handling                           */
+#include "H5FDprivate.h"    /* File drivers                             */
+#include "H5FDonion.h"      /* Onion file driver                        */
+#include "H5FDonion_priv.h" /* Onion file driver internals              */
+#include "H5MMprivate.h"    /* Memory management                        */
 
 /* 2^n for uint64_t types -- H5_EXP2 unsafe past 32 bits */
 #define U64_EXP2(n) ((uint64_t)1 << (n))
@@ -51,13 +52,13 @@ H5FD__onion_ingest_revision_record(H5FD_onion_revision_record_t *r_out, H5FD_t *
     haddr_t        addr      = 0;
     size_t         size      = 0;
 
-    FUNC_ENTER_PACKAGE;
+    FUNC_ENTER_PACKAGE
 
-    HDassert(r_out);
-    HDassert(raw_file);
-    HDassert(history);
-    HDassert(history->record_locs);
-    HDassert(history->n_revisions > 0);
+    assert(r_out);
+    assert(raw_file);
+    assert(history);
+    assert(history->record_locs);
+    assert(history->n_revisions > 0);
 
     high  = history->n_revisions - 1;
     range = high;
@@ -74,7 +75,7 @@ H5FD__onion_ingest_revision_record(H5FD_onion_revision_record_t *r_out, H5FD_t *
     r_out->archival_index.list = H5MM_xfree(r_out->archival_index.list);
 
     if (H5FD_get_eof(raw_file, H5FD_MEM_DRAW) < (addr + size))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "at least one record extends beyond EOF")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "at least one record extends beyond EOF");
 
     /* recovery-open may have EOA below revision record */
     if ((H5FD_get_eoa(raw_file, H5FD_MEM_DRAW) < (addr + size)) &&
@@ -91,17 +92,17 @@ H5FD__onion_ingest_revision_record(H5FD_onion_revision_record_t *r_out, H5FD_t *
         size = history->record_locs[n].record_size;
 
         if (NULL == (buf = H5MM_malloc(sizeof(char) * size)))
-            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate buffer space")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate buffer space");
 
         if (H5FD_read(raw_file, H5FD_MEM_DRAW, addr, size, buf) < 0)
-            HGOTO_ERROR(H5E_VFL, H5E_READERROR, FAIL, "can't read revision record from file")
+            HGOTO_ERROR(H5E_VFL, H5E_READERROR, FAIL, "can't read revision record from file");
 
         if (H5FD__onion_revision_record_decode(buf, r_out) != size)
-            HGOTO_ERROR(H5E_VFL, H5E_CANTDECODE, FAIL, "can't decode revision record (initial)")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTDECODE, FAIL, "can't decode revision record (initial)");
 
         sum = H5_checksum_fletcher32(buf, size - 4);
         if (r_out->checksum != sum)
-            HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "checksum mismatch between buffer and stored")
+            HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "checksum mismatch between buffer and stored");
 
         if (revision_num == r_out->revision_num)
             break;
@@ -125,34 +126,34 @@ H5FD__onion_ingest_revision_record(H5FD_onion_revision_record_t *r_out, H5FD_t *
         size = history->record_locs[n].record_size;
 
         if (NULL == (buf = H5MM_malloc(sizeof(char) * size)))
-            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate buffer space")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate buffer space");
 
         if (H5FD_read(raw_file, H5FD_MEM_DRAW, addr, size, buf) < 0)
-            HGOTO_ERROR(H5E_VFL, H5E_READERROR, FAIL, "can't read revision record from file")
+            HGOTO_ERROR(H5E_VFL, H5E_READERROR, FAIL, "can't read revision record from file");
 
         if (H5FD__onion_revision_record_decode(buf, r_out) != size)
-            HGOTO_ERROR(H5E_VFL, H5E_CANTDECODE, FAIL, "can't decode revision record (initial)")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTDECODE, FAIL, "can't decode revision record (initial)");
 
         sum = H5_checksum_fletcher32(buf, size - 4);
         if (r_out->checksum != sum)
-            HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "checksum mismatch between buffer and stored")
+            HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "checksum mismatch between buffer and stored");
 
         if (revision_num != r_out->revision_num)
             HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL,
-                        "could not find target revision!") /* TODO: corrupted? */
-    }                                                      /* end if revision ID at 'leaf' in binary search */
+                        "could not find target revision!"); /* TODO: corrupted? */
+    } /* end if revision ID at 'leaf' in binary search */
 
     if (r_out->comment_size > 0)
         if (NULL == (r_out->comment = H5MM_malloc(sizeof(char) * r_out->comment_size)))
-            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate comment space")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate comment space");
 
     if (r_out->archival_index.n_entries > 0)
         if (NULL == (r_out->archival_index.list =
                          H5MM_calloc(r_out->archival_index.n_entries * sizeof(H5FD_onion_index_entry_t))))
-            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate index entry list")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "can't allocate index entry list");
 
     if (H5FD__onion_revision_record_decode(buf, r_out) != size)
-        HGOTO_ERROR(H5E_VFL, H5E_CANTDECODE, FAIL, "can't decode revision record (final)")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTDECODE, FAIL, "can't decode revision record (final)");
 
 done:
     H5MM_xfree(buf);
@@ -161,7 +162,7 @@ done:
         H5MM_xfree(r_out->archival_index.list);
     }
 
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_ingest_revision_record() */
 
 /*-----------------------------------------------------------------------------
@@ -183,23 +184,23 @@ H5FD__onion_archival_index_is_valid(const H5FD_onion_archival_index_t *aix)
 {
     hbool_t ret_value = TRUE;
 
-    FUNC_ENTER_PACKAGE_NOERR;
+    FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(aix);
+    assert(aix);
 
     if (H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR != aix->version)
-        HGOTO_DONE(FALSE)
+        HGOTO_DONE(FALSE);
     if (NULL == aix->list)
-        HGOTO_DONE(FALSE)
+        HGOTO_DONE(FALSE);
 
     /* Ensure list is sorted on logical_page field */
     if (aix->n_entries > 1)
         for (uint64_t i = 1; i < aix->n_entries - 1; i++)
             if (aix->list[i + 1].logical_page <= aix->list[i].logical_page)
-                HGOTO_DONE(FALSE)
+                HGOTO_DONE(FALSE);
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_archival_index_is_valid() */
 
 /*-----------------------------------------------------------------------------
@@ -227,13 +228,13 @@ H5FD__onion_archival_index_find(const H5FD_onion_archival_index_t *aix, uint64_t
     H5FD_onion_index_entry_t *x         = NULL;
     int                       ret_value = 0;
 
-    FUNC_ENTER_PACKAGE_NOERR;
+    FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(aix);
-    HDassert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == aix->version);
-    HDassert(entry_out);
+    assert(aix);
+    assert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == aix->version);
+    assert(entry_out);
     if (aix->n_entries != 0)
-        HDassert(aix->list);
+        assert(aix->list);
 
     high  = aix->n_entries - 1;
     range = high;
@@ -241,7 +242,7 @@ H5FD__onion_archival_index_find(const H5FD_onion_archival_index_t *aix, uint64_t
     /* Trivial cases */
     if (aix->n_entries == 0 || logical_page > aix->list[high].logical_page ||
         logical_page < aix->list[0].logical_page)
-        HGOTO_DONE(0)
+        HGOTO_DONE(0);
 
     /*
      * Binary search on sorted list
@@ -249,7 +250,7 @@ H5FD__onion_archival_index_find(const H5FD_onion_archival_index_t *aix, uint64_t
 
     /* Winnow down to first of found or one element */
     while (range > 0) {
-        HDassert(high < aix->n_entries);
+        assert(high < aix->n_entries);
         n = low + (range / 2);
         x = &(aix->list[n]);
         if (x->logical_page == logical_page) {
@@ -266,7 +267,7 @@ H5FD__onion_archival_index_find(const H5FD_onion_archival_index_t *aix, uint64_t
         range = high - low;
     }
 
-    HDassert(high == low); /* one element */
+    assert(high == low); /* one element */
 
     /* n == low/high check because we may have tested it already above */
     if ((n != low || n != high) && (aix->list[low].logical_page == logical_page)) {
@@ -275,7 +276,7 @@ H5FD__onion_archival_index_find(const H5FD_onion_archival_index_t *aix, uint64_t
     }
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_archival_index_find() */
 
 /*-----------------------------------------------------------------------------
@@ -291,10 +292,10 @@ H5FD__onion_revision_index_destroy(H5FD_onion_revision_index_t *rix)
 {
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_PACKAGE_NOERR;
+    FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(rix);
-    HDassert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
+    assert(rix);
+    assert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
 
     for (size_t i = 0; 0 < rix->_hash_table_n_keys_populated && i < rix->_hash_table_size; i++) {
         H5FD_onion_revision_index_hash_chain_node_t *next = NULL;
@@ -304,7 +305,7 @@ H5FD__onion_revision_index_destroy(H5FD_onion_revision_index_t *rix)
             rix->_hash_table_n_keys_populated -= 1;
 
         while (node != NULL) {
-            HDassert(H5FD_ONION_REVISION_INDEX_HASH_CHAIN_NODE_VERSION_CURR == node->version);
+            assert(H5FD_ONION_REVISION_INDEX_HASH_CHAIN_NODE_VERSION_CURR == node->version);
 
             next = node->next;
             H5MM_xfree(node);
@@ -314,7 +315,7 @@ H5FD__onion_revision_index_destroy(H5FD_onion_revision_index_t *rix)
     H5MM_xfree(rix->_hash_table);
     H5MM_xfree(rix);
 
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_revision_index_destroy() */
 
 /*-----------------------------------------------------------------------------
@@ -335,17 +336,17 @@ H5FD__onion_revision_index_init(uint32_t page_size)
     H5FD_onion_revision_index_t *rix        = NULL;
     H5FD_onion_revision_index_t *ret_value  = NULL;
 
-    FUNC_ENTER_PACKAGE;
+    FUNC_ENTER_PACKAGE
 
-    HDassert(0 != page_size);
-    HDassert(POWER_OF_TWO(page_size));
+    assert(0 != page_size);
+    assert(POWER_OF_TWO(page_size));
 
     if (NULL == (rix = H5MM_calloc(sizeof(H5FD_onion_revision_index_t))))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, NULL, "cannot allocate index")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, NULL, "cannot allocate index");
 
     if (NULL ==
         (rix->_hash_table = H5MM_calloc(table_size * sizeof(H5FD_onion_revision_index_hash_chain_node_t *))))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, NULL, "cannot allocate hash table")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, NULL, "cannot allocate hash table");
 
     rix->version   = H5FD_ONION_REVISION_INDEX_VERSION_CURR;
     rix->n_entries = 0;
@@ -363,7 +364,7 @@ done:
     if (NULL == ret_value)
         H5MM_xfree(rix);
 
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_revision_index_init() */
 
 /*-----------------------------------------------------------------------------
@@ -389,14 +390,14 @@ H5FD__onion_revision_index_resize(H5FD_onion_revision_index_t *rix)
     uint64_t new_n_keys_populated = 0;
     herr_t   ret_value            = SUCCEED;
 
-    FUNC_ENTER_PACKAGE;
+    FUNC_ENTER_PACKAGE
 
-    HDassert(rix);
-    HDassert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
-    HDassert(rix->_hash_table);
+    assert(rix);
+    assert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
+    assert(rix->_hash_table);
 
     if (NULL == (new_table = H5MM_calloc(new_size * sizeof(H5FD_onion_revision_index_hash_chain_node_t *))))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "cannot allocate new hash table")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "cannot allocate new hash table");
 
     for (uint64_t i = 0; i < rix->_hash_table_size; i++) {
         while (rix->_hash_table[i] != NULL) {
@@ -427,7 +428,7 @@ H5FD__onion_revision_index_resize(H5FD_onion_revision_index_t *rix)
     rix->_hash_table                  = new_table;
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_revision_index_resize() */
 
 /*-----------------------------------------------------------------------------
@@ -451,21 +452,21 @@ H5FD__onion_revision_index_insert(H5FD_onion_revision_index_t *rix, const H5FD_o
     H5FD_onion_revision_index_hash_chain_node_t **append_dest = NULL;
     herr_t                                        ret_value   = SUCCEED;
 
-    FUNC_ENTER_PACKAGE;
+    FUNC_ENTER_PACKAGE
 
-    HDassert(rix);
-    HDassert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
-    HDassert(entry);
+    assert(rix);
+    assert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
+    assert(entry);
 
     /* Resize and re-hash table if necessary */
     if (rix->n_entries >= (rix->_hash_table_size * 2) ||
         rix->_hash_table_n_keys_populated >= (rix->_hash_table_size / 2)) {
         if (H5FD__onion_revision_index_resize(rix) < 0)
-            HGOTO_ERROR(H5E_VFL, H5E_NONE_MINOR, FAIL, "unable to resize and hash table")
+            HGOTO_ERROR(H5E_VFL, H5E_NONE_MINOR, FAIL, "unable to resize and hash table");
     }
 
     key = entry->logical_page & (rix->_hash_table_size - 1);
-    HDassert(key < rix->_hash_table_size);
+    assert(key < rix->_hash_table_size);
 
     if (NULL == rix->_hash_table[key]) {
         /* Key maps to empty bucket */
@@ -482,7 +483,7 @@ H5FD__onion_revision_index_insert(H5FD_onion_revision_index_t *rix, const H5FD_o
                 if (entry->phys_addr != node->entry_data.phys_addr) {
                     HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "physical address mismatch");
                 }
-                HDmemcpy(&node->entry_data, entry, sizeof(H5FD_onion_index_entry_t));
+                memcpy(&node->entry_data, entry, sizeof(H5FD_onion_index_entry_t));
                 append_dest = NULL; /* Node updated, do not append */
                 break;
             }
@@ -492,16 +493,16 @@ H5FD__onion_revision_index_insert(H5FD_onion_revision_index_t *rix, const H5FD_o
     /* Add new entry to bucket chain */
     if (append_dest != NULL) {
         if (NULL == (node = H5MM_malloc(sizeof(H5FD_onion_revision_index_hash_chain_node_t))))
-            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "cannot allocate new ash chain node")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "cannot allocate new ash chain node");
         node->version = H5FD_ONION_REVISION_INDEX_HASH_CHAIN_NODE_VERSION_CURR;
         node->next    = NULL;
-        HDmemcpy(&node->entry_data, entry, sizeof(H5FD_onion_index_entry_t));
+        memcpy(&node->entry_data, entry, sizeof(H5FD_onion_index_entry_t));
         *append_dest = node;
         rix->n_entries++;
     }
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_revision_index_insert() */
 
 /*-----------------------------------------------------------------------------
@@ -524,15 +525,15 @@ H5FD__onion_revision_index_find(const H5FD_onion_revision_index_t *rix, uint64_t
     uint64_t key       = 0;
     int      ret_value = 0;
 
-    FUNC_ENTER_PACKAGE_NOERR;
+    FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(rix);
-    HDassert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
-    HDassert(rix->_hash_table);
-    HDassert(entry_out);
+    assert(rix);
+    assert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
+    assert(rix->_hash_table);
+    assert(entry_out);
 
     key = logical_page & (rix->_hash_table_size - 1);
-    HDassert(key < rix->_hash_table_size);
+    assert(key < rix->_hash_table_size);
 
     if (rix->_hash_table[key] != NULL) {
         H5FD_onion_revision_index_hash_chain_node_t *node = NULL;
@@ -546,7 +547,7 @@ H5FD__onion_revision_index_find(const H5FD_onion_revision_index_t *rix, uint64_t
         }
     }
 
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_revision_index_find() */
 
 /*-----------------------------------------------------------------------------
@@ -596,60 +597,60 @@ H5FD__onion_revision_record_decode(unsigned char *buf, H5FD_onion_revision_recor
     unsigned char *ptr          = NULL;
     size_t         ret_value    = 0;
 
-    FUNC_ENTER_PACKAGE;
+    FUNC_ENTER_PACKAGE
 
-    HDassert(buf != NULL);
-    HDassert(record != NULL);
-    HDassert(H5FD_ONION_REVISION_RECORD_VERSION_CURR == record->version);
-    HDassert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == record->archival_index.version);
+    assert(buf != NULL);
+    assert(record != NULL);
+    assert(H5FD_ONION_REVISION_RECORD_VERSION_CURR == record->version);
+    assert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == record->archival_index.version);
 
     if (HDstrncmp((const char *)buf, H5FD_ONION_REVISION_RECORD_SIGNATURE, 4))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid signature")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid signature");
 
     if (H5FD_ONION_REVISION_RECORD_VERSION_CURR != buf[4])
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid record version")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid record version");
 
     ptr = buf + 8;
 
-    HDmemcpy(&ui64, ptr, 8);
+    memcpy(&ui64, ptr, 8);
     ui8p = (uint8_t *)&ui64;
     UINT64DECODE(ui8p, record->revision_num);
     ptr += 8;
 
-    HDmemcpy(&ui64, ptr, 8);
+    memcpy(&ui64, ptr, 8);
     ui8p = (uint8_t *)&ui64;
     UINT64DECODE(ui8p, record->parent_revision_num);
     ptr += 8;
 
-    HDmemcpy(record->time_of_creation, ptr, 16);
+    memcpy(record->time_of_creation, ptr, 16);
     ptr += 16;
 
-    HDmemcpy(&ui64, ptr, 8);
+    memcpy(&ui64, ptr, 8);
     ui8p = (uint8_t *)&ui64;
     UINT64DECODE(ui8p, record->logical_eof);
     ptr += 8;
 
-    HDmemcpy(&ui32, ptr, 4);
+    memcpy(&ui32, ptr, 4);
     ui8p = (uint8_t *)&ui32;
     UINT32DECODE(ui8p, page_size);
     ptr += 4;
 
     if (page_size == 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "page size is zero")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "page size is zero");
     if (!POWER_OF_TWO(page_size))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "page size not power of two")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "page size not power of two");
 
     for (record->archival_index.page_size_log2 = 0;
          (((uint32_t)1 << record->archival_index.page_size_log2) & page_size) == 0;
          record->archival_index.page_size_log2++)
         ;
 
-    HDmemcpy(&ui64, ptr, 8);
+    memcpy(&ui64, ptr, 8);
     ui8p = (uint8_t *)&ui64;
     UINT64DECODE(ui8p, n_entries);
     ptr += 8;
 
-    HDmemcpy(&ui32, ptr, 4);
+    memcpy(&ui32, ptr, 4);
     ui8p = (uint8_t *)&ui32;
     UINT32DECODE(ui8p, comment_size);
     ptr += 4;
@@ -659,70 +660,70 @@ H5FD__onion_revision_record_decode(unsigned char *buf, H5FD_onion_revision_recor
         ptr += H5FD_ONION_ENCODED_SIZE_INDEX_ENTRY * n_entries;
     }
     else if (n_entries != record->archival_index.n_entries) {
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "n_entries in archival index does not match decoded")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "n_entries in archival index does not match decoded");
     }
     else {
         H5FD_onion_index_entry_t *entry = NULL;
 
         if (record->archival_index.list == NULL)
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "no archival index entry list")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "no archival index entry list");
 
         for (size_t i = 0; i < n_entries; i++) {
             entry = &record->archival_index.list[i];
 
-            HDmemcpy(&ui64, ptr, 8);
+            memcpy(&ui64, ptr, 8);
             ui8p = (uint8_t *)&ui64;
             UINT64DECODE(ui8p, entry->logical_page);
             ptr += 8;
 
             /* logical_page actually encoded as address; check and convert */
             if (entry->logical_page & (page_size - 1))
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "logical address does not align with page size")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "logical address does not align with page size");
 
             entry->logical_page = entry->logical_page >> record->archival_index.page_size_log2;
 
-            HDmemcpy(&ui64, ptr, 8);
+            memcpy(&ui64, ptr, 8);
             ui8p = (uint8_t *)&ui64;
             UINT64DECODE(ui8p, entry->phys_addr);
             ptr += 8;
 
-            HDmemcpy(&ui32, ptr, 4);
+            memcpy(&ui32, ptr, 4);
             ui8p = (uint8_t *)&ui32;
             UINT32DECODE(ui8p, sum);
             ptr += 4;
 
             ui32 = H5_checksum_fletcher32((ptr - 20), 16);
             if (ui32 != sum)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "index entry checksum mismatch")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "index entry checksum mismatch");
         }
     }
 
     if (record->comment_size == 0) {
         if (record->comment != NULL)
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "comment pointer prematurely allocated")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "comment pointer prematurely allocated");
         record->comment_size = comment_size;
     }
     else {
         if (record->comment == NULL)
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "no comment pointer")
-        HDmemcpy(record->comment, ptr, comment_size);
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "no comment pointer");
+        memcpy(record->comment, ptr, comment_size);
     }
     ptr += comment_size;
 
     sum = H5_checksum_fletcher32(buf, (size_t)(ptr - buf));
 
-    HDmemcpy(&ui32, ptr, 4);
+    memcpy(&ui32, ptr, 4);
     ui8p = (uint8_t *)&ui32;
     UINT32DECODE(ui8p, record->checksum);
     ptr += 4;
 
     if (sum != record->checksum)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "checksum mismatch")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "checksum mismatch");
 
     ret_value = (size_t)(ptr - buf);
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_revision_record_decode() */
 
 /*-----------------------------------------------------------------------------
@@ -753,23 +754,23 @@ H5FD__onion_revision_record_encode(H5FD_onion_revision_record_t *record, unsigne
     uint32_t       vers_u32  = (uint32_t)record->version; /* pad out unused bytes */
     uint32_t       page_size = 0;
 
-    FUNC_ENTER_PACKAGE_NOERR;
+    FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(checksum != NULL);
-    HDassert(buf != NULL);
-    HDassert(record != NULL);
-    HDassert(vers_u32 < 0x100);
-    HDassert(H5FD_ONION_REVISION_RECORD_VERSION_CURR == record->version);
-    HDassert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == record->archival_index.version);
+    assert(checksum != NULL);
+    assert(buf != NULL);
+    assert(record != NULL);
+    assert(vers_u32 < 0x100);
+    assert(H5FD_ONION_REVISION_RECORD_VERSION_CURR == record->version);
+    assert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == record->archival_index.version);
 
     page_size = (uint32_t)(1 << record->archival_index.page_size_log2);
 
-    HDmemcpy(ptr, H5FD_ONION_REVISION_RECORD_SIGNATURE, 4);
+    memcpy(ptr, H5FD_ONION_REVISION_RECORD_SIGNATURE, 4);
     ptr += 4;
     UINT32ENCODE(ptr, vers_u32);
     UINT64ENCODE(ptr, record->revision_num);
     UINT64ENCODE(ptr, record->parent_revision_num);
-    HDmemcpy(ptr, record->time_of_creation, 16);
+    memcpy(ptr, record->time_of_creation, 16);
     ptr += 16;
     UINT64ENCODE(ptr, record->logical_eof);
     UINT32ENCODE(ptr, page_size);
@@ -779,7 +780,7 @@ H5FD__onion_revision_record_encode(H5FD_onion_revision_record_t *record, unsigne
     if (record->archival_index.n_entries > 0) {
         uint64_t page_size_log2 = record->archival_index.page_size_log2;
 
-        HDassert(record->archival_index.list != NULL);
+        assert(record->archival_index.list != NULL);
         for (uint64_t i = 0; i < record->archival_index.n_entries; i++) {
             uint32_t                  sum       = 0;
             H5FD_onion_index_entry_t *entry     = NULL;
@@ -796,15 +797,15 @@ H5FD__onion_revision_record_encode(H5FD_onion_revision_record_t *record, unsigne
     }
 
     if (record->comment_size > 0) {
-        HDassert(record->comment != NULL && *record->comment != '\0');
-        HDmemcpy(ptr, record->comment, record->comment_size);
+        assert(record->comment != NULL && *record->comment != '\0');
+        memcpy(ptr, record->comment, record->comment_size);
         ptr += record->comment_size;
     }
 
     *checksum = H5_checksum_fletcher32(buf, (size_t)(ptr - buf));
     UINT32ENCODE(ptr, *checksum);
 
-    FUNC_LEAVE_NOAPI((size_t)(ptr - buf));
+    FUNC_LEAVE_NOAPI((size_t)(ptr - buf))
 } /* end H5FD__onion_revision_record_encode() */
 
 /*-----------------------------------------------------------------------------
@@ -853,13 +854,13 @@ H5FD__onion_merge_revision_index_into_archival_index(const H5FD_onion_revision_i
     };
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_PACKAGE;
+    FUNC_ENTER_PACKAGE
 
-    HDassert(rix);
-    HDassert(aix);
-    HDassert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
-    HDassert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == aix->version);
-    HDassert(aix->page_size_log2 == rix->page_size_log2);
+    assert(rix);
+    assert(aix);
+    assert(H5FD_ONION_REVISION_INDEX_VERSION_CURR == rix->version);
+    assert(H5FD_ONION_ARCHIVAL_INDEX_VERSION_CURR == aix->version);
+    assert(aix->page_size_log2 == rix->page_size_log2);
 
     /* If the revision index is empty there is nothing to archive */
     if (rix->n_entries == 0)
@@ -869,20 +870,20 @@ H5FD__onion_merge_revision_index_into_archival_index(const H5FD_onion_revision_i
     new_aix.page_size_log2 = aix->page_size_log2;
 
     if (NULL == (new_aix.list = H5MM_calloc(rix->n_entries * sizeof(H5FD_onion_index_entry_t))))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "unable to allocate new archival index list")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "unable to allocate new archival index list");
 
     for (uint64_t i = 0; i < rix->_hash_table_size; i++) {
         const H5FD_onion_revision_index_hash_chain_node_t *node = NULL;
 
         for (node = rix->_hash_table[i]; node != NULL; node = node->next) {
-            HDmemcpy(&new_aix.list[new_aix.n_entries], &node->entry_data, sizeof(H5FD_onion_index_entry_t));
+            memcpy(&new_aix.list[new_aix.n_entries], &node->entry_data, sizeof(H5FD_onion_index_entry_t));
             new_aix.n_entries++;
         }
     }
 
     /* Sort the new archival list */
-    HDqsort(new_aix.list, new_aix.n_entries, sizeof(H5FD_onion_index_entry_t),
-            H5FD__onion_archival_index_list_sort_cmp);
+    qsort(new_aix.list, new_aix.n_entries, sizeof(H5FD_onion_index_entry_t),
+          H5FD__onion_archival_index_list_sort_cmp);
 
     /* Add the old archival index entries to a 'kept' list containing the
      * old archival list entries that are not also included in the revision
@@ -893,14 +894,14 @@ H5FD__onion_merge_revision_index_into_archival_index(const H5FD_onion_revision_i
      */
     if (aix->n_entries > 0)
         if (NULL == (kept_list = H5MM_calloc(aix->n_entries * sizeof(H5FD_onion_index_entry_t))))
-            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "unable to allocate larger archival index list")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "unable to allocate larger archival index list");
 
     for (uint64_t i = 0; i < aix->n_entries; i++) {
         const H5FD_onion_index_entry_t *entry = NULL;
 
         /* Add only if page not already added from revision index */
         if (H5FD__onion_archival_index_find(&new_aix, aix->list[i].logical_page, &entry) == 0) {
-            HDmemcpy(&kept_list[n_kept], &aix->list[i], sizeof(H5FD_onion_index_entry_t));
+            memcpy(&kept_list[n_kept], &aix->list[i], sizeof(H5FD_onion_index_entry_t));
             n_kept++;
         }
     }
@@ -910,26 +911,26 @@ H5FD__onion_merge_revision_index_into_archival_index(const H5FD_onion_revision_i
      */
     H5MM_xfree(aix->list);
     if (NULL == (aix->list = H5MM_calloc((new_aix.n_entries + n_kept) * sizeof(H5FD_onion_index_entry_t))))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "unable to allocate exact-size archival index list")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, FAIL, "unable to allocate exact-size archival index list");
 
     /* Copy (new) revision list entries to replacement list */
-    HDmemcpy(aix->list, new_aix.list, sizeof(H5FD_onion_index_entry_t) * new_aix.n_entries);
+    memcpy(aix->list, new_aix.list, sizeof(H5FD_onion_index_entry_t) * new_aix.n_entries);
     aix->n_entries = new_aix.n_entries;
 
     /* Copy (old) kept archival list entries to replacement list */
     if (n_kept > 0) {
-        HDmemcpy(&aix->list[aix->n_entries], kept_list, sizeof(H5FD_onion_index_entry_t) * n_kept);
+        memcpy(&aix->list[aix->n_entries], kept_list, sizeof(H5FD_onion_index_entry_t) * n_kept);
         aix->n_entries += n_kept;
     }
 
     /* Sort this list */
-    HDqsort(aix->list, aix->n_entries, sizeof(H5FD_onion_index_entry_t),
-            H5FD__onion_archival_index_list_sort_cmp);
+    qsort(aix->list, aix->n_entries, sizeof(H5FD_onion_index_entry_t),
+          H5FD__onion_archival_index_list_sort_cmp);
 
 done:
     /* Free the temporary lists */
     H5MM_xfree(kept_list);
     H5MM_xfree(new_aix.list);
 
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__onion_merge_revision_index_into_archival_index() */
