@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Richard Warren
- *              Wednesday, July 1, 2020
- *
  * Purpose:     This is part of a parallel subfiling I/O driver.
  *
  */
@@ -63,8 +60,6 @@
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  JRM -- 12/13/21
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -101,10 +96,10 @@ H5FD__subfiling__truncate_sub_files(hid_t context_id, int64_t logical_file_eof,
 
         num_subfiles_owned = sf_context->sf_num_fids;
 
-        if (NULL == (recv_reqs = HDmalloc((size_t)num_subfiles_owned * sizeof(*recv_reqs))))
+        if (NULL == (recv_reqs = malloc((size_t)num_subfiles_owned * sizeof(*recv_reqs))))
             H5_SUBFILING_GOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL,
                                     "can't allocate receive requests array");
-        if (NULL == (recv_msgs = HDmalloc((size_t)num_subfiles_owned * 3 * sizeof(*recv_msgs))))
+        if (NULL == (recv_msgs = malloc((size_t)num_subfiles_owned * 3 * sizeof(*recv_msgs))))
             H5_SUBFILING_GOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "can't allocate message array");
 
         /*
@@ -175,7 +170,7 @@ H5FD__subfiling__truncate_sub_files(hid_t context_id, int64_t logical_file_eof,
                 }
             }
 
-            HDassert(test_file_eof == logical_file_eof);
+            assert(test_file_eof == logical_file_eof);
         }
 #endif /* NDEBUG */
     }
@@ -186,8 +181,8 @@ H5FD__subfiling__truncate_sub_files(hid_t context_id, int64_t logical_file_eof,
             H5_SUBFILING_MPI_GOTO_ERROR(FAIL, "MPI_Barrier failed", mpi_code);
 
 done:
-    HDfree(recv_msgs);
-    HDfree(recv_reqs);
+    free(recv_msgs);
+    free(recv_reqs);
 
     H5_SUBFILING_FUNC_LEAVE;
 } /* H5FD__subfiling__truncate_sub_files() */
@@ -276,8 +271,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  JRM -- 1/18/22
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -295,24 +288,24 @@ H5FD__subfiling__get_real_eof(hid_t context_id, int64_t *logical_eof_ptr)
     int                  mpi_code;            /* MPI return code */
     herr_t               ret_value = SUCCEED; /* Return value */
 
-    HDassert(logical_eof_ptr);
+    assert(logical_eof_ptr);
 
     if (NULL == (sf_context = (subfiling_context_t *)H5_get_subfiling_object(context_id)))
         H5_SUBFILING_GOTO_ERROR(H5E_FILE, H5E_BADVALUE, FAIL, "can't get subfile context");
 
-    HDassert(sf_context->topology);
+    assert(sf_context->topology);
 
     n_io_concentrators = sf_context->topology->n_io_concentrators;
     num_subfiles       = sf_context->sf_num_subfiles;
 
-    HDassert(n_io_concentrators > 0);
-    HDassert(num_subfiles >= n_io_concentrators);
+    assert(n_io_concentrators > 0);
+    assert(num_subfiles >= n_io_concentrators);
 
-    if (NULL == (sf_eofs = HDmalloc((size_t)num_subfiles * sizeof(int64_t))))
+    if (NULL == (sf_eofs = malloc((size_t)num_subfiles * sizeof(int64_t))))
         H5_SUBFILING_GOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "can't allocate subfile EOFs array");
-    if (NULL == (recv_reqs = HDmalloc((size_t)num_subfiles * sizeof(*recv_reqs))))
+    if (NULL == (recv_reqs = malloc((size_t)num_subfiles * sizeof(*recv_reqs))))
         H5_SUBFILING_GOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "can't allocate receive requests array");
-    if (NULL == (recv_msg = HDmalloc((size_t)num_subfiles * sizeof(msg))))
+    if (NULL == (recv_msg = malloc((size_t)num_subfiles * sizeof(msg))))
         H5_SUBFILING_GOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "can't allocate message array");
 
     for (int i = 0; i < num_subfiles; i++) {
@@ -352,9 +345,9 @@ H5FD__subfiling__get_real_eof(hid_t context_id, int64_t *logical_eof_ptr)
     for (int i = 0; i < num_subfiles; i++) {
         int ioc_rank = (int)recv_msg[3 * i];
 
-        HDassert(ioc_rank >= 0);
-        HDassert(ioc_rank < n_io_concentrators);
-        HDassert(sf_eofs[i] == -1);
+        assert(ioc_rank >= 0);
+        assert(ioc_rank < n_io_concentrators);
+        assert(sf_eofs[i] == -1);
 
         sf_eofs[i] = recv_msg[(3 * i) + 1];
     }
@@ -405,9 +398,9 @@ done:
         }
     }
 
-    HDfree(recv_msg);
-    HDfree(recv_reqs);
-    HDfree(sf_eofs);
+    free(recv_msg);
+    free(recv_reqs);
+    free(sf_eofs);
 
     H5_SUBFILING_FUNC_LEAVE;
 } /* H5FD__subfiling__get_real_eof() */
