@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -19,7 +18,7 @@
  *
  */
 
-#define H5F_PACKAGE /*suppress error about including H5Fpkg	  */
+#define H5F_FRIEND /*suppress error about including H5Fpkg	  */
 
 #include "H5Eprivate.h"  /* Error handling		  	*/
 #include "H5Fpkg.h"      /* File access                          */
@@ -74,12 +73,12 @@ H5FO_create(const H5F_t *f)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     /* Create container used to store open object info */
     if ((f->shared->open_objs = H5SL_create(H5SL_TYPE_HADDR, NULL)) == NULL)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to create open object container")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to create open object container");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -114,15 +113,15 @@ H5FO_opened(const H5F_t *f, haddr_t addr)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->open_objs);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->open_objs);
+    assert(H5_addr_defined(addr));
 
     /* Get the object node from the container */
     if (NULL != (open_obj = (H5FO_open_obj_t *)H5SL_search(f->shared->open_objs, &addr))) {
         ret_value = open_obj->obj;
-        HDassert(ret_value != NULL);
+        assert(ret_value != NULL);
     } /* end if */
     else
         ret_value = NULL;
@@ -160,15 +159,15 @@ H5FO_insert(const H5F_t *f, haddr_t addr, void *obj, hbool_t delete_flag)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->open_objs);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(obj);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->open_objs);
+    assert(H5_addr_defined(addr));
+    assert(obj);
 
     /* Allocate new opened object information structure */
     if ((open_obj = H5FL_MALLOC(H5FO_open_obj_t)) == NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_NOSPACE, FAIL, "memory allocation failed")
+        HGOTO_ERROR(H5E_CACHE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
     /* Assign information */
     open_obj->addr    = addr;
@@ -177,7 +176,7 @@ H5FO_insert(const H5F_t *f, haddr_t addr, void *obj, hbool_t delete_flag)
 
     /* Insert into container */
     if (H5SL_insert(f->shared->open_objs, &open_obj->addr, open_obj) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "can't insert object into container")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "can't insert object into container");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -203,7 +202,7 @@ done:
  REVISION LOG
 --------------------------------------------------------------------------*/
 herr_t
-H5FO_delete(H5F_t *f, hid_t dxpl_id, haddr_t addr)
+H5FO_delete(H5F_t *f, haddr_t addr)
 {
     H5FO_open_obj_t *open_obj;            /* Information about open object */
     herr_t           ret_value = SUCCEED; /* Return value */
@@ -211,19 +210,19 @@ H5FO_delete(H5F_t *f, hid_t dxpl_id, haddr_t addr)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->open_objs);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->open_objs);
+    assert(H5_addr_defined(addr));
 
     /* Remove from container */
     if (NULL == (open_obj = (H5FO_open_obj_t *)H5SL_remove(f->shared->open_objs, &addr)))
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "can't remove object from container")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "can't remove object from container");
 
     /* Check if the object was deleted from the file */
     if (open_obj->deleted) {
-        if (H5O_delete(f, dxpl_id, addr) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTDELETE, FAIL, "can't delete object from file")
+        if (H5O_delete(f, addr) < 0)
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTDELETE, FAIL, "can't delete object from file");
     } /* end if */
 
     /* Release the object information */
@@ -261,10 +260,10 @@ H5FO_mark(const H5F_t *f, haddr_t addr, hbool_t deleted)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->open_objs);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->open_objs);
+    assert(H5_addr_defined(addr));
 
     /* Get the object node from the container */
     if (NULL != (open_obj = (H5FO_open_obj_t *)H5SL_search(f->shared->open_objs, &addr)))
@@ -304,10 +303,10 @@ H5FO_marked(const H5F_t *f, haddr_t addr)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->open_objs);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->open_objs);
+    assert(H5_addr_defined(addr));
 
     /* Get the object node from the container */
     if (NULL != (open_obj = (H5FO_open_obj_t *)H5SL_search(f->shared->open_objs, &addr)))
@@ -342,17 +341,17 @@ H5FO_dest(const H5F_t *f)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->open_objs);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->open_objs);
 
     /* Check if the object info set is empty */
     if (H5SL_count(f->shared->open_objs) != 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "objects still in open object info set")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "objects still in open object info set");
 
     /* Release the open object info set container */
     if (H5SL_close(f->shared->open_objs) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTCLOSEOBJ, FAIL, "can't close open object info set")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTCLOSEOBJ, FAIL, "can't close open object info set");
 
     f->shared->open_objs = NULL;
 
@@ -386,11 +385,11 @@ H5FO_top_create(H5F_t *f)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
+    assert(f);
 
     /* Create container used to store open object info */
     if ((f->obj_count = H5SL_create(H5SL_TYPE_HADDR, NULL)) == NULL)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to create open object container")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to create open object container");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -424,9 +423,9 @@ H5FO_top_incr(const H5F_t *f, haddr_t addr)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->obj_count);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->obj_count);
+    assert(H5_addr_defined(addr));
 
     /* Get the object node from the container */
     if (NULL != (obj_count = (H5FO_obj_count_t *)H5SL_search(f->obj_count, &addr))) {
@@ -435,7 +434,7 @@ H5FO_top_incr(const H5F_t *f, haddr_t addr)
     else {
         /* Allocate new opened object information structure */
         if (NULL == (obj_count = H5FL_MALLOC(H5FO_obj_count_t)))
-            HGOTO_ERROR(H5E_CACHE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HGOTO_ERROR(H5E_CACHE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
         /* Assign information */
         obj_count->addr  = addr;
@@ -443,7 +442,7 @@ H5FO_top_incr(const H5F_t *f, haddr_t addr)
 
         /* Insert into container */
         if (H5SL_insert(f->obj_count, &obj_count->addr, obj_count) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "can't insert object into container")
+            HGOTO_ERROR(H5E_CACHE, H5E_CANTINSERT, FAIL, "can't insert object into container");
     } /* end if */
 
 done:
@@ -478,9 +477,9 @@ H5FO_top_decr(const H5F_t *f, haddr_t addr)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->obj_count);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->obj_count);
+    assert(H5_addr_defined(addr));
 
     /* Get the object node from the container */
     if (NULL != (obj_count = (H5FO_obj_count_t *)H5SL_search(f->obj_count, &addr))) {
@@ -490,14 +489,14 @@ H5FO_top_decr(const H5F_t *f, haddr_t addr)
         if (obj_count->count == 0) {
             /* Remove from container */
             if (NULL == (obj_count = (H5FO_obj_count_t *)H5SL_remove(f->obj_count, &addr)))
-                HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "can't remove object from container")
+                HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "can't remove object from container");
 
             /* Release the object information */
             obj_count = H5FL_FREE(H5FO_obj_count_t, obj_count);
         } /* end if */
     }     /* end if */
     else
-        HGOTO_ERROR(H5E_CACHE, H5E_NOTFOUND, FAIL, "can't decrement ref. count")
+        HGOTO_ERROR(H5E_CACHE, H5E_NOTFOUND, FAIL, "can't decrement ref. count");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -531,9 +530,9 @@ H5FO_top_count(const H5F_t *f, haddr_t addr)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->obj_count);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->obj_count);
+    assert(H5_addr_defined(addr));
 
     /* Get the object node from the container */
     if (NULL != (obj_count = (H5FO_obj_count_t *)H5SL_search(f->obj_count, &addr)))
@@ -570,16 +569,16 @@ H5FO_top_dest(H5F_t *f)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(f->obj_count);
+    assert(f);
+    assert(f->obj_count);
 
     /* Check if the object count set is empty */
     if (H5SL_count(f->obj_count) != 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "objects still in open object info set")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "objects still in open object info set");
 
     /* Release the open object count set container */
     if (H5SL_close(f->obj_count) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTCLOSEOBJ, FAIL, "can't close open object info set")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTCLOSEOBJ, FAIL, "can't close open object info set");
 
     f->obj_count = NULL;
 
