@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Faccum.c
- *                      Jan 10 2008
- *                      Quincey Koziol
  *
  * Purpose:             File metadata "accumulator" routines.  (Used to
  *                      cache small metadata I/Os and group them into a
@@ -93,9 +91,6 @@ H5FL_BLK_DEFINE_STATIC(meta_accum);
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Jan 10 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -107,8 +102,8 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert(buf);
+    assert(f_sh);
+    assert(buf);
 
     /* Translate to file driver I/O info object */
     file = f_sh->lf;
@@ -122,11 +117,11 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
 
         if (size < H5F_ACCUM_MAX_SIZE) {
             /* Sanity check */
-            HDassert(!accum->buf || (accum->alloc_size >= accum->size));
+            assert(!accum->buf || (accum->alloc_size >= accum->size));
 
             /* Current read adjoins or overlaps with metadata accumulator */
-            if (H5F_addr_defined(accum->loc) &&
-                (H5F_addr_overlap(addr, size, accum->loc, accum->size) || ((addr + size) == accum->loc) ||
+            if (H5_addr_defined(accum->loc) &&
+                (H5_addr_overlap(addr, size, accum->loc, accum->size) || ((addr + size) == accum->loc) ||
                  (accum->loc + accum->size) == addr)) {
                 size_t  amount_before; /* Amount to read before current accumulator */
                 haddr_t new_addr;      /* New address of the accumulator buffer */
@@ -146,13 +141,13 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
                     /* Reallocate the metadata accumulator buffer */
                     if (NULL == (accum->buf = H5FL_BLK_REALLOC(meta_accum, accum->buf, new_alloc_size)))
                         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                                    "unable to allocate metadata accumulator buffer")
+                                    "unable to allocate metadata accumulator buffer");
 
                     /* Note the new buffer size */
                     accum->alloc_size = new_alloc_size;
 
                     /* Clear the memory */
-                    HDmemset(accum->buf + accum->size, 0, (accum->alloc_size - accum->size));
+                    memset(accum->buf + accum->size, 0, (accum->alloc_size - accum->size));
                 } /* end if */
 
                 /* Read the part before the metadata accumulator */
@@ -161,7 +156,7 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
                     H5_CHECKED_ASSIGN(amount_before, size_t, (accum->loc - addr), hsize_t);
 
                     /* Make room for the metadata to read in */
-                    HDmemmove(accum->buf + amount_before, accum->buf, accum->size);
+                    memmove(accum->buf + amount_before, accum->buf, accum->size);
 
                     /* Adjust dirty region tracking info, if present */
                     if (accum->dirty)
@@ -169,7 +164,7 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
 
                     /* Dispatch to driver */
                     if (H5FD_read(file, map_type, addr, amount_before, accum->buf) < 0)
-                        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
+                        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed");
                 } /* end if */
                 else
                     amount_before = 0;
@@ -185,7 +180,7 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
                     /* Dispatch to driver */
                     if (H5FD_read(file, map_type, (accum->loc + accum->size), amount_after,
                                   (accum->buf + accum->size + amount_before)) < 0)
-                        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
+                        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed");
                 } /* end if */
 
                 /* Copy the data out of the buffer */
@@ -199,13 +194,13 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
             else {
                 /* Dispatch to driver */
                 if (H5FD_read(file, map_type, addr, size, buf) < 0)
-                    HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
+                    HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed");
             } /* end else */
         }     /* end if */
         else {
             /* Read the data */
             if (H5FD_read(file, map_type, addr, size, buf) < 0)
-                HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
+                HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed");
 
             /* Check for overlap w/dirty accumulator */
             /* (Note that this could be improved by updating the non-dirty
@@ -213,14 +208,14 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
              *  just read in. -QAK)
              */
             if (accum->dirty &&
-                H5F_addr_overlap(addr, size, accum->loc + accum->dirty_off, accum->dirty_len)) {
+                H5_addr_overlap(addr, size, accum->loc + accum->dirty_off, accum->dirty_len)) {
                 haddr_t dirty_loc = accum->loc + accum->dirty_off; /* File offset of dirty information */
                 size_t  buf_off;                                   /* Offset of dirty region in buffer */
                 size_t  dirty_off;                                 /* Offset within dirty region */
                 size_t  overlap_size;                              /* Size of overlap with dirty region */
 
                 /* Check for read starting before beginning dirty region */
-                if (H5F_addr_le(addr, dirty_loc)) {
+                if (H5_addr_le(addr, dirty_loc)) {
                     /* Compute offset of dirty region within buffer */
                     buf_off = (size_t)(dirty_loc - addr);
 
@@ -228,7 +223,7 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
                     dirty_off = 0;
 
                     /* Check for read ending within dirty region */
-                    if (H5F_addr_lt(addr + size, dirty_loc + accum->dirty_len))
+                    if (H5_addr_lt(addr + size, dirty_loc + accum->dirty_len))
                         overlap_size = (size_t)((addr + size) - buf_off);
                     else /* Access covers whole dirty region */
                         overlap_size = accum->dirty_len;
@@ -249,7 +244,7 @@ H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t si
     else {
         /* Read the data */
         if (H5FD_read(file, map_type, addr, size, buf) < 0)
-            HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
+            HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed");
     } /* end else */
 
 done:
@@ -263,9 +258,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Jun 11 2009
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -275,11 +267,11 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, H5FD_t *file, H5F_accum_adjust_t adju
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(accum);
-    HDassert(file);
-    HDassert(H5F_ACCUM_APPEND == adjust || H5F_ACCUM_PREPEND == adjust);
-    HDassert(size > 0);
-    HDassert(size <= H5F_ACCUM_MAX_SIZE);
+    assert(accum);
+    assert(file);
+    assert(H5F_ACCUM_APPEND == adjust || H5F_ACCUM_PREPEND == adjust);
+    assert(size > 0);
+    assert(size <= H5F_ACCUM_MAX_SIZE);
 
     /* Check if we need more buffer space */
     if ((size + accum->size) > accum->alloc_size) {
@@ -338,7 +330,7 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, H5FD_t *file, H5F_accum_adjust_t adju
                          */
                         if (H5FD_write(file, H5FD_MEM_DEFAULT, (accum->loc + accum->dirty_off),
                                        accum->dirty_len, (accum->buf + accum->dirty_off)) < 0)
-                            HGOTO_ERROR(H5E_FILE, H5E_WRITEERROR, FAIL, "file write failed")
+                            HGOTO_ERROR(H5E_FILE, H5E_WRITEERROR, FAIL, "file write failed");
 
                         /* Reset accumulator dirty flag */
                         accum->dirty = FALSE;
@@ -351,7 +343,7 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, H5FD_t *file, H5F_accum_adjust_t adju
                          */
                         if (H5FD_write(file, H5FD_MEM_DEFAULT, (accum->loc + accum->dirty_off),
                                        accum->dirty_len, (accum->buf + accum->dirty_off)) < 0)
-                            HGOTO_ERROR(H5E_FILE, H5E_WRITEERROR, FAIL, "file write failed")
+                            HGOTO_ERROR(H5E_FILE, H5E_WRITEERROR, FAIL, "file write failed");
 
                         /* Reset accumulator dirty flag */
                         accum->dirty = FALSE;
@@ -368,7 +360,7 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, H5FD_t *file, H5F_accum_adjust_t adju
             /* When appending, need to adjust location of accumulator */
             if (H5F_ACCUM_APPEND == adjust) {
                 /* Move remnant of accumulator down */
-                HDmemmove(accum->buf, (accum->buf + shrink_size), remnant_size);
+                memmove(accum->buf, (accum->buf + shrink_size), remnant_size);
 
                 /* Adjust accumulator's location */
                 accum->loc += shrink_size;
@@ -381,14 +373,14 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, H5FD_t *file, H5F_accum_adjust_t adju
 
             /* Reallocate the metadata accumulator buffer */
             if (NULL == (new_buf = H5FL_BLK_REALLOC(meta_accum, accum->buf, new_size)))
-                HGOTO_ERROR(H5E_FILE, H5E_CANTALLOC, FAIL, "unable to allocate metadata accumulator buffer")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTALLOC, FAIL, "unable to allocate metadata accumulator buffer");
 
             /* Update accumulator info */
             accum->buf        = new_buf;
             accum->alloc_size = new_size;
 
             /* Clear the memory */
-            HDmemset(accum->buf + accum->size, 0, (accum->alloc_size - (accum->size + size)));
+            memset(accum->buf + accum->size, 0, (accum->alloc_size - (accum->size + size)));
         } /* end if */
     }     /* end if */
 
@@ -404,9 +396,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Jan 10 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -418,9 +407,9 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert(H5F_SHARED_INTENT(f_sh) & H5F_ACC_RDWR);
-    HDassert(buf);
+    assert(f_sh);
+    assert(H5F_SHARED_INTENT(f_sh) & H5F_ACC_RDWR);
+    assert(buf);
 
     /* Translate to file driver pointer */
     file = f_sh->lf;
@@ -434,18 +423,18 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
 
         if (size < H5F_ACCUM_MAX_SIZE) {
             /* Sanity check */
-            HDassert(!accum->buf || (accum->alloc_size >= accum->size));
+            assert(!accum->buf || (accum->alloc_size >= accum->size));
 
             /* Check if there is already metadata in the accumulator */
             if (accum->size > 0) {
                 /* Check if the new metadata adjoins the beginning of the current accumulator */
-                if (H5F_addr_defined(accum->loc) && (addr + size) == accum->loc) {
+                if (H5_addr_defined(accum->loc) && (addr + size) == accum->loc) {
                     /* Check if we need to adjust accumulator size */
                     if (H5F__accum_adjust(accum, file, H5F_ACCUM_PREPEND, size) < 0)
-                        HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
+                        HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator");
 
                     /* Move the existing metadata to the proper location */
-                    HDmemmove(accum->buf + size, accum->buf, accum->size);
+                    memmove(accum->buf + size, accum->buf, accum->size);
 
                     /* Copy the new metadata at the front */
                     H5MM_memcpy(accum->buf, buf, size);
@@ -464,10 +453,10 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                     accum->dirty_off = 0;
                 } /* end if */
                 /* Check if the new metadata adjoins the end of the current accumulator */
-                else if (H5F_addr_defined(accum->loc) && addr == (accum->loc + accum->size)) {
+                else if (H5_addr_defined(accum->loc) && addr == (accum->loc + accum->size)) {
                     /* Check if we need to adjust accumulator size */
                     if (H5F__accum_adjust(accum, file, H5F_ACCUM_APPEND, size) < 0)
-                        HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
+                        HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator");
 
                     /* Copy the new metadata to the end */
                     H5MM_memcpy(accum->buf + accum->size, buf, size);
@@ -485,8 +474,8 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                     accum->size += size;
                 } /* end if */
                 /* Check if the piece of metadata being written overlaps the metadata accumulator */
-                else if (H5F_addr_defined(accum->loc) &&
-                         H5F_addr_overlap(addr, size, accum->loc, accum->size)) {
+                else if (H5_addr_defined(accum->loc) &&
+                         H5_addr_overlap(addr, size, accum->loc, accum->size)) {
                     size_t add_size; /* New size of the accumulator buffer */
 
                     /* Check if the new metadata is entirely within the current accumulator */
@@ -529,13 +518,13 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
 
                         /* Check if we need to adjust accumulator size */
                         if (H5F__accum_adjust(accum, file, H5F_ACCUM_PREPEND, add_size) < 0)
-                            HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
+                            HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator");
 
                         /* Calculate the proper offset of the existing metadata */
                         H5_CHECKED_ASSIGN(old_offset, size_t, (addr + size) - accum->loc, hsize_t);
 
                         /* Move the existing metadata to the proper location */
-                        HDmemmove(accum->buf + size, accum->buf + old_offset, (accum->size - old_offset));
+                        memmove(accum->buf + size, accum->buf + old_offset, (accum->size - old_offset));
 
                         /* Copy the new metadata at the front */
                         H5MM_memcpy(accum->buf, buf, size);
@@ -571,7 +560,7 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
 
                         /* Check if we need to adjust accumulator size */
                         if (H5F__accum_adjust(accum, file, H5F_ACCUM_APPEND, add_size) < 0)
-                            HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
+                            HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator");
 
                         /* Compute offset of dirty region (after adjusting accumulator) */
                         dirty_off = (size_t)(addr - accum->loc);
@@ -612,13 +601,13 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                             if (NULL ==
                                 (accum->buf = H5FL_BLK_REALLOC(meta_accum, accum->buf, new_alloc_size)))
                                 HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                                            "unable to allocate metadata accumulator buffer")
+                                            "unable to allocate metadata accumulator buffer");
 
                             /* Note the new buffer size */
                             accum->alloc_size = new_alloc_size;
 
                             /* Clear the memory */
-                            HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
+                            memset(accum->buf + size, 0, (accum->alloc_size - size));
                         } /* end if */
 
                         /* Copy the new metadata to the buffer */
@@ -640,7 +629,7 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                     if (accum->dirty) {
                         if (H5FD_write(file, H5FD_MEM_DEFAULT, accum->loc + accum->dirty_off,
                                        accum->dirty_len, accum->buf + accum->dirty_off) < 0)
-                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
+                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed");
 
                         /* Reset accumulator dirty flag */
                         accum->dirty = FALSE;
@@ -658,14 +647,14 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                         /* Grow the metadata accumulator buffer */
                         if (NULL == (accum->buf = H5FL_BLK_REALLOC(meta_accum, accum->buf, new_size)))
                             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                                        "unable to allocate metadata accumulator buffer")
+                                        "unable to allocate metadata accumulator buffer");
 
                         /* Note the new buffer size */
                         accum->alloc_size = new_size;
 
                         /* Clear the memory */
                         clear_size = MAX(accum->size, size);
-                        HDmemset(accum->buf + clear_size, 0, (accum->alloc_size - clear_size));
+                        memset(accum->buf + clear_size, 0, (accum->alloc_size - clear_size));
                     } /* end if */
                     else {
                         /* Check if we should shrink the accumulator buffer */
@@ -677,7 +666,7 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                             /* Shrink the accumulator buffer */
                             if (NULL == (accum->buf = H5FL_BLK_REALLOC(meta_accum, accum->buf, tmp_size)))
                                 HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                                            "unable to allocate metadata accumulator buffer")
+                                            "unable to allocate metadata accumulator buffer");
 
                             /* Note the new buffer size */
                             accum->alloc_size = tmp_size;
@@ -709,13 +698,13 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                     /* Reallocate the metadata accumulator buffer */
                     if (NULL == (accum->buf = H5FL_BLK_REALLOC(meta_accum, accum->buf, new_size)))
                         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                                    "unable to allocate metadata accumulator buffer")
+                                    "unable to allocate metadata accumulator buffer");
 
                     /* Note the new buffer size */
                     accum->alloc_size = new_size;
 
                     /* Clear the memory */
-                    HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
+                    memset(accum->buf + size, 0, (accum->alloc_size - size));
                 } /* end if */
 
                 /* Update the metadata accumulator information */
@@ -736,21 +725,21 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
             if ((H5F_SHARED_INTENT(f_sh) & H5F_ACC_SWMR_WRITE) > 0)
                 /* Flush if dirty and reset accumulator */
                 if (H5F__accum_reset(f_sh, TRUE) < 0)
-                    HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator")
+                    HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator");
 
             /* Write the data */
             if (H5FD_write(file, map_type, addr, size, buf) < 0)
-                HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
+                HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed");
 
             /* Check for overlap w/accumulator */
             /* (Note that this could be improved by updating the accumulator
              *  with [some of] the information just read in. -QAK)
              */
-            if (H5F_addr_defined(accum->loc) && H5F_addr_overlap(addr, size, accum->loc, accum->size)) {
+            if (H5_addr_defined(accum->loc) && H5_addr_overlap(addr, size, accum->loc, accum->size)) {
                 /* Check for write starting before beginning of accumulator */
-                if (H5F_addr_le(addr, accum->loc)) {
+                if (H5_addr_le(addr, accum->loc)) {
                     /* Check for write ending within accumulator */
-                    if (H5F_addr_le(addr + size, accum->loc + accum->size)) {
+                    if (H5_addr_le(addr + size, accum->loc + accum->size)) {
                         size_t overlap_size; /* Size of overlapping region */
 
                         /* Compute overlap size */
@@ -764,13 +753,13 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                                 dirty_start + accum->dirty_len; /* File address of end of dirty region */
 
                             /* Check if entire dirty region is overwritten */
-                            if (H5F_addr_le(dirty_end, addr + size)) {
+                            if (H5_addr_le(dirty_end, addr + size)) {
                                 accum->dirty     = FALSE;
                                 accum->dirty_len = 0;
                             } /* end if */
                             else {
                                 /* Check for dirty region falling after write */
-                                if (H5F_addr_le(addr + size, dirty_start))
+                                if (H5_addr_le(addr + size, dirty_start))
                                     accum->dirty_off = overlap_size;
                                 else { /* Dirty region overlaps w/written region */
                                     accum->dirty_off = 0;
@@ -782,19 +771,19 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                         /* Trim bottom of accumulator off */
                         accum->loc += overlap_size;
                         accum->size -= overlap_size;
-                        HDmemmove(accum->buf, accum->buf + overlap_size, accum->size);
+                        memmove(accum->buf, accum->buf + overlap_size, accum->size);
                     }      /* end if */
                     else { /* Access covers whole accumulator */
                         /* Reset accumulator, but don't flush */
                         if (H5F__accum_reset(f_sh, FALSE) < 0)
-                            HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator")
+                            HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator");
                     }                    /* end else */
                 }                        /* end if */
                 else {                   /* Write starts after beginning of accumulator */
                     size_t overlap_size; /* Size of overlapping region */
 
                     /* Sanity check */
-                    HDassert(H5F_addr_gt(addr + size, accum->loc + accum->size));
+                    assert(H5_addr_gt(addr + size, accum->loc + accum->size));
 
                     /* Compute overlap size */
                     overlap_size = (size_t)((accum->loc + accum->size) - addr);
@@ -807,13 +796,13 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
                             dirty_start + accum->dirty_len; /* File address of end of dirty region */
 
                         /* Check if entire dirty region is overwritten */
-                        if (H5F_addr_ge(dirty_start, addr)) {
+                        if (H5_addr_ge(dirty_start, addr)) {
                             accum->dirty     = FALSE;
                             accum->dirty_len = 0;
                         } /* end if */
                         else {
                             /* Check for dirty region falling before write */
-                            if (H5F_addr_le(dirty_end, addr))
+                            if (H5_addr_le(dirty_end, addr))
                                 ; /* noop */
                             else  /* Dirty region overlaps w/written region */
                                 accum->dirty_len = (size_t)(addr - dirty_start);
@@ -829,7 +818,7 @@ H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr, size_t s
     else {
         /* Write the data */
         if (H5FD_write(file, map_type, addr, size, buf) < 0)
-            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
+            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed");
     } /* end else */
 
 done:
@@ -844,9 +833,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Jan 10 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -859,7 +845,7 @@ H5F__accum_free(H5F_shared_t *f_sh, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(f_sh);
+    assert(f_sh);
 
     /* Set up alias for file's metadata accumulator info */
     accum = &f_sh->accum;
@@ -868,19 +854,19 @@ H5F__accum_free(H5F_shared_t *f_sh, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr
     file = f_sh->lf;
 
     /* Adjust the metadata accumulator to remove the freed block, if it overlaps */
-    if ((f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && H5F_addr_defined(accum->loc) &&
-        H5F_addr_overlap(addr, size, accum->loc, accum->size)) {
+    if ((f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && H5_addr_defined(accum->loc) &&
+        H5_addr_overlap(addr, size, accum->loc, accum->size)) {
         size_t overlap_size; /* Size of overlap with accumulator */
 
         /* Sanity check */
         /* (The metadata accumulator should not intersect w/raw data */
-        HDassert(H5FD_MEM_DRAW != type);
-        HDassert(H5FD_MEM_GHEAP != type); /* (global heap data is being treated as raw data currently) */
+        assert(H5FD_MEM_DRAW != type);
+        assert(H5FD_MEM_GHEAP != type); /* (global heap data is being treated as raw data currently) */
 
         /* Check for overlapping the beginning of the accumulator */
-        if (H5F_addr_le(addr, accum->loc)) {
+        if (H5_addr_le(addr, accum->loc)) {
             /* Check for completely overlapping the accumulator */
-            if (H5F_addr_ge(addr + size, accum->loc + accum->size)) {
+            if (H5_addr_ge(addr + size, accum->loc + accum->size)) {
                 /* Reset the accumulator, but don't free buffer */
                 accum->loc   = HADDR_UNDEF;
                 accum->size  = 0;
@@ -895,7 +881,7 @@ H5F__accum_free(H5F_shared_t *f_sh, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr
                 new_accum_size = accum->size - overlap_size;
 
                 /* Move the accumulator buffer information to eliminate the freed block */
-                HDmemmove(accum->buf, accum->buf + overlap_size, new_accum_size);
+                memmove(accum->buf, accum->buf + overlap_size, new_accum_size);
 
                 /* Adjust the accumulator information */
                 accum->loc += overlap_size;
@@ -928,36 +914,36 @@ H5F__accum_free(H5F_shared_t *f_sh, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr
             H5_CHECKED_ASSIGN(overlap_size, size_t, (accum->loc + accum->size) - addr, haddr_t);
 
             /* Check if block to free begins before end of dirty region */
-            if (accum->dirty && H5F_addr_lt(addr, dirty_end)) {
+            if (accum->dirty && H5_addr_lt(addr, dirty_end)) {
                 haddr_t tail_addr;
 
                 /* Calculate the address of the tail to write */
                 tail_addr = addr + size;
 
                 /* Check if the block to free begins before dirty region */
-                if (H5F_addr_lt(addr, dirty_start)) {
+                if (H5_addr_lt(addr, dirty_start)) {
                     /* Check if block to free is entirely before dirty region */
-                    if (H5F_addr_le(tail_addr, dirty_start)) {
+                    if (H5_addr_le(tail_addr, dirty_start)) {
                         /* Write out the entire dirty region of the accumulator */
                         if (H5FD_write(file, H5FD_MEM_DEFAULT, dirty_start, accum->dirty_len,
                                        accum->buf + accum->dirty_off) < 0)
-                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
+                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed");
                     } /* end if */
                     /* Block to free overlaps with some/all of dirty region */
                     /* Check for unfreed dirty region to write */
-                    else if (H5F_addr_lt(tail_addr, dirty_end)) {
+                    else if (H5_addr_lt(tail_addr, dirty_end)) {
                         size_t write_size;
                         size_t dirty_delta;
 
                         write_size  = (size_t)(dirty_end - tail_addr);
                         dirty_delta = accum->dirty_len - write_size;
 
-                        HDassert(write_size > 0);
+                        assert(write_size > 0);
 
                         /* Write out the unfreed dirty region of the accumulator */
                         if (H5FD_write(file, H5FD_MEM_DEFAULT, dirty_start + dirty_delta, write_size,
                                        accum->buf + accum->dirty_off + dirty_delta) < 0)
-                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
+                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed");
                     } /* end if */
 
                     /* Reset dirty flag */
@@ -966,23 +952,23 @@ H5F__accum_free(H5F_shared_t *f_sh, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr
                 /* Block to free begins at beginning of or in middle of dirty region */
                 else {
                     /* Check if block to free ends before end of dirty region */
-                    if (H5F_addr_lt(tail_addr, dirty_end)) {
+                    if (H5_addr_lt(tail_addr, dirty_end)) {
                         size_t write_size;
                         size_t dirty_delta;
 
                         write_size  = (size_t)(dirty_end - tail_addr);
                         dirty_delta = accum->dirty_len - write_size;
 
-                        HDassert(write_size > 0);
+                        assert(write_size > 0);
 
                         /* Write out the unfreed end of the dirty region of the accumulator */
                         if (H5FD_write(file, H5FD_MEM_DEFAULT, dirty_start + dirty_delta, write_size,
                                        accum->buf + accum->dirty_off + dirty_delta) < 0)
-                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
+                            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed");
                     } /* end if */
 
                     /* Check for block to free beginning at same location as dirty region */
-                    if (H5F_addr_eq(addr, dirty_start)) {
+                    if (H5_addr_eq(addr, dirty_start)) {
                         /* Reset dirty flag */
                         accum->dirty = FALSE;
                     } /* end if */
@@ -1010,9 +996,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Jan 10 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1023,7 +1006,7 @@ H5F__accum_flush(H5F_shared_t *f_sh)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
+    assert(f_sh);
 
     /* Check if we need to flush out the metadata accumulator */
     if ((f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && f_sh->accum.dirty) {
@@ -1035,7 +1018,7 @@ H5F__accum_flush(H5F_shared_t *f_sh)
         /* Flush the metadata contents */
         if (H5FD_write(file, H5FD_MEM_DEFAULT, f_sh->accum.loc + f_sh->accum.dirty_off, f_sh->accum.dirty_len,
                        f_sh->accum.buf + f_sh->accum.dirty_off) < 0)
-            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
+            HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed");
 
         /* Reset the dirty flag */
         f_sh->accum.dirty = FALSE;
@@ -1052,9 +1035,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Jan 10 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1065,12 +1045,12 @@ H5F__accum_reset(H5F_shared_t *f_sh, hbool_t flush)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(f_sh);
+    assert(f_sh);
 
     /* Flush any dirty data in accumulator, if requested */
     if (flush)
         if (H5F__accum_flush(f_sh) < 0)
-            HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "can't flush metadata accumulator")
+            HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "can't flush metadata accumulator");
 
     /* Check if we need to reset the metadata accumulator information */
     if (f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) {
