@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol
- *              Tuesday, July 19, 2011
- *
  * Purpose:	Each file has a small cache of global heap collections called
  *		the CWFS list and recently accessed collections with free
  *		space appear on this list.  As collections are accessed the
@@ -86,9 +83,6 @@
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, July 19, 2011
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -99,9 +93,9 @@ H5F_cwfs_add(H5F_t *f, H5HG_heap_t *heap)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check args */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(heap);
+    assert(f);
+    assert(f->shared);
+    assert(heap);
 
     /*
      * Add the new heap to the CWFS list, removing some other entry if
@@ -110,7 +104,7 @@ H5F_cwfs_add(H5F_t *f, H5HG_heap_t *heap)
      */
     if (NULL == f->shared->cwfs) {
         if (NULL == (f->shared->cwfs = (H5HG_heap_t **)H5MM_malloc(H5F_NCWFS * sizeof(H5HG_heap_t *))))
-            HGOTO_ERROR(H5E_FILE, H5E_CANTALLOC, FAIL, "can't allocate CWFS for file")
+            HGOTO_ERROR(H5E_FILE, H5E_CANTALLOC, FAIL, "can't allocate CWFS for file");
         f->shared->cwfs[0] = heap;
         f->shared->ncwfs   = 1;
     }
@@ -119,13 +113,13 @@ H5F_cwfs_add(H5F_t *f, H5HG_heap_t *heap)
 
         for (i = H5F_NCWFS - 1; i >= 0; --i)
             if (H5HG_FREE_SIZE(f->shared->cwfs[i]) < H5HG_FREE_SIZE(heap)) {
-                HDmemmove(f->shared->cwfs + 1, f->shared->cwfs, (size_t)i * sizeof(H5HG_heap_t *));
+                memmove(f->shared->cwfs + 1, f->shared->cwfs, (size_t)i * sizeof(H5HG_heap_t *));
                 f->shared->cwfs[0] = heap;
                 break;
             } /* end if */
     }
     else {
-        HDmemmove(f->shared->cwfs + 1, f->shared->cwfs, f->shared->ncwfs * sizeof(H5HG_heap_t *));
+        memmove(f->shared->cwfs + 1, f->shared->cwfs, f->shared->ncwfs * sizeof(H5HG_heap_t *));
         f->shared->cwfs[0] = heap;
         f->shared->ncwfs += 1;
     } /* end else */
@@ -143,9 +137,6 @@ done:
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Wednesday, July 20, 2011
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -158,9 +149,9 @@ H5F_cwfs_find_free_heap(H5F_t *f, size_t need, haddr_t *addr)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check args */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(addr);
+    assert(f);
+    assert(f->shared);
+    assert(addr);
 
     /* Note that we don't have metadata cache locks on the entries in
      * f->shared->cwfs.
@@ -204,10 +195,11 @@ H5F_cwfs_find_free_heap(H5F_t *f, size_t need, haddr_t *addr)
                     H5MF_try_extend(f, H5FD_MEM_GHEAP, H5HG_ADDR(f->shared->cwfs[cwfsno]),
                                     (hsize_t)H5HG_SIZE(f->shared->cwfs[cwfsno]), (hsize_t)new_need);
                 if (was_extended < 0)
-                    HGOTO_ERROR(H5E_HEAP, H5E_CANTEXTEND, FAIL, "error trying to extend heap")
+                    HGOTO_ERROR(H5E_HEAP, H5E_CANTEXTEND, FAIL, "error trying to extend heap");
                 else if (was_extended == TRUE) {
                     if (H5HG_extend(f, H5HG_ADDR(f->shared->cwfs[cwfsno]), new_need) < 0)
-                        HGOTO_ERROR(H5E_HEAP, H5E_CANTRESIZE, FAIL, "unable to extend global heap collection")
+                        HGOTO_ERROR(H5E_HEAP, H5E_CANTRESIZE, FAIL,
+                                    "unable to extend global heap collection");
                     *addr = H5HG_ADDR(f->shared->cwfs[cwfsno]);
                     found = TRUE;
                     break;
@@ -240,9 +232,6 @@ done:
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Wednesday, July 20, 2011
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -254,9 +243,9 @@ H5F_cwfs_advance_heap(H5F_t *f, H5HG_heap_t *heap, hbool_t add_heap)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check args */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(heap);
+    assert(f);
+    assert(f->shared);
+    assert(heap);
 
     for (u = 0; u < f->shared->ncwfs; u++)
         if (f->shared->cwfs[u] == heap) {
@@ -282,9 +271,6 @@ H5F_cwfs_advance_heap(H5F_t *f, H5HG_heap_t *heap, hbool_t add_heap)
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Wednesday, July 20, 2011
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -296,14 +282,14 @@ H5F_cwfs_remove_heap(H5F_shared_t *shared, H5HG_heap_t *heap)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check args */
-    HDassert(shared);
-    HDassert(heap);
+    assert(shared);
+    assert(heap);
 
     /* Remove the heap from the CWFS list */
     for (u = 0; u < shared->ncwfs; u++) {
         if (shared->cwfs[u] == heap) {
             shared->ncwfs -= 1;
-            HDmemmove(shared->cwfs + u, shared->cwfs + u + 1, (shared->ncwfs - u) * sizeof(H5HG_heap_t *));
+            memmove(shared->cwfs + u, shared->cwfs + u + 1, (shared->ncwfs - u) * sizeof(H5HG_heap_t *));
             break;
         } /* end if */
     }     /* end for */
