@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Fio.c
- *                      Jan 10 2008
- *                      Quincey Koziol
  *
  * Purpose:             File I/O routines.
  *
@@ -74,9 +72,6 @@
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Jul 10 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -88,20 +83,20 @@ H5F_shared_block_read(H5F_shared_t *f_sh, H5FD_mem_t type, haddr_t addr, size_t
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert(buf);
-    HDassert(H5F_addr_defined(addr));
+    assert(f_sh);
+    assert(buf);
+    assert(H5_addr_defined(addr));
 
     /* Check for attempting I/O on 'temporary' file address */
-    if (H5F_addr_le(f_sh->tmp_addr, (addr + size)))
-        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space")
+    if (H5_addr_le(f_sh->tmp_addr, (addr + size)))
+        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space");
 
     /* Treat global heap as raw data */
     map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
 
     /* Pass through page buffer layer */
     if (H5PB_read(f_sh, map_type, addr, size, buf) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "read through page buffer failed")
+        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "read through page buffer failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -116,9 +111,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Jul 10 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -130,21 +122,21 @@ H5F_block_read(H5F_t *f, H5FD_mem_t type, haddr_t addr, size_t size, void *buf /
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(buf);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->shared);
+    assert(buf);
+    assert(H5_addr_defined(addr));
 
     /* Check for attempting I/O on 'temporary' file address */
-    if (H5F_addr_le(f->shared->tmp_addr, (addr + size)))
-        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space")
+    if (H5_addr_le(f->shared->tmp_addr, (addr + size)))
+        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space");
 
     /* Treat global heap as raw data */
     map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
 
     /* Pass through page buffer layer */
     if (H5PB_read(f->shared, map_type, addr, size, buf) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "read through page buffer failed")
+        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "read through page buffer failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -159,9 +151,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Jul 10 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -173,21 +162,21 @@ H5F_shared_block_write(H5F_shared_t *f_sh, H5FD_mem_t type, haddr_t addr, size_t
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert(H5F_SHARED_INTENT(f_sh) & H5F_ACC_RDWR);
-    HDassert(buf);
-    HDassert(H5F_addr_defined(addr));
+    assert(f_sh);
+    assert(H5F_SHARED_INTENT(f_sh) & H5F_ACC_RDWR);
+    assert(buf);
+    assert(H5_addr_defined(addr));
 
     /* Check for attempting I/O on 'temporary' file address */
-    if (H5F_addr_le(f_sh->tmp_addr, (addr + size)))
-        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space")
+    if (H5_addr_le(f_sh->tmp_addr, (addr + size)))
+        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space");
 
     /* Treat global heap as raw data */
     map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
 
     /* Pass through page buffer layer */
     if (H5PB_write(f_sh, map_type, addr, size, buf) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "write through page buffer failed")
+        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "write through page buffer failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -202,9 +191,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Jul 10 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -216,22 +202,22 @@ H5F_block_write(H5F_t *f, H5FD_mem_t type, haddr_t addr, size_t size, const void
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(H5F_INTENT(f) & H5F_ACC_RDWR);
-    HDassert(buf);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(f->shared);
+    assert(H5F_INTENT(f) & H5F_ACC_RDWR);
+    assert(buf);
+    assert(H5_addr_defined(addr));
 
     /* Check for attempting I/O on 'temporary' file address */
-    if (H5F_addr_le(f->shared->tmp_addr, (addr + size)))
-        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space")
+    if (H5_addr_le(f->shared->tmp_addr, (addr + size)))
+        HGOTO_ERROR(H5E_IO, H5E_BADRANGE, FAIL, "attempting I/O in temporary file space");
 
     /* Treat global heap as raw data */
     map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
 
     /* Pass through page buffer layer */
     if (H5PB_write(f->shared, map_type, addr, size, buf) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "write through page buffer failed")
+        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "write through page buffer failed");
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_block_write() */
@@ -247,9 +233,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Neil Fortner
- *              May 3 2021
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -262,12 +245,12 @@ H5F_shared_select_read(H5F_shared_t *f_sh, H5FD_mem_t type, uint32_t count, H5S_
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert((mem_spaces) || (count == 0));
-    HDassert((file_spaces) || (count == 0));
-    HDassert((offsets) || (count == 0));
-    HDassert((element_sizes) || (count == 0));
-    HDassert((bufs) || (count == 0));
+    assert(f_sh);
+    assert((mem_spaces) || (count == 0));
+    assert((file_spaces) || (count == 0));
+    assert((offsets) || (count == 0));
+    assert((element_sizes) || (count == 0));
+    assert((bufs) || (count == 0));
 
     /* Treat global heap as raw data */
     map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
@@ -275,7 +258,7 @@ H5F_shared_select_read(H5F_shared_t *f_sh, H5FD_mem_t type, uint32_t count, H5S_
     /* Pass down to file driver layer (bypass page buffer for now) */
     if (H5FD_read_selection(f_sh->lf, map_type, count, mem_spaces, file_spaces, offsets, element_sizes,
                             bufs) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "selection read through file driver failed")
+        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "selection read through file driver failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -292,9 +275,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Neil Fortner
- *              May 4 2021
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -307,12 +287,12 @@ H5F_shared_select_write(H5F_shared_t *f_sh, H5FD_mem_t type, uint32_t count, H5S
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert((mem_spaces) || (count == 0));
-    HDassert((file_spaces) || (count == 0));
-    HDassert((offsets) || (count == 0));
-    HDassert((element_sizes) || (count == 0));
-    HDassert((bufs) || (count == 0));
+    assert(f_sh);
+    assert((mem_spaces) || (count == 0));
+    assert((file_spaces) || (count == 0));
+    assert((offsets) || (count == 0));
+    assert((element_sizes) || (count == 0));
+    assert((bufs) || (count == 0));
 
     /* Treat global heap as raw data */
     map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
@@ -320,7 +300,7 @@ H5F_shared_select_write(H5F_shared_t *f_sh, H5FD_mem_t type, uint32_t count, H5S
     /* Pass down to file driver layer (bypass page buffer for now) */
     if (H5FD_write_selection(f_sh->lf, map_type, count, mem_spaces, file_spaces, offsets, element_sizes,
                              bufs) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "selection write through file driver failed")
+        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "selection write through file driver failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -335,11 +315,11 @@ H5F_shared_vector_read(H5F_shared_t *f_sh, uint32_t count, H5FD_mem_t types[], h
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert((types) || (count == 0));
-    HDassert((addrs) || (count == 0));
-    HDassert((sizes) || (count == 0));
-    HDassert((bufs) || (count == 0));
+    assert(f_sh);
+    assert((types) || (count == 0));
+    assert((addrs) || (count == 0));
+    assert((sizes) || (count == 0));
+    assert((bufs) || (count == 0));
 
     /*
      * Note that we don't try to map global heap data to raw
@@ -348,13 +328,21 @@ H5F_shared_vector_read(H5F_shared_t *f_sh, uint32_t count, H5FD_mem_t types[], h
      * for now, assume the caller has done this already.
      */
 #ifndef NDEBUG
-    for (uint32_t i = 0; i < count; i++)
-        HDassert(types[i] != H5FD_MEM_GHEAP);
+    for (uint32_t i = 0; i < count; i++) {
+        /* Break early if H5FD_MEM_NOLIST was specified
+         * since a full 'count'-sized array may not
+         * have been passed for 'types'
+         */
+        if (i > 0 && types[i] == H5FD_MEM_NOLIST)
+            break;
+
+        assert(types[i] != H5FD_MEM_GHEAP);
+    }
 #endif
 
     /* Pass down to file driver layer (bypass page buffer for now) */
     if (H5FD_read_vector(f_sh->lf, count, types, addrs, sizes, bufs) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "vector read through file driver failed")
+        HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "vector read through file driver failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -380,11 +368,11 @@ H5F_shared_vector_write(H5F_shared_t *f_sh, uint32_t count, H5FD_mem_t types[],
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(f_sh);
-    HDassert((types) || (count == 0));
-    HDassert((addrs) || (count == 0));
-    HDassert((sizes) || (count == 0));
-    HDassert((bufs) || (count == 0));
+    assert(f_sh);
+    assert((types) || (count == 0));
+    assert((addrs) || (count == 0));
+    assert((sizes) || (count == 0));
+    assert((bufs) || (count == 0));
 
     /*
      * Note that we don't try to map global heap data to raw
@@ -393,13 +381,21 @@ H5F_shared_vector_write(H5F_shared_t *f_sh, uint32_t count, H5FD_mem_t types[],
      * for now, assume the caller has done this already.
      */
 #ifndef NDEBUG
-    for (uint32_t i = 0; i < count; i++)
-        HDassert(types[i] != H5FD_MEM_GHEAP);
+    for (uint32_t i = 0; i < count; i++) {
+        /* Break early if H5FD_MEM_NOLIST was specified
+         * since a full 'count'-sized array may not
+         * have been passed for 'types'
+         */
+        if (i > 0 && types[i] == H5FD_MEM_NOLIST)
+            break;
+
+        assert(types[i] != H5FD_MEM_GHEAP);
+    }
 #endif
 
     /* Pass down to file driver layer (bypass page buffer for now) */
     if (H5FD_write_vector(f_sh->lf, count, types, addrs, sizes, bufs) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "vector write through file driver failed")
+        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "vector write through file driver failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -413,9 +409,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:	Mike McGreevy
- *              September 9, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -427,47 +420,20 @@ H5F_flush_tagged_metadata(H5F_t *f, haddr_t tag)
 
     /* Use tag to search for and flush associated metadata */
     if (H5AC_flush_tagged_metadata(f, tag) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "unable to flush tagged metadata")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTFLUSH, FAIL, "unable to flush tagged metadata");
 
     /* Flush and reset the accumulator */
     if (H5F__accum_reset(f->shared, TRUE) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator")
+        HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator");
 
     /* Flush file buffers to disk. */
     if (H5FD_flush(f->shared->lf, FALSE) < 0)
-        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "low level flush failed")
+        HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "low level flush failed");
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_flush_tagged_metadata */
 
-/*-------------------------------------------------------------------------
- * Function:    H5F_evict_tagged_metadata
- *
- * Purpose:     Evicts metadata from the cache with specified tag.
- *
- * Return:      Non-negative on success/Negative on failure
- *
- * Programmer:	Mike McGreevy
- *              September 9, 2010
- *
- *-------------------------------------------------------------------------
- */
-herr_t
-H5F_evict_tagged_metadata(H5F_t *f, haddr_t tag)
-{
-    herr_t ret_value = SUCCEED;
-
-    FUNC_ENTER_NOAPI(FAIL)
-
-    /* Evict the object's metadata */
-    if (H5AC_evict_tagged_metadata(f, tag, TRUE) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTEXPUNGE, FAIL, "unable to evict tagged metadata")
-
-done:
-    FUNC_LEAVE_NOAPI(ret_value);
-} /* end H5F_evict_tagged_metadata */
-
 /*-------------------------------------------------------------------------
  * Function:    H5F__evict_cache_entries
  *
@@ -475,9 +441,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Vailin Choi
- *		Dec 2013
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -487,12 +450,12 @@ H5F__evict_cache_entries(H5F_t *f)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     /* Evict all except pinned entries in the cache */
     if (H5AC_evict(f) < 0)
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTEXPUNGE, FAIL, "unable to evict all except pinned entries")
+        HGOTO_ERROR(H5E_CACHE, H5E_CANTEXPUNGE, FAIL, "unable to evict all except pinned entries");
 
 #ifndef NDEBUG
     {
@@ -501,24 +464,24 @@ H5F__evict_cache_entries(H5F_t *f)
 
         /* Retrieve status of the superblock */
         if (H5AC_get_entry_status(f, (haddr_t)0, &status) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "unable to get entry status")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "unable to get entry status");
 
         /* Verify status of the superblock entry in the cache */
         if (!(status & H5AC_ES__IN_CACHE) || !(status & H5AC_ES__IS_PINNED))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "unable to get entry status")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "unable to get entry status");
 
         /* Get the number of cache entries */
         if (H5AC_get_cache_size(f->shared->cache, NULL, NULL, NULL, &cur_num_entries) < 0)
-            HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "H5AC_get_cache_size() failed.")
+            HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "H5AC_get_cache_size() failed.");
 
         /* Should be the only one left in the cache (the superblock) */
         if (cur_num_entries != 1)
-            HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "number of cache entries is not correct")
+            HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "number of cache entries is not correct");
     }
 #endif /* NDEBUG */
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F__evict_cache_entries() */
 
 /*-------------------------------------------------------------------------
@@ -531,9 +494,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:	Vailin Choi
- *		Sept 2013
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -542,8 +502,8 @@ H5F_get_checksums(const uint8_t *buf, size_t buf_size, uint32_t *s_chksum /*out*
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Check arguments */
-    HDassert(buf);
-    HDassert(buf_size);
+    assert(buf);
+    assert(buf_size);
 
     /* Return the stored checksum */
     if (s_chksum) {
