@@ -34,9 +34,6 @@ static void H5F__mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsign
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Saturday, July  2, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -47,7 +44,7 @@ H5F__close_mounts(H5F_t *f)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(f);
+    assert(f);
 
     /* Unmount all child files.  Loop backwards to avoid having to adjust u when
      * a file is unmounted.  Note that we rely on unsigned u "wrapping around"
@@ -61,21 +58,21 @@ H5F__close_mounts(H5F_t *f)
 
             /* Close the internal group maintaining the mount point */
             if (H5G_close(f->shared->mtab.child[u].group) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "can't close child group")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "can't close child group");
 
             /* Close the child file */
             if (H5F_try_close(f->shared->mtab.child[u].file, NULL) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, FAIL, "can't close child file")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, FAIL, "can't close child file");
 
             /* Eliminate the mount point from the table */
-            HDmemmove(f->shared->mtab.child + u, f->shared->mtab.child + u + 1,
-                      (f->shared->mtab.nmounts - u - 1) * sizeof(f->shared->mtab.child[0]));
+            memmove(f->shared->mtab.child + u, f->shared->mtab.child + u + 1,
+                    (f->shared->mtab.nmounts - u - 1) * sizeof(f->shared->mtab.child[0]));
             f->shared->mtab.nmounts--;
             f->nmounts--;
         }
     }
 
-    HDassert(f->nmounts == 0);
+    assert(f->nmounts == 0);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -90,9 +87,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Tuesday, October  6, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -111,10 +105,10 @@ H5F_mount(const H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UN
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(loc);
-    HDassert(name && *name);
-    HDassert(child);
-    HDassert(TRUE == H5P_isa_class(plist_id, H5P_FILE_MOUNT));
+    assert(loc);
+    assert(name && *name);
+    assert(child);
+    assert(TRUE == H5P_isa_class(plist_id, H5P_FILE_MOUNT));
 
     /* Set up group location to fill in */
     mp_loc.oloc = &mp_oloc;
@@ -128,41 +122,41 @@ H5F_mount(const H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UN
      * that the mount wouldn't introduce a cycle in the mount tree.
      */
     if (child->parent)
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "file is already mounted")
+        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "file is already mounted");
     if (H5G_loc_find(loc, name, &mp_loc) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "group not found")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "group not found");
     /* If the mount location is holding its file open, that file will close
      * and remove the mount as soon as we exit this function.  Prevent the
      * user from doing this.
      */
     if (mp_loc.oloc->holding_file != FALSE)
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount path cannot contain links to external files")
+        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount path cannot contain links to external files");
 
     /* Open the mount point group */
     if (NULL == (mount_point = H5G_open(&mp_loc)))
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point not found")
+        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point not found");
 
     /* Check if the proposed mount point group is already a mount point */
     if (H5G_MOUNTED(mount_point))
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use")
+        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use");
 
     /* Retrieve information from the mount point group */
     /* (Some of which we had before but was reset in mp_loc when the group
      *  "took over" the group location - QAK)
      */
     parent = H5G_fileof(mount_point);
-    HDassert(parent);
+    assert(parent);
     mp_loc.oloc = H5G_oloc(mount_point);
-    HDassert(mp_loc.oloc);
+    assert(mp_loc.oloc);
     mp_loc.path = H5G_nameof(mount_point);
-    HDassert(mp_loc.path);
+    assert(mp_loc.path);
     for (ancestor = parent; ancestor; ancestor = ancestor->parent)
         if (ancestor->shared == child->shared)
-            HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount would introduce a cycle")
+            HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount would introduce a cycle");
 
     /* Make certain that the parent & child files have the same "file close degree" */
     if (parent->shared->fc_degree != child->shared->fc_degree)
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mounted file has different file close degree than parent")
+        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mounted file has different file close degree than parent");
 
     /*
      * Use a binary search to locate the position that the child should be
@@ -177,7 +171,7 @@ H5F_mount(const H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UN
 
         md   = (lt + rt) / 2;
         oloc = H5G_oloc(parent->shared->mtab.child[md].group);
-        cmp  = H5F_addr_cmp(mp_loc.oloc->addr, oloc->addr);
+        cmp  = H5_addr_cmp(mp_loc.oloc->addr, oloc->addr);
         if (cmp < 0)
             rt = md;
         else if (cmp > 0)
@@ -186,7 +180,7 @@ H5F_mount(const H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UN
     if (cmp > 0)
         md++;
     if (!cmp)
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use")
+        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use");
 
     /* Make room in the table */
     if (parent->shared->mtab.nmounts >= parent->shared->mtab.nalloc) {
@@ -195,14 +189,14 @@ H5F_mount(const H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UN
                                                      n * sizeof(parent->shared->mtab.child[0]));
 
         if (!x)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for mount table")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for mount table");
         parent->shared->mtab.child  = x;
         parent->shared->mtab.nalloc = n;
     }
 
     /* Insert into table */
-    HDmemmove(parent->shared->mtab.child + md + 1, parent->shared->mtab.child + md,
-              (parent->shared->mtab.nmounts - md) * sizeof(parent->shared->mtab.child[0]));
+    memmove(parent->shared->mtab.child + md + 1, parent->shared->mtab.child + md,
+            (parent->shared->mtab.nmounts - md) * sizeof(parent->shared->mtab.child[0]));
     parent->shared->mtab.nmounts++;
     parent->nmounts++;
     parent->shared->mtab.child[md].group = mount_point;
@@ -211,29 +205,29 @@ H5F_mount(const H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UN
 
     /* Set the group's mountpoint flag */
     if (H5G_mount(parent->shared->mtab.child[md].group) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to set group mounted flag")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to set group mounted flag");
 
     /* Get the group location for the root group in the file to unmount */
     if (NULL == (root_loc.oloc = H5G_oloc(child->shared->root_grp)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group");
     if (NULL == (root_loc.path = H5G_nameof(child->shared->root_grp)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group");
 
     /* Search the open IDs and replace names for mount operation */
     /* We pass H5G_UNKNOWN as object type; search all IDs */
     if (H5G_name_replace(NULL, H5G_NAME_MOUNT, mp_loc.oloc->file, mp_loc.path->full_path_r,
                          root_loc.oloc->file, root_loc.path->full_path_r) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to replace name")
+        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to replace name");
 
 done:
     if (ret_value < 0) {
         if (mount_point) {
             if (H5G_close(mount_point) < 0)
-                HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close mounted group")
+                HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close mounted group");
         }
         else {
             if (H5G_loc_free(&mp_loc) < 0)
-                HDONE_ERROR(H5E_SYM, H5E_CANTRELEASE, FAIL, "unable to free mount location")
+                HDONE_ERROR(H5E_SYM, H5E_CANTRELEASE, FAIL, "unable to free mount location");
         }
     }
 
@@ -253,9 +247,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Tuesday, October  6, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -275,8 +266,8 @@ H5F_unmount(const H5G_loc_t *loc, const char *name)
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(loc);
-    HDassert(name && *name);
+    assert(loc);
+    assert(name && *name);
 
     /* Set up mount point location to fill in */
     mp_loc.oloc = &mp_oloc;
@@ -289,13 +280,13 @@ H5F_unmount(const H5G_loc_t *loc, const char *name)
      * then we must have found the mount point.
      */
     if (H5G_loc_find(loc, name, &mp_loc /*out*/) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_NOTFOUND, FAIL, "group not found")
+        HGOTO_ERROR(H5E_FILE, H5E_NOTFOUND, FAIL, "group not found");
     mp_loc_setup = TRUE;
     child        = mp_loc.oloc->file;
     mnt_oloc     = H5G_oloc(child->shared->root_grp);
     child_idx    = -1;
 
-    if (child->parent && H5F_addr_eq(mp_oloc.addr, mnt_oloc->addr)) {
+    if (child->parent && H5_addr_eq(mp_oloc.addr, mnt_oloc->addr)) {
         unsigned u; /*counters			*/
 
         /*
@@ -326,7 +317,7 @@ H5F_unmount(const H5G_loc_t *loc, const char *name)
         while (lt < rt && cmp) {
             md       = (lt + rt) / 2;
             mnt_oloc = H5G_oloc(parent->shared->mtab.child[md].group);
-            cmp      = H5F_addr_cmp(mp_oloc.addr, mnt_oloc->addr);
+            cmp      = H5_addr_cmp(mp_oloc.addr, mnt_oloc->addr);
             if (cmp < 0)
                 rt = md;
             else
@@ -334,7 +325,7 @@ H5F_unmount(const H5G_loc_t *loc, const char *name)
         }
 
         if (cmp)
-            HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "not a mount point")
+            HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "not a mount point");
 
         /* Found the correct index, set the info about the child */
         child_idx = (int)md;
@@ -348,40 +339,40 @@ H5F_unmount(const H5G_loc_t *loc, const char *name)
          * Could be different due to the shared mount table. */
         parent = child->parent;
     } /* end else */
-    HDassert(child_idx >= 0);
+    assert(child_idx >= 0);
 
     /* Save the information about the child from the mount table */
     child_group = parent->shared->mtab.child[child_idx].group;
 
     /* Get the group location for the root group in the file to unmount */
     if (NULL == (root_loc.oloc = H5G_oloc(child->shared->root_grp)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group");
     if (NULL == (root_loc.path = H5G_nameof(child->shared->root_grp)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group");
 
     /* Search the open IDs replace names to reflect unmount operation */
     if (H5G_name_replace(NULL, H5G_NAME_UNMOUNT, mp_loc.oloc->file, mp_loc.path->full_path_r,
                          root_loc.oloc->file, root_loc.path->full_path_r) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to replace name")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to replace name");
 
     /* Eliminate the mount point from the table */
-    HDmemmove(parent->shared->mtab.child + (unsigned)child_idx,
-              (parent->shared->mtab.child + (unsigned)child_idx) + 1,
-              ((parent->shared->mtab.nmounts - (unsigned)child_idx) - 1) *
-                  sizeof(parent->shared->mtab.child[0]));
+    memmove(parent->shared->mtab.child + (unsigned)child_idx,
+            (parent->shared->mtab.child + (unsigned)child_idx) + 1,
+            ((parent->shared->mtab.nmounts - (unsigned)child_idx) - 1) *
+                sizeof(parent->shared->mtab.child[0]));
     parent->shared->mtab.nmounts -= 1;
     parent->nmounts -= 1;
 
     /* Unmount the child file from the parent file */
     if (H5G_unmount(child_group) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTRELEASE, FAIL, "unable to reset group mounted flag")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTRELEASE, FAIL, "unable to reset group mounted flag");
     if (H5G_close(child_group) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close unmounted group")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close unmounted group");
 
     /* Detach child file from parent & see if it should close */
     child->parent = NULL;
     if (H5F_try_close(child, NULL) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, FAIL, "unable to close unmounted file")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, FAIL, "unable to close unmounted file");
 
 done:
     /* Free the mount point location's information, if it's been set up */
@@ -399,9 +390,6 @@ done:
  * Return:	Success:	TRUE/FALSE
  *		Failure:	(can't happen)
  *
- * Programmer:	Quincey Koziol
- *              Thursday, January  2, 2002
- *
  *-------------------------------------------------------------------------
  */
 hbool_t
@@ -411,7 +399,7 @@ H5F_is_mount(const H5F_t *file)
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(file);
+    assert(file);
 
     if (file->parent != NULL)
         ret_value = TRUE;
@@ -429,9 +417,6 @@ H5F_is_mount(const H5F_t *file)
  *
  * Return:      void
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, July 19, 2005
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -442,9 +427,9 @@ H5F__mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_ob
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(nopen_files);
-    HDassert(nopen_objs);
+    assert(f);
+    assert(nopen_files);
+    assert(nopen_objs);
 
     /* If this file is still open, increment number of file IDs open */
     if (H5F_ID_EXISTS(f))
@@ -478,9 +463,6 @@ H5F__mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_ob
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *              Tues, July 19, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -489,9 +471,9 @@ H5F__mount_count_ids(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(nopen_files);
-    HDassert(nopen_objs);
+    assert(f);
+    assert(nopen_files);
+    assert(nopen_objs);
 
     /* Find the top file in the mounting hierarchy */
     while (f->parent)
@@ -510,9 +492,6 @@ H5F__mount_count_ids(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *              Fri, August 21, 2009
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -525,7 +504,7 @@ H5F__flush_mounts_recurse(H5F_t *f)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(f);
+    assert(f);
 
     /* Flush all child files, not stopping for errors */
     for (u = 0; u < f->shared->mtab.nmounts; u++)
@@ -534,11 +513,11 @@ H5F__flush_mounts_recurse(H5F_t *f)
 
     /* Call the "real" flush routine, for this file */
     if (H5F__flush(f) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush file's cached information")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush file's cached information");
 
     /* Check flush errors for children - errors are already on the stack */
     if (nerrors)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush file's child mounts")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush file's child mounts");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -551,9 +530,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *              Fri, August 21, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -564,7 +540,7 @@ H5F_flush_mounts(H5F_t *f)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
+    assert(f);
 
     /* Find the top file in the mount hierarchy */
     while (f->parent)
@@ -572,7 +548,7 @@ H5F_flush_mounts(H5F_t *f)
 
     /* Flush the mounted file hierarchy */
     if (H5F__flush_mounts_recurse(f) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush mounted file hierarchy")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush mounted file hierarchy");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -586,9 +562,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *              Tuesday, October  6, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -604,7 +577,7 @@ H5F_traverse_mount(H5O_loc_t *oloc /*in,out*/)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(oloc);
+    assert(oloc);
 
     /*
      * The loop is necessary because we might have file1 mounted at the root
@@ -621,7 +594,7 @@ H5F_traverse_mount(H5O_loc_t *oloc /*in,out*/)
         while (lt < rt && cmp) {
             md       = (lt + rt) / 2;
             mnt_oloc = H5G_oloc(parent->shared->mtab.child[md].group);
-            cmp      = H5F_addr_cmp(oloc->addr, mnt_oloc->addr);
+            cmp      = H5_addr_cmp(oloc->addr, mnt_oloc->addr);
             if (cmp < 0)
                 rt = md;
             else
@@ -638,11 +611,11 @@ H5F_traverse_mount(H5O_loc_t *oloc /*in,out*/)
 
             /* Release the mount point */
             if (H5O_loc_free(oloc) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTFREE, FAIL, "unable to free object location")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTFREE, FAIL, "unable to free object location");
 
             /* Copy the entry for the root group */
             if (H5O_loc_copy_deep(oloc, mnt_oloc) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTCOPY, FAIL, "unable to copy object location")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTCOPY, FAIL, "unable to copy object location");
 
             /* In case the shared root group info points to a different file handle
              * than the child, modify oloc */
