@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Fquery.c
- *                      Jan 10 2008
- *                      Quincey Koziol
  *
  * Purpose:             File structure query routines.
  *
@@ -79,7 +77,7 @@ H5F_shared_get_intent(const H5F_shared_t *f_sh)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f_sh);
+    assert(f_sh);
 
     FUNC_LEAVE_NOAPI(f_sh->flags)
 } /* end H5F_shared_get_intent() */
@@ -100,7 +98,7 @@ H5F_get_intent(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->shared->flags)
 } /* end H5F_get_intent() */
@@ -114,8 +112,6 @@ H5F_get_intent(const H5F_t *f)
  *
  * Return:  low_bound on success/abort on failure (shouldn't fail)
  *
- * Programmer:  Vailin Choi; June 2016
- *
  *-------------------------------------------------------------------------
  */
 H5F_libver_t
@@ -124,7 +120,7 @@ H5F_get_low_bound(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->shared->low_bound)
 } /* end H5F_get_low_bound() */
@@ -138,8 +134,6 @@ H5F_get_low_bound(const H5F_t *f)
  *
  * Return:  high_bound on success/abort on failure (shouldn't fail)
  *
- * Programmer:  Vailin Choi; June 2016
- *
  *-------------------------------------------------------------------------
  */
 H5F_libver_t
@@ -148,7 +142,7 @@ H5F_get_high_bound(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->shared->high_bound)
 } /* end H5F_get_high_bound() */
@@ -168,8 +162,8 @@ H5F_get_open_name(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->open_name);
+    assert(f);
+    assert(f->open_name);
 
     FUNC_LEAVE_NOAPI(f->open_name)
 } /* end H5F_get_open_name() */
@@ -189,8 +183,8 @@ H5F_get_actual_name(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->actual_name);
+    assert(f);
+    assert(f->actual_name);
 
     FUNC_LEAVE_NOAPI(f->actual_name)
 } /* end H5F_get_actual_name() */
@@ -211,9 +205,9 @@ H5F_get_extpath(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->extpath);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->extpath);
 
     FUNC_LEAVE_NOAPI(f->shared->extpath)
 } /* end H5F_get_extpath() */
@@ -232,7 +226,7 @@ H5F_get_shared(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->shared)
 } /* end H5F_get_shared() */
@@ -251,10 +245,10 @@ H5F_same_shared(const H5F_t *f1, const H5F_t *f2)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f1);
-    HDassert(f1->shared);
-    HDassert(f2);
-    HDassert(f2->shared);
+    assert(f1);
+    assert(f1->shared);
+    assert(f2);
+    assert(f2->shared);
 
     FUNC_LEAVE_NOAPI(f1->shared == f2->shared)
 } /* end H5F_same_shared() */
@@ -273,7 +267,7 @@ H5F_get_nopen_objs(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->nopen_objs)
 } /* end H5F_get_nopen_objs() */
@@ -292,7 +286,7 @@ H5F_file_id_exists(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->id_exists)
 } /* end H5F_file_id_exists() */
@@ -311,7 +305,7 @@ H5F_get_parent(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->parent)
 } /* end H5F_get_parent() */
@@ -330,7 +324,7 @@ H5F_get_nmounts(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->nmounts)
 } /* end H5F_get_nmounts() */
@@ -349,7 +343,7 @@ H5F_get_read_attempts(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->shared->read_attempts)
 } /* end H5F_get_read_attempts() */
@@ -369,8 +363,8 @@ H5F_get_fcpl(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->fcpl_id)
 } /* end H5F_get_fcpl() */
@@ -391,8 +385,8 @@ H5F_sizeof_addr(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->sizeof_addr)
 } /* end H5F_sizeof_addr() */
@@ -413,8 +407,8 @@ H5F_sizeof_size(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->sizeof_size)
 } /* H5F_sizeof_size() */
@@ -433,8 +427,8 @@ H5F_get_sohm_addr(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->sohm_addr)
 } /* end H5F_get_sohm_addr() */
@@ -453,8 +447,8 @@ H5F_get_sohm_vers(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->sohm_vers)
 } /* end H5F_get_sohm_vers() */
@@ -473,8 +467,8 @@ H5F_get_sohm_nindexes(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->sohm_nindexes)
 } /* end H5F_get_sohm_nindexes() */
@@ -497,9 +491,9 @@ H5F_sym_leaf_k(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->sblock);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->sblock);
 
     FUNC_LEAVE_NOAPI(f->shared->sblock->sym_leaf_k)
 } /* end H5F_sym_leaf_k() */
@@ -517,7 +511,7 @@ H5F_get_min_dset_ohdr(const H5F_t *f)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->shared->crt_dset_min_ohdr_flag)
 } /* end H5F_get_min_dset_ohdr */
@@ -540,10 +534,10 @@ H5F_Kvalue(const H5F_t *f, const H5B_class_t *type)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->sblock);
-    HDassert(type);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->sblock);
+    assert(type);
 
     FUNC_LEAVE_NOAPI(f->shared->sblock->btree_k[type->id])
 } /* end H5F_Kvalue() */
@@ -562,8 +556,8 @@ H5F_get_nrefs(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->nrefs)
 } /* end H5F_get_nrefs() */
@@ -586,8 +580,8 @@ H5F_rdcc_nslots(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->rdcc_nslots)
 } /* end H5F_rdcc_nelmts() */
@@ -610,8 +604,8 @@ H5F_rdcc_nbytes(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->rdcc_nbytes)
 } /* end H5F_rdcc_nbytes() */
@@ -634,8 +628,8 @@ H5F_rdcc_w0(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->rdcc_w0)
 } /* end H5F_rdcc_w0() */
@@ -656,9 +650,9 @@ H5F_get_base_addr(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->sblock);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->sblock);
 
     FUNC_LEAVE_NOAPI(f->shared->sblock->base_addr)
 } /* end H5F_get_base_addr() */
@@ -681,8 +675,8 @@ H5F_grp_btree_shared(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->grp_btree_shared)
 } /* end H5F_grp_btree_shared() */
@@ -705,8 +699,8 @@ H5F_sieve_buf_size(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->sieve_buf_size)
 } /* end H5F_sieve_buf_size() */
@@ -721,9 +715,6 @@ H5F_sieve_buf_size(const H5F_t *f)
  * Return:  Success:    The "garbage collect references flag" is returned.
  *          Failure:    (should not happen)
  *
- * Programmer:  Quincey Koziol
- *              Jul  8 2005
- *
  *-------------------------------------------------------------------------
  */
 unsigned
@@ -732,8 +723,8 @@ H5F_gc_ref(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->gc_ref)
 } /* end H5F_gc_ref() */
@@ -753,8 +744,8 @@ H5F_get_fc_degree(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->fc_degree)
 } /* end H5F_get_fc_degree() */
@@ -776,8 +767,8 @@ H5F_get_evict_on_close(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->evict_on_close)
 } /* end H5F_get_evict_on_close() */
@@ -797,8 +788,8 @@ H5F_store_msg_crt_idx(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->store_msg_crt_idx)
 } /* end H5F_store_msg_crt_idx() */
@@ -818,7 +809,7 @@ H5F_shared_has_feature(const H5F_shared_t *f_sh, unsigned feature)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f_sh);
+    assert(f_sh);
 
     FUNC_LEAVE_NOAPI((hbool_t)(f_sh->lf->feature_flags & feature))
 } /* end H5F_shared_has_feature() */
@@ -838,8 +829,8 @@ H5F_has_feature(const H5F_t *f, unsigned feature)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI((hbool_t)(f->shared->lf->feature_flags & feature))
 } /* end H5F_has_feature() */
@@ -860,9 +851,9 @@ H5F_get_driver_id(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->lf);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->lf);
 
     FUNC_LEAVE_NOAPI(f->shared->lf->driver_id)
 } /* end H5F_get_driver_id() */
@@ -884,14 +875,14 @@ H5F_get_fileno(const H5F_t *f, unsigned long *filenum)
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(f);
-    HDassert(f->shared);
-    HDassert(f->shared->lf);
-    HDassert(filenum);
+    assert(f);
+    assert(f->shared);
+    assert(f->shared->lf);
+    assert(filenum);
 
     /* Retrieve the file's serial number */
     if (H5FD_get_fileno(f->shared->lf, filenum) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_BADRANGE, FAIL, "can't retrieve fileno")
+        HGOTO_ERROR(H5E_FILE, H5E_BADRANGE, FAIL, "can't retrieve fileno");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -912,11 +903,11 @@ H5F_shared_get_eoa(const H5F_shared_t *f_sh, H5FD_mem_t type)
 
     FUNC_ENTER_NOAPI(HADDR_UNDEF)
 
-    HDassert(f_sh);
+    assert(f_sh);
 
     /* Dispatch to driver */
     if (HADDR_UNDEF == (ret_value = H5FD_get_eoa(f_sh->lf, type)))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, HADDR_UNDEF, "driver get_eoa request failed")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, HADDR_UNDEF, "driver get_eoa request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -937,12 +928,12 @@ H5F_get_eoa(const H5F_t *f, H5FD_mem_t type)
 
     FUNC_ENTER_NOAPI(HADDR_UNDEF)
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     /* Dispatch to driver */
     if (HADDR_UNDEF == (ret_value = H5FD_get_eoa(f->shared->lf, type)))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, HADDR_UNDEF, "driver get_eoa request failed")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, HADDR_UNDEF, "driver get_eoa request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -963,8 +954,8 @@ H5F_shared_get_file_driver(const H5F_shared_t *f_sh, H5FD_t **file_handle)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f_sh);
-    HDassert(file_handle);
+    assert(f_sh);
+    assert(file_handle);
 
     *file_handle = f_sh->lf;
 
@@ -989,12 +980,12 @@ H5F_get_vfd_handle(const H5F_t *file, hid_t fapl, void **file_handle)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(file);
-    HDassert(file_handle);
+    assert(file);
+    assert(file_handle);
 
     /* Get the VFD handle */
     if (H5FD_get_vfd_handle(file->shared->lf, fapl, file_handle) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get file handle for file driver")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get file handle for file driver");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1017,10 +1008,10 @@ H5F_is_tmp_addr(const H5F_t *f, haddr_t addr)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
-    FUNC_LEAVE_NOAPI(H5F_addr_le(f->shared->tmp_addr, addr))
+    FUNC_LEAVE_NOAPI(H5_addr_le(f->shared->tmp_addr, addr))
 } /* end H5F_is_tmp_addr() */
 
 /*-------------------------------------------------------------------------
@@ -1040,8 +1031,8 @@ H5F_use_tmp_space(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->use_tmp_space)
 } /* end H5F_use_tmp_space() */
@@ -1063,7 +1054,7 @@ H5F_coll_md_read(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->shared->coll_md_read)
 } /* end H5F_coll_md_read() */
@@ -1076,9 +1067,6 @@ H5F_coll_md_read(const H5F_t *f)
  * Return:      Success:    Non-negative
  *              Failure:    Negative
  *
- * Programmer:  Houjun Tang
- *              May 19, 2022
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1088,12 +1076,12 @@ H5F_shared_get_mpi_file_sync_required(const H5F_shared_t *f_sh, hbool_t *flag /*
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(f_sh);
-    HDassert(flag);
+    assert(f_sh);
+    assert(flag);
 
     /* Dispatch to driver */
     if ((ret_value = H5FD_mpi_get_file_sync_required(f_sh->lf, flag)) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "driver get_file_sync_required request failed")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "driver get_file_sync_required request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1117,8 +1105,8 @@ H5F_use_mdc_logging(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->use_mdc_logging)
 } /* end H5F_use_mdc_logging() */
@@ -1140,8 +1128,8 @@ H5F_start_mdc_log_on_access(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->start_mdc_log_on_access)
 } /* end H5F_start_mdc_log_on_access() */
@@ -1163,8 +1151,8 @@ H5F_mdc_log_location(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->mdc_log_location)
 } /* end H5F_mdc_log_location() */
@@ -1184,8 +1172,8 @@ H5F_get_alignment(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->alignment)
 } /* end H5F_get_alignment() */
@@ -1205,8 +1193,8 @@ H5F_get_threshold(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->threshold)
 } /* end H5F_get_threshold() */
@@ -1226,8 +1214,8 @@ H5F_get_pgend_meta_thres(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->pgend_meta_thres)
 } /* end H5F_get_pgend_meta_thres() */
@@ -1247,8 +1235,8 @@ H5F_get_point_of_no_return(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->point_of_no_return)
 } /* end H5F_get_point_of_no_return() */
@@ -1268,8 +1256,8 @@ H5F_get_null_fsm_addr(const H5F_t *f)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->null_fsm_addr)
 } /* end H5F_get_null_fsm_addr() */
@@ -1281,9 +1269,6 @@ H5F_get_null_fsm_addr(const H5F_t *f)
  *
  * Return:   VOL class pointer for file, can't fail
  *
- * Programmer:    Quincey Koziol
- *        Saturday, August 17, 2019
- *
  *-------------------------------------------------------------------------
  */
 const H5VL_class_t *
@@ -1291,8 +1276,8 @@ H5F_get_vol_cls(const H5F_t *f)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->vol_cls)
 } /* end H5F_get_vol_cls */
@@ -1311,7 +1296,7 @@ H5F_get_vol_obj(const H5F_t *f)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
+    assert(f);
 
     FUNC_LEAVE_NOAPI(f->vol_obj)
 } /* end H5F_get_vol_obj */
@@ -1324,9 +1309,6 @@ H5F_get_vol_obj(const H5F_t *f)
  * Return:      Success:        Non-negative
  *              Failure:        Negative
  *
- * Programmer:    Quincey Koziol
- *        Saturday, August 17, 2019
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1337,12 +1319,12 @@ H5F__get_cont_info(const H5F_t *f, H5VL_file_cont_info_t *info)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     /* Verify structure version */
     if (info->version != H5VL_CONTAINER_INFO_VERSION)
-        HGOTO_ERROR(H5E_FILE, H5E_VERSION, FAIL, "wrong container info version #")
+        HGOTO_ERROR(H5E_FILE, H5E_VERSION, FAIL, "wrong container info version #");
 
     /* Set the container info fields */
     info->feature_flags = 0; /* None currently defined */
@@ -1367,8 +1349,8 @@ H5F_get_file_locking(const H5F_t *f)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     FUNC_LEAVE_NOAPI(f->shared->use_file_locking)
 } /* end H5F_get_file_locking */
@@ -1389,8 +1371,8 @@ H5F_has_vector_select_io(const H5F_t *f, hbool_t is_write)
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(f);
-    HDassert(f->shared);
+    assert(f);
+    assert(f->shared);
 
     if (is_write)
         ret_value = (f->shared->lf->cls->write_vector != NULL || f->shared->lf->cls->write_selection != NULL);
