@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5Ftest.c
- *			Jan  3 2007
- *			Quincey Koziol
  *
  * Purpose:		File testing routines.
  *
@@ -79,9 +77,6 @@
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Jan  3, 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -95,20 +90,20 @@ H5F__get_sohm_mesg_count_test(hid_t file_id, unsigned type_id, size_t *mesg_coun
 
     /* Check arguments */
     if (NULL == (file = (H5F_t *)H5VL_object_verify(file_id, H5I_FILE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file");
 
     /* Push API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Retrieve count for message type */
     if (H5SM__get_mesg_count_test(file, type_id, mesg_count) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve shared message count")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve shared message count");
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_FILE, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_FILE, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F__get_sohm_mesg_count_test() */
@@ -123,9 +118,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Neil Fortner
- *	        Mar  31, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -139,20 +131,20 @@ H5F__check_cached_stab_test(hid_t file_id)
 
     /* Check arguments */
     if (NULL == (file = (H5F_t *)H5VL_object_verify(file_id, H5I_FILE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file");
 
     /* Push API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Verify the cached stab info */
     if (H5G__verify_cached_stab_test(H5G_oloc(file->shared->root_grp), file->shared->sblock->root_ent) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to verify cached symbol table info")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to verify cached symbol table info");
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_FILE, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_FILE, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F__check_cached_stab_test() */
@@ -164,9 +156,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Jun 10, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -179,7 +168,7 @@ H5F__get_maxaddr_test(hid_t file_id, haddr_t *maxaddr)
 
     /* Check arguments */
     if (NULL == (file = (H5F_t *)H5VL_object_verify(file_id, H5I_FILE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file");
 
     /* Retrieve maxaddr for file */
     *maxaddr = file->shared->maxaddr;
@@ -196,9 +185,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Jul 10, 2016
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -211,7 +197,7 @@ H5F__get_sbe_addr_test(hid_t file_id, haddr_t *sbe_addr)
 
     /* Check arguments */
     if (NULL == (file = (H5F_t *)H5VL_object_verify(file_id, H5I_FILE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file");
 
     /* Retrieve maxaddr for file */
     *sbe_addr = file->shared->sblock->ext_addr;
@@ -227,9 +213,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *	        Oct 13, 2018
- *
  *-------------------------------------------------------------------------
  */
 htri_t
@@ -242,9 +225,9 @@ H5F__same_file_test(hid_t file_id1, hid_t file_id2)
 
     /* Check arguments */
     if (NULL == (file1 = (H5F_t *)H5VL_object_verify(file_id1, H5I_FILE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file");
     if (NULL == (file2 = (H5F_t *)H5VL_object_verify(file_id2, H5I_FILE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file");
 
     /* If they are using the same underlying "shared" file struct, they are the same file */
     ret_value = (file1->shared == file2->shared);
@@ -265,9 +248,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Dana Robinson
- *              Summer 2020
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -279,7 +259,7 @@ H5F__reparse_file_lock_variable_test(void)
 
     /* Check the file locking environment variable */
     if (H5F__parse_file_lock_env_var(&use_locks_env_g) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to parse file locking environment variable")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to parse file locking environment variable");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
