@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5Gcompact.c
- *			Sep  5 2005
- *			Quincey Koziol
  *
  * Purpose:		Functions for handling compact storage.
  *
@@ -70,9 +68,6 @@ static herr_t H5G__compact_lookup_cb(const void *_mesg, unsigned H5_ATTR_UNUSED
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep  5 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -85,13 +80,13 @@ H5G__compact_build_table_cb(const void *_mesg, unsigned H5_ATTR_UNUSED idx, void
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(lnk);
-    HDassert(udata);
-    HDassert(udata->curr_lnk < udata->ltable->nlinks);
+    assert(lnk);
+    assert(udata);
+    assert(udata->curr_lnk < udata->ltable->nlinks);
 
     /* Copy link message into table */
     if (NULL == H5O_msg_copy(H5O_LINK_ID, lnk, &(udata->ltable->lnks[udata->curr_lnk])))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message");
 
     /* Increment current link entry to operate on */
     udata->curr_lnk++;
@@ -109,9 +104,6 @@ done:
  * Return:	Success:        Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *	        Sep  6, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -123,9 +115,9 @@ H5G__compact_build_table(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_ind
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(oloc);
-    HDassert(linfo);
-    HDassert(ltable);
+    assert(oloc);
+    assert(linfo);
+    assert(ltable);
 
     /* Set size of table */
     H5_CHECK_OVERFLOW(linfo->nlinks, hsize_t, size_t);
@@ -138,7 +130,7 @@ H5G__compact_build_table(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_ind
 
         /* Allocate the link table */
         if ((ltable->lnks = (H5O_link_t *)H5MM_calloc(sizeof(H5O_link_t) * ltable->nlinks)) == NULL)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
         /* Set up user data for iteration */
         udata.ltable   = ltable;
@@ -148,11 +140,11 @@ H5G__compact_build_table(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_ind
         op.op_type  = H5O_MESG_OP_APP;
         op.u.app_op = H5G__compact_build_table_cb;
         if (H5O_msg_iterate(oloc, H5O_LINK_ID, &op, &udata) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages")
+            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages");
 
         /* Sort link table in correct iteration order */
         if (H5G__link_sort_table(ltable, idx_type, order) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTSORT, FAIL, "error sorting link messages")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTSORT, FAIL, "error sorting link messages");
     } /* end if */
     else
         ltable->lnks = NULL;
@@ -170,9 +162,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  6 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -183,12 +172,12 @@ H5G__compact_insert(const H5O_loc_t *grp_oloc, H5O_link_t *obj_lnk)
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(grp_oloc && grp_oloc->file);
-    HDassert(obj_lnk);
+    assert(grp_oloc && grp_oloc->file);
+    assert(obj_lnk);
 
     /* Insert link message into group */
     if (H5O_msg_create(grp_oloc, H5O_LINK_ID, 0, H5O_UPDATE_TIME, obj_lnk) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -201,9 +190,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *	        Sep  6, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -217,15 +203,15 @@ H5G__compact_get_name_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(oloc);
+    assert(oloc);
 
     /* Build table of all link messages */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Check for going out of bounds */
     if (idx >= ltable.nlinks)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "index out of bound")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "index out of bound");
 
     /* Get the length of the name */
     *name_len = HDstrlen(ltable.lnks[idx].name);
@@ -240,7 +226,7 @@ H5G__compact_get_name_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_get_name_by_idx() */
@@ -253,9 +239,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep  5 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -268,17 +251,17 @@ H5G__compact_remove_common_cb(const void *_mesg, unsigned H5_ATTR_UNUSED idx, vo
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(lnk);
-    HDassert(udata);
+    assert(lnk);
+    assert(udata);
 
     /* If we've found the right link, get the object type */
     if (HDstrcmp(lnk->name, udata->name) == 0) {
         /* Replace path names for link being removed */
         if (H5G__link_name_replace(udata->file, udata->grp_full_path_r, lnk) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5_ITER_ERROR, "unable to get object type")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5_ITER_ERROR, "unable to get object type");
 
         /* Stop the iteration, we found the correct link */
-        HGOTO_DONE(H5_ITER_STOP)
+        HGOTO_DONE(H5_ITER_STOP);
     } /* end if */
 
 done:
@@ -292,9 +275,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Monday, September 19, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -305,8 +285,8 @@ H5G__compact_remove(const H5O_loc_t *oloc, H5RS_str_t *grp_full_path_r, const ch
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(oloc && oloc->file);
-    HDassert(name && *name);
+    assert(oloc && oloc->file);
+    assert(name && *name);
 
     /* Initialize data to pass through object header iteration */
     udata.file            = oloc->file;
@@ -315,7 +295,7 @@ H5G__compact_remove(const H5O_loc_t *oloc, H5RS_str_t *grp_full_path_r, const ch
 
     /* Iterate over the link messages to delete the right one */
     if (H5O_msg_remove_op(oloc, H5O_LINK_ID, H5O_FIRST, H5G__compact_remove_common_cb, &udata, TRUE) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -328,9 +308,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, November 14, 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -343,16 +320,16 @@ H5G__compact_remove_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5RS
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(oloc && oloc->file);
-    HDassert(linfo);
+    assert(oloc && oloc->file);
+    assert(linfo);
 
     /* Build table of all link messages, sorted according to desired order */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Check for going out of bounds */
     if (n >= ltable.nlinks)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound");
 
     /* Initialize data to pass through object header iteration */
     udata.file            = oloc->file;
@@ -361,12 +338,12 @@ H5G__compact_remove_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5RS
 
     /* Iterate over the link messages to delete the right one */
     if (H5O_msg_remove_op(oloc, H5O_LINK_ID, H5O_FIRST, H5G__compact_remove_common_cb, &udata, TRUE) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to delete link message");
 
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_remove_by_idx() */
@@ -378,9 +355,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Monday, October  3, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -394,13 +368,13 @@ H5G__compact_iterate(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_index_t
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(oloc);
-    HDassert(linfo);
-    HDassert(op);
+    assert(oloc);
+    assert(linfo);
+    assert(op);
 
     /* Build table of all link messages */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Iterate over links in table */
     if ((ret_value = H5G__link_iterate_table(&ltable, skip, last_lnk, op, op_data)) < 0)
@@ -409,7 +383,7 @@ H5G__compact_iterate(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_index_t
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_iterate() */
@@ -422,9 +396,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep 20 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -437,22 +408,22 @@ H5G__compact_lookup_cb(const void *_mesg, unsigned H5_ATTR_UNUSED idx, void *_ud
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(lnk);
-    HDassert(udata);
+    assert(lnk);
+    assert(udata);
 
     /* Check for name to get information */
     if (HDstrcmp(lnk->name, udata->name) == 0) {
         if (udata->lnk) {
             /* Copy link information */
             if (NULL == H5O_msg_copy(H5O_LINK_ID, lnk, udata->lnk))
-                HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message")
+                HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message");
         } /* end if */
 
         /* Indicate that the correct link was found */
         *udata->found = TRUE;
 
         /* Stop iteration now */
-        HGOTO_DONE(H5_ITER_STOP)
+        HGOTO_DONE(H5_ITER_STOP);
     } /* end if */
 
 done:
@@ -466,9 +437,6 @@ done:
  *
  * Return:	Non-negative (TRUE/FALSE) on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Sep 20 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -481,9 +449,9 @@ H5G__compact_lookup(const H5O_loc_t *oloc, const char *name, hbool_t *found, H5O
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(name && *name);
-    HDassert(found);
-    HDassert(lnk && oloc->file);
+    assert(name && *name);
+    assert(found);
+    assert(lnk && oloc->file);
 
     /* Set up user data for iteration */
     udata.name  = name;
@@ -494,7 +462,7 @@ H5G__compact_lookup(const H5O_loc_t *oloc, const char *name, hbool_t *found, H5O
     op.op_type  = H5O_MESG_OP_APP;
     op.u.app_op = H5G__compact_lookup_cb;
     if (H5O_msg_iterate(oloc, H5O_LINK_ID, &op, &udata) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages")
+        HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over link messages");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -508,9 +476,6 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Nov  6 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -523,26 +488,26 @@ H5G__compact_lookup_by_idx(const H5O_loc_t *oloc, const H5O_linfo_t *linfo, H5_i
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(oloc && oloc->file);
-    HDassert(linfo);
-    HDassert(lnk);
+    assert(oloc && oloc->file);
+    assert(linfo);
+    assert(lnk);
 
     /* Build table of all link messages, sorted according to desired order */
     if (H5G__compact_build_table(oloc, linfo, idx_type, order, &ltable) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "can't create link message table");
 
     /* Check for going out of bounds */
     if (n >= ltable.nlinks)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "index out of bound");
 
     /* Copy link information */
     if (NULL == H5O_msg_copy(H5O_LINK_ID, &ltable.lnks[n], lnk))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTCOPY, H5_ITER_ERROR, "can't copy link message");
 
 done:
     /* Release link table */
     if (ltable.lnks && H5G__link_release_table(&ltable) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table")
+        HDONE_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__compact_lookup_by_idx() */
