@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5Gname.c
- *			Sep 12 2005
- *			Quincey Koziol
  *
  * Purpose:		Functions for handling group hierarchy paths.
  *
@@ -106,9 +104,6 @@ static int         H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key);
  *
  *		Failure:	Ptr to the null terminator of NAME.
  *
- * Programmer:	Robb Matzke
- *		Aug 11 1997
- *
  *-------------------------------------------------------------------------
  */
 const char *
@@ -116,7 +111,7 @@ H5G__component(const char *name, size_t *size_p)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(name);
+    assert(name);
 
     while ('/' == *name)
         name++;
@@ -135,9 +130,6 @@ H5G__component(const char *name, size_t *size_p)
  * Return:	Success:	Ptr to normalized name.
  *		Failure:	NULL
  *
- * Programmer:	Quincey Koziol
- *              Saturday, August 16, 2003
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -151,11 +143,11 @@ H5G_normalize(const char *name)
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Sanity check */
-    HDassert(name);
+    assert(name);
 
     /* Duplicate the name, to return */
     if (NULL == (norm = H5MM_strdup(name)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for normalized string")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for normalized string");
 
     /* Walk through the characters, omitting duplicated '/'s */
     s = d      = 0;
@@ -197,9 +189,6 @@ done:
  * Return: TRUE for valid prefix, FALSE for not a valid prefix, FAIL
  *              on error
  *
- * Programmer: Quincey Koziol
- *
- * Date: September 24, 2002
  *
  *-------------------------------------------------------------------------
  */
@@ -215,13 +204,13 @@ H5G__common_path(const H5RS_str_t *fullpath_r, const H5RS_str_t *prefix_r)
 
     /* Get component of each name */
     fullpath = H5RS_get_str(fullpath_r);
-    HDassert(fullpath);
+    assert(fullpath);
     fullpath = H5G__component(fullpath, &nchars1);
-    HDassert(fullpath);
+    assert(fullpath);
     prefix = H5RS_get_str(prefix_r);
-    HDassert(prefix);
+    assert(prefix);
     prefix = H5G__component(prefix, &nchars2);
-    HDassert(prefix);
+    assert(prefix);
 
     /* Check if we have a real string for each component */
     while (*fullpath && *prefix) {
@@ -235,15 +224,15 @@ H5G__common_path(const H5RS_str_t *fullpath_r, const H5RS_str_t *prefix_r)
 
                 /* Get next component of each name */
                 fullpath = H5G__component(fullpath, &nchars1);
-                HDassert(fullpath);
+                assert(fullpath);
                 prefix = H5G__component(prefix, &nchars2);
-                HDassert(prefix);
+                assert(prefix);
             } /* end if */
             else
-                HGOTO_DONE(FALSE)
+                HGOTO_DONE(FALSE);
         } /* end if */
         else
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(FALSE);
     } /* end while */
 
     /* If we reached the end of the prefix path to check, it must be a valid prefix */
@@ -261,10 +250,6 @@ done:
  *
  * Return: Pointer to reference counted string on success, NULL on error
  *
- * Programmer: Quincey Koziol
- *
- * Date: August 19, 2005
- *
  *-------------------------------------------------------------------------
  */
 static H5RS_str_t *
@@ -275,12 +260,12 @@ H5G__build_fullpath(const char *prefix, const char *name)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(prefix);
-    HDassert(name);
+    assert(prefix);
+    assert(name);
 
     /* Create full path */
     if (NULL == (ret_value = H5RS_create(prefix)))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, NULL, "can't create ref-counted string")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, NULL, "can't create ref-counted string");
     if (prefix[HDstrlen(prefix) - 1] != '/')
         H5RS_aputc(ret_value, '/'); /* Add separator, if the prefix doesn't end in one */
     H5RS_acat(ret_value, name);
@@ -297,9 +282,6 @@ done:
  * Return:	Success:	Non-NULL, combined path
  *		Failure:	NULL
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, October 11, 2005
- *
  *-------------------------------------------------------------------------
  */
 H5RS_str_t *
@@ -310,12 +292,12 @@ H5G_build_fullpath_refstr_str(H5RS_str_t *prefix_r, const char *name)
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(prefix_r);
-    HDassert(name);
+    assert(prefix_r);
+    assert(name);
 
     /* Get the raw string for the user path */
     prefix = H5RS_get_str(prefix_r);
-    HDassert(prefix);
+    assert(prefix);
 
     /* Create reference counted string for path */
     ret_value = H5G__build_fullpath(prefix, name);
@@ -331,9 +313,6 @@ H5G_build_fullpath_refstr_str(H5RS_str_t *prefix_r, const char *name)
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Monday, September 12, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -342,13 +321,13 @@ H5G__name_init(H5G_name_t *name, const char *path)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(name);
+    assert(name);
 
     /* Set the initial paths for a name object */
     name->full_path_r = H5RS_create(path);
-    HDassert(name->full_path_r);
+    assert(name->full_path_r);
     name->user_path_r = H5RS_create(path);
-    HDassert(name->user_path_r);
+    assert(name->user_path_r);
     name->obj_hidden = 0;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
@@ -362,9 +341,6 @@ H5G__name_init(H5G_name_t *name, const char *path)
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Pedro Vicente
- *              Thursday, August 22, 2002
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -374,9 +350,9 @@ H5G_name_set(const H5G_name_t *loc, H5G_name_t *obj, const char *name)
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(loc);
-    HDassert(obj);
-    HDassert(name);
+    assert(loc);
+    assert(obj);
+    assert(name);
 
     /* Free & reset the object's previous paths info (if they exist) */
     H5G_name_free(obj);
@@ -385,14 +361,14 @@ H5G_name_set(const H5G_name_t *loc, H5G_name_t *obj, const char *name)
     if (loc->full_path_r) {
         /* Go build the new full path */
         if ((obj->full_path_r = H5G_build_fullpath_refstr_str(loc->full_path_r, name)) == NULL)
-            HGOTO_ERROR(H5E_SYM, H5E_PATH, FAIL, "can't build user path name")
+            HGOTO_ERROR(H5E_SYM, H5E_PATH, FAIL, "can't build user path name");
     } /* end if */
 
     /* Create the object's user path, if a user path exists in the location */
     if (loc->user_path_r) {
         /* Go build the new user path */
         if ((obj->user_path_r = H5G_build_fullpath_refstr_str(loc->user_path_r, name)) == NULL)
-            HGOTO_ERROR(H5E_SYM, H5E_PATH, FAIL, "can't build user path name")
+            HGOTO_ERROR(H5E_SYM, H5E_PATH, FAIL, "can't build user path name");
     } /* end if */
 
 done:
@@ -407,9 +383,6 @@ done:
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Monday, September 12, 2005
- *
  * Notes:       'depth' parameter determines how much of the group entry
  *              structure we want to copy.  The depths are:
  *                  H5_COPY_SHALLOW - Copy all the fields from the source
@@ -428,13 +401,13 @@ H5G_name_copy(H5G_name_t *dst, const H5G_name_t *src, H5_copy_depth_t depth)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Check arguments */
-    HDassert(src);
-    HDassert(dst);
+    assert(src);
+    assert(dst);
 #if defined(H5_USING_MEMCHECKER) || !defined(NDEBUG)
-    HDassert(dst->full_path_r == NULL);
-    HDassert(dst->user_path_r == NULL);
+    assert(dst->full_path_r == NULL);
+    assert(dst->user_path_r == NULL);
 #endif /* H5_USING_MEMCHECKER */
-    HDassert(depth == H5_COPY_SHALLOW || depth == H5_COPY_DEEP);
+    assert(depth == H5_COPY_SHALLOW || depth == H5_COPY_DEEP);
 
     /* Copy the top level information */
     H5MM_memcpy(dst, src, sizeof(H5G_name_t));
@@ -463,9 +436,6 @@ H5G_name_copy(H5G_name_t *dst, const H5G_name_t *src, H5_copy_depth_t depth)
  * Return:	Success:	Non-negative, length of name
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, December 13, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -476,7 +446,7 @@ H5G_get_name(const H5G_loc_t *loc, char *name /*out*/, size_t size, size_t *name
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(loc);
+    assert(loc);
 
     /* If the user path is available and it's not "hidden", use it */
     if (loc->path->user_path_r != NULL && loc->path->obj_hidden == 0) {
@@ -502,7 +472,7 @@ H5G_get_name(const H5G_loc_t *loc, char *name /*out*/, size_t size, size_t *name
     else if (!loc->path->obj_hidden) {
         /* Search for name of object */
         if (H5G_get_name_by_addr(loc->oloc->file, loc->oloc, name, size, name_len) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't determine name")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't determine name");
 
         /* Indicate that the name is _not_ cached, if requested */
         /* (Currently only used for testing - QAK, 2010/07/26) */
@@ -522,9 +492,6 @@ done:
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Monday, September 12, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -533,10 +500,10 @@ H5G_name_reset(H5G_name_t *name)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Check arguments */
-    HDassert(name);
+    assert(name);
 
     /* Clear the group hier. name to an empty state */
-    HDmemset(name, 0, sizeof(H5G_name_t));
+    memset(name, 0, sizeof(H5G_name_t));
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5G_name_reset() */
@@ -548,10 +515,6 @@ H5G_name_reset(H5G_name_t *name)
  *
  * Return:	Success
  *
- * Programmer: Pedro Vicente
- *
- * Date: August 22, 2002
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -560,7 +523,7 @@ H5G_name_free(H5G_name_t *name)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Check args */
-    HDassert(name);
+    assert(name);
 
     if (name->full_path_r) {
         H5RS_decr(name->full_path_r);
@@ -583,9 +546,6 @@ H5G_name_free(H5G_name_t *name)
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, December 13, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -600,14 +560,14 @@ H5G__name_move_path(H5RS_str_t **path_r_ptr, const char *full_suffix, const char
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(path_r_ptr && *path_r_ptr);
-    HDassert(full_suffix);
-    HDassert(src_path);
-    HDassert(dst_path);
+    assert(path_r_ptr && *path_r_ptr);
+    assert(full_suffix);
+    assert(src_path);
+    assert(dst_path);
 
     /* Get pointer to path to update */
     path = H5RS_get_str(*path_r_ptr);
-    HDassert(path);
+    assert(path);
 
     /* Check if path needs to be updated */
     full_suffix_len = HDstrlen(full_suffix);
@@ -647,7 +607,7 @@ H5G__name_move_path(H5RS_str_t **path_r_ptr, const char *full_suffix, const char
 
         /* Allocate new ref-counted string */
         if (NULL == (rs = H5RS_create(NULL)))
-            HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string");
 
         /* Create the new path */
         if (path_prefix2_len > 0)
@@ -674,10 +634,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: June 5, 2002
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -692,7 +648,7 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(obj_ptr);
+    assert(obj_ptr);
 
     /* Get the symbol table entry */
     switch (H5I_get_type(obj_id)) {
@@ -709,14 +665,14 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
         case H5I_DATATYPE:
             /* Avoid non-named datatypes */
             if (!H5T_is_named((H5T_t *)obj_ptr))
-                HGOTO_DONE(SUCCEED) /* Do not exit search over IDs */
+                HGOTO_DONE(SUCCEED); /* Do not exit search over IDs */
 
             oloc     = H5T_oloc((H5T_t *)obj_ptr);
             obj_path = H5T_nameof((H5T_t *)obj_ptr);
             break;
 
         case H5I_MAP:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "maps not supported in native VOL connector")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "maps not supported in native VOL connector");
 
         case H5I_UNINIT:
         case H5I_BADID:
@@ -734,14 +690,14 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
         case H5I_EVENTSET:
         case H5I_NTYPES:
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unknown data object")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unknown data object");
     } /* end switch */
-    HDassert(oloc);
-    HDassert(obj_path);
+    assert(oloc);
+    assert(obj_path);
 
     /* Check if the object has a full path still */
     if (!obj_path->full_path_r)
-        HGOTO_DONE(SUCCEED) /* No need to look at object, it's path is already invalid */
+        HGOTO_DONE(SUCCEED); /* No need to look at object, it's path is already invalid */
 
     /* Find the top file in object's mount hier. */
     if (H5F_PARENT(oloc->file)) {
@@ -768,7 +724,7 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
 
     /* Check if the object is in same file mount hier. */
     if (!H5F_SAME_SHARED(top_obj_file, names->src_file))
-        HGOTO_DONE(SUCCEED) /* No need to look at object, it's path is already invalid */
+        HGOTO_DONE(SUCCEED); /* No need to look at object, it's path is already invalid */
 
     switch (names->op) {
         /*-------------------------------------------------------------------------
@@ -788,7 +744,7 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
 
                 /* Create new full path */
                 if (NULL == (rs = H5RS_create(src_path)))
-                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
+                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string");
                 H5RS_acat(rs, full_path);
 
                 /* Release previous full path */
@@ -829,7 +785,7 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
 
                 /* Create new full path suffix */
                 if (NULL == (rs = H5RS_create(full_suffix)))
-                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
+                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string");
 
                 /* Release previous full path */
                 H5RS_decr(obj_path->full_path_r);
@@ -880,7 +836,7 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
                 H5RS_str_t *rs;          /* Ref-counted string for new path */
 
                 /* Sanity check */
-                HDassert(names->dst_full_path_r);
+                assert(names->dst_full_path_r);
 
                 /* Get pointers to paths of interest */
                 full_path = H5RS_get_str(obj_path->full_path_r);
@@ -888,8 +844,8 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
                 dst_path  = H5RS_get_str(names->dst_full_path_r);
 
                 /* Make certain that the source and destination names are full (not relative) paths */
-                HDassert(*src_path == '/');
-                HDassert(*dst_path == '/');
+                assert(*src_path == '/');
+                assert(*dst_path == '/');
 
                 /* Get pointer to "full suffix" */
                 full_suffix = full_path + HDstrlen(src_path);
@@ -897,11 +853,11 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
                 /* Update the user path, if one exists */
                 if (obj_path->user_path_r)
                     if (H5G__name_move_path(&(obj_path->user_path_r), full_suffix, src_path, dst_path) < 0)
-                        HGOTO_ERROR(H5E_SYM, H5E_PATH, FAIL, "can't build user path name")
+                        HGOTO_ERROR(H5E_SYM, H5E_PATH, FAIL, "can't build user path name");
 
                 /* Create new full path */
                 if (NULL == (rs = H5RS_create(dst_path)))
-                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
+                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string");
                 H5RS_acat(rs, full_suffix);
 
                 /* Release previous full path */
@@ -913,11 +869,11 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
             break;
 
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid operation")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid operation");
     } /* end switch */
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__name_replace_cb() */
 
 /*-------------------------------------------------------------------------
@@ -932,10 +888,6 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: Pedro Vicente
- *
- * Date: June 11, 2002
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -947,7 +899,7 @@ H5G_name_replace(const H5O_link_t *lnk, H5G_names_op_t op, H5F_t *src_file, H5RS
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(src_file);
+    assert(src_file);
 
     /* Check if the object we are manipulating has a path */
     if (src_full_path_r) {
@@ -969,7 +921,7 @@ H5G_name_replace(const H5O_link_t *lnk, H5G_names_op_t op, H5F_t *src_file, H5RS
 
                     /* Get the type of the object */
                     if (H5O_obj_type(&tmp_oloc, &obj_type) < 0)
-                        HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't get object type")
+                        HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't get object type");
 
                     /* Determine which type of objects to operate on */
                     switch (obj_type) {
@@ -990,13 +942,13 @@ H5G_name_replace(const H5O_link_t *lnk, H5G_names_op_t op, H5F_t *src_file, H5RS
 
                         case H5O_TYPE_MAP:
                             HGOTO_ERROR(H5E_SYM, H5E_BADTYPE, FAIL,
-                                        "maps not supported in native VOL connector")
+                                        "maps not supported in native VOL connector");
 
                         case H5O_TYPE_UNKNOWN:
                         case H5O_TYPE_NTYPES:
                             /* Search and replace names through datatype IDs */
                         default:
-                            HGOTO_ERROR(H5E_SYM, H5E_BADTYPE, FAIL, "not valid object type")
+                            HGOTO_ERROR(H5E_SYM, H5E_BADTYPE, FAIL, "not valid object type");
                     } /* end switch */
                 }     /* end case */
                 break;
@@ -1012,7 +964,7 @@ H5G_name_replace(const H5O_link_t *lnk, H5G_names_op_t op, H5F_t *src_file, H5RS
                 default: /* User-defined link */
                     /* Check for unknown library-defined link type */
                     if (lnk->type < H5L_TYPE_UD_MIN)
-                        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "unknown link type")
+                        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "unknown link type");
 
                     /* User-defined & external links automatically wipe out
                      * names (because it would be too much work to track them),
@@ -1044,17 +996,17 @@ H5G_name_replace(const H5O_link_t *lnk, H5G_names_op_t op, H5F_t *src_file, H5RS
             /* Search through group IDs */
             if (search_group)
                 if (H5I_iterate(H5I_GROUP, H5G__name_replace_cb, &names, FALSE) < 0)
-                    HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over groups")
+                    HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over groups");
 
             /* Search through dataset IDs */
             if (search_dataset)
                 if (H5I_iterate(H5I_DATASET, H5G__name_replace_cb, &names, FALSE) < 0)
-                    HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over datasets")
+                    HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over datasets");
 
             /* Search through datatype IDs */
             if (search_datatype)
                 if (H5I_iterate(H5I_DATATYPE, H5G__name_replace_cb, &names, FALSE) < 0)
-                    HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over datatypes")
+                    HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over datatypes");
         } /* end if */
     }     /* end if */
 
@@ -1071,9 +1023,6 @@ done:
  * 	            0 if not correct object
  * 	            negative on failure.
  *
- * Programmer:	Quincey Koziol
- *              November 4 2007
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1089,10 +1038,10 @@ H5G__get_name_by_addr_cb(hid_t gid, const char *path, const H5L_info2_t *linfo,
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(path);
-    HDassert(linfo);
-    HDassert(udata->loc);
-    HDassert(udata->path == NULL);
+    assert(path);
+    assert(linfo);
+    assert(udata->loc);
+    assert(udata->path == NULL);
 
     /* Check for hard link with correct address */
     if (linfo->type == H5L_TYPE_HARD) {
@@ -1100,14 +1049,14 @@ H5G__get_name_by_addr_cb(hid_t gid, const char *path, const H5L_info2_t *linfo,
 
         /* Retrieve hard link address from VOL token */
         if (H5VL_native_token_to_addr(udata->loc->file, H5I_FILE, linfo->u.token, &link_addr) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTUNSERIALIZE, FAIL, "can't deserialize object token into address")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTUNSERIALIZE, FAIL, "can't deserialize object token into address");
 
         if (udata->loc->addr == link_addr) {
             H5G_loc_t grp_loc; /* Location of group */
 
             /* Get group's location */
             if (H5G_loc(gid, &grp_loc) < 0)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5_ITER_ERROR, "bad group location")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5_ITER_ERROR, "bad group location");
 
             /* Set up opened object location to fill in */
             obj_loc.oloc = &obj_oloc;
@@ -1116,24 +1065,24 @@ H5G__get_name_by_addr_cb(hid_t gid, const char *path, const H5L_info2_t *linfo,
 
             /* Find the object */
             if (H5G_loc_find(&grp_loc, path, &obj_loc /*out*/) < 0)
-                HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, H5_ITER_ERROR, "object not found")
+                HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, H5_ITER_ERROR, "object not found");
             obj_found = TRUE;
 
             /* Check for object in same file (handles mounted files) */
             /* (re-verify address, in case we traversed a file mount) */
             if (udata->loc->addr == obj_loc.oloc->addr && udata->loc->file == obj_loc.oloc->file) {
                 if (NULL == (udata->path = H5MM_strdup(path)))
-                    HGOTO_ERROR(H5E_SYM, H5E_CANTALLOC, H5_ITER_ERROR, "can't duplicate path string")
+                    HGOTO_ERROR(H5E_SYM, H5E_CANTALLOC, H5_ITER_ERROR, "can't duplicate path string");
 
                 /* We found a match so we return immediately */
-                HGOTO_DONE(H5_ITER_STOP)
+                HGOTO_DONE(H5_ITER_STOP);
             } /* end if */
         }     /* end if */
     }         /* end if */
 
 done:
     if (obj_found && H5G_loc_free(&obj_loc) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRELEASE, H5_ITER_ERROR, "can't free location")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRELEASE, H5_ITER_ERROR, "can't free location");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__get_name_by_addr_cb() */
@@ -1149,9 +1098,6 @@ done:
  *
  *              Failure:    -1
  *
- * Programmer:	Quincey Koziol
- *		November 4 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1165,18 +1111,18 @@ H5G_get_name_by_addr(H5F_t *f, const H5O_loc_t *loc, char *name, size_t size, si
     herr_t          ret_value = SUCCEED; /* Return value             */
 
     /* Portably clear udata struct (before FUNC_ENTER) */
-    HDmemset(&udata, 0, sizeof(udata));
+    memset(&udata, 0, sizeof(udata));
 
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Construct a group location for root group of the file */
     if (H5G_root_loc(f, &root_loc) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't get root group's location")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't get root group's location");
 
     /* Check for root group being the object looked for */
     if (root_loc.oloc->addr == loc->addr && root_loc.oloc->file == loc->file) {
         if (NULL == (udata.path = H5MM_strdup("")))
-            HGOTO_ERROR(H5E_SYM, H5E_CANTALLOC, FAIL, "can't duplicate path string")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTALLOC, FAIL, "can't duplicate path string");
         found_obj = TRUE;
     } /* end if */
     else {
@@ -1187,7 +1133,7 @@ H5G_get_name_by_addr(H5F_t *f, const H5O_loc_t *loc, char *name, size_t size, si
         /* Visit all the links in the file */
         if ((status = H5G_visit(&root_loc, "/", H5_INDEX_NAME, H5_ITER_NATIVE, H5G__get_name_by_addr_cb,
                                 &udata)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "group traversal failed while looking for object name")
+            HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "group traversal failed while looking for object name");
         else if (status > 0)
             found_obj = TRUE;
     } /* end else */
