@@ -10,9 +10,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Quincey Koziol
- *              Monday, October 17, 2005
- *
+/*
  * Purpose:	Group testing functions.
  */
 
@@ -95,90 +93,90 @@ H5G__is_empty_test(hid_t gid)
 
     /* Get group structure */
     if (NULL == (grp = (H5G_t *)H5VL_object_verify(gid, H5I_GROUP)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* "New format" checks */
 
     /* Check if the group has any link messages */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_LINK_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists > 0) {
         /* Sanity check that new group format shouldn't have old messages */
         if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_STAB_ID)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
         if (msg_exists > 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link messages found")
+            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link messages found");
 
-        HGOTO_DONE(FALSE)
+        HGOTO_DONE(FALSE);
     } /* end if */
 
     /* Check for a link info message */
     if ((linfo_exists = H5O_msg_exists(&(grp->oloc), H5O_LINFO_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (linfo_exists > 0) {
         H5O_linfo_t linfo; /* Link info message */
 
         /* Sanity check that new group format shouldn't have old messages */
         if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_STAB_ID)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
         if (msg_exists > 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link info messages found")
+            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link info messages found");
 
         /* Get the link info */
         if (H5G__obj_get_linfo(&(grp->oloc), &linfo) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "can't get link info")
+            HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "can't get link info");
 
         /* Check for 'dense' link storage file addresses being defined */
-        if (H5F_addr_defined(linfo.fheap_addr))
-            HGOTO_DONE(FALSE)
-        if (H5F_addr_defined(linfo.name_bt2_addr))
-            HGOTO_DONE(FALSE)
-        if (H5F_addr_defined(linfo.corder_bt2_addr))
-            HGOTO_DONE(FALSE)
+        if (H5_addr_defined(linfo.fheap_addr))
+            HGOTO_DONE(FALSE);
+        if (H5_addr_defined(linfo.name_bt2_addr))
+            HGOTO_DONE(FALSE);
+        if (H5_addr_defined(linfo.corder_bt2_addr))
+            HGOTO_DONE(FALSE);
 
         /* Check for link count */
         if (linfo.nlinks > 0)
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(FALSE);
     } /* end if */
 
     /* "Old format" checks */
 
     /* Check if the group has a symbol table message */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_STAB_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists > 0) {
         H5O_stab_t stab;   /* Info about local heap & B-tree */
         hsize_t    nlinks; /* Number of links in the group */
 
         /* Sanity check that old group format shouldn't have new messages */
         if (linfo_exists > 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link info messages found")
+            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link info messages found");
         if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_GINFO_ID)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
         if (msg_exists > 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and group info messages found")
+            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and group info messages found");
 
         /* Get the B-tree & local heap info */
         if (NULL == H5O_msg_read(&(grp->oloc), H5O_STAB_ID, &stab))
-            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "unable to read symbol table message")
+            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "unable to read symbol table message");
 
         /* Get the count of links in the group */
         if (H5G__stab_count(&(grp->oloc), &nlinks) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "unable to count links")
+            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "unable to count links");
 
         /* Check for link count */
         if (nlinks > 0)
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(FALSE);
     } /* end if */
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5G__is_empty_test() */
@@ -214,24 +212,24 @@ H5G__has_links_test(hid_t gid, unsigned *nmsgs)
 
     /* Get group structure */
     if (NULL == (grp = (H5G_t *)H5VL_object_verify(gid, H5I_GROUP)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Check if the group has any link messages */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_LINK_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists == 0)
-        HGOTO_DONE(FALSE)
+        HGOTO_DONE(FALSE);
 
     /* Check if the group has a symbol table message */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_STAB_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists > 0)
-        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link messages found")
+        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link messages found");
 
     /* Check if we should retrieve the number of link messages */
     if (nmsgs) {
@@ -239,13 +237,13 @@ H5G__has_links_test(hid_t gid, unsigned *nmsgs)
 
         /* Check how many link messages there are */
         if ((msg_count = H5O_msg_count(&(grp->oloc), H5O_LINK_ID)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTCOUNT, FAIL, "unable to count link messages")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTCOUNT, FAIL, "unable to count link messages");
         *nmsgs = (unsigned)msg_count;
     } /* end if */
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5G__has_links_test() */
@@ -280,28 +278,28 @@ H5G__has_stab_test(hid_t gid)
 
     /* Get group structure */
     if (NULL == (grp = (H5G_t *)H5VL_object_verify(gid, H5I_GROUP)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Check if the group has a symbol table message */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_STAB_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists == 0)
-        HGOTO_DONE(FALSE)
+        HGOTO_DONE(FALSE);
 
     /* Check if the group has any link messages */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_LINK_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists > 0)
-        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link messages found")
+        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "both symbol table and link messages found");
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5G__has_stab_test() */
@@ -338,45 +336,45 @@ H5G__is_new_dense_test(hid_t gid)
 
     /* Get group structure */
     if (NULL == (grp = (H5G_t *)H5VL_object_verify(gid, H5I_GROUP)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Check if the group has a symbol table message */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_STAB_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists > 0)
-        HGOTO_DONE(FALSE)
+        HGOTO_DONE(FALSE);
 
     /* Check if the group has any link messages */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_LINK_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists > 0)
-        HGOTO_DONE(FALSE)
+        HGOTO_DONE(FALSE);
 
     /* Check if the group has link info message */
     if ((msg_exists = H5O_msg_exists(&(grp->oloc), H5O_LINFO_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
     if (msg_exists > 0) {
         H5O_linfo_t linfo; /* Link info message */
 
         /* Get the link info */
         if (H5G__obj_get_linfo(&(grp->oloc), &linfo) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "can't get link info")
+            HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "can't get link info");
 
         /* Check for 'dense' link storage file addresses being defined */
-        if (!H5F_addr_defined(linfo.fheap_addr))
-            HGOTO_DONE(FALSE)
-        if (!H5F_addr_defined(linfo.name_bt2_addr))
-            HGOTO_DONE(FALSE)
+        if (!H5_addr_defined(linfo.fheap_addr))
+            HGOTO_DONE(FALSE);
+        if (!H5_addr_defined(linfo.name_bt2_addr))
+            HGOTO_DONE(FALSE);
     } /* end if */
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5G__is_new_dense_test() */
@@ -416,45 +414,45 @@ H5G__new_dense_info_test(hid_t gid, hsize_t *name_count, hsize_t *corder_count)
 
     /* Get group structure */
     if (NULL == (grp = (H5G_t *)H5VL_object_verify(gid, H5I_GROUP)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Set metadata tag in API context */
-    H5_BEGIN_TAG(grp->oloc.addr);
+    H5_BEGIN_TAG(grp->oloc.addr)
 
     /* Get the link info */
     if (H5G__obj_get_linfo(&(grp->oloc), &linfo) < 0)
-        HGOTO_ERROR_TAG(H5E_SYM, H5E_BADMESG, FAIL, "can't get link info")
+        HGOTO_ERROR_TAG(H5E_SYM, H5E_BADMESG, FAIL, "can't get link info");
 
     /* Check for 'dense' link storage file addresses being defined */
-    if (!H5F_addr_defined(linfo.fheap_addr))
-        HGOTO_DONE_TAG(FAIL)
-    if (!H5F_addr_defined(linfo.name_bt2_addr))
-        HGOTO_DONE_TAG(FAIL)
+    if (!H5_addr_defined(linfo.fheap_addr))
+        HGOTO_DONE_TAG(FAIL);
+    if (!H5_addr_defined(linfo.name_bt2_addr))
+        HGOTO_DONE_TAG(FAIL);
 
     /* Open the name index v2 B-tree */
     if (NULL == (bt2_name = H5B2_open(grp->oloc.file, linfo.name_bt2_addr, NULL)))
-        HGOTO_ERROR_TAG(H5E_SYM, H5E_CANTOPENOBJ, FAIL, "unable to open v2 B-tree for name index")
+        HGOTO_ERROR_TAG(H5E_SYM, H5E_CANTOPENOBJ, FAIL, "unable to open v2 B-tree for name index");
 
     /* Retrieve # of records in name index */
     if (H5B2_get_nrec(bt2_name, name_count) < 0)
-        HGOTO_ERROR_TAG(H5E_SYM, H5E_CANTCOUNT, FAIL, "unable to retrieve # of records from name index")
+        HGOTO_ERROR_TAG(H5E_SYM, H5E_CANTCOUNT, FAIL, "unable to retrieve # of records from name index");
 
     /* Check if there is a creation order index */
-    if (H5F_addr_defined(linfo.corder_bt2_addr)) {
+    if (H5_addr_defined(linfo.corder_bt2_addr)) {
         /* Open the creation order index v2 B-tree */
         if (NULL == (bt2_corder = H5B2_open(grp->oloc.file, linfo.corder_bt2_addr, NULL)))
             HGOTO_ERROR_TAG(H5E_SYM, H5E_CANTOPENOBJ, FAIL,
-                            "unable to open v2 B-tree for creation order index")
+                            "unable to open v2 B-tree for creation order index");
 
         /* Retrieve # of records in creation order index */
         if (H5B2_get_nrec(bt2_corder, corder_count) < 0)
             HGOTO_ERROR_TAG(H5E_SYM, H5E_CANTCOUNT, FAIL,
-                            "unable to retrieve # of records from creation order index")
+                            "unable to retrieve # of records from creation order index");
     } /* end if */
     else
         *corder_count = 0;
@@ -465,11 +463,11 @@ H5G__new_dense_info_test(hid_t gid, hsize_t *name_count, hsize_t *corder_count)
 done:
     /* Release resources */
     if (bt2_name && H5B2_close(bt2_name) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index")
+        HDONE_ERROR(H5E_SYM, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for name index");
     if (bt2_corder && H5B2_close(bt2_corder) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for creation order index")
+        HDONE_ERROR(H5E_SYM, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree for creation order index");
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5G__new_dense_info_test() */
@@ -505,24 +503,24 @@ H5G__lheap_size_test(hid_t gid, size_t *lheap_size)
 
     /* Get group structure */
     if (NULL == (grp = (H5G_t *)H5VL_object_verify(gid, H5I_GROUP)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Make certain the group has a symbol table message */
     if (NULL == H5O_msg_read(&(grp->oloc), H5O_STAB_ID, &stab))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read symbol table message")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read symbol table message");
 
     /* Check the size of the local heap for the group */
     if (H5HL_get_size(grp->oloc.file, stab.heap_addr, lheap_size) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTGETSIZE, FAIL, "can't query local heap size")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTGETSIZE, FAIL, "can't query local heap size");
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5G__lheap_size_test() */
@@ -560,16 +558,16 @@ H5G__user_path_test(hid_t obj_id, char *user_path, size_t *user_path_len, unsign
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(user_path_len);
-    HDassert(obj_hidden);
+    assert(user_path_len);
+    assert(obj_hidden);
 
     /* Get pointer to object for ID */
     if (NULL == (obj_ptr = H5VL_object(obj_id)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "can't get object for ID")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "can't get object for ID");
 
     /* Set API context */
     if (H5CX_push() < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set API context");
     api_ctx_pushed = TRUE;
 
     /* Get the symbol table entry */
@@ -585,13 +583,13 @@ H5G__user_path_test(hid_t obj_id, char *user_path, size_t *user_path_len, unsign
         case H5I_DATATYPE:
             /* Avoid non-named datatypes */
             if (!H5T_is_named((H5T_t *)obj_ptr))
-                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a named datatype")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a named datatype");
 
             obj_path = H5T_nameof((H5T_t *)obj_ptr);
             break;
 
         case H5I_MAP:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "maps not supported in native VOL connector")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "maps not supported in native VOL connector");
 
         case H5I_UNINIT:
         case H5I_BADID:
@@ -609,9 +607,9 @@ H5G__user_path_test(hid_t obj_id, char *user_path, size_t *user_path_len, unsign
         case H5I_EVENTSET:
         case H5I_NTYPES:
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unknown data object type")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unknown data object type");
     } /* end switch */
-    HDassert(obj_path);
+    assert(obj_path);
 
     /* Retrieve a copy of the user path and put it into the buffer */
     if (obj_path->user_path_r) {
@@ -634,7 +632,7 @@ H5G__user_path_test(hid_t obj_id, char *user_path, size_t *user_path_len, unsign
 
 done:
     if (api_ctx_pushed && H5CX_pop(FALSE) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context")
+        HDONE_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "can't reset API context");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5G__user_path_test() */
@@ -649,9 +647,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:	Neil Fortner
- *	        Mar  31, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -665,30 +660,30 @@ H5G__verify_cached_stab_test(H5O_loc_t *grp_oloc, H5G_entry_t *ent)
 
     /* Verify that stab info is cached in ent */
     if (ent->type != H5G_CACHED_STAB)
-        HGOTO_ERROR(H5E_SYM, H5E_BADTYPE, FAIL, "symbol table information is not cached")
+        HGOTO_ERROR(H5E_SYM, H5E_BADTYPE, FAIL, "symbol table information is not cached");
 
     /* Read the symbol table message from the group */
     if (NULL == H5O_msg_read(grp_oloc, H5O_STAB_ID, &stab))
-        HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "unable to read symbol table message")
+        HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "unable to read symbol table message");
 
     /* Verify that the cached symbol table info matches the symbol table message
      * in the object header.
      */
     if ((ent->cache.stab.btree_addr != stab.btree_addr) || (ent->cache.stab.heap_addr != stab.heap_addr))
-        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "cached stab info does not match object header")
+        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "cached stab info does not match object header");
 
     /* Verify that the btree address is valid */
     if (H5B_valid(grp_oloc->file, H5B_SNODE, stab.btree_addr) < 0)
-        HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, FAIL, "b-tree address is invalid")
+        HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, FAIL, "b-tree address is invalid");
 
     /* Verify that the heap address is valid */
     if (NULL == (heap = H5HL_protect(grp_oloc->file, stab.heap_addr, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "heap address is invalid")
+        HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "heap address is invalid");
 
 done:
     /* Release resources */
     if (heap && H5HL_unprotect(heap) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_PROTECT, FAIL, "unable to unprotect symbol table heap")
+        HDONE_ERROR(H5E_SYM, H5E_PROTECT, FAIL, "unable to unprotect symbol table heap");
 
     FUNC_LEAVE_NOAPI_TAG(ret_value)
 } /* end H5G__verify_cached_stab_test() */
@@ -703,9 +698,6 @@ done:
  *
  * Return:      H5_ITER_STOP/H5_ITER_CONT/H5_ITER_ERROR
  *
- * Programmer:  Neil Fortner
- *              Apr 8, 2011
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -723,12 +715,12 @@ H5G__verify_cached_stabs_test_cb(H5F_t *f, const void H5_ATTR_UNUSED *_lt_key, h
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(H5_addr_defined(addr));
 
     /* Load the node */
     if (NULL == (sn = (H5G_node_t *)H5AC_protect(f, H5AC_SNODE, addr, f, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_SYM, H5E_CANTLOAD, H5_ITER_ERROR, "unable to load symbol table node")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTLOAD, H5_ITER_ERROR, "unable to load symbol table node");
 
     /* Check each target object to see if its stab message (if present) matches
      * the cached stab (if present).  If one exists, both must exist. */
@@ -743,28 +735,28 @@ H5G__verify_cached_stabs_test_cb(H5F_t *f, const void H5_ATTR_UNUSED *_lt_key, h
 
         /* Load target object header */
         if (NULL == (targ_oh = H5O_protect(&targ_oloc, H5AC__READ_ONLY_FLAG, FALSE)))
-            HGOTO_ERROR(H5E_SYM, H5E_CANTPROTECT, H5_ITER_ERROR, "unable to protect target object header")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTPROTECT, H5_ITER_ERROR, "unable to protect target object header");
 
         /* Check if a symbol table message exists */
         if ((stab_exists = H5O_msg_exists_oh(targ_oh, H5O_STAB_ID)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, H5_ITER_ERROR, "unable to check for STAB message")
+            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, H5_ITER_ERROR, "unable to check for STAB message");
 
         if (stab_exists) {
             /* Read symbol table message */
             if (NULL == H5O_msg_read_oh(f, targ_oh, H5O_STAB_ID, &stab))
-                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5_ITER_ERROR, "unable to read STAB message")
+                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5_ITER_ERROR, "unable to read STAB message");
 
             /* Check if the stab matches the cached stab info */
             if (sn->entry[i].type != H5G_CACHED_STAB)
-                HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, H5_ITER_ERROR, "STAB message is not cached in group node")
+                HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, H5_ITER_ERROR, "STAB message is not cached in group node");
 
             if ((sn->entry[i].cache.stab.btree_addr != stab.btree_addr) ||
                 (sn->entry[i].cache.stab.heap_addr != stab.heap_addr))
                 HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, H5_ITER_ERROR,
-                            "cached symbol table information is incorrect")
+                            "cached symbol table information is incorrect");
         }
         else if (sn->entry[i].type == H5G_CACHED_STAB)
-            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, H5_ITER_ERROR, "nonexistent STAB message is cached")
+            HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, H5_ITER_ERROR, "nonexistent STAB message is cached");
 
         /* Unprotect target object */
         if (H5O_unprotect(&targ_oloc, targ_oh, H5AC__NO_FLAGS_SET) < 0)
@@ -774,10 +766,10 @@ H5G__verify_cached_stabs_test_cb(H5F_t *f, const void H5_ATTR_UNUSED *_lt_key, h
 
 done:
     if (sn && H5AC_unprotect(f, H5AC_SNODE, addr, sn, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_SYM, H5E_PROTECT, H5_ITER_ERROR, "unable to release object header")
+        HDONE_ERROR(H5E_SYM, H5E_PROTECT, H5_ITER_ERROR, "unable to release object header");
 
     if (targ_oh) {
-        HDassert(ret_value == H5_ITER_ERROR);
+        assert(ret_value == H5_ITER_ERROR);
         if (H5O_unprotect(&targ_oloc, targ_oh, H5AC__NO_FLAGS_SET) < 0)
             HDONE_ERROR(H5E_SYM, H5E_CANTUNPROTECT, H5_ITER_ERROR, "unable to release object header");
     } /* end if */
@@ -797,9 +789,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Neil Fortner
- *              April 6 2011
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -815,11 +804,11 @@ H5G__verify_cached_stabs_test(hid_t gid)
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(gid >= 0);
+    assert(gid >= 0);
 
     /* Check args */
     if (NULL == (grp = (H5G_t *)H5VL_object_verify(gid, H5I_GROUP)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group");
 
     /* Set up metadata tagging */
     H5AC_tag(grp->oloc.addr, &prev_tag);
@@ -827,7 +816,7 @@ H5G__verify_cached_stabs_test(hid_t gid)
     /* Check for group having a symbol table message */
     /* Check for the group having a group info message */
     if ((stab_exists = H5O_msg_exists(&(grp->oloc), H5O_STAB_ID)) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to read object header");
 
     /* No need to check anything if the symbol table doesn't exist */
     if (!stab_exists)
@@ -835,7 +824,7 @@ H5G__verify_cached_stabs_test(hid_t gid)
 
     /* Read the stab */
     if (NULL == H5O_msg_read(&(grp->oloc), H5O_STAB_ID, &stab))
-        HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "can't get symbol table info")
+        HGOTO_ERROR(H5E_SYM, H5E_BADMESG, FAIL, "can't get symbol table info");
 
     /* Iterate over the b-tree, checking validity of cached information */
     if ((ret_value = H5B_iterate(grp->oloc.file, H5B_SNODE, stab.btree_addr, H5G__verify_cached_stabs_test_cb,
