@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5HF.c
- *			Feb 24 2006
- *			Quincey Koziol
  *
  * Purpose:		Implements a "fractal heap" for storing variable-
  *                      length objects in a file.
@@ -80,9 +78,6 @@ H5FL_DEFINE_STATIC(H5HF_t);
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sep 11 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -103,9 +98,6 @@ H5HF__op_read(const void *obj, size_t obj_len, void *op_data)
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Dec 18 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -133,9 +125,6 @@ H5HF__op_write(const void *obj, size_t obj_len, void *op_data)
  * Return:	Pointer to heap wrapper on success
  *              NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Feb 24 2006
- *
  *-------------------------------------------------------------------------
  */
 H5HF_t *
@@ -151,29 +140,30 @@ H5HF_create(H5F_t *f, const H5HF_create_t *cparam)
     /*
      * Check arguments.
      */
-    HDassert(f);
-    HDassert(cparam);
+    assert(f);
+    assert(cparam);
 
     /* Create shared fractal heap header */
     if (HADDR_UNDEF == (fh_addr = H5HF__hdr_create(f, cparam)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, NULL, "can't create fractal heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, NULL, "can't create fractal heap header");
 
     /* Allocate fractal heap wrapper */
     if (NULL == (fh = H5FL_MALLOC(H5HF_t)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed for fractal heap info")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed for fractal heap info");
 
     /* Lock the heap header into memory */
     if (NULL == (hdr = H5HF__hdr_protect(f, fh_addr, H5AC__NO_FLAGS_SET)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect fractal heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect fractal heap header");
 
     /* Point fractal heap wrapper at header and bump it's ref count */
     fh->hdr = hdr;
     if (H5HF__hdr_incr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment reference count on shared heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment reference count on shared heap header");
 
     /* Increment # of files using this heap header */
     if (H5HF__hdr_fuse_incr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment file reference count on shared heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL,
+                    "can't increment file reference count on shared heap header");
 
     /* Set file pointer for this heap open context */
     fh->f = f;
@@ -183,10 +173,10 @@ H5HF_create(H5F_t *f, const H5HF_create_t *cparam)
 
 done:
     if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release fractal heap header")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release fractal heap header");
     if (!ret_value && fh)
         if (H5HF_close(fh) < 0)
-            HDONE_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, NULL, "unable to close fractal heap")
+            HDONE_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, NULL, "unable to close fractal heap");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_create() */
@@ -199,9 +189,6 @@ done:
  * Return:	Pointer to heap wrapper on success
  *              NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Apr 18 2006
- *
  *-------------------------------------------------------------------------
  */
 H5HF_t *
@@ -216,29 +203,30 @@ H5HF_open(H5F_t *f, haddr_t fh_addr)
     /*
      * Check arguments.
      */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fh_addr));
+    assert(f);
+    assert(H5_addr_defined(fh_addr));
 
     /* Load the heap header into memory */
     if (NULL == (hdr = H5HF__hdr_protect(f, fh_addr, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect fractal heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect fractal heap header");
 
     /* Check for pending heap deletion */
     if (hdr->pending_delete)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, NULL, "can't open fractal heap pending deletion")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, NULL, "can't open fractal heap pending deletion");
 
     /* Create fractal heap info */
     if (NULL == (fh = H5FL_MALLOC(H5HF_t)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed for fractal heap info")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed for fractal heap info");
 
     /* Point fractal heap wrapper at header */
     fh->hdr = hdr;
     if (H5HF__hdr_incr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment reference count on shared heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment reference count on shared heap header");
 
     /* Increment # of files using this heap header */
     if (H5HF__hdr_fuse_incr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment file reference count on shared heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL,
+                    "can't increment file reference count on shared heap header");
 
     /* Set file pointer for this heap open context */
     fh->f = f;
@@ -248,10 +236,10 @@ H5HF_open(H5F_t *f, haddr_t fh_addr)
 
 done:
     if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release fractal heap header")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release fractal heap header");
     if (!ret_value && fh)
         if (H5HF_close(fh) < 0)
-            HDONE_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, NULL, "unable to close fractal heap")
+            HDONE_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, NULL, "unable to close fractal heap");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_open() */
@@ -263,9 +251,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 17 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -276,8 +261,8 @@ H5HF_get_id_len(H5HF_t *fh, size_t *id_len_p)
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(id_len_p);
+    assert(fh);
+    assert(id_len_p);
 
     /* Retrieve the ID length for entries in this heap */
     *id_len_p = fh->hdr->id_len;
@@ -292,9 +277,6 @@ H5HF_get_id_len(H5HF_t *fh, size_t *id_len_p)
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 18 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -305,8 +287,8 @@ H5HF_get_heap_addr(const H5HF_t *fh, haddr_t *heap_addr_p)
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(heap_addr_p);
+    assert(fh);
+    assert(heap_addr_p);
 
     /* Retrieve the heap header address for this heap */
     *heap_addr_p = fh->hdr->heap_addr;
@@ -322,9 +304,6 @@ H5HF_get_heap_addr(const H5HF_t *fh, haddr_t *heap_addr_p)
  * Return:	Non-negative on success (with heap ID of new object
  *              filled in), negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Feb 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -336,13 +315,13 @@ H5HF_insert(H5HF_t *fh, size_t size, const void *obj, void *id /*out*/)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(fh);
-    HDassert(obj);
-    HDassert(id);
+    assert(fh);
+    assert(obj);
+    assert(id);
 
     /* Check arguments */
     if (size == 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "can't insert 0-sized objects")
+        HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "can't insert 0-sized objects");
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
@@ -359,24 +338,24 @@ H5HF_insert(H5HF_t *fh, size_t size, const void *obj, void *id /*out*/)
          */
         H5_GCC_CLANG_DIAG_OFF("cast-qual")
         if (H5HF__huge_insert(hdr, size, (void *)obj, id) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'huge' object in fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'huge' object in fractal heap");
         H5_GCC_CLANG_DIAG_ON("cast-qual")
     } /* end if */
     /* Check for 'tiny' object */
     else if (size <= hdr->tiny_max_len) {
         /* Store 'tiny' object in heap */
         if (H5HF__tiny_insert(hdr, size, obj, id) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'tiny' object in fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'tiny' object in fractal heap");
     } /* end if */
     else {
         /* Check if we are in "append only" mode, or if there's enough room for the object */
         if (hdr->write_once) {
-            HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "'write once' managed blocks not supported yet")
+            HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "'write once' managed blocks not supported yet");
         } /* end if */
         else {
             /* Allocate space for object in 'managed' heap */
             if (H5HF__man_insert(hdr, size, obj, id) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'managed' object in fractal heap")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'managed' object in fractal heap");
         } /* end else */
     }     /* end else */
 
@@ -391,9 +370,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		May  9 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -408,16 +384,16 @@ H5HF_get_obj_len(H5HF_t *fh, const void *_id, size_t *obj_len_p)
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(id);
-    HDassert(obj_len_p);
+    assert(fh);
+    assert(id);
+    assert(obj_len_p);
 
     /* Get the ID flags */
     id_flags = *id;
 
     /* Check for correct heap ID version */
     if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
-        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version");
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
@@ -425,19 +401,19 @@ H5HF_get_obj_len(H5HF_t *fh, const void *_id, size_t *obj_len_p)
     /* Check type of object in heap */
     if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         if (H5HF__man_get_obj_len(fh->hdr, id, obj_len_p) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'managed' object's length")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'managed' object's length");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         if (H5HF__huge_get_obj_len(fh->hdr, id, obj_len_p) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'huge' object's length")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'huge' object's length");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         if (H5HF__tiny_get_obj_len(fh->hdr, id, obj_len_p) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'tiny' object's length")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'tiny' object's length");
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+        fprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet");
     } /* end else */
 
 done:
@@ -451,9 +427,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug 20 2015
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -468,16 +441,16 @@ H5HF_get_obj_off(H5HF_t *fh, const void *_id, hsize_t *obj_off_p)
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(id);
-    HDassert(obj_off_p);
+    assert(fh);
+    assert(id);
+    assert(obj_off_p);
 
     /* Get the ID flags */
     id_flags = *id;
 
     /* Check for correct heap ID version */
     if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
-        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version");
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
@@ -489,15 +462,15 @@ H5HF_get_obj_off(H5HF_t *fh, const void *_id, hsize_t *obj_off_p)
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Huge objects are located directly in the file */
         if (H5HF__huge_get_obj_off(fh->hdr, id, obj_off_p) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'huge' object's offset")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'huge' object's offset");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Tiny objects are not stored in the heap */
         *obj_off_p = (hsize_t)0;
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+        fprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet");
     } /* end else */
 
 done:
@@ -511,9 +484,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Mar 18 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -528,16 +498,16 @@ H5HF_read(H5HF_t *fh, const void *_id, void *obj /*out*/)
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(id);
-    HDassert(obj);
+    assert(fh);
+    assert(id);
+    assert(obj);
 
     /* Get the ID flags */
     id_flags = *id;
 
     /* Check for correct heap ID version */
     if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
-        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version");
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
@@ -546,21 +516,21 @@ H5HF_read(H5HF_t *fh, const void *_id, void *obj /*out*/)
     if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         /* Read object from managed heap blocks */
         if (H5HF__man_read(fh->hdr, id, obj) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read object from fractal heap");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Read 'huge' object from file */
         if (H5HF__huge_read(fh->hdr, id, obj) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read 'huge' object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read 'huge' object from fractal heap");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Read 'tiny' object from file */
         if (H5HF__tiny_read(fh->hdr, id, obj) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read 'tiny' object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read 'tiny' object from fractal heap");
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+        fprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet");
     } /* end else */
 
 done:
@@ -586,9 +556,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Dec 18 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -603,16 +570,16 @@ H5HF_write(H5HF_t *fh, void *_id, hbool_t H5_ATTR_UNUSED *id_changed, const void
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(id);
-    HDassert(obj);
+    assert(fh);
+    assert(id);
+    assert(obj);
 
     /* Get the ID flags */
     id_flags = *id;
 
     /* Check for correct heap ID version */
     if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
-        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version");
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
@@ -622,21 +589,21 @@ H5HF_write(H5HF_t *fh, void *_id, hbool_t H5_ATTR_UNUSED *id_changed, const void
         /* Operate on object from managed heap blocks */
         /* (ID can't change and modifying object is "easy" to manage) */
         if (H5HF__man_write(fh->hdr, id, obj) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "can't write to 'managed' heap object")
+            HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "can't write to 'managed' heap object");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Operate on "huge" object */
         if (H5HF__huge_write(fh->hdr, id, obj) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "can't write to 'huge' heap object")
+            HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "can't write to 'huge' heap object");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Check for writing a 'tiny' object */
         /* (which isn't supported yet - ID will change) */
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "modifying 'tiny' object not supported yet")
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "modifying 'tiny' object not supported yet");
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+        fprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet");
     } /* end else */
 
 done:
@@ -655,9 +622,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sept 11 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -672,16 +636,16 @@ H5HF_op(H5HF_t *fh, const void *_id, H5HF_operator_t op, void *op_data)
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(id);
-    HDassert(op);
+    assert(fh);
+    assert(id);
+    assert(op);
 
     /* Get the ID flags */
     id_flags = *id;
 
     /* Check for correct heap ID version */
     if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
-        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version");
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
@@ -690,21 +654,21 @@ H5HF_op(H5HF_t *fh, const void *_id, H5HF_operator_t op, void *op_data)
     if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         /* Operate on object from managed heap blocks */
         if (H5HF__man_op(fh->hdr, id, op, op_data) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on object from fractal heap");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Operate on 'huge' object from file */
         if (H5HF__huge_op(fh->hdr, id, op, op_data) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on 'huge' object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on 'huge' object from fractal heap");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Operate on 'tiny' object from file */
         if (H5HF__tiny_op(fh->hdr, id, op, op_data) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on 'tiny' object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on 'tiny' object from fractal heap");
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+        fprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet");
     } /* end else */
 
 done:
@@ -718,9 +682,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		May 15 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -735,16 +696,16 @@ H5HF_remove(H5HF_t *fh, const void *_id)
     /*
      * Check arguments.
      */
-    HDassert(fh);
-    HDassert(fh->hdr);
-    HDassert(id);
+    assert(fh);
+    assert(fh->hdr);
+    assert(id);
 
     /* Get the ID flags */
     id_flags = *id;
 
     /* Check for correct heap ID version */
     if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
-        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version");
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
@@ -753,21 +714,21 @@ H5HF_remove(H5HF_t *fh, const void *_id)
     if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         /* Remove object from managed heap blocks */
         if (H5HF__man_remove(fh->hdr, id) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from fractal heap");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Remove 'huge' object from file & v2 B-tree tracker */
         if (H5HF__huge_remove(fh->hdr, id) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove 'huge' object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove 'huge' object from fractal heap");
     } /* end if */
     else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Remove 'tiny' object from heap statistics */
         if (H5HF__tiny_remove(fh->hdr, id) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove 'tiny' object from fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove 'tiny' object from fractal heap");
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+        fprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet");
     } /* end else */
 
 done:
@@ -781,9 +742,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 17 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -798,7 +756,7 @@ H5HF_close(H5HF_t *fh)
     /*
      * Check arguments.
      */
-    HDassert(fh);
+    assert(fh);
 
     /* Decrement file reference & check if this is the last open fractal heap using the shared heap header */
     if (0 == H5HF__hdr_fuse_decr(fh->hdr)) {
@@ -812,7 +770,7 @@ H5HF_close(H5HF_t *fh)
          *      the metadata cache - QAK)
          */
         if (H5HF__space_close(fh->hdr) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release free space info")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release free space info");
 
         /* Reset the block iterator, if necessary */
         /* (Can't put this in header "destroy" routine, because it has
@@ -822,7 +780,7 @@ H5HF_close(H5HF_t *fh)
          */
         if (H5HF__man_iter_ready(&fh->hdr->next_block))
             if (H5HF__man_iter_reset(&fh->hdr->next_block) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't reset block iterator")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't reset block iterator");
 
         /* Shut down the huge object information */
         /* (Can't put this in header "destroy" routine, because it has
@@ -830,7 +788,7 @@ H5HF_close(H5HF_t *fh)
          *      modified by the shutdown routine - QAK)
          */
         if (H5HF__huge_term(fh->hdr) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release 'huge' object info")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release 'huge' object info");
 
         /* Check for pending heap deletion */
         if (fh->hdr->pending_delete) {
@@ -847,7 +805,7 @@ H5HF_close(H5HF_t *fh)
      *  immediately -QAK)
      */
     if (H5HF__hdr_decr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL, "can't decrement reference count on shared heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL, "can't decrement reference count on shared heap header");
 
     /* Check for pending heap deletion */
     if (pending_delete) {
@@ -855,11 +813,11 @@ H5HF_close(H5HF_t *fh)
 
         /* Lock the heap header into memory */
         if (NULL == (hdr = H5HF__hdr_protect(fh->f, heap_addr, H5AC__NO_FLAGS_SET)))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header");
 
         /* Delete heap, starting with header (unprotects header) */
         if (H5HF__hdr_delete(hdr) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "unable to delete fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "unable to delete fractal heap");
     } /* end if */
 
 done:
@@ -876,9 +834,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  4 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -892,12 +847,12 @@ H5HF_delete(H5F_t *f, haddr_t fh_addr)
     /*
      * Check arguments.
      */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fh_addr));
+    assert(f);
+    assert(H5_addr_defined(fh_addr));
 
     /* Lock the heap header into memory */
     if (NULL == (hdr = H5HF__hdr_protect(f, fh_addr, H5AC__NO_FLAGS_SET)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header");
 
     /* Check for files using shared heap header */
     if (hdr->file_rc)
@@ -905,14 +860,14 @@ H5HF_delete(H5F_t *f, haddr_t fh_addr)
     else {
         /* Delete heap now, starting with header (unprotects header) */
         if (H5HF__hdr_delete(hdr) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "unable to delete fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "unable to delete fractal heap");
         hdr = NULL;
     } /* end if */
 
 done:
     /* Unprotect the header, if an error occurred */
     if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release fractal heap header")
+        HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release fractal heap header");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_delete() */
