@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5HFhuge.c
- *			Aug  7 2006
- *			Quincey Koziol
  *
  * Purpose:		Routines for "huge" objects in fractal heap
  *
@@ -84,9 +82,6 @@ static herr_t  H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  7 2006
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -100,7 +95,7 @@ H5HF__huge_bt2_create(H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Compute the size of 'raw' records on disk */
     /* (Note: the size for huge IDs could be set to 'huge_id_size', instead
@@ -147,12 +142,13 @@ H5HF__huge_bt2_create(H5HF_hdr_t *hdr)
 
     /* Create v2 B-tree for tracking 'huge' objects */
     if (NULL == (hdr->huge_bt2 = H5B2_create(hdr->f, &bt2_cparam, hdr->f)))
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTCREATE, FAIL, "can't create v2 B-tree for tracking 'huge' heap objects")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTCREATE, FAIL,
+                    "can't create v2 B-tree for tracking 'huge' heap objects");
 
     /* Retrieve the v2 B-tree's address in the file */
     if (H5B2_get_addr(hdr->huge_bt2, &hdr->huge_bt2_addr) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL,
-                    "can't get v2 B-tree address for tracking 'huge' heap objects")
+                    "can't get v2 B-tree address for tracking 'huge' heap objects");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -165,9 +161,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  7 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -178,7 +171,7 @@ H5HF__huge_init(H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Compute information about 'huge' objects for the heap */
 
@@ -234,9 +227,6 @@ H5HF__huge_init(H5HF_hdr_t *hdr)
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug 15 2006
- *
  *-------------------------------------------------------------------------
  */
 static hsize_t
@@ -250,12 +240,12 @@ H5HF__huge_new_id(H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Check for wrapping around 'huge' object ID space */
     if (hdr->huge_ids_wrapped)
         /* Fail for now - eventually should iterate through v2 B-tree, looking for available ID */
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, 0, "wrapping 'huge' object IDs not supported yet")
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, 0, "wrapping 'huge' object IDs not supported yet");
     else {
         /* Get new 'huge' object ID to use for object */
         /* (avoids using ID 0) */
@@ -280,9 +270,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  7 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -300,17 +287,17 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(obj_size > hdr->max_man_size);
-    HDassert(obj);
-    HDassert(id);
+    assert(hdr);
+    assert(obj_size > hdr->max_man_size);
+    assert(obj);
+    assert(id);
 
     /* Check if the v2 B-tree for tracking 'huge' heap objects has been created yet */
-    if (!H5F_addr_defined(hdr->huge_bt2_addr)) {
+    if (!H5_addr_defined(hdr->huge_bt2_addr)) {
         /* Go create (& open) v2 B-tree */
         if (H5HF__huge_bt2_create(hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTCREATE, FAIL,
-                        "can't create v2 B-tree for tracking 'huge' heap objects")
+                        "can't create v2 B-tree for tracking 'huge' heap objects");
     } /* end if */
     else {
         /* Check if v2 B-tree is open yet */
@@ -318,10 +305,10 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
             /* Open existing v2 B-tree */
             if (NULL == (hdr->huge_bt2 = H5B2_open(hdr->f, hdr->huge_bt2_addr, hdr->f)))
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, FAIL,
-                            "unable to open v2 B-tree for tracking 'huge' heap objects")
+                            "unable to open v2 B-tree for tracking 'huge' heap objects");
         } /* end if */
     }     /* end else */
-    HDassert(hdr->huge_bt2);
+    assert(hdr->huge_bt2);
 
     /* Check for I/O pipeline filter on heap */
     if (hdr->filter_len > 0) {
@@ -335,14 +322,14 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
         /* Allocate buffer to perform I/O filtering on */
         write_size = obj_size;
         if (NULL == (write_buf = H5MM_malloc(write_size)))
-            HGOTO_ERROR(H5E_HEAP, H5E_NOSPACE, FAIL, "memory allocation failed for pipeline buffer")
+            HGOTO_ERROR(H5E_HEAP, H5E_NOSPACE, FAIL, "memory allocation failed for pipeline buffer");
         H5MM_memcpy(write_buf, obj, write_size);
 
         /* Push direct block data through I/O filter pipeline */
         nbytes = write_size;
         if (H5Z_pipeline(&(hdr->pline), 0, &filter_mask, H5Z_NO_EDC, filter_cb, &nbytes, &write_size,
                          &write_buf) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTFILTER, FAIL, "output pipeline failed")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTFILTER, FAIL, "output pipeline failed");
 
         /* Update size of object on disk */
         write_size = nbytes;
@@ -354,15 +341,15 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
 
     /* Allocate space in the file for storing the 'huge' object */
     if (HADDR_UNDEF == (obj_addr = H5MF_alloc(hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, (hsize_t)write_size)))
-        HGOTO_ERROR(H5E_HEAP, H5E_NOSPACE, FAIL, "file allocation failed for fractal heap huge object")
+        HGOTO_ERROR(H5E_HEAP, H5E_NOSPACE, FAIL, "file allocation failed for fractal heap huge object");
 
     /* Write the object's data to disk */
     if (H5F_block_write(hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, obj_addr, write_size, write_buf) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "writing 'huge' object to file failed")
+        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "writing 'huge' object to file failed");
 
     /* Release buffer for writing, if we had one */
     if (write_buf != obj) {
-        HDassert(hdr->filter_len > 0);
+        assert(hdr->filter_len > 0);
         H5MM_xfree(write_buf);
     } /* end if */
 
@@ -380,7 +367,7 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
             /* Insert record for object in v2 B-tree */
             if (H5B2_insert(hdr->huge_bt2, &obj_rec) < 0)
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL,
-                            "couldn't insert object tracking record in v2 B-tree")
+                            "couldn't insert object tracking record in v2 B-tree");
 
             /* Encode ID for user */
             *id++ = H5HF_ID_VERS_CURR | H5HF_ID_TYPE_HUGE;
@@ -399,7 +386,7 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
             /* Insert record for object in v2 B-tree */
             if (H5B2_insert(hdr->huge_bt2, &obj_rec) < 0)
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL,
-                            "couldn't insert object tracking record in v2 B-tree")
+                            "couldn't insert object tracking record in v2 B-tree");
 
             /* Encode ID for user */
             *id++ = H5HF_ID_VERS_CURR | H5HF_ID_TYPE_HUGE;
@@ -415,7 +402,7 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
 
         /* Get new ID for object */
         if (0 == (new_id = H5HF__huge_new_id(hdr)))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't generate new ID for object")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't generate new ID for object");
 
         if (hdr->filter_len > 0) {
             /* Initialize record for object in v2 B-tree */
@@ -440,11 +427,12 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
 
         /* Insert record for tracking object in v2 B-tree */
         if (H5B2_insert(hdr->huge_bt2, ins_rec) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "couldn't insert object tracking record in v2 B-tree")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL,
+                        "couldn't insert object tracking record in v2 B-tree");
 
         /* Encode ID for user */
         *id++ = H5HF_ID_VERS_CURR | H5HF_ID_TYPE_HUGE;
-        UINT64ENCODE_VAR(id, new_id, hdr->huge_id_size)
+        UINT64ENCODE_VAR(id, new_id, hdr->huge_id_size);
     } /* end else */
 
     /* Update statistics about heap */
@@ -453,7 +441,7 @@ H5HF__huge_insert(H5HF_hdr_t *hdr, size_t obj_size, void *obj, void *_id)
 
     /* Mark heap header as modified */
     if (H5HF__hdr_dirty(hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -466,9 +454,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  8 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -481,10 +466,10 @@ H5HF__huge_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
-    HDassert(id);
-    HDassert(obj_len_p);
+    assert(hdr);
+    assert(H5_addr_defined(hdr->huge_bt2_addr));
+    assert(id);
+    assert(obj_len_p);
 
     /* Skip over the flag byte */
     id++;
@@ -514,7 +499,7 @@ H5HF__huge_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
             /* Open existing v2 B-tree */
             if (NULL == (hdr->huge_bt2 = H5B2_open(hdr->f, hdr->huge_bt2_addr, hdr->f)))
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, FAIL,
-                            "unable to open v2 B-tree for tracking 'huge' heap objects")
+                            "unable to open v2 B-tree for tracking 'huge' heap objects");
         } /* end if */
 
         if (hdr->filter_len > 0) {
@@ -522,14 +507,14 @@ H5HF__huge_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
             H5HF_huge_bt2_filt_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Look up object in v2 B-tree */
             if (H5B2_find(hdr->huge_bt2, &search_rec, &found, H5HF__huge_bt2_filt_indir_found, &found_rec) <
                 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree");
             if (!found)
-                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree");
 
             /* Retrieve the object's length */
             *obj_len_p = (size_t)found_rec.obj_size;
@@ -539,13 +524,13 @@ H5HF__huge_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
             H5HF_huge_bt2_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Look up object in v2 B-tree */
             if (H5B2_find(hdr->huge_bt2, &search_rec, &found, H5HF__huge_bt2_indir_found, &found_rec) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree");
             if (!found)
-                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree");
 
             /* Retrieve the object's length */
             *obj_len_p = (size_t)found_rec.len;
@@ -563,9 +548,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  8 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -579,10 +561,10 @@ H5HF__huge_get_obj_off(H5HF_hdr_t *hdr, const uint8_t *id, hsize_t *obj_off_p)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
-    HDassert(id);
-    HDassert(obj_off_p);
+    assert(hdr);
+    assert(H5_addr_defined(hdr->huge_bt2_addr));
+    assert(id);
+    assert(obj_off_p);
 
     /* Skip over the flag byte */
     id++;
@@ -596,14 +578,14 @@ H5HF__huge_get_obj_off(H5HF_hdr_t *hdr, const uint8_t *id, hsize_t *obj_off_p)
         hbool_t found = FALSE; /* Whether entry was found */
 
         /* Sanity check */
-        HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
+        assert(H5_addr_defined(hdr->huge_bt2_addr));
 
         /* Check if v2 B-tree is open yet */
         if (NULL == hdr->huge_bt2) {
             /* Open existing v2 B-tree */
             if (NULL == (hdr->huge_bt2 = H5B2_open(hdr->f, hdr->huge_bt2_addr, hdr->f)))
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, FAIL,
-                            "unable to open v2 B-tree for tracking 'huge' heap objects")
+                            "unable to open v2 B-tree for tracking 'huge' heap objects");
         } /* end if */
 
         if (hdr->filter_len > 0) {
@@ -611,14 +593,14 @@ H5HF__huge_get_obj_off(H5HF_hdr_t *hdr, const uint8_t *id, hsize_t *obj_off_p)
             H5HF_huge_bt2_filt_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Look up object in v2 B-tree */
             if (H5B2_find(hdr->huge_bt2, &search_rec, &found, H5HF__huge_bt2_filt_indir_found, &found_rec) <
                 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree");
             if (!found)
-                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree");
 
             /* Retrieve the object's address & length */
             obj_addr = found_rec.addr;
@@ -628,13 +610,13 @@ H5HF__huge_get_obj_off(H5HF_hdr_t *hdr, const uint8_t *id, hsize_t *obj_off_p)
             H5HF_huge_bt2_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Look up object in v2 B-tree */
             if (H5B2_find(hdr->huge_bt2, &search_rec, &found, H5HF__huge_bt2_indir_found, &found_rec) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree");
             if (!found)
-                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree");
 
             /* Retrieve the object's address & length */
             obj_addr = found_rec.addr;
@@ -655,9 +637,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  8 2006
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -674,9 +653,9 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(is_read || op);
+    assert(hdr);
+    assert(id);
+    assert(is_read || op);
 
     /* Skip over the flag byte */
     id++;
@@ -695,14 +674,14 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
         hbool_t found = FALSE; /* Whether entry was found */
 
         /* Sanity check */
-        HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
+        assert(H5_addr_defined(hdr->huge_bt2_addr));
 
         /* Check if v2 B-tree is open yet */
         if (NULL == hdr->huge_bt2) {
             /* Open existing v2 B-tree */
             if (NULL == (hdr->huge_bt2 = H5B2_open(hdr->f, hdr->huge_bt2_addr, hdr->f)))
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, FAIL,
-                            "unable to open v2 B-tree for tracking 'huge' heap objects")
+                            "unable to open v2 B-tree for tracking 'huge' heap objects");
         } /* end if */
 
         if (hdr->filter_len > 0) {
@@ -710,14 +689,14 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
             H5HF_huge_bt2_filt_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Look up object in v2 B-tree */
             if (H5B2_find(hdr->huge_bt2, &search_rec, &found, H5HF__huge_bt2_filt_indir_found, &found_rec) <
                 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree");
             if (!found)
-                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree");
 
             /* Retrieve the object's address & length */
             obj_addr = found_rec.addr;
@@ -729,13 +708,13 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
             H5HF_huge_bt2_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Look up object in v2 B-tree */
             if (H5B2_find(hdr->huge_bt2, &search_rec, &found, H5HF__huge_bt2_indir_found, &found_rec) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree");
             if (!found)
-                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree");
 
             /* Retrieve the object's address & length */
             obj_addr = found_rec.addr;
@@ -746,7 +725,7 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
     /* Set up buffer for reading */
     if (hdr->filter_len > 0 || !is_read) {
         if (NULL == (read_buf = H5MM_malloc((size_t)obj_size)))
-            HGOTO_ERROR(H5E_HEAP, H5E_NOSPACE, FAIL, "memory allocation failed for pipeline buffer")
+            HGOTO_ERROR(H5E_HEAP, H5E_NOSPACE, FAIL, "memory allocation failed for pipeline buffer");
     } /* end if */
     else
         read_buf = op_data;
@@ -754,7 +733,7 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
     /* Read the object's (possibly filtered) data from the file */
     /* (reads directly into application's buffer if no filters are present) */
     if (H5F_block_read(hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, obj_addr, (size_t)obj_size, read_buf) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_READERROR, FAIL, "can't read 'huge' object's data from the file")
+        HGOTO_ERROR(H5E_HEAP, H5E_READERROR, FAIL, "can't read 'huge' object's data from the file");
 
     /* Check for I/O pipeline filter on heap */
     if (hdr->filter_len > 0) {
@@ -770,7 +749,7 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
         read_size = nbytes = obj_size;
         if (H5Z_pipeline(&(hdr->pline), H5Z_FLAG_REVERSE, &filter_mask, H5Z_NO_EDC, filter_cb, &nbytes,
                          &read_size, &read_buf) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTFILTER, FAIL, "input filter failed")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTFILTER, FAIL, "input filter failed");
         obj_size = nbytes;
     } /* end if */
 
@@ -788,7 +767,7 @@ H5HF__huge_op_real(H5HF_hdr_t *hdr, const uint8_t *id, hbool_t is_read, H5HF_ope
             read_buf = H5MM_xfree(read_buf);
 
             /* Indicate error */
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "application's callback failed")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "application's callback failed");
         } /* end if */
     }     /* end if */
 
@@ -801,41 +780,36 @@ done:
 } /* end H5HF__huge_op_real() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF__huge_write
+ * Function:    H5HF__huge_write
  *
- * Purpose:	Write a 'huge' object to the heap
+ * Purpose:     Write a 'huge' object to the heap
  *
- * Note:	This implementation somewhat limited: it doesn't handle
- *		heaps with filters, which would require re-compressing the
- *		huge object and probably changing the address of the object
- *		on disk (and possibly the heap ID for "direct" huge IDs).
+ * Note:        This implementation somewhat limited: it doesn't handle
+ *              heaps with filters, which would require re-compressing the
+ *              huge object and probably changing the address of the object
+ *              on disk (and possibly the heap ID for "direct" huge IDs).
  *
- * Return:	SUCCEED/FAIL
- *
- * Programmer:	Quincey Koziol
- *		Feb 21 2007
+ * Return:      SUCCEED/FAIL
  *
  *-------------------------------------------------------------------------
  */
 herr_t
 H5HF__huge_write(H5HF_hdr_t *hdr, const uint8_t *id, const void *obj)
 {
-    haddr_t obj_addr;            /* Object's address in the file */
-    size_t  obj_size;            /* Object's size in the file */
-    herr_t  ret_value = SUCCEED; /* Return value */
+    haddr_t obj_addr  = HADDR_UNDEF; /* Object's address in the file */
+    size_t  obj_size  = 0;           /* Object's size in the file */
+    herr_t  ret_value = SUCCEED;
 
     FUNC_ENTER_PACKAGE
 
-    /*
-     * Check arguments.
-     */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(obj);
+    assert(hdr);
+    assert(id);
+    assert(obj);
 
     /* Check for filters on the heap */
     if (hdr->filter_len > 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "modifying 'huge' object with filters not supported yet")
+        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL,
+                    "modifying 'huge' object with filters not supported yet");
 
     /* Skip over the flag byte */
     id++;
@@ -845,41 +819,41 @@ H5HF__huge_write(H5HF_hdr_t *hdr, const uint8_t *id, const void *obj)
         /* Retrieve the object's address and length (common) */
         H5F_addr_decode(hdr->f, &id, &obj_addr);
         H5F_DECODE_LENGTH(hdr->f, id, obj_size);
-    } /* end if */
+    }
     else {
         H5HF_huge_bt2_indir_rec_t found_rec;     /* Record found from tracking object */
         H5HF_huge_bt2_indir_rec_t search_rec;    /* Record for searching for object */
         hbool_t                   found = FALSE; /* Whether entry was found */
 
         /* Sanity check */
-        HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
+        assert(H5_addr_defined(hdr->huge_bt2_addr));
 
         /* Check if v2 B-tree is open yet */
         if (NULL == hdr->huge_bt2) {
             /* Open existing v2 B-tree */
             if (NULL == (hdr->huge_bt2 = H5B2_open(hdr->f, hdr->huge_bt2_addr, hdr->f)))
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, FAIL,
-                            "unable to open v2 B-tree for tracking 'huge' heap objects")
-        } /* end if */
+                            "unable to open v2 B-tree for tracking 'huge' heap objects");
+        }
 
         /* Get ID for looking up 'huge' object in v2 B-tree */
-        UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+        UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
         /* Look up object in v2 B-tree */
         if (H5B2_find(hdr->huge_bt2, &search_rec, &found, H5HF__huge_bt2_indir_found, &found_rec) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTFIND, FAIL, "can't check for object in v2 B-tree");
         if (!found)
-            HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree")
+            HGOTO_ERROR(H5E_HEAP, H5E_NOTFOUND, FAIL, "can't find object in v2 B-tree");
 
         /* Retrieve the object's address & length */
         obj_addr = found_rec.addr;
         H5_CHECKED_ASSIGN(obj_size, size_t, found_rec.len, hsize_t);
-    } /* end else */
+    }
 
     /* Write the object's data to the file */
     /* (writes directly from application's buffer) */
     if (H5F_block_write(hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, obj_addr, obj_size, obj) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "writing 'huge' object to file failed")
+        HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "writing 'huge' object to file failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -892,9 +866,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sept 11 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -907,13 +878,13 @@ H5HF__huge_read(H5HF_hdr_t *hdr, const uint8_t *id, void *obj)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(obj);
+    assert(hdr);
+    assert(id);
+    assert(obj);
 
     /* Call the internal 'op' routine */
     if (H5HF__huge_op_real(hdr, id, TRUE, NULL, obj) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -926,9 +897,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Sept 11 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -941,13 +909,13 @@ H5HF__huge_op(H5HF_hdr_t *hdr, const uint8_t *id, H5HF_operator_t op, void *op_d
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(op);
+    assert(hdr);
+    assert(id);
+    assert(op);
 
     /* Call the internal 'op' routine routine */
     if (H5HF__huge_op_real(hdr, id, FALSE, op, op_data) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -960,9 +928,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  8 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -976,16 +941,16 @@ H5HF__huge_remove(H5HF_hdr_t *hdr, const uint8_t *id)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
-    HDassert(id);
+    assert(hdr);
+    assert(H5_addr_defined(hdr->huge_bt2_addr));
+    assert(id);
 
     /* Check if v2 B-tree is open yet */
     if (NULL == hdr->huge_bt2) {
         /* Open existing v2 B-tree */
         if (NULL == (hdr->huge_bt2 = H5B2_open(hdr->f, hdr->huge_bt2_addr, hdr->f)))
             HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, FAIL,
-                        "unable to open v2 B-tree for tracking 'huge' heap objects")
+                        "unable to open v2 B-tree for tracking 'huge' heap objects");
     } /* end if */
 
     /* Skip over the flag byte */
@@ -1007,7 +972,7 @@ H5HF__huge_remove(H5HF_hdr_t *hdr, const uint8_t *id)
             /* Remove the record for tracking the 'huge' object from the v2 B-tree */
             /* (space in the file for the object is freed in the 'remove' callback) */
             if (H5B2_remove(hdr->huge_bt2, &search_rec, H5HF__huge_bt2_filt_dir_remove, &udata) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree");
         } /* end if */
         else {
             H5HF_huge_bt2_dir_rec_t search_rec; /* Record for searching for object */
@@ -1020,7 +985,7 @@ H5HF__huge_remove(H5HF_hdr_t *hdr, const uint8_t *id)
             /* Remove the record for tracking the 'huge' object from the v2 B-tree */
             /* (space in the file for the object is freed in the 'remove' callback) */
             if (H5B2_remove(hdr->huge_bt2, &search_rec, H5HF__huge_bt2_dir_remove, &udata) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree");
         } /* end else */
     }     /* end if */
     else {
@@ -1028,23 +993,23 @@ H5HF__huge_remove(H5HF_hdr_t *hdr, const uint8_t *id)
             H5HF_huge_bt2_filt_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Remove the record for tracking the 'huge' object from the v2 B-tree */
             /* (space in the file for the object is freed in the 'remove' callback) */
             if (H5B2_remove(hdr->huge_bt2, &search_rec, H5HF__huge_bt2_filt_indir_remove, &udata) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree");
         } /* end if */
         else {
             H5HF_huge_bt2_indir_rec_t search_rec; /* Record for searching for object */
 
             /* Get ID for looking up 'huge' object in v2 B-tree */
-            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size)
+            UINT64DECODE_VAR(id, search_rec.id, hdr->huge_id_size);
 
             /* Remove the record for tracking the 'huge' object from the v2 B-tree */
             /* (space in the file for the object is freed in the 'remove' callback) */
             if (H5B2_remove(hdr->huge_bt2, &search_rec, H5HF__huge_bt2_indir_remove, &udata) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from B-tree");
         } /* end else */
     }     /* end else */
 
@@ -1054,7 +1019,7 @@ H5HF__huge_remove(H5HF_hdr_t *hdr, const uint8_t *id)
 
     /* Mark heap header as modified */
     if (H5HF__hdr_dirty(hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1067,9 +1032,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  8 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1082,30 +1044,30 @@ H5HF__huge_term(H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Check if v2 B-tree index is open */
     if (hdr->huge_bt2) {
         /* Sanity check */
-        HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
+        assert(H5_addr_defined(hdr->huge_bt2_addr));
 
         /* Close v2 B-tree index */
         if (H5B2_close(hdr->huge_bt2) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, FAIL, "can't close v2 B-tree");
         hdr->huge_bt2 = NULL;
     } /* end if */
 
     /* Check if there are no more 'huge' objects in the heap and delete the
      *  v2 B-tree that tracks them, if so
      */
-    if (H5F_addr_defined(hdr->huge_bt2_addr) && hdr->huge_nobjs == 0) {
+    if (H5_addr_defined(hdr->huge_bt2_addr) && hdr->huge_nobjs == 0) {
         /* Sanity check */
-        HDassert(hdr->huge_size == 0);
+        assert(hdr->huge_size == 0);
 
         /* Delete the v2 B-tree */
         /* (any v2 B-tree class will work here) */
         if (H5B2_delete(hdr->f, hdr->huge_bt2_addr, hdr->f, NULL, NULL) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "can't delete v2 B-tree")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "can't delete v2 B-tree");
 
         /* Reset the information about 'huge' objects in the file */
         hdr->huge_bt2_addr    = HADDR_UNDEF;
@@ -1114,7 +1076,7 @@ H5HF__huge_term(H5HF_hdr_t *hdr)
 
         /* Mark heap header as modified */
         if (H5HF__hdr_dirty(hdr) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty");
     } /* end if */
 
 done:
@@ -1129,9 +1091,6 @@ done:
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Aug  8 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1146,10 +1105,10 @@ H5HF__huge_delete(H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(H5F_addr_defined(hdr->huge_bt2_addr));
-    HDassert(hdr->huge_nobjs);
-    HDassert(hdr->huge_size);
+    assert(hdr);
+    assert(H5_addr_defined(hdr->huge_bt2_addr));
+    assert(hdr->huge_nobjs);
+    assert(hdr->huge_size);
 
     /* Set up the callback info */
     udata.hdr = hdr;
@@ -1170,7 +1129,7 @@ H5HF__huge_delete(H5HF_hdr_t *hdr)
 
     /* Delete the v2 B-tree */
     if (H5B2_delete(hdr->f, hdr->huge_bt2_addr, hdr->f, op, &udata) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "can't delete v2 B-tree")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "can't delete v2 B-tree");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
