@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -14,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5HFiter.c
- *			Apr 24 2006
- *			Quincey Koziol
  *
  * Purpose:		Block iteration routines for fractal heaps.
  *
@@ -26,7 +23,7 @@
 /* Module Setup */
 /****************/
 
-#define H5HF_PACKAGE /*suppress error about including H5HFpkg  */
+#include "H5HFmodule.h" /* This source code file is part of the H5HF module */
 
 /***********/
 /* Headers */
@@ -65,10 +62,10 @@
 /*******************/
 
 /* Declare a free list to manage the H5HF_block_loc_t struct */
-H5FL_DEFINE(H5HF_block_loc_t);
+H5FL_DEFINE_STATIC(H5HF_block_loc_t);
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_init
+ * Function:	H5HF__man_iter_init
  *
  * Purpose:	Initialize a block iterator for walking over all the blocks
  *              in a fractal heap.  (initialization finishes when iterator is
@@ -76,42 +73,36 @@ H5FL_DEFINE(H5HF_block_loc_t);
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_init(H5HF_block_iter_t *biter)
+H5HF__man_iter_init(H5HF_block_iter_t *biter)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
+    assert(biter);
 
     /* Reset block iterator information */
-    HDmemset(biter, 0, sizeof(H5HF_block_iter_t));
+    memset(biter, 0, sizeof(H5HF_block_iter_t));
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_man_iter_init() */
+} /* end H5HF__man_iter_init() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_start_offset
+ * Function:	H5HF__man_iter_start_offset
  *
  * Purpose:	Initialize a block iterator to a particular location, given
  *              an offset in the heap
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_start_offset(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_block_iter_t *biter, hsize_t offset)
+H5HF__man_iter_start_offset(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, hsize_t offset)
 {
     H5HF_indirect_t *iblock;               /* Indirect block for location context */
     haddr_t          iblock_addr;          /* Address of indirect block */
@@ -124,21 +115,21 @@ H5HF_man_iter_start_offset(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_block_iter_t *bi
     hbool_t          root_block = TRUE;    /* Flag to indicate the current block is the root indirect block */
     herr_t           ret_value  = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
-    HDassert(!biter->ready);
+    assert(biter);
+    assert(!biter->ready);
 
     /* Check for empty heap */
-    HDassert(offset >= hdr->man_dtable.cparam.start_block_size);
+    assert(offset >= hdr->man_dtable.cparam.start_block_size);
 
     /* Allocate level structure */
     if (NULL == (biter->curr = H5FL_MALLOC(H5HF_block_loc_t)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                    "memory allocation failed for direct block free list section")
+                    "memory allocation failed for direct block free list section");
 
     /*
     1:  <Scan down block offsets for dtable rows until find a row >= offset>
@@ -204,28 +195,29 @@ H5HF_man_iter_start_offset(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_block_iter_t *bi
         } /* end else */
 
         /* Load indirect block for this context location */
-        if (NULL == (iblock = H5HF_man_iblock_protect(hdr, dxpl_id, iblock_addr, iblock_nrows, iblock_parent,
-                                                      iblock_par_entry, FALSE, H5AC_WRITE, &did_protect)))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap indirect block")
+        if (NULL ==
+            (iblock = H5HF__man_iblock_protect(hdr, iblock_addr, iblock_nrows, iblock_parent,
+                                               iblock_par_entry, FALSE, H5AC__NO_FLAGS_SET, &did_protect)))
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap indirect block");
 
         /* Make indirect block the context for the current location */
         biter->curr->context = iblock;
 
         /* Hold the indirect block with the location */
-        if (H5HF_iblock_incr(biter->curr->context) < 0)
+        if (H5HF__iblock_incr(biter->curr->context) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL,
-                        "can't increment reference count on shared indirect block")
+                        "can't increment reference count on shared indirect block");
 
         /* Release the current indirect block */
-        if (H5HF_man_iblock_unprotect(iblock, dxpl_id, H5AC__NO_FLAGS_SET, did_protect) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release fractal heap indirect block")
+        if (H5HF__man_iblock_unprotect(iblock, H5AC__NO_FLAGS_SET, did_protect) < 0)
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release fractal heap indirect block");
         iblock = NULL;
 
         /* See if the location falls in a direct block row */
         /* Or, if the offset has just filled up a direct or indirect block */
         if (curr_offset == (col * hdr->man_dtable.row_block_size[row]) ||
             row < hdr->man_dtable.max_direct_rows) {
-            HDassert(curr_offset - (col * hdr->man_dtable.row_block_size[row]) == 0);
+            assert(curr_offset - (col * hdr->man_dtable.row_block_size[row]) == 0);
             break; /* Done now */
         }          /* end if */
         /* Indirect block row */
@@ -235,7 +227,7 @@ H5HF_man_iter_start_offset(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_block_iter_t *bi
             /* Allocate level structure */
             if (NULL == (new_loc = H5FL_MALLOC(H5HF_block_loc_t)))
                 HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                            "memory allocation failed for direct block free list section")
+                            "memory allocation failed for direct block free list section");
 
             /* Link new level into iterator */
             new_loc->up = biter->curr;
@@ -253,29 +245,26 @@ H5HF_man_iter_start_offset(H5HF_hdr_t *hdr, hid_t dxpl_id, H5HF_block_iter_t *bi
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_iter_start_offset() */
+} /* end H5HF__man_iter_start_offset() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_set_entry
+ * Function:	H5HF__man_iter_set_entry
  *
  * Purpose:	Set the current entry for the iterator
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		May 31 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_set_entry(const H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigned entry)
+H5HF__man_iter_set_entry(const H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigned entry)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
+    assert(biter);
 
     /* Set location context */
     biter->curr->entry = entry;
@@ -283,42 +272,39 @@ H5HF_man_iter_set_entry(const H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigne
     biter->curr->col   = entry % hdr->man_dtable.cparam.width;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_man_iter_set_entry() */
+} /* end H5HF__man_iter_set_entry() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_start_entry
+ * Function:	H5HF__man_iter_start_entry
  *
  * Purpose:	Initialize a block iterator to a particular location within
  *              an indirect block
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_start_entry(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, H5HF_indirect_t *iblock,
-                          unsigned start_entry)
+H5HF__man_iter_start_entry(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, H5HF_indirect_t *iblock,
+                           unsigned start_entry)
 {
     H5HF_block_loc_t *new_loc   = NULL;    /* Pointer to new block location */
     herr_t            ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(biter);
-    HDassert(!biter->ready);
-    HDassert(iblock);
+    assert(hdr);
+    assert(biter);
+    assert(!biter->ready);
+    assert(iblock);
 
     /* Create new location for iterator */
     if (NULL == (new_loc = H5FL_MALLOC(H5HF_block_loc_t)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                    "memory allocation failed for direct block free list section")
+                    "memory allocation failed for direct block free list section");
 
     /* Set up location context */
     new_loc->entry   = start_entry;
@@ -328,8 +314,8 @@ H5HF_man_iter_start_entry(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, H5HF_indire
     new_loc->up      = NULL;
 
     /* Increment reference count on indirect block */
-    if (H5HF_iblock_incr(new_loc->context) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL, "can't increment reference count on shared indirect block")
+    if (H5HF__iblock_incr(new_loc->context) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL, "can't increment reference count on shared indirect block");
 
     /* Make new location the current location */
     biter->curr = new_loc;
@@ -342,32 +328,29 @@ done:
         new_loc = H5FL_FREE(H5HF_block_loc_t, new_loc);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_iter_start_entry() */
+} /* end H5HF__man_iter_start_entry() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_reset
+ * Function:	H5HF__man_iter_reset
  *
  * Purpose:	Reset a block iterator to it's initial state, freeing any
  *              location context it currently has
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_reset(H5HF_block_iter_t *biter)
+H5HF__man_iter_reset(H5HF_block_iter_t *biter)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
+    assert(biter);
 
     /* Free any location contexts that exist */
     if (biter->curr) {
@@ -382,9 +365,9 @@ H5HF_man_iter_reset(H5HF_block_iter_t *biter)
 
             /* If this node is holding an indirect block, release the block */
             if (curr_loc->context)
-                if (H5HF_iblock_decr(curr_loc->context) < 0)
+                if (H5HF__iblock_decr(curr_loc->context) < 0)
                     HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL,
-                                "can't decrement reference count on shared indirect block")
+                                "can't decrement reference count on shared indirect block");
 
             /* Free the current location context */
             curr_loc = H5FL_FREE(H5HF_block_loc_t, curr_loc);
@@ -402,74 +385,68 @@ H5HF_man_iter_reset(H5HF_block_iter_t *biter)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_iter_reset() */
+} /* end H5HF__man_iter_reset() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_next
+ * Function:	H5HF__man_iter_next
  *
  * Purpose:	Advance to the next block within the current block of the heap
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_next(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigned nentries)
+H5HF__man_iter_next(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigned nentries)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
-    HDassert(biter->curr);
-    HDassert(biter->curr->context);
-    HDassert(biter->curr->row < biter->curr->context->nrows);
+    assert(biter);
+    assert(biter->curr);
+    assert(biter->curr->context);
+    assert(biter->curr->row < biter->curr->context->nrows);
 
     /* Advance entry in current block */
     biter->curr->entry += nentries;
     biter->curr->row = biter->curr->entry / hdr->man_dtable.cparam.width;
     biter->curr->col = biter->curr->entry % hdr->man_dtable.cparam.width;
-    /*    HDassert(biter->curr->row <= biter->curr->context->nrows); */
+    /*    assert(biter->curr->row <= biter->curr->context->nrows); */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_man_iter_next() */
+} /* end H5HF__man_iter_next() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_up
+ * Function:	H5HF__man_iter_up
  *
  * Purpose:	Move iterator up one level
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_up(H5HF_block_iter_t *biter)
+H5HF__man_iter_up(H5HF_block_iter_t *biter)
 {
     H5HF_block_loc_t *up_loc;              /* Pointer to 'up' block location */
     herr_t            ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
-    HDassert(biter->ready);
-    HDassert(biter->curr);
-    HDassert(biter->curr->up);
-    HDassert(biter->curr->context);
+    assert(biter);
+    assert(biter->ready);
+    assert(biter->curr);
+    assert(biter->curr->up);
+    assert(biter->curr->context);
 
     /* Release hold on current location's indirect block */
-    if (H5HF_iblock_decr(biter->curr->context) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL, "can't decrement reference count on shared indirect block")
+    if (H5HF__iblock_decr(biter->curr->context) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL, "can't decrement reference count on shared indirect block");
 
     /* Get pointer to location context above this one */
     up_loc = biter->curr->up;
@@ -482,40 +459,37 @@ H5HF_man_iter_up(H5HF_block_iter_t *biter)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_iter_up() */
+} /* end H5HF__man_iter_up() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_down
+ * Function:	H5HF__man_iter_down
  *
  * Purpose:	Move iterator down one level
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_down(H5HF_block_iter_t *biter, H5HF_indirect_t *iblock)
+H5HF__man_iter_down(H5HF_block_iter_t *biter, H5HF_indirect_t *iblock)
 {
     H5HF_block_loc_t *down_loc  = NULL;    /* Pointer to new 'down' block location */
     herr_t            ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
-    HDassert(biter->ready);
-    HDassert(biter->curr);
-    HDassert(biter->curr->context);
+    assert(biter);
+    assert(biter->ready);
+    assert(biter->curr);
+    assert(biter->curr->context);
 
     /* Create new location to move down to */
     if (NULL == (down_loc = H5FL_MALLOC(H5HF_block_loc_t)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL,
-                    "memory allocation failed for direct block free list section")
+                    "memory allocation failed for direct block free list section");
 
     /* Initialize down location */
     down_loc->row     = 0;
@@ -525,8 +499,8 @@ H5HF_man_iter_down(H5HF_block_iter_t *biter, H5HF_indirect_t *iblock)
     down_loc->up      = biter->curr;
 
     /* Increment reference count on indirect block */
-    if (H5HF_iblock_incr(down_loc->context) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL, "can't increment reference count on shared indirect block")
+    if (H5HF__iblock_incr(down_loc->context) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL, "can't increment reference count on shared indirect block");
 
     /* Make down location the current location */
     biter->curr = down_loc;
@@ -536,31 +510,28 @@ done:
         down_loc = H5FL_FREE(H5HF_block_loc_t, down_loc);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_man_iter_down() */
+} /* end H5HF__man_iter_down() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_curr
+ * Function:	H5HF__man_iter_curr
  *
  * Purpose:	Retrieve information about the current block iterator location
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_man_iter_curr(H5HF_block_iter_t *biter, unsigned *row, unsigned *col, unsigned *entry,
-                   H5HF_indirect_t **block)
+H5HF__man_iter_curr(H5HF_block_iter_t *biter, unsigned *row, unsigned *col, unsigned *entry,
+                    H5HF_indirect_t **block)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
-    HDassert(biter->ready);
+    assert(biter);
+    assert(biter->ready);
 
     /* Retrieve the information asked for */
     if (row)
@@ -573,67 +544,26 @@ H5HF_man_iter_curr(H5HF_block_iter_t *biter, unsigned *row, unsigned *col, unsig
         *block = biter->curr->context;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_man_iter_curr() */
+} /* end H5HF__man_iter_curr() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_offset
- *
- * Purpose:	Retrieve offset of iterator in heap
- *
- * Return:	SUCCEED/FAIL
- *
- * Programmer:	Quincey Koziol
- *		Apr 25 2006
- *
- *-------------------------------------------------------------------------
- */
-herr_t
-H5HF_man_iter_offset(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, hsize_t *offset)
-{
-    hsize_t curr_offset; /* For computing offset in heap */
-
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
-
-    /*
-     * Check arguments.
-     */
-    HDassert(biter);
-    HDassert(biter->ready);
-    HDassert(biter->curr->context);
-    HDassert(offset);
-
-    /* Compute the offset in the heap */
-    curr_offset = biter->curr->context->block_off;
-    curr_offset += hdr->man_dtable.row_block_off[biter->curr->row];
-    curr_offset += biter->curr->col * hdr->man_dtable.row_block_size[biter->curr->row];
-
-    /* Assign the return value */
-    *offset = curr_offset;
-
-    FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_man_iter_offset() */
-
-/*-------------------------------------------------------------------------
- * Function:	H5HF_man_iter_ready
+ * Function:	H5HF__man_iter_ready
  *
  * Purpose:	Query if iterator is ready to use
  *
  * Return:	SUCCEED/FAIL
  *
- * Programmer:	Quincey Koziol
- *		Apr 25 2006
- *
  *-------------------------------------------------------------------------
  */
 hbool_t
-H5HF_man_iter_ready(H5HF_block_iter_t *biter)
+H5HF__man_iter_ready(H5HF_block_iter_t *biter)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
      */
-    HDassert(biter);
+    assert(biter);
 
     FUNC_LEAVE_NOAPI(biter->ready)
-} /* end H5HF_man_iter_ready() */
+} /* end H5HF__man_iter_ready() */
