@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5HFspace.c
- *			May  2 2006
- *			Quincey Koziol
  *
  * Purpose:		Space allocation routines for fractal heaps.
  *
@@ -78,9 +76,6 @@
  *
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		May  2 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -96,14 +91,14 @@ H5HF__space_start(H5HF_hdr_t *hdr, hbool_t may_create)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Check for creating free space info for the heap */
-    if (H5F_addr_defined(hdr->fs_addr)) {
+    if (H5_addr_defined(hdr->fs_addr)) {
         /* Open an existing free space structure for the heap */
         if (NULL == (hdr->fspace = H5FS_open(hdr->f, hdr->fs_addr, NELMTS(classes), classes, hdr,
                                              (hsize_t)H5HF_FSPACE_THRHD_DEF, (hsize_t)H5HF_FSPACE_ALIGN_DEF)))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize free space info")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize free space info");
     } /* end if */
     else {
         /* Check if we are allowed to create the free space manager */
@@ -121,8 +116,8 @@ H5HF__space_start(H5HF_hdr_t *hdr, hbool_t may_create)
             if (NULL ==
                 (hdr->fspace = H5FS_create(hdr->f, &hdr->fs_addr, &fs_create, NELMTS(classes), classes, hdr,
                                            (hsize_t)H5HF_FSPACE_THRHD_DEF, (hsize_t)H5HF_FSPACE_ALIGN_DEF)))
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize free space info")
-            HDassert(H5F_addr_defined(hdr->fs_addr));
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize free space info");
+            assert(H5_addr_defined(hdr->fs_addr));
         } /* end if */
     }     /* end else */
 
@@ -139,9 +134,6 @@ done:
  *
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		May 15 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -155,20 +147,20 @@ H5HF__space_add(H5HF_hdr_t *hdr, H5HF_free_section_t *node, unsigned flags)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(node);
+    assert(hdr);
+    assert(node);
 
     /* Check if the free space for the heap has been initialized */
     if (!hdr->fspace)
         if (H5HF__space_start(hdr, TRUE) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space");
 
     /* Construct user data */
     udata.hdr = hdr;
 
     /* Add to the free space for the heap */
     if (H5FS_sect_add(hdr->f, hdr->fspace, (H5FS_section_info_t *)node, flags, &udata) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't add section to heap free space")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't add section to heap free space");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -182,9 +174,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		May  2 2006
- *
  *-------------------------------------------------------------------------
  */
 htri_t
@@ -198,19 +187,19 @@ H5HF__space_find(H5HF_hdr_t *hdr, hsize_t request, H5HF_free_section_t **node)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(request);
-    HDassert(node);
+    assert(hdr);
+    assert(request);
+    assert(node);
 
     /* Check if the free space for the heap has been initialized */
     if (!hdr->fspace)
         if (H5HF__space_start(hdr, FALSE) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space");
 
     /* Search for free space in the heap */
     if (hdr->fspace)
         if ((node_found = H5FS_sect_find(hdr->f, hdr->fspace, request, (H5FS_section_info_t **)node)) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "can't locate free space in fractal heap")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "can't locate free space in fractal heap");
 
     /* Set return value */
     ret_value = node_found;
@@ -229,9 +218,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		Feb 24 2012
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -245,15 +231,15 @@ H5HF__space_revert_root_cb(H5FS_section_info_t *_sect, void H5_ATTR_UNUSED *_uda
     /*
      * Check arguments.
      */
-    HDassert(sect);
+    assert(sect);
 
     /* Only modify "live" single blocks... */
     if (sect->sect_info.type == H5HF_FSPACE_SECT_SINGLE && sect->sect_info.state == H5FS_SECT_LIVE) {
         /* Release hold on previous indirect block (we must have one) */
-        HDassert(sect->u.single.parent);
+        assert(sect->u.single.parent);
         if (H5HF__iblock_decr(sect->u.single.parent) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL,
-                        "can't decrement reference count on section's indirect block")
+                        "can't decrement reference count on section's indirect block");
 
         /* Reset parent information */
         sect->u.single.parent    = NULL;
@@ -273,9 +259,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		Feb 23 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -288,13 +271,14 @@ H5HF__space_revert_root(const H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Only need to scan the sections if the free space has been initialized */
     if (hdr->fspace)
         /* Iterate over all sections, resetting the parent pointers in 'single' sections */
         if (H5FS_sect_iterate(hdr->f, hdr->fspace, H5HF__space_revert_root_cb, NULL) < 0)
-            HGOTO_ERROR(H5E_FSPACE, H5E_BADITER, FAIL, "can't iterate over sections to reset parent pointers")
+            HGOTO_ERROR(H5E_FSPACE, H5E_BADITER, FAIL,
+                        "can't iterate over sections to reset parent pointers");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -310,9 +294,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		Feb 24 2012
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -327,24 +308,24 @@ H5HF__space_create_root_cb(H5FS_section_info_t *_sect, void *_udata)
     /*
      * Check arguments.
      */
-    HDassert(sect);
-    HDassert(root_iblock);
+    assert(sect);
+    assert(root_iblock);
 
     /* Sanity check sections */
     /* (If we are switching from a direct block for the root block of the heap, */
     /*	there should only be 'single' type sections. -QAK) */
-    HDassert(sect->sect_info.type == H5HF_FSPACE_SECT_SINGLE);
+    assert(sect->sect_info.type == H5HF_FSPACE_SECT_SINGLE);
 
     /* Increment ref. count on new root indirect block */
     if (H5HF__iblock_incr(root_iblock) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, FAIL,
-                    "can't increment reference count on section's indirect block")
+                    "can't increment reference count on section's indirect block");
 
     /* Set parent info ("live" section must _NOT_ have a parent right now) */
     if (sect->sect_info.state == H5FS_SECT_SERIALIZED)
         sect->sect_info.state = H5FS_SECT_LIVE; /* Mark "live" now */
     else
-        HDassert(!sect->u.single.parent);
+        assert(!sect->u.single.parent);
     sect->u.single.parent    = root_iblock;
     sect->u.single.par_entry = 0;
 
@@ -362,9 +343,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		Feb 24 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -377,15 +355,15 @@ H5HF__space_create_root(const H5HF_hdr_t *hdr, H5HF_indirect_t *root_iblock)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(root_iblock);
+    assert(hdr);
+    assert(root_iblock);
 
     /* Only need to scan the sections if the free space has been initialized */
     if (hdr->fspace)
         /* Iterate over all sections, setting the parent pointers in 'single' sections to the new indirect
          * block */
         if (H5FS_sect_iterate(hdr->f, hdr->fspace, H5HF__space_create_root_cb, root_iblock) < 0)
-            HGOTO_ERROR(H5E_FSPACE, H5E_BADITER, FAIL, "can't iterate over sections to set parent pointers")
+            HGOTO_ERROR(H5E_FSPACE, H5E_BADITER, FAIL, "can't iterate over sections to set parent pointers");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -399,9 +377,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		August 14 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -414,18 +389,18 @@ H5HF__space_size(H5HF_hdr_t *hdr, hsize_t *fs_size)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(fs_size);
+    assert(hdr);
+    assert(fs_size);
 
     /* Check if the free space for the heap has been initialized */
     if (!hdr->fspace)
         if (H5HF__space_start(hdr, FALSE) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space");
 
     /* Get free space metadata size */
     if (hdr->fspace) {
         if (H5FS_size(hdr->fspace, fs_size) < 0)
-            HGOTO_ERROR(H5E_FSPACE, H5E_CANTGET, FAIL, "can't retrieve FS meta storage info")
+            HGOTO_ERROR(H5E_FSPACE, H5E_CANTGET, FAIL, "can't retrieve FS meta storage info");
     } /* end if */
     else
         *fs_size = 0;
@@ -442,9 +417,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		July 24 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -457,13 +429,13 @@ H5HF__space_remove(H5HF_hdr_t *hdr, H5HF_free_section_t *node)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(hdr->fspace);
-    HDassert(node);
+    assert(hdr);
+    assert(hdr->fspace);
+    assert(node);
 
     /* Remove from the free space for the heap */
     if (H5FS_sect_remove(hdr->f, hdr->fspace, (H5FS_section_info_t *)node) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove section from heap free space")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove section from heap free space");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -478,9 +450,6 @@ done:
  *
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		May  2 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -493,7 +462,7 @@ H5HF__space_close(H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Check if the free space was ever opened */
     if (hdr->fspace) {
@@ -501,17 +470,17 @@ H5HF__space_close(H5HF_hdr_t *hdr)
 
         /* Retrieve the number of sections for this heap */
         if (H5FS_sect_stats(hdr->fspace, NULL, &nsects) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTCOUNT, FAIL, "can't query free space section count")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTCOUNT, FAIL, "can't query free space section count");
 
         /* Close the free space for the heap */
         if (H5FS_close(hdr->f, hdr->fspace) < 0)
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release free space info")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release free space info");
         hdr->fspace = NULL;
 
         /* Check if we can delete the free space manager for this heap */
         if (!nsects) {
             if (H5FS_delete(hdr->f, hdr->fs_addr) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "can't delete free space info")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "can't delete free space info");
             hdr->fs_addr = HADDR_UNDEF;
         } /* end if */
     }     /* end if */
@@ -528,9 +497,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		Aug  7 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -543,11 +509,11 @@ H5HF__space_delete(H5HF_hdr_t *hdr)
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Delete the free space manager */
     if (H5FS_delete(hdr->f, hdr->fs_addr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "can't delete to free space manager")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "can't delete to free space manager");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -562,9 +528,6 @@ done:
  *
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *		July 10 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -577,13 +540,13 @@ H5HF__space_sect_change_class(H5HF_hdr_t *hdr, H5HF_free_section_t *sect, uint16
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(hdr->fspace);
-    HDassert(sect);
+    assert(hdr);
+    assert(hdr->fspace);
+    assert(sect);
 
     /* Notify the free space manager that a section has changed class */
     if (H5FS_sect_change_class(hdr->f, hdr->fspace, (H5FS_section_info_t *)sect, new_class) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTMODIFY, FAIL, "can't modify class of free space section")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTMODIFY, FAIL, "can't modify class of free space section");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
