@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:         H5HL.c
- *                  Jul 16 1997
- *                  Robb Matzke
  *
  * Purpose:         Heap functions for the local heaps used by symbol
  *                  tables to store names (among other things).
@@ -31,11 +29,14 @@
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"   /* Generic Functions        */
-#include "H5Eprivate.h"  /* Error handling           */
-#include "H5Fprivate.h"  /* File access              */
-#include "H5HLpkg.h"     /* Local Heaps              */
-#include "H5MFprivate.h" /* File memory management   */
+#include "H5private.h"   /* Generic Functions                        */
+#include "H5ACprivate.h" /* Metadata Cache                           */
+#include "H5Eprivate.h"  /* Error Handling                           */
+#include "H5Fprivate.h"  /* Files                                    */
+#include "H5FLprivate.h" /* Free Lists                               */
+#include "H5HLpkg.h"     /* Local Heaps                              */
+#include "H5MFprivate.h" /* File Memory Management                   */
+#include "H5MMprivate.h" /* Memory Management                        */
 
 /****************/
 /* Local Macros */
@@ -89,9 +90,6 @@ H5FL_BLK_DEFINE(lheap_chunk);
  *                          returned through the ADDR argument.
  *              Failure:    FAIL.  addr_p will be HADDR_UNDEF.
  *
- * Programmer:  Robb Matzke
- *              Jul 16 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -105,8 +103,8 @@ H5HL_create(H5F_t *f, size_t size_hint, haddr_t *addr_p /*out*/)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
-    HDassert(f);
-    HDassert(addr_p);
+    assert(f);
+    assert(addr_p);
 
     /* Adjust size hint as necessary */
     if (size_hint && size_hint < H5HL_SIZEOF_FREE(f))
@@ -164,7 +162,7 @@ done:
         }
         else {
             if (heap) {
-                if (H5F_addr_defined(heap->prfx_addr))
+                if (H5_addr_defined(heap->prfx_addr))
                     if (FAIL == H5MF_xfree(f, H5FD_MEM_LHEAP, heap->prfx_addr, total_size))
                         HDONE_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "can't release heap data?");
                 if (FAIL == H5HL__dest(heap))
@@ -183,9 +181,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Bill Wendling
- *              Sept. 16, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -197,8 +192,8 @@ H5HL__minimize_heap_space(H5F_t *f, H5HL_t *heap)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(f);
-    HDassert(heap);
+    assert(f);
+    assert(heap);
 
     /* Check to see if we can reduce the size of the heap in memory by
      * eliminating free blocks at the tail of the buffer before flushing the
@@ -244,7 +239,7 @@ H5HL__minimize_heap_space(H5F_t *f, H5HL_t *heap)
                         /* Truncate the free block */
                         last_fl->size = H5HL_ALIGN(new_heap_size - last_fl->offset);
                         new_heap_size = last_fl->offset + last_fl->size;
-                        HDassert(last_fl->size >= H5HL_SIZEOF_FREE(f));
+                        assert(last_fl->size >= H5HL_SIZEOF_FREE(f));
                     }
                     else {
                         /* Set the size of the memory buffer to the start
@@ -260,8 +255,8 @@ H5HL__minimize_heap_space(H5F_t *f, H5HL_t *heap)
                     /* Truncate the free block */
                     last_fl->size = H5HL_ALIGN(new_heap_size - last_fl->offset);
                     new_heap_size = last_fl->offset + last_fl->size;
-                    HDassert(last_fl->size >= H5HL_SIZEOF_FREE(f));
-                    HDassert(last_fl->size == H5HL_ALIGN(last_fl->size));
+                    assert(last_fl->size >= H5HL_SIZEOF_FREE(f));
+                    assert(last_fl->size == H5HL_ALIGN(last_fl->size));
                 }
             }
         }
@@ -272,7 +267,7 @@ H5HL__minimize_heap_space(H5F_t *f, H5HL_t *heap)
      * storage.
      */
     if (new_heap_size != heap->dblk_size) {
-        HDassert(new_heap_size < heap->dblk_size);
+        assert(new_heap_size < heap->dblk_size);
 
         /* Resize the memory buffer */
         if (NULL == (heap->dblk_image = H5FL_BLK_REALLOC(lheap_chunk, heap->dblk_image, new_heap_size)))
@@ -295,9 +290,6 @@ done:
  * Return:      Success:    Non-NULL pointer to the local heap prefix.
  *              Failure:    NULL
  *
- * Programmer:  Bill Wendling
- *              Sept. 17, 2003
- *
  *-------------------------------------------------------------------------
  */
 H5HL_t *
@@ -314,11 +306,11 @@ H5HL_protect(H5F_t *f, haddr_t addr, unsigned flags)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(H5_addr_defined(addr));
 
     /* Only the H5AC__READ_ONLY_FLAG may appear in flags */
-    HDassert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
+    assert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
 
     /* Construct the user data for protect callback */
     prfx_udata.sizeof_size = H5F_SIZEOF_SIZE(f);
@@ -378,9 +370,6 @@ done:
  * Return:      Success:    Valid pointer
  *              Failure:    NULL
  *
- * Programmer:  Bill Wendling
- *              Sept. 17, 2003
- *
  *-------------------------------------------------------------------------
  */
 void *
@@ -391,7 +380,7 @@ H5HL_offset_into(const H5HL_t *heap, size_t offset)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Sanity check */
-    HDassert(heap);
+    assert(heap);
     if (offset >= heap->dblk_size)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, NULL, "unable to offset into local heap data block");
 
@@ -408,9 +397,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Bill Wendling
- *              Sept. 17, 2003
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -421,7 +407,7 @@ H5HL_unprotect(H5HL_t *heap)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(heap);
+    assert(heap);
 
     /* Decrement # of times heap is protected */
     heap->prots--;
@@ -436,7 +422,7 @@ H5HL_unprotect(H5HL_t *heap)
         }
         else {
             /* Sanity check */
-            HDassert(heap->dblk);
+            assert(heap->dblk);
 
             /* Mark local heap data block as evictable again */
             /* (data block still pins prefix) */
@@ -457,9 +443,6 @@ done:
  *
  * Return:      NULL
  *
- * Programmer:  Robb Matzke
- *              Jul 17 1997
- *
  *-------------------------------------------------------------------------
  */
 static H5HL_free_t *
@@ -490,9 +473,6 @@ H5HL__remove_free(H5HL_t *heap, H5HL_free_t *fl)
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Oct 12 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -503,13 +483,13 @@ H5HL__dirty(H5HL_t *heap)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(heap);
-    HDassert(heap->prfx);
+    assert(heap);
+    assert(heap->prfx);
 
     /* Mark heap data block as dirty, if there is one */
     if (!heap->single_cache_obj) {
         /* Sanity check */
-        HDassert(heap->dblk);
+        assert(heap->dblk);
 
         if (FAIL == H5AC_mark_entry_dirty(heap->dblk))
             HGOTO_ERROR(H5E_HEAP, H5E_CANTMARKDIRTY, FAIL, "unable to mark heap data block as dirty");
@@ -534,9 +514,6 @@ done:
  *              Failure:    FAIL
  *                          Offset set to SIZE_MAX
  *
- * Programmer:  Robb Matzke
- *              Jul 17 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -551,11 +528,11 @@ H5HL_insert(H5F_t *f, H5HL_t *heap, size_t buf_size, const void *buf, size_t *of
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(heap);
-    HDassert(buf_size > 0);
-    HDassert(buf);
-    HDassert(offset_out);
+    assert(f);
+    assert(heap);
+    assert(buf_size > 0);
+    assert(buf);
+    assert(offset_out);
 
     /* Mark heap as dirty in cache */
     /* (A bit early in the process, but it's difficult to determine in the
@@ -581,8 +558,8 @@ H5HL_insert(H5F_t *f, H5HL_t *heap, size_t buf_size, const void *buf, size_t *of
             offset = fl->offset;
             fl->offset += need_size;
             fl->size -= need_size;
-            HDassert(fl->offset == H5HL_ALIGN(fl->offset));
-            HDassert(fl->size == H5HL_ALIGN(fl->size));
+            assert(fl->offset == H5HL_ALIGN(fl->offset));
+            assert(fl->size == H5HL_ALIGN(fl->size));
             found = TRUE;
             break;
         }
@@ -626,7 +603,7 @@ H5HL_insert(H5F_t *f, H5HL_t *heap, size_t buf_size, const void *buf, size_t *of
             need_more = need_size;
 
         new_dblk_size = heap->dblk_size + need_more;
-        HDassert(heap->dblk_size < new_dblk_size);
+        assert(heap->dblk_size < new_dblk_size);
         old_dblk_size = heap->dblk_size;
         H5_CHECK_OVERFLOW(heap->dblk_size, size_t, hsize_t);
         H5_CHECK_OVERFLOW(new_dblk_size, size_t, hsize_t);
@@ -668,14 +645,14 @@ H5HL_insert(H5F_t *f, H5HL_t *heap, size_t buf_size, const void *buf, size_t *of
             offset = last_fl->offset;
             last_fl->offset += need_size;
             last_fl->size += need_more - need_size;
-            HDassert(last_fl->offset == H5HL_ALIGN(last_fl->offset));
-            HDassert(last_fl->size == H5HL_ALIGN(last_fl->size));
+            assert(last_fl->offset == H5HL_ALIGN(last_fl->offset));
+            assert(last_fl->size == H5HL_ALIGN(last_fl->size));
 
             if (last_fl->size < H5HL_SIZEOF_FREE(f)) {
 #ifdef H5HL_DEBUG
                 if (H5DEBUG(HL) && last_fl->size) {
-                    HDfprintf(H5DEBUG(HL), "H5HL: lost %lu bytes at line %d\n",
-                              (unsigned long)(last_fl->size), __LINE__);
+                    fprintf(H5DEBUG(HL), "H5HL: lost %lu bytes at line %d\n", (unsigned long)(last_fl->size),
+                            __LINE__);
                 }
 #endif
                 last_fl = H5HL__remove_free(heap, last_fl);
@@ -691,8 +668,8 @@ H5HL_insert(H5F_t *f, H5HL_t *heap, size_t buf_size, const void *buf, size_t *of
                     HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "memory allocation failed");
                 fl->offset = old_dblk_size + need_size;
                 fl->size   = need_more - need_size;
-                HDassert(fl->offset == H5HL_ALIGN(fl->offset));
-                HDassert(fl->size == H5HL_ALIGN(fl->size));
+                assert(fl->offset == H5HL_ALIGN(fl->offset));
+                assert(fl->size == H5HL_ALIGN(fl->size));
                 fl->prev = NULL;
                 fl->next = heap->freelist;
                 if (heap->freelist)
@@ -701,16 +678,16 @@ H5HL_insert(H5F_t *f, H5HL_t *heap, size_t buf_size, const void *buf, size_t *of
 #ifdef H5HL_DEBUG
             }
             else if (H5DEBUG(HL) && need_more > need_size) {
-                HDfprintf(H5DEBUG(HL), "H5HL_insert: lost %lu bytes at line %d\n",
-                          (unsigned long)(need_more - need_size), __LINE__);
+                fprintf(H5DEBUG(HL), "H5HL_insert: lost %lu bytes at line %d\n",
+                        (unsigned long)(need_more - need_size), __LINE__);
 #endif
             }
         }
 
 #ifdef H5HL_DEBUG
         if (H5DEBUG(HL)) {
-            HDfprintf(H5DEBUG(HL), "H5HL: resize mem buf from %lu to %lu bytes\n",
-                      (unsigned long)(old_dblk_size), (unsigned long)(old_dblk_size + need_more));
+            fprintf(H5DEBUG(HL), "H5HL: resize mem buf from %lu to %lu bytes\n",
+                    (unsigned long)(old_dblk_size), (unsigned long)(old_dblk_size + need_more));
         }
 #endif
         if (NULL == (heap->dblk_image = H5FL_BLK_REALLOC(lheap_chunk, heap->dblk_image, heap->dblk_size)))
@@ -718,7 +695,7 @@ H5HL_insert(H5F_t *f, H5HL_t *heap, size_t buf_size, const void *buf, size_t *of
 
         /* Clear new section so junk doesn't appear in the file */
         /* (Avoid clearing section which will be overwritten with newly inserted data) */
-        HDmemset(heap->dblk_image + offset + buf_size, 0, (new_dblk_size - (offset + buf_size)));
+        memset(heap->dblk_image + offset + buf_size, 0, (new_dblk_size - (offset + buf_size)));
     }
 
     /* Copy the data into the heap */
@@ -748,9 +725,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Robb Matzke
- *              Jul 16 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -762,15 +736,15 @@ H5HL_remove(H5F_t *f, H5HL_t *heap, size_t offset, size_t size)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(heap);
-    HDassert(size > 0);
-    HDassert(offset == H5HL_ALIGN(offset));
+    assert(f);
+    assert(heap);
+    assert(size > 0);
+    assert(offset == H5HL_ALIGN(offset));
 
     size = H5HL_ALIGN(size);
 
-    HDassert(offset < heap->dblk_size);
-    HDassert(offset + size <= heap->dblk_size);
+    assert(offset < heap->dblk_size);
+    assert(offset + size <= heap->dblk_size);
 
     /* Mark heap as dirty in cache
      *
@@ -793,21 +767,21 @@ H5HL_remove(H5F_t *f, H5HL_t *heap, size_t offset, size_t size)
         if ((offset + size) == fl->offset) {
             fl->offset = offset;
             fl->size += size;
-            HDassert(fl->offset == H5HL_ALIGN(fl->offset));
-            HDassert(fl->size == H5HL_ALIGN(fl->size));
+            assert(fl->offset == H5HL_ALIGN(fl->offset));
+            assert(fl->size == H5HL_ALIGN(fl->size));
             fl2 = fl->next;
             while (fl2) {
                 if ((fl2->offset + fl2->size) == fl->offset) {
                     fl->offset = fl2->offset;
                     fl->size += fl2->size;
-                    HDassert(fl->offset == H5HL_ALIGN(fl->offset));
-                    HDassert(fl->size == H5HL_ALIGN(fl->size));
+                    assert(fl->offset == H5HL_ALIGN(fl->offset));
+                    assert(fl->size == H5HL_ALIGN(fl->size));
                     fl2 = H5HL__remove_free(heap, fl2);
                     if (((fl->offset + fl->size) == heap->dblk_size) && ((2 * fl->size) > heap->dblk_size)) {
                         if (FAIL == H5HL__minimize_heap_space(f, heap))
                             HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "heap size minimization failed");
                     }
-                    HGOTO_DONE(SUCCEED)
+                    HGOTO_DONE(SUCCEED);
                 }
                 fl2 = fl2->next;
             }
@@ -815,22 +789,22 @@ H5HL_remove(H5F_t *f, H5HL_t *heap, size_t offset, size_t size)
                 if (FAIL == H5HL__minimize_heap_space(f, heap))
                     HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "heap size minimization failed");
             }
-            HGOTO_DONE(SUCCEED)
+            HGOTO_DONE(SUCCEED);
         }
         else if (fl->offset + fl->size == offset) {
             fl->size += size;
             fl2 = fl->next;
-            HDassert(fl->size == H5HL_ALIGN(fl->size));
+            assert(fl->size == H5HL_ALIGN(fl->size));
             while (fl2) {
                 if (fl->offset + fl->size == fl2->offset) {
                     fl->size += fl2->size;
-                    HDassert(fl->size == H5HL_ALIGN(fl->size));
+                    assert(fl->size == H5HL_ALIGN(fl->size));
                     fl2 = H5HL__remove_free(heap, fl2);
                     if (((fl->offset + fl->size) == heap->dblk_size) && ((2 * fl->size) > heap->dblk_size)) {
                         if (FAIL == H5HL__minimize_heap_space(f, heap))
                             HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "heap size minimization failed");
                     }
-                    HGOTO_DONE(SUCCEED)
+                    HGOTO_DONE(SUCCEED);
                 }
                 fl2 = fl2->next;
             }
@@ -838,7 +812,7 @@ H5HL_remove(H5F_t *f, H5HL_t *heap, size_t offset, size_t size)
                 if (FAIL == H5HL__minimize_heap_space(f, heap))
                     HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "heap size minimization failed");
             }
-            HGOTO_DONE(SUCCEED)
+            HGOTO_DONE(SUCCEED);
         }
         fl = fl->next;
     }
@@ -851,10 +825,10 @@ H5HL_remove(H5F_t *f, H5HL_t *heap, size_t offset, size_t size)
     if (size < H5HL_SIZEOF_FREE(f)) {
 #ifdef H5HL_DEBUG
         if (H5DEBUG(HL)) {
-            HDfprintf(H5DEBUG(HL), "H5HL: lost %lu bytes\n", (unsigned long)size);
+            fprintf(H5DEBUG(HL), "H5HL: lost %lu bytes\n", (unsigned long)size);
         }
 #endif
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
     }
 
     /* Add an entry to the free list */
@@ -862,8 +836,8 @@ H5HL_remove(H5F_t *f, H5HL_t *heap, size_t offset, size_t size)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "memory allocation failed");
     fl->offset = offset;
     fl->size   = size;
-    HDassert(fl->offset == H5HL_ALIGN(fl->offset));
-    HDassert(fl->size == H5HL_ALIGN(fl->size));
+    assert(fl->offset == H5HL_ALIGN(fl->offset));
+    assert(fl->size == H5HL_ALIGN(fl->size));
     fl->prev = NULL;
     fl->next = heap->freelist;
     if (heap->freelist)
@@ -885,9 +859,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Mar 22 2003
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -903,8 +874,8 @@ H5HL_delete(H5F_t *f, haddr_t addr)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
+    assert(f);
+    assert(H5_addr_defined(addr));
 
     /* Construct the user data for protect callback */
     prfx_udata.sizeof_size = H5F_SIZEOF_SIZE(f);
@@ -949,9 +920,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Nov  7 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -965,9 +933,9 @@ H5HL_get_size(H5F_t *f, haddr_t addr, size_t *size)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(size);
+    assert(f);
+    assert(H5_addr_defined(addr));
+    assert(size);
 
     /* Construct the user data for protect callback */
     prfx_udata.sizeof_size = H5F_SIZEOF_SIZE(f);
@@ -1001,9 +969,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              June 19 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1017,9 +982,9 @@ H5HL_heapsize(H5F_t *f, haddr_t addr, hsize_t *heap_size)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(addr));
-    HDassert(heap_size);
+    assert(f);
+    assert(H5_addr_defined(addr));
+    assert(heap_size);
 
     /* Construct the user data for protect callback */
     prfx_udata.sizeof_size = H5F_SIZEOF_SIZE(f);
