@@ -28,12 +28,14 @@
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"   /* Generic Functions            */
-#include "H5Eprivate.h"  /* Error handling               */
-#include "H5HLpkg.h"     /* Local Heaps                  */
-#include "H5MFprivate.h" /* File memory management       */
-#include "H5MMprivate.h" /* Memory management			*/
-#include "H5WBprivate.h" /* Wrapped Buffers              */
+#include "H5private.h"   /* Generic Functions                        */
+#include "H5ACprivate.h" /* Metadata Cache                           */
+#include "H5Cprivate.h"  /* Cache                                    */
+#include "H5Eprivate.h"  /* Error Handling                           */
+#include "H5Fprivate.h"  /* Files                                    */
+#include "H5FLprivate.h" /* Free Lists                               */
+#include "H5HLpkg.h"     /* Local Heaps                              */
+#include "H5MMprivate.h" /* Memory Management                        */
 
 /****************/
 /* Local Macros */
@@ -149,22 +151,22 @@ H5HL__hdr_deserialize(H5HL_t *heap, const uint8_t *image, size_t len, H5HL_cache
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(heap);
-    HDassert(image);
-    HDassert(udata);
+    assert(heap);
+    assert(image);
+    assert(udata);
 
     /* Magic number */
     if (H5_IS_BUFFER_OVERFLOW(image, H5_SIZEOF_MAGIC, p_end))
         HGOTO_ERROR(H5E_HEAP, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
-    if (HDmemcmp(image, H5HL_MAGIC, (size_t)H5_SIZEOF_MAGIC) != 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad local heap signature")
+    if (memcmp(image, H5HL_MAGIC, (size_t)H5_SIZEOF_MAGIC) != 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad local heap signature");
     image += H5_SIZEOF_MAGIC;
 
     /* Version */
     if (H5_IS_BUFFER_OVERFLOW(image, 1, p_end))
         HGOTO_ERROR(H5E_HEAP, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
     if (H5HL_VERSION != *image++)
-        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "wrong version number in local heap")
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "wrong version number in local heap");
 
     /* Reserved */
     if (H5_IS_BUFFER_OVERFLOW(image, 3, p_end))
@@ -178,20 +180,26 @@ H5HL__hdr_deserialize(H5HL_t *heap, const uint8_t *image, size_t len, H5HL_cache
     /* Heap data size */
     if (H5_IS_BUFFER_OVERFLOW(image, udata->sizeof_size, p_end))
         HGOTO_ERROR(H5E_HEAP, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
-    H5F_DECODE_LENGTH_LEN(image, heap->dblk_size, udata->sizeof_size);
+    H5_DECODE_LENGTH_LEN(image, heap->dblk_size, udata->sizeof_size);
 
     /* Free list head */
     if (H5_IS_BUFFER_OVERFLOW(image, udata->sizeof_size, p_end))
         HGOTO_ERROR(H5E_HEAP, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
-    H5F_DECODE_LENGTH_LEN(image, heap->free_block, udata->sizeof_size);
+    H5_DECODE_LENGTH_LEN(image, heap->free_block, udata->sizeof_size);
     if (heap->free_block != H5HL_FREE_NULL && heap->free_block >= heap->dblk_size)
-        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap free list")
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad heap free list");
 
     /* Heap data address */
     if (H5_IS_BUFFER_OVERFLOW(image, udata->sizeof_addr, p_end))
         HGOTO_ERROR(H5E_HEAP, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
     H5F_addr_decode_len(udata->sizeof_addr, &image, &(heap->dblk_addr));
 
+    /* Check that the datablock address is valid (might not be true
+     * in a corrupt file)
+     */
+    if (!H5_addr_defined(heap->dblk_addr))
+        HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "bad datablock address");
+
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HL__hdr_deserialize() */
@@ -203,9 +211,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Oct 12 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -218,8 +223,8 @@ H5HL__fl_deserialize(H5HL_t *heap)
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(heap);
-    HDassert(!heap->freelist);
+    assert(heap);
+    assert(!heap->freelist);
 
     /* Build free list */
     free_block = heap->free_block;
@@ -228,25 +233,25 @@ H5HL__fl_deserialize(H5HL_t *heap)
 
         /* Sanity check */
         if (free_block >= heap->dblk_size)
-            HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "bad heap free list")
+            HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "bad heap free list");
 
         /* Allocate & initialize free list node */
         if (NULL == (fl = H5FL_MALLOC(H5HL_free_t)))
-            HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "memory allocation failed")
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, FAIL, "memory allocation failed");
         fl->offset = (size_t)free_block;
         fl->prev   = tail;
         fl->next   = NULL;
 
         /* Decode offset of next free block */
         image = heap->dblk_image + free_block;
-        H5F_DECODE_LENGTH_LEN(image, free_block, heap->sizeof_size);
+        H5_DECODE_LENGTH_LEN(image, free_block, heap->sizeof_size);
         if (0 == free_block)
-            HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "free block size is zero?")
+            HGOTO_ERROR(H5E_HEAP, H5E_BADVALUE, FAIL, "free block size is zero?");
 
         /* Decode length of this free block */
-        H5F_DECODE_LENGTH_LEN(image, fl->size, heap->sizeof_size);
+        H5_DECODE_LENGTH_LEN(image, fl->size, heap->sizeof_size);
         if ((fl->offset + fl->size) > heap->dblk_size)
-            HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "bad heap free list")
+            HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "bad heap free list");
 
         /* Append node onto list */
         if (tail)
@@ -273,9 +278,6 @@ done:
  *
  * Return:      Nothing (void)
  *
- * Programmer:  Quincey Koziol
- *              Oct 12 2008
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -286,21 +288,21 @@ H5HL__fl_serialize(const H5HL_t *heap)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check arguments */
-    HDassert(heap);
+    assert(heap);
 
     /* Serialize the free list into the heap data's image */
     for (fl = heap->freelist; fl; fl = fl->next) {
         uint8_t *image; /* Pointer into raw data buffer */
 
-        HDassert(fl->offset == H5HL_ALIGN(fl->offset));
+        assert(fl->offset == H5HL_ALIGN(fl->offset));
         image = heap->dblk_image + fl->offset;
 
         if (fl->next)
-            H5F_ENCODE_LENGTH_LEN(image, fl->next->offset, heap->sizeof_size)
+            H5_ENCODE_LENGTH_LEN(image, fl->next->offset, heap->sizeof_size);
         else
-            H5F_ENCODE_LENGTH_LEN(image, H5HL_FREE_NULL, heap->sizeof_size)
+            H5_ENCODE_LENGTH_LEN(image, H5HL_FREE_NULL, heap->sizeof_size);
 
-        H5F_ENCODE_LENGTH_LEN(image, fl->size, heap->sizeof_size)
+        H5_ENCODE_LENGTH_LEN(image, fl->size, heap->sizeof_size);
     }
 
     FUNC_LEAVE_NOAPI_VOID
@@ -316,9 +318,6 @@ H5HL__fl_serialize(const H5HL_t *heap)
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -327,7 +326,7 @@ H5HL__cache_prefix_get_initial_load_size(void H5_ATTR_UNUSED *_udata, size_t *im
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(image_len);
+    assert(image_len);
 
     /* Set the image length size */
     *image_len = H5HL_SPEC_READ_SIZE;
@@ -344,9 +343,6 @@ H5HL__cache_prefix_get_initial_load_size(void H5_ATTR_UNUSED *_udata, size_t *im
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  Quincey Koziol
- *              November 18, 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -360,16 +356,16 @@ H5HL__cache_prefix_get_final_load_size(const void *_image, size_t image_len, voi
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(image);
-    HDassert(udata);
-    HDassert(actual_len);
-    HDassert(*actual_len == image_len);
+    assert(image);
+    assert(udata);
+    assert(actual_len);
+    assert(*actual_len == image_len);
 
-    HDmemset(&heap, 0, sizeof(H5HL_t));
+    memset(&heap, 0, sizeof(H5HL_t));
 
     /* Deserialize the heap's header */
     if (H5HL__hdr_deserialize(&heap, (const uint8_t *)image, image_len, udata) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDECODE, FAIL, "can't decode local heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDECODE, FAIL, "can't decode local heap header");
 
     /* Set the final size for the cache image */
     *actual_len = heap.prfx_size;
@@ -377,7 +373,7 @@ H5HL__cache_prefix_get_final_load_size(const void *_image, size_t image_len, voi
     /* Check if heap block exists */
     if (heap.dblk_size)
         /* Check if heap data block is contiguous with header */
-        if (H5F_addr_eq((heap.prfx_addr + heap.prfx_size), heap.dblk_addr))
+        if (H5_addr_eq((heap.prfx_addr + heap.prfx_size), heap.dblk_addr))
             /* Note that the heap should be a single object in the cache */
             *actual_len += heap.dblk_size;
 
@@ -410,14 +406,14 @@ H5HL__cache_prefix_deserialize(const void *_image, size_t len, void *_udata, hbo
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(image);
-    HDassert(len > 0);
-    HDassert(udata);
-    HDassert(udata->sizeof_size > 0);
-    HDassert(udata->sizeof_addr > 0);
-    HDassert(udata->sizeof_prfx > 0);
-    HDassert(H5F_addr_defined(udata->prfx_addr));
-    HDassert(dirty);
+    assert(image);
+    assert(len > 0);
+    assert(udata);
+    assert(udata->sizeof_size > 0);
+    assert(udata->sizeof_addr > 0);
+    assert(udata->sizeof_prfx > 0);
+    assert(H5_addr_defined(udata->prfx_addr));
+    assert(dirty);
 
     /* Allocate space in memory for the heap */
     if (NULL == (heap = H5HL__new(udata->sizeof_size, udata->sizeof_addr, udata->sizeof_prfx)))
@@ -425,7 +421,7 @@ H5HL__cache_prefix_deserialize(const void *_image, size_t len, void *_udata, hbo
 
     /* Deserialize the heap's header */
     if (H5HL__hdr_deserialize(heap, (const uint8_t *)image, len, udata) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDECODE, NULL, "can't decode local heap header")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDECODE, NULL, "can't decode local heap header");
 
     /* Allocate the heap prefix */
     if (NULL == (prfx = H5HL__prfx_new(heap)))
@@ -434,13 +430,13 @@ H5HL__cache_prefix_deserialize(const void *_image, size_t len, void *_udata, hbo
     /* Check if heap block exists */
     if (heap->dblk_size) {
         /* Check if heap data block is contiguous with header */
-        if (H5F_addr_eq((heap->prfx_addr + heap->prfx_size), heap->dblk_addr)) {
+        if (H5_addr_eq((heap->prfx_addr + heap->prfx_size), heap->dblk_addr)) {
             /* Note that the heap should be a single object in the cache */
             heap->single_cache_obj = TRUE;
 
             /* Allocate space for the heap data image */
             if (NULL == (heap->dblk_image = H5FL_BLK_MALLOC(lheap_chunk, heap->dblk_size)))
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed");
 
             /* Set image to the start of the data block.  This is necessary
              * because there may be a gap between the used portion of the
@@ -454,7 +450,7 @@ H5HL__cache_prefix_deserialize(const void *_image, size_t len, void *_udata, hbo
 
             /* Build free list */
             if (H5HL__fl_deserialize(heap) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, NULL, "can't initialize free list")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, NULL, "can't initialize free list");
         }
         else
             /* Note that the heap should _NOT_ be a single
@@ -491,9 +487,6 @@ done:
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -504,10 +497,9 @@ H5HL__cache_prefix_image_len(const void *_thing, size_t *image_len)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(prfx);
-    HDassert(prfx->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(prfx->cache_info.type == H5AC_LHEAP_PRFX);
-    HDassert(image_len);
+    assert(prfx);
+    assert(prfx->cache_info.type == H5AC_LHEAP_PRFX);
+    assert(image_len);
 
     /* Set the prefix's size */
     *image_len = prfx->heap->prfx_size;
@@ -532,9 +524,6 @@ H5HL__cache_prefix_image_len(const void *_thing, size_t *image_len)
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -548,24 +537,23 @@ H5HL__cache_prefix_serialize(const H5_ATTR_NDEBUG_UNUSED H5F_t *f, void *_image,
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(image);
-    HDassert(prfx);
-    HDassert(prfx->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(prfx->cache_info.type == H5AC_LHEAP_PRFX);
-    HDassert(H5F_addr_eq(prfx->cache_info.addr, prfx->heap->prfx_addr));
-    HDassert(prfx->heap);
+    assert(f);
+    assert(image);
+    assert(prfx);
+    assert(prfx->cache_info.type == H5AC_LHEAP_PRFX);
+    assert(H5_addr_eq(prfx->cache_info.addr, prfx->heap->prfx_addr));
+    assert(prfx->heap);
 
     /* Get the pointer to the heap */
     heap = prfx->heap;
-    HDassert(heap);
+    assert(heap);
 
 #ifndef NDEBUG
     /* Compute the buffer size */
     size_t buf_size = heap->prfx_size; /* expected size of the image buffer */
     if (heap->single_cache_obj)
         buf_size += heap->dblk_size;
-    HDassert(len == buf_size);
+    assert(len == buf_size);
 #endif
 
     /* Update the free block value from the free list */
@@ -578,8 +566,8 @@ H5HL__cache_prefix_serialize(const H5_ATTR_NDEBUG_UNUSED H5F_t *f, void *_image,
     *image++ = 0; /*reserved*/
     *image++ = 0; /*reserved*/
     *image++ = 0; /*reserved*/
-    H5F_ENCODE_LENGTH_LEN(image, heap->dblk_size, heap->sizeof_size);
-    H5F_ENCODE_LENGTH_LEN(image, heap->free_block, heap->sizeof_size);
+    H5_ENCODE_LENGTH_LEN(image, heap->dblk_size, heap->sizeof_size);
+    H5_ENCODE_LENGTH_LEN(image, heap->free_block, heap->sizeof_size);
     H5F_addr_encode_len(heap->sizeof_addr, &image, heap->dblk_addr);
 
     /* Check if the local heap is a single object in cache */
@@ -592,7 +580,7 @@ H5HL__cache_prefix_serialize(const H5_ATTR_NDEBUG_UNUSED H5F_t *f, void *_image,
              * the prefix and the data block due to alignment constraints.
              */
             gap = heap->prfx_size - (size_t)(image - (uint8_t *)_image);
-            HDmemset(image, 0, gap);
+            memset(image, 0, gap);
             image += gap;
         }
 
@@ -603,14 +591,14 @@ H5HL__cache_prefix_serialize(const H5_ATTR_NDEBUG_UNUSED H5F_t *f, void *_image,
         H5MM_memcpy(image, heap->dblk_image, heap->dblk_size);
 
         /* Sanity check */
-        HDassert((size_t)(image - (uint8_t *)_image) + heap->dblk_size == len);
+        assert((size_t)(image - (uint8_t *)_image) + heap->dblk_size == len);
     }
     else {
         /* Sanity check */
-        HDassert((size_t)(image - (uint8_t *)_image) <= len);
+        assert((size_t)(image - (uint8_t *)_image) <= len);
 
         /* Clear rest of local heap */
-        HDmemset(image, 0, len - (size_t)(image - (uint8_t *)_image));
+        memset(image, 0, len - (size_t)(image - (uint8_t *)_image));
     }
 
     FUNC_LEAVE_NOAPI(SUCCEED)
@@ -626,16 +614,9 @@ H5HL__cache_prefix_serialize(const H5_ATTR_NDEBUG_UNUSED H5F_t *f, void *_image,
  *		from a failed speculative load attempt.  See comments below for
  *		details.
  *
- * Note:	The metadata cache sets the object's cache_info.magic to
- *		H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC before calling a free_icr
- *		callback (checked in assert).
- *
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -647,14 +628,13 @@ H5HL__cache_prefix_free_icr(void *_thing)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(prfx);
-    HDassert(prfx->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC);
-    HDassert(prfx->cache_info.type == H5AC_LHEAP_PRFX);
-    HDassert(H5F_addr_eq(prfx->cache_info.addr, prfx->heap->prfx_addr));
+    assert(prfx);
+    assert(prfx->cache_info.type == H5AC_LHEAP_PRFX);
+    assert(H5_addr_eq(prfx->cache_info.addr, prfx->heap->prfx_addr));
 
     /* Destroy local heap prefix */
     if (H5HL__prfx_dest(prfx) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't destroy local heap prefix")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't destroy local heap prefix");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -670,9 +650,6 @@ done:
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -683,9 +660,9 @@ H5HL__cache_datablock_get_initial_load_size(void *_udata, size_t *image_len)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(heap);
-    HDassert(heap->dblk_size > 0);
-    HDassert(image_len);
+    assert(heap);
+    assert(heap->dblk_size > 0);
+    assert(image_len);
 
     /* Set the image length size */
     *image_len = heap->dblk_size;
@@ -703,9 +680,6 @@ H5HL__cache_datablock_get_initial_load_size(void *_udata, size_t *image_len)
  * Return:      Success:        Pointer to in core representation
  *              Failure:        NULL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -718,13 +692,13 @@ H5HL__cache_datablock_deserialize(const void *image, size_t len, void *_udata, h
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(image);
-    HDassert(len > 0);
-    HDassert(heap);
-    HDassert(heap->dblk_size == len);
-    HDassert(!heap->single_cache_obj);
-    HDassert(NULL == heap->dblk);
-    HDassert(dirty);
+    assert(image);
+    assert(len > 0);
+    assert(heap);
+    assert(heap->dblk_size == len);
+    assert(!heap->single_cache_obj);
+    assert(NULL == heap->dblk);
+    assert(dirty);
 
     /* Allocate space in memory for the heap data block */
     if (NULL == (dblk = H5HL__dblk_new(heap)))
@@ -764,9 +738,6 @@ done:
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -777,12 +748,11 @@ H5HL__cache_datablock_image_len(const void *_thing, size_t *image_len)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(dblk);
-    HDassert(dblk->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(dblk->cache_info.type == H5AC_LHEAP_DBLK);
-    HDassert(dblk->heap);
-    HDassert(dblk->heap->dblk_size > 0);
-    HDassert(image_len);
+    assert(dblk);
+    assert(dblk->cache_info.type == H5AC_LHEAP_DBLK);
+    assert(dblk->heap);
+    assert(dblk->heap->dblk_size > 0);
+    assert(image_len);
 
     *image_len = dblk->heap->dblk_size;
 
@@ -798,9 +768,6 @@ H5HL__cache_datablock_image_len(const void *_thing, size_t *image_len)
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -813,15 +780,14 @@ H5HL__cache_datablock_serialize(const H5F_t H5_ATTR_NDEBUG_UNUSED *f, void *imag
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(image);
-    HDassert(dblk);
-    HDassert(dblk->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(dblk->cache_info.type == H5AC_LHEAP_DBLK);
-    HDassert(dblk->heap);
+    assert(f);
+    assert(image);
+    assert(dblk);
+    assert(dblk->cache_info.type == H5AC_LHEAP_DBLK);
+    assert(dblk->heap);
     heap = dblk->heap;
-    HDassert(heap->dblk_size == len);
-    HDassert(!heap->single_cache_obj);
+    assert(heap->dblk_size == len);
+    assert(!heap->single_cache_obj);
 
     /* Update the free block value from the free list */
     heap->free_block = heap->freelist ? heap->freelist->offset : H5HL_FREE_NULL;
@@ -844,9 +810,6 @@ H5HL__cache_datablock_serialize(const H5F_t H5_ATTR_NDEBUG_UNUSED *f, void *imag
  * Return:	Success:	SUCCEED
  *		Failure:	FAIL
  *
- * Programmer:	Quincey Koziol
- *		November 19, 2016
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -858,7 +821,7 @@ H5HL__cache_datablock_notify(H5C_notify_action_t action, void *_thing)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(dblk);
+    assert(dblk);
 
     switch (action) {
         case H5AC_NOTIFY_ACTION_AFTER_INSERT:
@@ -867,12 +830,12 @@ H5HL__cache_datablock_notify(H5C_notify_action_t action, void *_thing)
 
         case H5AC_NOTIFY_ACTION_AFTER_LOAD:
             /* Sanity checks */
-            HDassert(dblk->heap);
-            HDassert(dblk->heap->prfx);
+            assert(dblk->heap);
+            assert(dblk->heap->prfx);
 
             /* Pin the heap's prefix */
             if (FAIL == H5AC_pin_protected_entry(dblk->heap->prfx))
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTPIN, FAIL, "unable to pin local heap prefix")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTPIN, FAIL, "unable to pin local heap prefix");
             break;
 
         case H5AC_NOTIFY_ACTION_AFTER_FLUSH:
@@ -887,16 +850,16 @@ H5HL__cache_datablock_notify(H5C_notify_action_t action, void *_thing)
 
         case H5AC_NOTIFY_ACTION_BEFORE_EVICT:
             /* Sanity checks */
-            HDassert(dblk->heap);
-            HDassert(dblk->heap->prfx);
+            assert(dblk->heap);
+            assert(dblk->heap->prfx);
 
             /* Unpin the local heap prefix */
             if (FAIL == H5AC_unpin_entry(dblk->heap->prfx))
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTUNPIN, FAIL, "unable to unpin local heap prefix")
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTUNPIN, FAIL, "unable to unpin local heap prefix");
             break;
 
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unknown action from metadata cache")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unknown action from metadata cache");
             break;
     }
 
@@ -909,16 +872,9 @@ done:
  *
  * Purpose:	Free the in memory representation of the supplied local heap data block.
  *
- * Note:	The metadata cache sets the object's cache_info.magic to
- *		H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC before calling a free_icr
- *		callback (checked in assert).
- *
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              6/21/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -930,13 +886,12 @@ H5HL__cache_datablock_free_icr(void *_thing)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(dblk);
-    HDassert(dblk->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC);
-    HDassert(dblk->cache_info.type == H5AC_LHEAP_DBLK);
+    assert(dblk);
+    assert(dblk->cache_info.type == H5AC_LHEAP_DBLK);
 
     /* Destroy the data block */
     if (H5HL__dblk_dest(dblk) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to destroy local heap data block")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to destroy local heap data block");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
