@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  * Purpose:	Free space section callbacks for file.
  *
  */
@@ -166,7 +163,7 @@ const H5FS_section_class_t H5MF_FSPACE_SECT_CLS_LARGE[1] = {{
 /*******************/
 
 /* Declare a free list to manage the H5MF_free_section_t struct */
-H5FL_DEFINE(H5MF_free_section_t);
+H5FL_DEFINE_STATIC(H5MF_free_section_t);
 
 /*
  * "simple/small/large" section callbacks
@@ -179,9 +176,6 @@ H5FL_DEFINE(H5MF_free_section_t);
  *
  * Return:	Pointer to new section on success/NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		January  8 2008
- *
  *-------------------------------------------------------------------------
  */
 H5MF_free_section_t *
@@ -193,12 +187,12 @@ H5MF__sect_new(unsigned ctype, haddr_t sect_off, hsize_t sect_size)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments.  */
-    HDassert(sect_size);
+    assert(sect_size);
 
     /* Create free space section node */
     if (NULL == (sect = H5FL_MALLOC(H5MF_free_section_t)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL,
-                    "memory allocation failed for direct block free list section")
+                    "memory allocation failed for direct block free list section");
 
     /* Set the information passed in */
     sect->sect_info.addr = sect_off;
@@ -223,9 +217,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -236,7 +227,7 @@ H5MF__sect_free(H5FS_section_info_t *_sect)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments. */
-    HDassert(sect);
+    assert(sect);
 
     /* Release the section */
     sect = H5FL_FREE(H5MF_free_section_t, sect);
@@ -252,9 +243,6 @@ H5MF__sect_free(H5FS_section_info_t *_sect)
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  *-------------------------------------------------------------------------
  */
 static H5FS_section_info_t *
@@ -267,13 +255,13 @@ H5MF__sect_deserialize(const H5FS_section_class_t *cls, const uint8_t H5_ATTR_UN
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(cls);
-    HDassert(H5F_addr_defined(sect_addr));
-    HDassert(sect_size);
+    assert(cls);
+    assert(H5_addr_defined(sect_addr));
+    assert(sect_size);
 
     /* Create free space section for block */
     if (NULL == (sect = H5MF__sect_new(cls->type, sect_addr, sect_size)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "can't initialize free space section")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "can't initialize free space section");
 
     /* Set return value */
     ret_value = (H5FS_section_info_t *)sect;
@@ -290,9 +278,6 @@ done:
  * Return:	Success:	non-negative
  *          Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -309,7 +294,7 @@ H5MF__sect_valid(const H5FS_section_class_t H5_ATTR_UNUSED *cls, const H5FS_sect
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments. */
-    HDassert(sect);
+    assert(sect);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5MF__sect_valid() */
@@ -323,8 +308,6 @@ H5MF__sect_valid(const H5FS_section_class_t H5_ATTR_UNUSED *cls, const H5FS_sect
  * Return:	Success:	the fragment for aligning sect
  *          Failure:	null
  *
- * Programmer:	Vailin Choi, July 29, 2008
- *
  *-------------------------------------------------------------------------
  */
 static H5FS_section_info_t *
@@ -336,7 +319,7 @@ H5MF__sect_split(H5FS_section_info_t *sect, hsize_t frag_size)
 
     /* Allocate space for new section */
     if (NULL == (ret_value = H5MF__sect_new(sect->type, sect->addr, frag_size)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "can't initialize free space section")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "can't initialize free space section");
 
     /* Set new section's info */
     sect->addr += frag_size;
@@ -360,9 +343,6 @@ done:
  * Return:	Success:	non-negative (TRUE/FALSE)
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  *-------------------------------------------------------------------------
  */
 static htri_t
@@ -376,13 +356,13 @@ H5MF__sect_simple_can_merge(const H5FS_section_info_t *_sect1, const H5FS_sectio
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments. */
-    HDassert(sect1);
-    HDassert(sect2);
-    HDassert(sect1->sect_info.type == sect2->sect_info.type); /* Checks "MERGE_SYM" flag */
-    HDassert(H5F_addr_lt(sect1->sect_info.addr, sect2->sect_info.addr));
+    assert(sect1);
+    assert(sect2);
+    assert(sect1->sect_info.type == sect2->sect_info.type); /* Checks "MERGE_SYM" flag */
+    assert(H5_addr_lt(sect1->sect_info.addr, sect2->sect_info.addr));
 
     /* Check if second section adjoins first section */
-    ret_value = H5F_addr_eq(sect1->sect_info.addr + sect1->sect_info.size, sect2->sect_info.addr);
+    ret_value = H5_addr_eq(sect1->sect_info.addr + sect1->sect_info.size, sect2->sect_info.addr);
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5MF__sect_simple_can_merge() */
@@ -397,9 +377,6 @@ H5MF__sect_simple_can_merge(const H5FS_section_info_t *_sect1, const H5FS_sectio
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -413,18 +390,18 @@ H5MF__sect_simple_merge(H5FS_section_info_t **_sect1, H5FS_section_info_t *_sect
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(sect1);
-    HDassert((*sect1)->sect_info.type == H5MF_FSPACE_SECT_SIMPLE);
-    HDassert(sect2);
-    HDassert(sect2->sect_info.type == H5MF_FSPACE_SECT_SIMPLE);
-    HDassert(H5F_addr_eq((*sect1)->sect_info.addr + (*sect1)->sect_info.size, sect2->sect_info.addr));
+    assert(sect1);
+    assert((*sect1)->sect_info.type == H5MF_FSPACE_SECT_SIMPLE);
+    assert(sect2);
+    assert(sect2->sect_info.type == H5MF_FSPACE_SECT_SIMPLE);
+    assert(H5_addr_eq((*sect1)->sect_info.addr + (*sect1)->sect_info.size, sect2->sect_info.addr));
 
     /* Add second section's size to first section */
     (*sect1)->sect_info.size += sect2->sect_info.size;
 
     /* Get rid of second section */
     if (H5MF__sect_free((H5FS_section_info_t *)sect2) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -438,9 +415,6 @@ done:
  * Return:	Success:	non-negative (TRUE/FALSE)
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  *-------------------------------------------------------------------------
  */
 static htri_t
@@ -455,34 +429,33 @@ H5MF__sect_simple_can_shrink(const H5FS_section_info_t *_sect, void *_udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(sect);
-    HDassert(udata);
-    HDassert(udata->f);
+    assert(sect);
+    assert(udata);
+    assert(udata->f);
 
     /* Retrieve the end of the file's address space */
     if (HADDR_UNDEF == (eoa = H5F_get_eoa(udata->f, udata->alloc_type)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGET, FAIL, "driver get_eoa request failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGET, FAIL, "driver get_eoa request failed");
 
     /* Compute address of end of section to check */
     end = sect->sect_info.addr + sect->sect_info.size;
 
     /* Check if the section is exactly at the end of the allocated space in the file */
-    if (H5F_addr_eq(end, eoa)) {
+    if (H5_addr_eq(end, eoa)) {
         /* Set the shrinking type */
         udata->shrink = H5MF_SHRINK_EOA;
 #ifdef H5MF_ALLOC_DEBUG_MORE
-        HDfprintf(stderr,
-                  "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, shrinks file, eoa = %" PRIuHADDR "\n",
-                  __func__, sect->sect_info.addr, sect->sect_info.size, eoa);
+        fprintf(stderr, "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, shrinks file, eoa = %" PRIuHADDR "\n",
+                __func__, sect->sect_info.addr, sect->sect_info.size, eoa);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
 
         /* Indicate shrinking can occur */
-        HGOTO_DONE(TRUE)
+        HGOTO_DONE(TRUE);
     } /* end if */
     else {
         /* Shrinking can't occur if the 'eoa_shrink_only' flag is set and we're not shrinking the EOA */
         if (udata->allow_eoa_shrink_only)
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(FALSE);
 
         /* Check if this section is allowed to merge with metadata aggregation block */
         if (udata->f->shared->fs_aggr_merge[udata->alloc_type] & H5F_FS_MERGE_METADATA) {
@@ -491,18 +464,18 @@ H5MF__sect_simple_can_shrink(const H5FS_section_info_t *_sect, void *_udata)
             /* See if section can absorb the aggregator & vice versa */
             if ((status = H5MF__aggr_can_absorb(udata->f, &(udata->f->shared->meta_aggr), sect,
                                                 &(udata->shrink))) < 0)
-                HGOTO_ERROR(H5E_RESOURCE, H5E_CANTMERGE, FAIL, "error merging section with aggregation block")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_CANTMERGE, FAIL,
+                            "error merging section with aggregation block");
             else if (status > 0) {
                 /* Set the aggregator to operate on */
                 udata->aggr = &(udata->f->shared->meta_aggr);
 #ifdef H5MF_ALLOC_DEBUG_MORE
-                HDfprintf(stderr,
-                          "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, adjoins metadata aggregator\n",
-                          __func__, sect->sect_info.addr, sect->sect_info.size);
+                fprintf(stderr, "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, adjoins metadata aggregator\n",
+                        __func__, sect->sect_info.addr, sect->sect_info.size);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
 
                 /* Indicate shrinking can occur */
-                HGOTO_DONE(TRUE)
+                HGOTO_DONE(TRUE);
             } /* end if */
         }     /* end if */
 
@@ -513,18 +486,19 @@ H5MF__sect_simple_can_shrink(const H5FS_section_info_t *_sect, void *_udata)
             /* See if section can absorb the aggregator & vice versa */
             if ((status = H5MF__aggr_can_absorb(udata->f, &(udata->f->shared->sdata_aggr), sect,
                                                 &(udata->shrink))) < 0)
-                HGOTO_ERROR(H5E_RESOURCE, H5E_CANTMERGE, FAIL, "error merging section with aggregation block")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_CANTMERGE, FAIL,
+                            "error merging section with aggregation block");
             else if (status > 0) {
                 /* Set the aggregator to operate on */
                 udata->aggr = &(udata->f->shared->sdata_aggr);
 #ifdef H5MF_ALLOC_DEBUG_MORE
-                HDfprintf(stderr,
-                          "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, adjoins small data aggregator\n",
-                          __func__, sect->sect_info.addr, sect->sect_info.size);
+                fprintf(stderr,
+                        "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, adjoins small data aggregator\n",
+                        __func__, sect->sect_info.addr, sect->sect_info.size);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
 
                 /* Indicate shrinking can occur */
-                HGOTO_DONE(TRUE)
+                HGOTO_DONE(TRUE);
             } /* end if */
         }     /* end if */
     }         /* end else */
@@ -544,9 +518,6 @@ done:
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, January  8, 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -559,34 +530,34 @@ H5MF__sect_simple_shrink(H5FS_section_info_t **_sect, void *_udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(sect);
-    HDassert(udata);
-    HDassert(udata->f);
+    assert(sect);
+    assert(udata);
+    assert(udata->f);
 
     /* Check for shrinking file */
     if (H5MF_SHRINK_EOA == udata->shrink) {
         /* Sanity check */
-        HDassert(H5F_INTENT(udata->f) & H5F_ACC_RDWR);
+        assert(H5F_INTENT(udata->f) & H5F_ACC_RDWR);
 
         /* Release section's space at EOA */
         if (H5F__free(udata->f, udata->alloc_type, (*sect)->sect_info.addr, (*sect)->sect_info.size) < 0)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "driver free request failed")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "driver free request failed");
     } /* end if */
     else {
         /* Sanity check */
-        HDassert(udata->aggr);
+        assert(udata->aggr);
 
         /* Absorb the section into the aggregator or vice versa */
         if (H5MF__aggr_absorb(udata->f, udata->aggr, *sect, udata->allow_sect_absorb) < 0)
             HGOTO_ERROR(H5E_RESOURCE, H5E_CANTMERGE, FAIL,
-                        "can't absorb section into aggregator or vice versa")
+                        "can't absorb section into aggregator or vice versa");
     } /* end else */
 
     /* Check for freeing section */
     if (udata->shrink != H5MF_SHRINK_SECT_ABSORB_AGGR) {
         /* Free section */
         if (H5MF__sect_free((H5FS_section_info_t *)*sect) < 0)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free simple section node")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free simple section node");
 
         /* Mark section as freed, for free space manager */
         *sect = NULL;
@@ -611,8 +582,6 @@ done:
  * Return:      Success:        non-negative
  *              Failure:        negative
  *
- * Programmer:  Vailin Choi; Dec 2012
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -627,8 +596,8 @@ H5MF__sect_small_add(H5FS_section_info_t **_sect, unsigned *flags, void *_udata)
     FUNC_ENTER_PACKAGE
 
 #ifdef H5MF_ALLOC_DEBUG_MORE
-    HDfprintf(stderr, "%s: Entering, section {%" PRIuHADDR ", %" PRIuHSIZE "}\n", __func__,
-              (*sect)->sect_info.addr, (*sect)->sect_info.size);
+    fprintf(stderr, "%s: Entering, section {%" PRIuHADDR ", %" PRIuHSIZE "}\n", __func__,
+            (*sect)->sect_info.addr, (*sect)->sect_info.size);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
 
     /* Do not adjust the section raw data or global heap data */
@@ -643,20 +612,20 @@ H5MF__sect_small_add(H5FS_section_info_t **_sect, unsigned *flags, void *_udata)
     if (!rem && (*sect)->sect_info.size <= H5F_PGEND_META_THRES(udata->f) &&
         (*flags & H5FS_ADD_RETURNED_SPACE)) {
         if (H5MF__sect_free((H5FS_section_info_t *)(*sect)) < 0)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node");
         *sect = NULL;
         *flags &= (unsigned)~H5FS_ADD_RETURNED_SPACE;
         *flags |= H5FS_PAGE_END_NO_ADD;
 #ifdef H5MF_ALLOC_DEBUG_MORE
-        HDfprintf(stderr, "%s: section is dropped\n", __func__);
+        fprintf(stderr, "%s: section is dropped\n", __func__);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
     }  /* end if */
     /* Adjust the section if it is not at page end but its size + prem is at page end */
     else if (prem <= H5F_PGEND_META_THRES(udata->f)) {
         (*sect)->sect_info.size += prem;
 #ifdef H5MF_ALLOC_DEBUG_MORE
-        HDfprintf(stderr, "%s: section is adjusted {%" PRIuHADDR ", %" PRIuHSIZE "}\n", __func__,
-                  (*sect)->sect_info.addr, (*sect)->sect_info.size);
+        fprintf(stderr, "%s: section is adjusted {%" PRIuHADDR ", %" PRIuHSIZE "}\n", __func__,
+                (*sect)->sect_info.addr, (*sect)->sect_info.size);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
     }  /* end if */
 
@@ -675,8 +644,6 @@ done:
  * Return:	Success:	non-negative (TRUE/FALSE)
  *          Failure:	negative
  *
- * Programmer:	Vailin Choi; Dec 2012
- *
  *-------------------------------------------------------------------------
  */
 static htri_t
@@ -690,13 +657,13 @@ H5MF__sect_small_can_merge(const H5FS_section_info_t *_sect1, const H5FS_section
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments. */
-    HDassert(sect1);
-    HDassert(sect2);
-    HDassert(sect1->sect_info.type == sect2->sect_info.type); /* Checks "MERGE_SYM" flag */
-    HDassert(H5F_addr_lt(sect1->sect_info.addr, sect2->sect_info.addr));
+    assert(sect1);
+    assert(sect2);
+    assert(sect1->sect_info.type == sect2->sect_info.type); /* Checks "MERGE_SYM" flag */
+    assert(H5_addr_lt(sect1->sect_info.addr, sect2->sect_info.addr));
 
     /* Check if second section adjoins first section */
-    ret_value = H5F_addr_eq(sect1->sect_info.addr + sect1->sect_info.size, sect2->sect_info.addr);
+    ret_value = H5_addr_eq(sect1->sect_info.addr + sect1->sect_info.size, sect2->sect_info.addr);
     if (ret_value > 0)
         /* If they are on different pages, couldn't merge */
         if ((sect1->sect_info.addr / udata->f->shared->fs_page_size) !=
@@ -704,7 +671,7 @@ H5MF__sect_small_can_merge(const H5FS_section_info_t *_sect1, const H5FS_section
             ret_value = FALSE;
 
 #ifdef H5MF_ALLOC_DEBUG_MORE
-    HDfprintf(stderr, "%s: Leaving: ret_value = %d\n", __func__, ret_value);
+    fprintf(stderr, "%s: Leaving: ret_value = %d\n", __func__, ret_value);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -722,8 +689,6 @@ H5MF__sect_small_can_merge(const H5FS_section_info_t *_sect1, const H5FS_section
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
- * Programmer:	Vailin Choi; Dec 2012
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -737,18 +702,18 @@ H5MF__sect_small_merge(H5FS_section_info_t **_sect1, H5FS_section_info_t *_sect2
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(sect1);
-    HDassert((*sect1)->sect_info.type == H5MF_FSPACE_SECT_SMALL);
-    HDassert(sect2);
-    HDassert(sect2->sect_info.type == H5MF_FSPACE_SECT_SMALL);
-    HDassert(H5F_addr_eq((*sect1)->sect_info.addr + (*sect1)->sect_info.size, sect2->sect_info.addr));
+    assert(sect1);
+    assert((*sect1)->sect_info.type == H5MF_FSPACE_SECT_SMALL);
+    assert(sect2);
+    assert(sect2->sect_info.type == H5MF_FSPACE_SECT_SMALL);
+    assert(H5_addr_eq((*sect1)->sect_info.addr + (*sect1)->sect_info.size, sect2->sect_info.addr));
 
     /* Add second section's size to first section */
     (*sect1)->sect_info.size += sect2->sect_info.size;
 
     if ((*sect1)->sect_info.size == udata->f->shared->fs_page_size) {
         if (H5MF_xfree(udata->f, udata->alloc_type, (*sect1)->sect_info.addr, (*sect1)->sect_info.size) < 0)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "can't free merged section")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "can't free merged section");
 
         /* Need to free possible metadata page in the PB cache */
         /* This is in response to the data corruption bug from fheap.c with page buffering + page strategy */
@@ -756,16 +721,16 @@ H5MF__sect_small_merge(H5FS_section_info_t **_sect1, H5FS_section_info_t *_sect2
         /* Note: Update of raw data page (large or small sized) is handled by the PB cache */
         if (udata->f->shared->page_buf != NULL && udata->alloc_type != H5FD_MEM_DRAW)
             if (H5PB_remove_entry(udata->f->shared, (*sect1)->sect_info.addr) < 0)
-                HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "can't free merged section")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "can't free merged section");
 
         if (H5MF__sect_free((H5FS_section_info_t *)(*sect1)) < 0)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node");
         *sect1 = NULL;
     } /* end if */
 
     /* Get rid of second section */
     if (H5MF__sect_free((H5FS_section_info_t *)sect2) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -785,8 +750,6 @@ done:
  * Return:	Success:	non-negative (TRUE/FALSE)
  *          Failure:	negative
  *
- * Programmer:	Vailin Choi; Dec 2012
- *
  *-------------------------------------------------------------------------
  */
 static htri_t
@@ -800,15 +763,15 @@ H5MF__sect_large_can_merge(const H5FS_section_info_t *_sect1, const H5FS_section
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments. */
-    HDassert(sect1);
-    HDassert(sect2);
-    HDassert(sect1->sect_info.type == sect2->sect_info.type); /* Checks "MERGE_SYM" flag */
-    HDassert(H5F_addr_lt(sect1->sect_info.addr, sect2->sect_info.addr));
+    assert(sect1);
+    assert(sect2);
+    assert(sect1->sect_info.type == sect2->sect_info.type); /* Checks "MERGE_SYM" flag */
+    assert(H5_addr_lt(sect1->sect_info.addr, sect2->sect_info.addr));
 
-    ret_value = H5F_addr_eq(sect1->sect_info.addr + sect1->sect_info.size, sect2->sect_info.addr);
+    ret_value = H5_addr_eq(sect1->sect_info.addr + sect1->sect_info.size, sect2->sect_info.addr);
 
 #ifdef H5MF_ALLOC_DEBUG_MORE
-    HDfprintf(stderr, "%s: Leaving: ret_value = %d\n", __func__, ret_value);
+    fprintf(stderr, "%s: Leaving: ret_value = %d\n", __func__, ret_value);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
 
     FUNC_LEAVE_NOAPI(ret_value)
@@ -824,8 +787,6 @@ H5MF__sect_large_can_merge(const H5FS_section_info_t *_sect1, const H5FS_section
  * Return:	Success:	non-negative
  *          Failure:	negative
  *
- * Programmer:	Vailin Choi; Dec 2012
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -838,18 +799,18 @@ H5MF__sect_large_merge(H5FS_section_info_t **_sect1, H5FS_section_info_t *_sect2
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(sect1);
-    HDassert((*sect1)->sect_info.type == H5MF_FSPACE_SECT_LARGE);
-    HDassert(sect2);
-    HDassert(sect2->sect_info.type == H5MF_FSPACE_SECT_LARGE);
-    HDassert(H5F_addr_eq((*sect1)->sect_info.addr + (*sect1)->sect_info.size, sect2->sect_info.addr));
+    assert(sect1);
+    assert((*sect1)->sect_info.type == H5MF_FSPACE_SECT_LARGE);
+    assert(sect2);
+    assert(sect2->sect_info.type == H5MF_FSPACE_SECT_LARGE);
+    assert(H5_addr_eq((*sect1)->sect_info.addr + (*sect1)->sect_info.size, sect2->sect_info.addr));
 
     /* Add second section's size to first section */
     (*sect1)->sect_info.size += sect2->sect_info.size;
 
     /* Get rid of second section */
     if (H5MF__sect_free((H5FS_section_info_t *)sect2) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free section node");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -863,8 +824,6 @@ done:
  * Return:	Success:	non-negative (TRUE/FALSE)
  *          Failure:	negative
  *
- * Programmer:	Vailin Choi; Dec 2012
- *
  *-------------------------------------------------------------------------
  */
 static htri_t
@@ -879,30 +838,29 @@ H5MF__sect_large_can_shrink(const H5FS_section_info_t *_sect, void *_udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(sect);
-    HDassert(sect->sect_info.type == H5MF_FSPACE_SECT_LARGE);
-    HDassert(udata);
-    HDassert(udata->f);
+    assert(sect);
+    assert(sect->sect_info.type == H5MF_FSPACE_SECT_LARGE);
+    assert(udata);
+    assert(udata->f);
 
     /* Retrieve the end of the file's address space */
     if (HADDR_UNDEF == (eoa = H5FD_get_eoa(udata->f->shared->lf, udata->alloc_type)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGET, FAIL, "driver get_eoa request failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTGET, FAIL, "driver get_eoa request failed");
 
     /* Compute address of end of section to check */
     end = sect->sect_info.addr + sect->sect_info.size;
 
     /* Check if the section is exactly at the end of the allocated space in the file */
-    if (H5F_addr_eq(end, eoa) && sect->sect_info.size >= udata->f->shared->fs_page_size) {
+    if (H5_addr_eq(end, eoa) && sect->sect_info.size >= udata->f->shared->fs_page_size) {
         /* Set the shrinking type */
         udata->shrink = H5MF_SHRINK_EOA;
 #ifdef H5MF_ALLOC_DEBUG_MORE
-        HDfprintf(stderr,
-                  "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, shrinks file, eoa = %" PRIuHADDR "\n",
-                  __func__, sect->sect_info.addr, sect->sect_info.size, eoa);
+        fprintf(stderr, "%s: section {%" PRIuHADDR ", %" PRIuHSIZE "}, shrinks file, eoa = %" PRIuHADDR "\n",
+                __func__, sect->sect_info.addr, sect->sect_info.size, eoa);
 #endif /* H5MF_ALLOC_DEBUG_MORE */
 
         /* Indicate shrinking can occur */
-        HGOTO_DONE(TRUE)
+        HGOTO_DONE(TRUE);
     } /* end if */
 
 done:
@@ -917,8 +875,6 @@ done:
  * Return:      Success:	non-negative
  *              Failure:	negative
  *
- * Programmer:	Vailin Choi; Dec 2012
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -932,13 +888,13 @@ H5MF__sect_large_shrink(H5FS_section_info_t **_sect, void *_udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
-    HDassert(sect);
-    HDassert((*sect)->sect_info.type == H5MF_FSPACE_SECT_LARGE);
-    HDassert(udata);
-    HDassert(udata->f);
-    HDassert(udata->shrink == H5MF_SHRINK_EOA);
-    HDassert(H5F_INTENT(udata->f) & H5F_ACC_RDWR);
-    HDassert(H5F_PAGED_AGGR(udata->f));
+    assert(sect);
+    assert((*sect)->sect_info.type == H5MF_FSPACE_SECT_LARGE);
+    assert(udata);
+    assert(udata->f);
+    assert(udata->shrink == H5MF_SHRINK_EOA);
+    assert(H5F_INTENT(udata->f) & H5F_ACC_RDWR);
+    assert(H5F_PAGED_AGGR(udata->f));
 
     /* Calculate possible mis-aligned fragment */
     H5MF_EOA_MISALIGN(udata->f, (*sect)->sect_info.addr, udata->f->shared->fs_page_size, frag_size);
@@ -947,14 +903,14 @@ H5MF__sect_large_shrink(H5FS_section_info_t **_sect, void *_udata)
     /* Retain partial page in the free-space manager so as to keep EOA at page boundary */
     if (H5F__free(udata->f, udata->alloc_type, (*sect)->sect_info.addr + frag_size,
                   (*sect)->sect_info.size - frag_size) < 0)
-        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "driver free request failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTFREE, FAIL, "driver free request failed");
 
     if (frag_size) /* Adjust section size for the partial page */
         (*sect)->sect_info.size = frag_size;
     else {
         /* Free section */
         if (H5MF__sect_free((H5FS_section_info_t *)*sect) < 0)
-            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free simple section node")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_CANTRELEASE, FAIL, "can't free simple section node");
 
         /* Mark section as freed, for free space manager */
         *sect = NULL;
