@@ -77,7 +77,7 @@ H5MM_malloc(size_t size)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    ret_value = HDmalloc(size);
+    ret_value = malloc(size);
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5MM_malloc() */
@@ -106,7 +106,7 @@ H5MM_calloc(size_t size)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    ret_value = HDcalloc(1, size);
+    ret_value = calloc(1, size);
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5MM_calloc() */
@@ -141,7 +141,7 @@ H5MM_realloc(void *mem, size_t size)
         /* Not defined in the standard, return NULL */
         ret_value = NULL;
     else {
-        ret_value = HDrealloc(mem, size);
+        ret_value = realloc(mem, size);
 
         /* Some platforms do not return NULL if size is zero. */
         if (0 == size)
@@ -170,7 +170,7 @@ H5MM_xstrdup(const char *s)
 
     if (s)
         if (NULL == (ret_value = HDstrdup(s)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "string duplication failed")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "string duplication failed");
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5MM_xstrdup() */
@@ -196,9 +196,9 @@ H5MM_strdup(const char *s)
     FUNC_ENTER_NOAPI(NULL)
 
     if (!s)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "NULL string not allowed")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "NULL string not allowed");
     if (NULL == (ret_value = HDstrdup(s)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "string duplication failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "string duplication failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -228,10 +228,10 @@ H5MM_strndup(const char *s, size_t n)
     FUNC_ENTER_NOAPI(NULL)
 
     if (!s)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "NULL string not allowed")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "NULL string not allowed");
 
     if (NULL == (ret_value = HDstrndup(s, n)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "string duplication failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "string duplication failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -255,7 +255,7 @@ H5MM_xfree(void *mem)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDfree(mem);
+    free(mem);
 
     FUNC_LEAVE_NOAPI(NULL)
 } /* end H5MM_xfree() */
@@ -301,14 +301,14 @@ H5MM_memcpy(void *dest, const void *src, size_t n)
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(dest);
-    HDassert(src);
+    assert(dest);
+    assert(src);
 
     /* Check for buffer overlap */
-    HDassert((char *)dest >= (const char *)src + n || (const char *)src >= (char *)dest + n);
+    assert((char *)dest >= (const char *)src + n || (const char *)src >= (char *)dest + n);
 
     /* Copy */
-    ret = HDmemcpy(dest, src, n);
+    ret = memcpy(dest, src, n);
 
     FUNC_LEAVE_NOAPI(ret)
 
