@@ -26,7 +26,7 @@
 /* Private headers needed by this file */
 #include "H5private.h"
 
-#define H5MM_free(Z) HDfree(Z)
+#define H5MM_free(Z) free(Z)
 
 /*
  * Library prototypes...
@@ -34,9 +34,9 @@
 H5_DLL void *H5MM_malloc(size_t size) H5_ATTR_MALLOC;
 H5_DLL void *H5MM_calloc(size_t size) H5_ATTR_MALLOC;
 H5_DLL void *H5MM_realloc(void *mem, size_t size);
-H5_DLL char *H5MM_xstrdup(const char *s);
-H5_DLL char *H5MM_strdup(const char *s);
-H5_DLL char *H5MM_strndup(const char *s, size_t n);
+H5_DLL char *H5MM_xstrdup(const char *s) H5_ATTR_MALLOC;
+H5_DLL char *H5MM_strdup(const char *s) H5_ATTR_MALLOC;
+H5_DLL char *H5MM_strndup(const char *s, size_t n) H5_ATTR_MALLOC;
 H5_DLL void *H5MM_xfree(void *mem);
 H5_DLL void *H5MM_xfree_const(const void *mem);
 H5_DLL void *H5MM_memcpy(void *dest, const void *src, size_t n);
