@@ -14,7 +14,7 @@
  *
  * Created:     H5Ocopy_ref.c
  *
- * Purpose:     Object with references copying routines.
+ * Purpose:     Object with references copying routines
  *
  *-------------------------------------------------------------------------
  */
@@ -30,6 +30,7 @@
 /* Headers */
 /***********/
 #include "H5private.h"   /* Generic Functions                        */
+#include "H5Eprivate.h"  /* Error handling                           */
 #include "H5Fprivate.h"  /* File                                     */
 #include "H5Iprivate.h"  /* IDs                                      */
 #include "H5Lprivate.h"  /* Links                                    */
@@ -99,15 +100,15 @@ H5O__copy_obj_by_ref(H5O_loc_t *src_oloc, H5O_loc_t *dst_oloc, H5G_loc_t *dst_ro
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(src_oloc);
-    HDassert(dst_oloc);
+    assert(src_oloc);
+    assert(dst_oloc);
 
     /* Perform the copy, or look up existing copy */
     if ((ret_value = H5O_copy_header_map(src_oloc, dst_oloc, cpy_info, FALSE, NULL, NULL)) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object");
 
     /* Check if a new valid object is copied to the destination */
-    if (H5F_addr_defined(dst_oloc->addr) && (ret_value > SUCCEED)) {
+    if (H5_addr_defined(dst_oloc->addr) && (ret_value > SUCCEED)) {
         char       tmp_obj_name[80];
         H5G_name_t new_path;
         H5O_loc_t  new_oloc;
@@ -131,10 +132,10 @@ H5O__copy_obj_by_ref(H5O_loc_t *src_oloc, H5O_loc_t *dst_oloc, H5G_loc_t *dst_ro
          * This could be changed in the future to slightly improve performance
          * --NAF */
         if (H5L_link(dst_root_loc, tmp_obj_name, &new_loc, cpy_info->lcpl_id) < 0)
-            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to insert link")
+            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to insert link");
 
         H5G_loc_free(&new_loc);
-    } /* if (H5F_addr_defined(dst_oloc.addr)) */
+    } /* if (H5_addr_defined(dst_oloc.addr)) */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -170,30 +171,30 @@ H5O__copy_expand_ref_object1(H5O_loc_t *src_oloc, const void *buf_src, H5O_loc_t
         H5O_token_t          tmp_token = {0};
 
         /* If data is not initialized, copy zeros and skip */
-        if (0 == HDmemcmp(src_buf, zeros, buf_size))
-            HDmemset(dst_buf, 0, buf_size);
+        if (0 == memcmp(src_buf, zeros, buf_size))
+            memset(dst_buf, 0, buf_size);
         else {
             /* Set up for the object copy for the reference */
             if (H5R__decode_token_obj_compat(src_buf, &buf_size, &tmp_token, token_size) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, FAIL, "unable to decode src object address")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, FAIL, "unable to decode src object address");
             if (H5VL_native_token_to_addr(src_oloc->file, H5I_FILE, tmp_token, &src_oloc->addr) < 0)
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTUNSERIALIZE, FAIL,
-                            "can't deserialize object token into address")
+                            "can't deserialize object token into address");
 
-            if (!H5F_addr_defined(src_oloc->addr) || src_oloc->addr == 0)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "undefined reference pointer")
+            if (!H5_addr_defined(src_oloc->addr) || src_oloc->addr == 0)
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "undefined reference pointer");
             dst_oloc->addr = HADDR_UNDEF;
 
             /* Attempt to copy object from source to destination file */
             if (H5O__copy_obj_by_ref(src_oloc, dst_oloc, dst_root_loc, cpy_info) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object");
 
             /* Set the object reference info for the destination file */
             if (H5VL_native_addr_to_token(dst_oloc->file, H5I_FILE, dst_oloc->addr, &tmp_token) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTSERIALIZE, FAIL, "can't serialize address into object token")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTSERIALIZE, FAIL, "can't serialize address into object token");
             if (H5R__encode_token_obj_compat((const H5O_token_t *)&tmp_token, token_size, dst_buf,
                                              &buf_size) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, FAIL, "unable to encode dst object address")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, FAIL, "unable to encode dst object address");
         } /* end else */
     }     /* end for */
 
@@ -233,26 +234,26 @@ H5O__copy_expand_ref_region1(H5O_loc_t *src_oloc, const void *buf_src, H5O_loc_t
         uint8_t             *q;
 
         /* If data is not initialized, copy zeros and skip */
-        if (0 == HDmemcmp(src_buf, zeros, buf_size))
-            HDmemset(dst_buf, 0, buf_size);
+        if (0 == memcmp(src_buf, zeros, buf_size))
+            memset(dst_buf, 0, buf_size);
         else {
             /* Read from heap */
             if (H5R__decode_heap(src_oloc->file, src_buf, &buf_size, &data, &data_size) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, FAIL, "unable to decode dataset region information")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTDECODE, FAIL, "unable to decode dataset region information");
 
             /* Get object address */
             p = (const uint8_t *)data;
             H5F_addr_decode(src_oloc->file, &p, &src_oloc->addr);
-            if (!H5F_addr_defined(src_oloc->addr) || src_oloc->addr == 0) {
+            if (!H5_addr_defined(src_oloc->addr) || src_oloc->addr == 0) {
                 H5MM_free(data);
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "undefined reference pointer")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "undefined reference pointer");
             }
             dst_oloc->addr = HADDR_UNDEF;
 
             /* Attempt to copy object from source to destination file */
             if (H5O__copy_obj_by_ref(src_oloc, dst_oloc, dst_root_loc, cpy_info) < 0) {
                 H5MM_free(data);
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object");
             } /* end if */
 
             /* Serialize object addr */
@@ -262,7 +263,7 @@ H5O__copy_expand_ref_region1(H5O_loc_t *src_oloc, const void *buf_src, H5O_loc_t
             /* Write to heap */
             if (H5R__encode_heap(dst_oloc->file, dst_buf, &buf_size, data, (size_t)data_size) < 0) {
                 H5MM_free(data);
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTENCODE, FAIL, "unable to encode dataset region information")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTENCODE, FAIL, "unable to encode dataset region information");
             }
 
             /* Free the buffer allocated in H5R__decode_heap() */
@@ -309,48 +310,48 @@ H5O__copy_expand_ref_object2(H5O_loc_t *src_oloc, hid_t tid_src, const H5T_t *dt
 
     /* Create datatype ID for src datatype. */
     if ((tid_src == H5I_INVALID_HID) && (tid_src = H5I_register(H5I_DATATYPE, dt_src, FALSE)) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register source file datatype")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register source file datatype");
 
     /* create a memory copy of the reference datatype */
     if (NULL == (dt_mem = H5T_copy(dt_src, H5T_COPY_TRANSIENT)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy");
     if ((tid_mem = H5I_register(H5I_DATATYPE, dt_mem, FALSE)) < 0) {
         (void)H5T_close_real(dt_mem);
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register memory datatype")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register memory datatype");
     } /* end if */
 
     /* create reference datatype at the destination file */
     if (NULL == (dt_dst = H5T_copy(dt_src, H5T_COPY_TRANSIENT)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy");
     if (H5T_set_loc(dt_dst, H5F_VOL_OBJ(dst_oloc->file), H5T_LOC_DISK) < 0) {
         (void)H5T_close_real(dt_dst);
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "cannot mark datatype on disk")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "cannot mark datatype on disk");
     } /* end if */
     if ((tid_dst = H5I_register(H5I_DATATYPE, dt_dst, FALSE)) < 0) {
         (void)H5T_close_real(dt_dst);
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register destination file datatype")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register destination file datatype");
     } /* end if */
 
     /* Set up the conversion functions */
     if (NULL == (tpath_src_mem = H5T_path_find(dt_src, dt_mem)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between src and mem datatypes")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between src and mem datatypes");
     if (NULL == (tpath_mem_dst = H5T_path_find(dt_mem, dt_dst)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between mem and dst datatypes")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between mem and dst datatypes");
 
     /* Use extra conversion buffer (TODO we should avoid using an extra buffer once the H5Ocopy code has been
      * reworked) */
     conv_buf_size = MAX(H5T_get_size(dt_src), H5T_get_size(dt_mem)) * ref_count;
     if (NULL == (conv_buf = H5FL_BLK_MALLOC(type_conv, conv_buf_size)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for copy buffer")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for copy buffer");
     H5MM_memcpy(conv_buf, buf_src, nbytes_src);
 
     /* Convert from source file to memory */
     if (H5T_convert(tpath_src_mem, tid_src, tid_mem, ref_count, (size_t)0, (size_t)0, conv_buf, NULL) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCONVERT, FAIL, "datatype conversion failed")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCONVERT, FAIL, "datatype conversion failed");
 
     /* Retrieve loc ID */
     if ((dst_loc_id = H5F_get_id(dst_oloc->file)) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
 
     /* Making equivalent references in the destination file */
     for (i = 0; i < ref_count; i++) {
@@ -358,63 +359,63 @@ H5O__copy_expand_ref_object2(H5O_loc_t *src_oloc, hid_t tid_src, const H5T_t *dt
         H5R_ref_priv_t *ref     = (H5R_ref_priv_t *)&ref_ptr[i];
 
         /* Check for null reference - only expand reference if it is not null */
-        if (HDmemcmp(ref, zeros, H5R_REF_BUF_SIZE)) {
+        if (memcmp(ref, zeros, H5R_REF_BUF_SIZE)) {
             H5O_token_t tmp_token = {0};
 
             /* Get src object address */
             if (H5R__get_obj_token(ref, &tmp_token, &token_size) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to get object token")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to get object token");
             if (H5VL_native_token_to_addr(src_oloc->file, H5I_FILE, tmp_token, &src_oloc->addr) < 0)
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTUNSERIALIZE, FAIL,
-                            "can't deserialize object token into address")
+                            "can't deserialize object token into address");
 
             /* Attempt to copy object from source to destination file */
             if (H5O__copy_obj_by_ref(src_oloc, dst_oloc, dst_root_loc, cpy_info) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object");
 
             /* Set dst object address */
             if (H5VL_native_addr_to_token(dst_oloc->file, H5I_FILE, dst_oloc->addr, &tmp_token) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTSERIALIZE, FAIL, "can't serialize address into object token")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTSERIALIZE, FAIL, "can't serialize address into object token");
             if (H5R__set_obj_token(ref, (const H5O_token_t *)&tmp_token, token_size) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "unable to set object token")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "unable to set object token");
             /* Do not set app_ref since references are released once the copy is done */
             if (H5R__set_loc_id(ref, dst_loc_id, TRUE, FALSE) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "unable to set destination loc id")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "unable to set destination loc id");
         } /* end if */
     }     /* end for */
 
     /* Copy into another buffer, to reclaim memory later */
     if (NULL == (reclaim_buf = H5FL_BLK_MALLOC(type_conv, conv_buf_size)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for copy buffer")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for copy buffer");
     H5MM_memcpy(reclaim_buf, conv_buf, conv_buf_size);
     if (NULL == (buf_space = H5S_create_simple((unsigned)1, buf_dim, NULL)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCREATE, FAIL, "can't create simple dataspace")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCREATE, FAIL, "can't create simple dataspace");
 
     /* Convert from memory to destination file */
     if (H5T_convert(tpath_mem_dst, tid_mem, tid_dst, ref_count, (size_t)0, (size_t)0, conv_buf, NULL) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCONVERT, FAIL, "datatype conversion failed")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCONVERT, FAIL, "datatype conversion failed");
     H5MM_memcpy(buf_dst, conv_buf, nbytes_src);
 
     /* Reclaim space from reference data */
     if (H5T_reclaim(tid_mem, buf_space, reclaim_buf) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "unable to reclaim reference data")
+        HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "unable to reclaim reference data");
 
 done:
     if (buf_space && (H5S_close(buf_space) < 0))
-        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't close dataspace")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't close dataspace");
     /* Don't decrement ID, we want to keep underlying datatype */
     if (reg_tid_src && (tid_src > 0) && (NULL == H5I_remove(tid_src)))
-        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID");
     if ((tid_mem > 0) && H5I_dec_ref(tid_mem) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID");
     if ((tid_dst > 0) && H5I_dec_ref(tid_dst) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "Can't decrement temporary datatype ID");
     if (reclaim_buf)
         reclaim_buf = H5FL_BLK_FREE(type_conv, reclaim_buf);
     if (conv_buf)
         conv_buf = H5FL_BLK_FREE(type_conv, conv_buf);
     if ((dst_loc_id != H5I_INVALID_HID) && (H5I_dec_ref(dst_loc_id) < 0))
-        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement refcount on location id")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement refcount on location id");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__copy_expand_ref_object2() */
@@ -441,12 +442,12 @@ H5O_copy_expand_ref(H5F_t *file_src, hid_t tid_src, const H5T_t *dt_src, void *b
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity checks */
-    HDassert(file_src);
-    HDassert(buf_src);
-    HDassert(file_dst);
-    HDassert(buf_dst);
-    HDassert(nbytes_src);
-    HDassert(cpy_info);
+    assert(file_src);
+    assert(buf_src);
+    assert(file_dst);
+    assert(buf_dst);
+    assert(nbytes_src);
+    assert(cpy_info);
 
     /* Initialize object locations */
     H5O_loc_reset(&src_oloc);
@@ -456,9 +457,9 @@ H5O_copy_expand_ref(H5F_t *file_src, hid_t tid_src, const H5T_t *dt_src, void *b
 
     /* Set up the root group in the destination file */
     if (NULL == (dst_root_loc.oloc = H5G_oloc(H5G_rootof(file_dst))))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group");
     if (NULL == (dst_root_loc.path = H5G_nameof(H5G_rootof(file_dst))))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group");
 
     /* Determine # of reference elements to copy */
     ref_count = nbytes_src / H5T_get_size(dt_src);
@@ -468,24 +469,24 @@ H5O_copy_expand_ref(H5F_t *file_src, hid_t tid_src, const H5T_t *dt_src, void *b
         case H5R_OBJECT1:
             if (H5O__copy_expand_ref_object1(&src_oloc, buf_src, &dst_oloc, &dst_root_loc, buf_dst, ref_count,
                                              cpy_info) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL, "unable to expand H5R_OBJECT1 reference")
+                HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL, "unable to expand H5R_OBJECT1 reference");
             break;
         case H5R_DATASET_REGION1:
             if (H5O__copy_expand_ref_region1(&src_oloc, buf_src, &dst_oloc, &dst_root_loc, buf_dst, ref_count,
                                              cpy_info) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL, "unable to expand H5R_DATASET_REGION1 reference")
+                HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL, "unable to expand H5R_DATASET_REGION1 reference");
             break;
         case H5R_DATASET_REGION2:
         case H5R_ATTR:
         case H5R_OBJECT2:
             if (H5O__copy_expand_ref_object2(&src_oloc, tid_src, dt_src, buf_src, nbytes_src, &dst_oloc,
                                              &dst_root_loc, buf_dst, ref_count, cpy_info) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL, "unable to expand reference")
+                HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL, "unable to expand reference");
             break;
         case H5R_BADTYPE:
         case H5R_MAXTYPE:
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid reference type")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid reference type");
             break;
     } /* end switch */
 
