@@ -195,18 +195,18 @@ H5O__fill_new_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(f);
-    HDassert(p);
+    assert(f);
+    assert(p);
 
     if (NULL == (fill = H5FL_CALLOC(H5O_fill_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value message")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value message");
 
     /* Version */
     if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
         HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
     fill->version = *p++;
     if (fill->version < H5O_FILL_VERSION_1 || fill->version > H5O_FILL_VERSION_LATEST)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for fill value message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for fill value message");
 
     /* Decode each version */
     if (fill->version < H5O_FILL_VERSION_3) {
@@ -240,7 +240,7 @@ H5O__fill_new_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
                     HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
 
                 if (NULL == (fill->buf = H5MM_malloc((size_t)fill->size)))
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
+                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value");
                 H5MM_memcpy(fill->buf, p, (size_t)fill->size);
             }
         }
@@ -260,7 +260,7 @@ H5O__fill_new_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
 
         /* Check for unknown flags */
         if (flags & (unsigned)~H5O_FILL_FLAGS_ALL)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "unknown flag for fill value message")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "unknown flag for fill value message");
 
         /* Space allocation time */
         fill->alloc_time =
@@ -272,8 +272,8 @@ H5O__fill_new_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
         /* Check for undefined fill value */
         if (flags & H5O_FILL_FLAG_UNDEFINED_VALUE) {
 
-            if (flags & (unsigned)~H5O_FILL_FLAG_HAVE_VALUE)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "have value and undefined value flags both set")
+            if (flags & H5O_FILL_FLAG_HAVE_VALUE)
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "have value and undefined value flags both set");
 
             /* Set value for "undefined" fill value */
             fill->size = -1;
@@ -291,7 +291,7 @@ H5O__fill_new_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
                 HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
 
             if (NULL == (fill->buf = H5MM_malloc((size_t)fill->size)))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value");
             H5MM_memcpy(fill->buf, p, (size_t)fill->size);
 
             /* Set the "defined" flag */
@@ -335,11 +335,11 @@ H5O__fill_old_decode(H5F_t *f, H5O_t *open_oh, unsigned H5_ATTR_UNUSED mesg_flag
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(f);
-    HDassert(p);
+    assert(f);
+    assert(p);
 
     if (NULL == (fill = H5FL_CALLOC(H5O_fill_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value message")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value message");
 
     /* Set non-zero default fields */
     fill->version    = H5O_FILL_VERSION_2;
@@ -361,17 +361,17 @@ H5O__fill_old_decode(H5F_t *f, H5O_t *open_oh, unsigned H5_ATTR_UNUSED mesg_flag
 
         /* Get the datatype message  */
         if ((exists = H5O_msg_exists_oh(open_oh, H5O_DTYPE_ID)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, NULL, "unable to read object header")
+            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, NULL, "unable to read object header");
         if (exists) {
             if (NULL == (dt = (H5T_t *)H5O_msg_read_oh(f, open_oh, H5O_DTYPE_ID, NULL)))
-                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, NULL, "can't read DTYPE message")
+                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, NULL, "can't read DTYPE message");
             /* Verify size */
             if (fill->size != (ssize_t)H5T_GET_SIZE(dt))
-                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, NULL, "inconsistent fill value size")
+                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, NULL, "inconsistent fill value size");
         }
 
         if (NULL == (fill->buf = H5MM_malloc((size_t)fill->size)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value");
         H5MM_memcpy(fill->buf, p, (size_t)fill->size);
         fill->fill_defined = TRUE;
     }
@@ -402,9 +402,6 @@ done:
  *
  * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:  Raymond Lu
- *              Feb 26, 2002
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -414,9 +411,9 @@ H5O__fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(f);
-    HDassert(p);
-    HDassert(fill && NULL == fill->type);
+    assert(f);
+    assert(p);
+    assert(fill && NULL == fill->type);
 
     /* Version */
     *p++ = (uint8_t)fill->version;
@@ -445,12 +442,12 @@ H5O__fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
         uint8_t flags = 0; /* Fill value setting flags */
 
         /* Encode space allocation time */
-        HDassert(fill->alloc_time == (H5O_FILL_MASK_ALLOC_TIME & fill->alloc_time));
+        assert(fill->alloc_time == (H5O_FILL_MASK_ALLOC_TIME & fill->alloc_time));
         flags =
             (uint8_t)(flags | ((H5O_FILL_MASK_ALLOC_TIME & fill->alloc_time) << H5O_FILL_SHIFT_ALLOC_TIME));
 
         /* Encode fill value writing time */
-        HDassert(fill->fill_time == (H5O_FILL_MASK_FILL_TIME & fill->fill_time));
+        assert(fill->fill_time == (H5O_FILL_MASK_FILL_TIME & fill->fill_time));
         flags = (uint8_t)(flags | ((H5O_FILL_MASK_FILL_TIME & fill->fill_time) << H5O_FILL_SHIFT_FILL_TIME));
 
         /* Check if we need to encode a fill value size */
@@ -462,7 +459,7 @@ H5O__fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
             *p++ = (uint8_t)flags;
 
             /* Sanity check */
-            HDassert(!fill->buf);
+            assert(!fill->buf);
         } /* end if */
         else if (fill->size > 0) {
             /* Indicate that a fill value size is present */
@@ -475,7 +472,7 @@ H5O__fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
             INT32ENCODE(p, fill->size);
 
             /* Encode the fill value */
-            HDassert(fill->buf);
+            assert(fill->buf);
             H5_CHECK_OVERFLOW(fill->size, ssize_t, size_t);
             H5MM_memcpy(p, fill->buf, (size_t)fill->size);
         } /* end if */
@@ -484,7 +481,7 @@ H5O__fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
             *p++ = (uint8_t)flags;
 
             /* Sanity check */
-            HDassert(!fill->buf);
+            assert(!fill->buf);
         } /* end else */
     }     /* end else */
 
@@ -498,9 +495,6 @@ H5O__fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *              Thursday, October  1, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -510,9 +504,9 @@ H5O__fill_old_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(f);
-    HDassert(p);
-    HDassert(fill && NULL == fill->type);
+    assert(f);
+    assert(p);
+    assert(fill && NULL == fill->type);
 
     UINT32ENCODE(p, fill->size);
     if (fill->buf)
@@ -532,9 +526,6 @@ H5O__fill_old_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
  * Return:    Success:    Ptr to _DEST
  *            Failure:    NULL
  *
- * Programmer:  Raymond Lu
- *              Feb 26, 2002
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -546,10 +537,10 @@ H5O__fill_copy(const void *_src, void *_dst)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(src);
+    assert(src);
 
     if (!dst && NULL == (dst = H5FL_MALLOC(H5O_fill_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill message")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill message");
 
     /* Shallow copy basic fields */
     *dst = *src;
@@ -557,7 +548,7 @@ H5O__fill_copy(const void *_src, void *_dst)
     /* Copy data type of fill value */
     if (src->type) {
         if (NULL == (dst->type = H5T_copy(src->type, H5T_COPY_TRANSIENT)))
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, NULL, "can't copy datatype")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, NULL, "can't copy datatype");
     } /* end if */
     else
         dst->type = NULL;
@@ -566,7 +557,7 @@ H5O__fill_copy(const void *_src, void *_dst)
     if (src->buf) {
         H5_CHECK_OVERFLOW(src->size, ssize_t, size_t);
         if (NULL == (dst->buf = H5MM_malloc((size_t)src->size)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value");
         H5MM_memcpy(dst->buf, src->buf, (size_t)src->size);
 
         /* Check for needing to convert/copy fill value */
@@ -576,7 +567,7 @@ H5O__fill_copy(const void *_src, void *_dst)
             /* Set up type conversion function */
             if (NULL == (tpath = H5T_path_find(src->type, dst->type)))
                 HGOTO_ERROR(H5E_OHDR, H5E_UNSUPPORTED, NULL,
-                            "unable to convert between src and dst data types")
+                            "unable to convert between src and dst data types");
 
             /* If necessary, convert fill value datatypes (which copies VL components, etc.) */
             if (!H5T_path_noop(tpath)) {
@@ -587,11 +578,11 @@ H5O__fill_copy(const void *_src, void *_dst)
                 /* Wrap copies of types to convert */
                 dst_id = H5I_register(H5I_DATATYPE, H5T_copy(dst->type, H5T_COPY_TRANSIENT), FALSE);
                 if (dst_id < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, NULL, "unable to copy/register datatype")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, NULL, "unable to copy/register datatype");
                 src_id = H5I_register(H5I_DATATYPE, H5T_copy(src->type, H5T_COPY_ALL), FALSE);
                 if (src_id < 0) {
                     H5I_dec_ref(dst_id);
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, NULL, "unable to copy/register datatype")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, NULL, "unable to copy/register datatype");
                 } /* end if */
 
                 /* Allocate a background buffer */
@@ -599,7 +590,7 @@ H5O__fill_copy(const void *_src, void *_dst)
                 if (H5T_path_bkg(tpath) && NULL == (bkg_buf = H5FL_BLK_CALLOC(type_conv, bkg_size))) {
                     H5I_dec_ref(src_id);
                     H5I_dec_ref(dst_id);
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
                 } /* end if */
 
                 /* Convert fill value */
@@ -609,7 +600,7 @@ H5O__fill_copy(const void *_src, void *_dst)
                     H5I_dec_ref(dst_id);
                     if (bkg_buf)
                         bkg_buf = H5FL_BLK_FREE(type_conv, bkg_buf);
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTCONVERT, NULL, "datatype conversion failed")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTCONVERT, NULL, "datatype conversion failed");
                 } /* end if */
 
                 /* Release the background buffer */
@@ -651,9 +642,6 @@ done:
  * Return:    Success:    Message data size in bytes w/o alignment.
  *          Failure:    0
  *
- * Programmer:  Raymond Lu
- *              Feb 26, 2002
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -664,8 +652,8 @@ H5O__fill_new_size(const H5F_t H5_ATTR_UNUSED *f, const void *_fill)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(f);
-    HDassert(fill);
+    assert(f);
+    assert(fill);
 
     /* Determine size for different versions */
     if (fill->version < H5O_FILL_VERSION_3) {
@@ -698,9 +686,6 @@ H5O__fill_new_size(const H5F_t H5_ATTR_UNUSED *f, const void *_fill)
  * Return:      Success:        Message data size in bytes w/o alignment.
  *              Failure:        0
  *
- * Programmer:  Robb Matzke
- *              Thursday, October  1, 1998
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -710,7 +695,7 @@ H5O__fill_old_size(const H5F_t H5_ATTR_UNUSED *f, const void *_fill)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(fill);
+    assert(fill);
 
     FUNC_LEAVE_NOAPI(4 + (size_t)fill->size)
 } /* end H5O__fill_old_size() */
@@ -722,9 +707,6 @@ H5O__fill_old_size(const H5F_t H5_ATTR_UNUSED *f, const void *_fill)
  *
  * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:    Quincey Koziol
- *              Monday, January 22, 2007
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -735,7 +717,7 @@ H5O_fill_reset_dyn(H5O_fill_t *fill)
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(fill);
+    assert(fill);
 
     if (fill->buf) {
         if (fill->type && H5T_detect_class(fill->type, H5T_VLEN, FALSE) > 0) {
@@ -744,20 +726,20 @@ H5O_fill_reset_dyn(H5O_fill_t *fill)
 
             /* Copy the fill value datatype and get an ID for it */
             if (NULL == (fill_type = H5T_copy(fill->type, H5T_COPY_TRANSIENT)))
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy fill value datatype")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy fill value datatype");
             if ((fill_type_id = H5I_register(H5I_DATATYPE, fill_type, FALSE)) < 0) {
                 (void)H5T_close_real(fill_type);
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register fill value datatype")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register fill value datatype");
             } /* end if */
 
             /* Create a scalar dataspace for the fill value element */
             if (NULL == (fill_space = H5S_create(H5S_SCALAR)))
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTCREATE, FAIL, "can't create scalar dataspace")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTCREATE, FAIL, "can't create scalar dataspace");
 
             /* Reclaim any variable length components of the fill value */
             if (H5T_reclaim(fill_type_id, fill_space, fill->buf) < 0) {
                 H5S_close(fill_space);
-                HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "unable to reclaim variable-length fill value data")
+                HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "unable to reclaim variable-length fill value data");
             } /* end if */
 
             /* Release the scalar fill value dataspace */
@@ -775,7 +757,7 @@ H5O_fill_reset_dyn(H5O_fill_t *fill)
 
 done:
     if (fill_type_id > 0 && H5I_dec_ref(fill_type_id) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement ref count for temp ID")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement ref count for temp ID");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_fill_reset_dyn() */
@@ -787,9 +769,6 @@ done:
  *
  * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:    Robb Matzke
- *              Thursday, October  1, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -799,7 +778,7 @@ H5O__fill_reset(void *_fill)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(fill);
+    assert(fill);
 
     /* Reset dynamic fields */
     H5O_fill_reset_dyn(fill);
@@ -819,9 +798,6 @@ H5O__fill_reset(void *_fill)
  *
  * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:    Quincey Koziol
- *              Thursday, December 5, 2002
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -829,7 +805,7 @@ H5O__fill_free(void *fill)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(fill);
+    assert(fill);
 
     fill = H5FL_FREE(H5O_fill_t, fill);
 
@@ -845,8 +821,6 @@ H5O__fill_free(void *fill)
  * Return:      Success:        Non-negative
  *              Failure:        Negative
  *
- * Programmer:  Vailin Choi; Dec 2017
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -859,13 +833,13 @@ H5O__fill_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void *mesg_src, hb
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(cpy_info);
-    HDassert(cpy_info->file_dst);
+    assert(cpy_info);
+    assert(cpy_info->file_dst);
 
     /* Check to ensure that the version of the message to be copied does not exceed
        the message version allowed by the destination file's high bound */
     if (fill_src->version > H5O_fill_ver_bounds[H5F_HIGH_BOUND(cpy_info->file_dst)])
-        HGOTO_ERROR(H5E_OHDR, H5E_BADRANGE, FAIL, "fill value message version out of bounds")
+        HGOTO_ERROR(H5E_OHDR, H5E_BADRANGE, FAIL, "fill value message version out of bounds");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -878,9 +852,6 @@ done:
  *
  * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:    Robb Matzke
- *              Thursday, October  1, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -891,81 +862,81 @@ H5O__fill_debug(H5F_t H5_ATTR_UNUSED *f, const void *_fill, FILE *stream, int in
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(f);
-    HDassert(fill);
-    HDassert(stream);
-    HDassert(indent >= 0);
-    HDassert(fwidth >= 0);
+    assert(f);
+    assert(fill);
+    assert(stream);
+    assert(indent >= 0);
+    assert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s ", indent, "", fwidth, "Space Allocation Time:");
+    fprintf(stream, "%*s%-*s ", indent, "", fwidth, "Space Allocation Time:");
     switch (fill->alloc_time) {
         case H5D_ALLOC_TIME_EARLY:
-            HDfprintf(stream, "Early\n");
+            fprintf(stream, "Early\n");
             break;
 
         case H5D_ALLOC_TIME_LATE:
-            HDfprintf(stream, "Late\n");
+            fprintf(stream, "Late\n");
             break;
 
         case H5D_ALLOC_TIME_INCR:
-            HDfprintf(stream, "Incremental\n");
+            fprintf(stream, "Incremental\n");
             break;
 
         case H5D_ALLOC_TIME_DEFAULT:
         case H5D_ALLOC_TIME_ERROR:
         default:
-            HDfprintf(stream, "Unknown!\n");
+            fprintf(stream, "Unknown!\n");
             break;
     } /* end switch */
-    HDfprintf(stream, "%*s%-*s ", indent, "", fwidth, "Fill Time:");
+    fprintf(stream, "%*s%-*s ", indent, "", fwidth, "Fill Time:");
     switch (fill->fill_time) {
         case H5D_FILL_TIME_ALLOC:
-            HDfprintf(stream, "On Allocation\n");
+            fprintf(stream, "On Allocation\n");
             break;
 
         case H5D_FILL_TIME_NEVER:
-            HDfprintf(stream, "Never\n");
+            fprintf(stream, "Never\n");
             break;
 
         case H5D_FILL_TIME_IFSET:
-            HDfprintf(stream, "If Set\n");
+            fprintf(stream, "If Set\n");
             break;
 
         case H5D_FILL_TIME_ERROR:
         default:
-            HDfprintf(stream, "Unknown!\n");
+            fprintf(stream, "Unknown!\n");
             break;
 
     } /* end switch */
-    HDfprintf(stream, "%*s%-*s ", indent, "", fwidth, "Fill Value Defined:");
+    fprintf(stream, "%*s%-*s ", indent, "", fwidth, "Fill Value Defined:");
     H5P_is_fill_value_defined((const H5O_fill_t *)fill, &fill_status);
     switch (fill_status) {
         case H5D_FILL_VALUE_UNDEFINED:
-            HDfprintf(stream, "Undefined\n");
+            fprintf(stream, "Undefined\n");
             break;
 
         case H5D_FILL_VALUE_DEFAULT:
-            HDfprintf(stream, "Default\n");
+            fprintf(stream, "Default\n");
             break;
 
         case H5D_FILL_VALUE_USER_DEFINED:
-            HDfprintf(stream, "User Defined\n");
+            fprintf(stream, "User Defined\n");
             break;
 
         case H5D_FILL_VALUE_ERROR:
         default:
-            HDfprintf(stream, "Unknown!\n");
+            fprintf(stream, "Unknown!\n");
             break;
 
     } /* end switch */
-    HDfprintf(stream, "%*s%-*s %zd\n", indent, "", fwidth, "Size:", fill->size);
-    HDfprintf(stream, "%*s%-*s ", indent, "", fwidth, "Data type:");
+    fprintf(stream, "%*s%-*s %zd\n", indent, "", fwidth, "Size:", fill->size);
+    fprintf(stream, "%*s%-*s ", indent, "", fwidth, "Data type:");
     if (fill->type) {
         H5T_debug(fill->type, stream);
-        HDfprintf(stream, "\n");
+        fprintf(stream, "\n");
     } /* end if */
     else
-        HDfprintf(stream, "<dataset type>\n");
+        fprintf(stream, "<dataset type>\n");
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__fill_debug() */
@@ -980,9 +951,6 @@ H5O__fill_debug(H5F_t H5_ATTR_UNUSED *f, const void *_fill, FILE *stream, int in
  *
  * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:    Robb Matzke
- *              Thursday, October  1, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -995,9 +963,9 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed)
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(fill);
-    HDassert(dset_type);
-    HDassert(fill_changed);
+    assert(fill);
+    assert(dset_type);
+    assert(fill_changed);
 
     /* No-op cases */
     if (!fill->buf || !fill->type || 0 == H5T_cmp(fill->type, dset_type, FALSE)) {
@@ -1016,7 +984,7 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed)
      * Can we convert between source and destination data types?
      */
     if (NULL == (tpath = H5T_path_find(fill->type, dset_type)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between src and dst datatypes")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between src and dst datatypes");
 
     /* Don't bother doing anything if there will be no actual conversion */
     if (!H5T_path_noop(tpath)) {
@@ -1024,7 +992,7 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed)
 
         if ((src_id = H5I_register(H5I_DATATYPE, H5T_copy(fill->type, H5T_COPY_ALL), FALSE)) < 0 ||
             (dst_id = H5I_register(H5I_DATATYPE, H5T_copy(dset_type, H5T_COPY_ALL), FALSE)) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy/register data type")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy/register data type");
 
         /*
          * Datatype conversions are always done in place, so we need a buffer
@@ -1033,17 +1001,17 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed)
         fill_type_size = H5T_get_size(fill->type);
 
         if (NULL == (buf = H5MM_malloc(MAX(fill_type_size, H5T_get_size(dset_type)))))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for type conversion")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for type conversion");
         H5MM_memcpy(buf, fill->buf, fill_type_size);
 
         /* Use CALLOC here to clear the buffer in case later the library thinks there's
          * data in the background. */
         if (H5T_path_bkg(tpath) && NULL == (bkg = H5MM_calloc(H5T_get_size(dset_type))))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for type conversion")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for type conversion");
 
         /* Do the conversion */
         if (H5T_convert(tpath, src_id, dst_id, (size_t)1, (size_t)0, (size_t)0, buf, bkg) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "datatype conversion failed")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "datatype conversion failed");
 
         /* Update the fill message */
         H5T_vlen_reclaim_elmt(fill->buf, fill->type);
@@ -1060,9 +1028,9 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed)
 
 done:
     if (src_id >= 0 && H5I_dec_ref(src_id) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement ref count for temp ID")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement ref count for temp ID");
     if (dst_id >= 0 && H5I_dec_ref(dst_id) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement ref count for temp ID")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "unable to decrement ref count for temp ID");
     if (bkg)
         H5MM_xfree(bkg);
 
@@ -1076,8 +1044,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Vailin Choi; December 2017
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1089,15 +1055,15 @@ H5O_fill_set_version(H5F_t *f, H5O_fill_t *fill)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(f);
-    HDassert(fill);
+    assert(f);
+    assert(fill);
 
     /* Upgrade to the version indicated by the file's low bound if higher */
     version = MAX(fill->version, H5O_fill_ver_bounds[H5F_LOW_BOUND(f)]);
 
     /* Version bounds check */
     if (version > H5O_fill_ver_bounds[H5F_HIGH_BOUND(f)])
-        HGOTO_ERROR(H5E_OHDR, H5E_BADRANGE, FAIL, "Filter pipeline version out of bounds")
+        HGOTO_ERROR(H5E_OHDR, H5E_BADRANGE, FAIL, "Filter pipeline version out of bounds");
 
     /* Set the message version */
     fill->version = version;
