@@ -91,35 +91,35 @@ H5O__ginfo_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh, unsign
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(f);
-    HDassert(p);
+    assert(f);
+    assert(p);
 
     /* Version of message */
     if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
-        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
     if (*p++ != H5O_GINFO_VERSION)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message");
 
     /* Allocate space for message */
     if (NULL == (ginfo = H5FL_CALLOC(H5O_ginfo_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* Get the flags for the group */
     if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
-        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
 
     flags = *p++;
     if (flags & ~H5O_GINFO_ALL_FLAGS)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad flag value for message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad flag value for message");
     ginfo->store_link_phase_change = (flags & H5O_GINFO_STORE_PHASE_CHANGE) ? TRUE : FALSE;
     ginfo->store_est_entry_info    = (flags & H5O_GINFO_STORE_EST_ENTRY_INFO) ? TRUE : FALSE;
 
     /* Get the max. # of links to store compactly & the min. # of links to store densely */
     if (ginfo->store_link_phase_change) {
         if (H5_IS_BUFFER_OVERFLOW(p, 2 * 2, p_end))
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
-        UINT16DECODE(p, ginfo->max_compact)
-        UINT16DECODE(p, ginfo->min_dense)
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
+        UINT16DECODE(p, ginfo->max_compact);
+        UINT16DECODE(p, ginfo->min_dense);
     }
     else {
         ginfo->max_compact = H5G_CRT_GINFO_MAX_COMPACT;
@@ -129,9 +129,9 @@ H5O__ginfo_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh, unsign
     /* Get the estimated # of entries & name lengths */
     if (ginfo->store_est_entry_info) {
         if (H5_IS_BUFFER_OVERFLOW(p, 2 * 2, p_end))
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
-        UINT16DECODE(p, ginfo->est_num_entries)
-        UINT16DECODE(p, ginfo->est_name_len)
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
+        UINT16DECODE(p, ginfo->est_num_entries);
+        UINT16DECODE(p, ginfo->est_name_len);
     }
     else {
         ginfo->est_num_entries = H5G_CRT_GINFO_EST_NUM_ENTRIES;
@@ -155,9 +155,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Aug 30 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -170,8 +167,8 @@ H5O__ginfo_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(p);
-    HDassert(ginfo);
+    assert(p);
+    assert(ginfo);
 
     /* Message version */
     *p++ = H5O_GINFO_VERSION;
@@ -183,14 +180,14 @@ H5O__ginfo_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared
 
     /* Store the max. # of links to store compactly & the min. # of links to store densely */
     if (ginfo->store_link_phase_change) {
-        UINT16ENCODE(p, ginfo->max_compact)
-        UINT16ENCODE(p, ginfo->min_dense)
+        UINT16ENCODE(p, ginfo->max_compact);
+        UINT16ENCODE(p, ginfo->min_dense);
     } /* end if */
 
     /* Estimated # of entries & name lengths */
     if (ginfo->store_est_entry_info) {
-        UINT16ENCODE(p, ginfo->est_num_entries)
-        UINT16ENCODE(p, ginfo->est_name_len)
+        UINT16ENCODE(p, ginfo->est_num_entries);
+        UINT16ENCODE(p, ginfo->est_name_len);
     } /* end if */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
@@ -206,9 +203,6 @@ H5O__ginfo_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared
  *
  *              Failure:        NULL
  *
- * Programmer:  Quincey Koziol
- *              Aug 30 2005
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -221,9 +215,9 @@ H5O__ginfo_copy(const void *_mesg, void *_dest)
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(ginfo);
+    assert(ginfo);
     if (!dest && NULL == (dest = H5FL_MALLOC(H5O_ginfo_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* copy */
     *dest = *ginfo;
@@ -246,9 +240,6 @@ done:
  *
  *              Failure:        zero
  *
- * Programmer:  Quincey Koziol
- *              Aug 30 2005
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -281,9 +272,6 @@ H5O__ginfo_size(const H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_sh
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, August 30, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -291,7 +279,7 @@ H5O__ginfo_free(void *mesg)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(mesg);
+    assert(mesg);
 
     mesg = H5FL_FREE(H5O_ginfo_t, mesg);
 
@@ -305,9 +293,6 @@ H5O__ginfo_free(void *mesg)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Aug 30 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -318,18 +303,18 @@ H5O__ginfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int i
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(ginfo);
-    HDassert(stream);
-    HDassert(indent >= 0);
-    HDassert(fwidth >= 0);
+    assert(f);
+    assert(ginfo);
+    assert(stream);
+    assert(indent >= 0);
+    assert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth, "Max. compact links:", ginfo->max_compact);
-    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth, "Min. dense links:", ginfo->min_dense);
-    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth,
-              "Estimated # of objects in group:", ginfo->est_num_entries);
-    HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth,
-              "Estimated length of object in group's name:", ginfo->est_name_len);
+    fprintf(stream, "%*s%-*s %u\n", indent, "", fwidth, "Max. compact links:", ginfo->max_compact);
+    fprintf(stream, "%*s%-*s %u\n", indent, "", fwidth, "Min. dense links:", ginfo->min_dense);
+    fprintf(stream, "%*s%-*s %u\n", indent, "", fwidth,
+            "Estimated # of objects in group:", ginfo->est_num_entries);
+    fprintf(stream, "%*s%-*s %u\n", indent, "", fwidth,
+            "Estimated length of object in group's name:", ginfo->est_name_len);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__ginfo_debug() */
