@@ -109,25 +109,25 @@ H5O__linfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUS
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(f);
-    HDassert(p);
+    assert(f);
+    assert(p);
 
     /* Check input buffer before decoding version and index flags */
     if (H5_IS_BUFFER_OVERFLOW(p, 2, p_end))
-        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
 
     /* Version of message */
     if (*p++ != H5O_LINFO_VERSION)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message");
 
     /* Allocate space for message */
     if (NULL == (linfo = H5FL_MALLOC(H5O_linfo_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* Get the index flags for the group */
     index_flags = *p++;
     if (index_flags & ~H5O_LINFO_ALL_FLAGS)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad flag value for message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad flag value for message");
     linfo->track_corder = (index_flags & H5O_LINFO_TRACK_CORDER) ? TRUE : FALSE;
     linfo->index_corder = (index_flags & H5O_LINFO_INDEX_CORDER) ? TRUE : FALSE;
 
@@ -137,15 +137,15 @@ H5O__linfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUS
     /* Max. link creation order value for the group, if tracked */
     if (linfo->track_corder) {
         if (H5_IS_BUFFER_OVERFLOW(p, 8, p_end))
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
-        INT64DECODE(p, linfo->max_corder)
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
+        INT64DECODE(p, linfo->max_corder);
     }
     else
         linfo->max_corder = 0;
 
     /* Check input buffer before decoding the next two addresses */
     if (H5_IS_BUFFER_OVERFLOW(p, addr_size + addr_size, p_end))
-        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
 
     /* Address of fractal heap to store "dense" links */
     H5F_addr_decode(f, &p, &(linfo->fheap_addr));
@@ -156,7 +156,7 @@ H5O__linfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUS
     /* Address of v2 B-tree to index creation order of links, if there is one */
     if (linfo->index_corder) {
         if (H5_IS_BUFFER_OVERFLOW(p, addr_size, p_end))
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
         H5F_addr_decode(f, &p, &(linfo->corder_bt2_addr));
     }
     else
@@ -180,9 +180,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Aug 23 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -194,9 +191,9 @@ H5O__linfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, c
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(p);
-    HDassert(linfo);
+    assert(f);
+    assert(p);
+    assert(linfo);
 
     /* Message version */
     *p++ = H5O_LINFO_VERSION;
@@ -208,7 +205,7 @@ H5O__linfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, c
 
     /* Max. link creation order value for the group, if tracked */
     if (linfo->track_corder)
-        INT64ENCODE(p, linfo->max_corder)
+        INT64ENCODE(p, linfo->max_corder);
 
     /* Address of fractal heap to store "dense" links */
     H5F_addr_encode(f, &p, linfo->fheap_addr);
@@ -220,7 +217,7 @@ H5O__linfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, c
     if (linfo->index_corder)
         H5F_addr_encode(f, &p, linfo->corder_bt2_addr);
     else
-        HDassert(!H5F_addr_defined(linfo->corder_bt2_addr));
+        assert(!H5_addr_defined(linfo->corder_bt2_addr));
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__linfo_encode() */
@@ -234,9 +231,6 @@ H5O__linfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, c
  * Return:      Success:        Ptr to _DEST
  *              Failure:        NULL
  *
- * Programmer:  Quincey Koziol
- *              Aug 23 2005
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -249,9 +243,9 @@ H5O__linfo_copy(const void *_mesg, void *_dest)
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(linfo);
+    assert(linfo);
     if (!dest && NULL == (dest = H5FL_MALLOC(H5O_linfo_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* copy */
     *dest = *linfo;
@@ -273,9 +267,6 @@ done:
  * Return:      Success:        Message data size in bytes without alignment.
  *              Failure:        zero
  *
- * Programmer:  Quincey Koziol
- *              Aug 23 2005
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -306,9 +297,6 @@ H5O__linfo_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const voi
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, August 23, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -316,7 +304,7 @@ H5O__linfo_free(void *mesg)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(mesg);
+    assert(mesg);
 
     mesg = H5FL_FREE(H5O_linfo_t, mesg);
 
@@ -330,9 +318,6 @@ H5O__linfo_free(void *mesg)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Saturday, September 16, 2006
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -344,13 +329,13 @@ H5O__linfo_delete(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, void *_mesg)
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(f);
-    HDassert(linfo);
+    assert(f);
+    assert(linfo);
 
     /* If the group is using "dense" link storage, delete it */
-    if (H5F_addr_defined(linfo->fheap_addr))
+    if (H5_addr_defined(linfo->fheap_addr))
         if (H5G__dense_delete(f, linfo, TRUE) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "unable to free dense link storage")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "unable to free dense link storage");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -365,9 +350,6 @@ done:
  *
  *              Failure:        NULL
  *
- * Programmer:  Quincey Koziol
- *              June 26, 2006
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -383,12 +365,12 @@ H5O__linfo_copy_file(H5F_t H5_ATTR_UNUSED *file_src, void *native_src, H5F_t *fi
     FUNC_ENTER_PACKAGE_TAG(H5AC__COPIED_TAG)
 
     /* check args */
-    HDassert(linfo_src);
-    HDassert(cpy_info);
+    assert(linfo_src);
+    assert(cpy_info);
 
     /* Copy the source message */
     if (NULL == (linfo_dst = (H5O_linfo_t *)H5O__linfo_copy(linfo_src, NULL)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, NULL, "memory allocation failed");
 
     /* If we are performing a 'shallow hierarchy' copy, and the links in this
      *  group won't be included in the destination, reset the link info for
@@ -406,10 +388,10 @@ H5O__linfo_copy_file(H5F_t H5_ATTR_UNUSED *file_src, void *native_src, H5F_t *fi
         /* (XXX: should probably get the "creation" parameters for the source group's
          *      dense link storage components and use those - QAK)
          */
-        if (H5F_addr_defined(linfo_src->fheap_addr)) {
+        if (H5_addr_defined(linfo_src->fheap_addr)) {
             /* Create the dense link storage */
             if (H5G__dense_create(file_dst, linfo_dst, udata->common.src_pline) < 0)
-                HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, NULL, "unable to create 'dense' form of new format group")
+                HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, NULL, "unable to create 'dense' form of new format group");
         } /* end if */
     }     /* end else */
 
@@ -433,9 +415,6 @@ done:
  * Return:	Success:        Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *		Sept 26 2006
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -449,21 +428,21 @@ H5O__linfo_post_copy_file_cb(const H5O_link_t *src_lnk, void *_udata)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(src_lnk);
-    HDassert(udata);
+    assert(src_lnk);
+    assert(udata);
 
     /* Copy the link (and the object it points to) */
     if (H5L__link_copy_file(udata->dst_oloc->file, src_lnk, udata->src_oloc, &dst_lnk, udata->cpy_info) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, H5_ITER_ERROR, "unable to copy link")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, H5_ITER_ERROR, "unable to copy link");
     dst_lnk_init = TRUE;
 
     /* Set metadata tag in API context */
-    H5_BEGIN_TAG(H5AC__COPIED_TAG);
+    H5_BEGIN_TAG(H5AC__COPIED_TAG)
 
     /* Insert the new object in the destination file's group */
     /* (Doesn't increment the link count - that's already been taken care of for hard links) */
     if (H5G__dense_insert(udata->dst_oloc->file, udata->dst_linfo, &dst_lnk) < 0)
-        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTINSERT, H5_ITER_ERROR, "unable to insert destination link")
+        HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTINSERT, H5_ITER_ERROR, "unable to insert destination link");
 
     /* Reset metadata tag in API context */
     H5_END_TAG
@@ -483,9 +462,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              September 26, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -499,19 +475,19 @@ H5O__linfo_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_l
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(src_oloc && src_oloc->file);
-    HDassert(linfo_src);
-    HDassert(dst_oloc && dst_oloc->file);
-    HDassert(H5F_addr_defined(dst_oloc->addr));
-    HDassert(linfo_dst);
-    HDassert(cpy_info);
+    assert(src_oloc && src_oloc->file);
+    assert(linfo_src);
+    assert(dst_oloc && dst_oloc->file);
+    assert(H5_addr_defined(dst_oloc->addr));
+    assert(linfo_dst);
+    assert(cpy_info);
 
     /* If we are performing a 'shallow hierarchy' copy, get out now */
     if (cpy_info->max_depth >= 0 && cpy_info->curr_depth >= cpy_info->max_depth)
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
 
     /* Check for copying dense link storage */
-    if (H5F_addr_defined(linfo_src->fheap_addr)) {
+    if (H5_addr_defined(linfo_src->fheap_addr)) {
         H5O_linfo_postcopy_ud_t udata; /* User data for iteration callback */
 
         /* Set up dense link iteration user data */
@@ -523,7 +499,7 @@ H5O__linfo_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_l
         /* Iterate over the links in the group, building a table of the link messages */
         if (H5G__dense_iterate(src_oloc->file, linfo_src, H5_INDEX_NAME, H5_ITER_NATIVE, (hsize_t)0, NULL,
                                H5O__linfo_post_copy_file_cb, &udata) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTNEXT, FAIL, "error iterating over links")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTNEXT, FAIL, "error iterating over links");
     } /* end if */
 
 done:
@@ -537,9 +513,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Aug 23 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -550,25 +523,25 @@ H5O__linfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int i
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(linfo);
-    HDassert(stream);
-    HDassert(indent >= 0);
-    HDassert(fwidth >= 0);
+    assert(f);
+    assert(linfo);
+    assert(stream);
+    assert(indent >= 0);
+    assert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
-              "Track creation order of links:", linfo->track_corder ? "TRUE" : "FALSE");
-    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
-              "Index creation order of links:", linfo->index_corder ? "TRUE" : "FALSE");
-    HDfprintf(stream, "%*s%-*s %" PRIuHSIZE "\n", indent, "", fwidth, "Number of links:", linfo->nlinks);
-    HDfprintf(stream, "%*s%-*s %" PRId64 "\n", indent, "", fwidth,
-              "Max. creation order value:", linfo->max_corder);
-    HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
-              "'Dense' link storage fractal heap address:", linfo->fheap_addr);
-    HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
-              "'Dense' link storage name index v2 B-tree address:", linfo->name_bt2_addr);
-    HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
-              "'Dense' link storage creation order index v2 B-tree address:", linfo->corder_bt2_addr);
+    fprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
+            "Track creation order of links:", linfo->track_corder ? "TRUE" : "FALSE");
+    fprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
+            "Index creation order of links:", linfo->index_corder ? "TRUE" : "FALSE");
+    fprintf(stream, "%*s%-*s %" PRIuHSIZE "\n", indent, "", fwidth, "Number of links:", linfo->nlinks);
+    fprintf(stream, "%*s%-*s %" PRId64 "\n", indent, "", fwidth,
+            "Max. creation order value:", linfo->max_corder);
+    fprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
+            "'Dense' link storage fractal heap address:", linfo->fheap_addr);
+    fprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
+            "'Dense' link storage name index v2 B-tree address:", linfo->name_bt2_addr);
+    fprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
+            "'Dense' link storage creation order index v2 B-tree address:", linfo->corder_bt2_addr);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__linfo_debug() */
