@@ -114,33 +114,33 @@ H5O__link_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(f);
-    HDassert(p);
+    assert(f);
+    assert(p);
 
     if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
-        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
     if (*p++ != H5O_LINK_VERSION)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message");
 
     /* Allocate space for message */
     if (NULL == (lnk = H5FL_CALLOC(H5O_link_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* Get the encoding flags for the link */
     if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
-        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
     link_flags = *p++;
     if (link_flags & ~H5O_LINK_ALL_FLAGS)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad flag value for message")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad flag value for message");
 
     /* Check for non-default link type */
     if (link_flags & H5O_LINK_STORE_LINK_TYPE) {
         /* Get the type of the link */
         if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
         lnk->type = (H5L_type_t)*p++;
         if (lnk->type < H5L_TYPE_HARD || lnk->type > H5L_TYPE_MAX)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad link type")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad link type");
     }
     else
         lnk->type = H5L_TYPE_HARD;
@@ -148,8 +148,8 @@ H5O__link_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
     /* Get the link creation time from the file */
     if (link_flags & H5O_LINK_STORE_CORDER) {
         if (H5_IS_BUFFER_OVERFLOW(p, 8, p_end))
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
-        INT64DECODE(p, lnk->corder)
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
+        INT64DECODE(p, lnk->corder);
         lnk->corder_valid = TRUE;
     }
     else {
@@ -161,10 +161,10 @@ H5O__link_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
     if (link_flags & H5O_LINK_STORE_NAME_CSET) {
         /* Get the link name's character set */
         if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
-            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+            HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
         lnk->cset = (H5T_cset_t)*p++;
         if (lnk->cset < H5T_CSET_ASCII || lnk->cset > H5T_CSET_UTF8)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad cset type")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad cset type");
     }
     else
         lnk->cset = H5T_CSET_ASCII;
@@ -173,39 +173,39 @@ H5O__link_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
     switch (link_flags & H5O_LINK_NAME_SIZE) {
         case 0: /* 1 byte size */
             if (H5_IS_BUFFER_OVERFLOW(p, 1, p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
             len = *p++;
             break;
 
         case 1: /* 2 byte size */
             if (H5_IS_BUFFER_OVERFLOW(p, 2, p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
             UINT16DECODE(p, len);
             break;
 
         case 2: /* 4 byte size */
             if (H5_IS_BUFFER_OVERFLOW(p, 4, p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
             UINT32DECODE(p, len);
             break;
 
         case 3: /* 8 byte size */
             if (H5_IS_BUFFER_OVERFLOW(p, 8, p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
             UINT64DECODE(p, len);
             break;
 
         default:
-            HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, NULL, "no appropriate size for name length")
+            HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, NULL, "no appropriate size for name length");
     }
     if (len == 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "invalid name length")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "invalid name length");
 
     /* Get the link's name */
     if (H5_IS_BUFFER_OVERFLOW(p, len, p_end))
-        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
     if (NULL == (lnk->name = (char *)H5MM_malloc(len + 1)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
     H5MM_memcpy(lnk->name, p, len);
     lnk->name[len] = '\0';
     p += len;
@@ -215,22 +215,22 @@ H5O__link_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
         case H5L_TYPE_HARD:
             /* Get the address of the object the link points to */
             if (H5_IS_BUFFER_OVERFLOW(p, H5F_sizeof_addr(f), p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
             H5F_addr_decode(f, &p, &(lnk->u.hard.addr));
             break;
 
         case H5L_TYPE_SOFT:
             /* Get the link value */
             if (H5_IS_BUFFER_OVERFLOW(p, 2, p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
-            UINT16DECODE(p, len)
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
+            UINT16DECODE(p, len);
             if (len == 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "invalid link length")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "invalid link length");
 
             if (H5_IS_BUFFER_OVERFLOW(p, len, p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
             if (NULL == (lnk->u.soft.name = (char *)H5MM_malloc((size_t)len + 1)))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
             H5MM_memcpy(lnk->u.soft.name, p, len);
             lnk->u.soft.name[len] = '\0';
             p += len;
@@ -242,20 +242,20 @@ H5O__link_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
         case H5L_TYPE_MAX:
         default:
             if (lnk->type < H5L_TYPE_UD_MIN || lnk->type > H5L_TYPE_MAX)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "unknown link type")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "unknown link type");
 
             /* A UD link.  Get the user-supplied data */
             if (H5_IS_BUFFER_OVERFLOW(p, 2, p_end))
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
-            UINT16DECODE(p, len)
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
+            UINT16DECODE(p, len);
             if (lnk->type == H5L_TYPE_EXTERNAL && len < 3)
-                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "external link information length < 3")
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "external link information length < 3");
             lnk->u.ud.size = len;
             if (len > 0) {
                 if (H5_IS_BUFFER_OVERFLOW(p, len, p_end))
-                    HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding")
+                    HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, NULL, "ran off end of input buffer while decoding");
                 if (NULL == (lnk->u.ud.udata = H5MM_malloc((size_t)len)))
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
                 H5MM_memcpy(lnk->u.ud.udata, p, len);
                 p += len;
             }
@@ -286,9 +286,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Aug 29 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -301,13 +298,13 @@ H5O__link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(p);
-    HDassert(lnk);
+    assert(f);
+    assert(p);
+    assert(lnk);
 
     /* Get length of link's name */
     len = (uint64_t)HDstrlen(lnk->name);
-    HDassert(len > 0);
+    assert(len > 0);
 
     /* encode */
     *p++ = H5O_LINK_VERSION;
@@ -332,7 +329,7 @@ H5O__link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
 
     /* Store the link creation order in the file, if its valid */
     if (lnk->corder_valid)
-        INT64ENCODE(p, lnk->corder)
+        INT64ENCODE(p, lnk->corder);
 
     /* Store a non-default link name character set */
     if (link_flags & H5O_LINK_STORE_NAME_CSET)
@@ -357,7 +354,7 @@ H5O__link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
             break;
 
         default:
-            HDassert(0 && "bad size for name");
+            assert(0 && "bad size for name");
     } /* end switch */
 
     /* Store the link's name */
@@ -374,8 +371,8 @@ H5O__link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
         case H5L_TYPE_SOFT:
             /* Store the link value */
             len = (uint16_t)HDstrlen(lnk->u.soft.name);
-            HDassert(len > 0);
-            UINT16ENCODE(p, len)
+            assert(len > 0);
+            UINT16ENCODE(p, len);
             H5MM_memcpy(p, lnk->u.soft.name, (size_t)len);
             p += len;
             break;
@@ -385,11 +382,11 @@ H5O__link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
         case H5L_TYPE_ERROR:
         case H5L_TYPE_MAX:
         default:
-            HDassert(lnk->type >= H5L_TYPE_UD_MIN && lnk->type <= H5L_TYPE_MAX);
+            assert(lnk->type >= H5L_TYPE_UD_MIN && lnk->type <= H5L_TYPE_MAX);
 
             /* Store the user-supplied data, however long it is */
             len = (uint16_t)lnk->u.ud.size;
-            UINT16ENCODE(p, len)
+            UINT16ENCODE(p, len);
             if (len > 0) {
                 H5MM_memcpy(p, lnk->u.ud.udata, (size_t)len);
                 p += len;
@@ -410,9 +407,6 @@ H5O__link_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
  *
  *              Failure:        NULL
  *
- * Programmer:  Quincey Koziol
- *              Aug 29 2005
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -425,27 +419,27 @@ H5O__link_copy(const void *_mesg, void *_dest)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(lnk);
+    assert(lnk);
     if (!dest && NULL == (dest = H5FL_MALLOC(H5O_link_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* Copy static information */
     *dest = *lnk;
 
     /* Duplicate the link's name */
-    HDassert(lnk->name);
+    assert(lnk->name);
     if (NULL == (dest->name = H5MM_xstrdup(lnk->name)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "can't duplicate link name")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "can't duplicate link name");
 
     /* Copy other information needed for different link types */
     if (lnk->type == H5L_TYPE_SOFT) {
         if (NULL == (dest->u.soft.name = H5MM_xstrdup(lnk->u.soft.name)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "can't duplicate soft link value")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "can't duplicate soft link value");
     } /* end if */
     else if (lnk->type >= H5L_TYPE_UD_MIN) {
         if (lnk->u.ud.size > 0) {
             if (NULL == (dest->u.ud.udata = H5MM_malloc(lnk->u.ud.size)))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
             H5MM_memcpy(dest->u.ud.udata, lnk->u.ud.udata, lnk->u.ud.size);
         } /* end if */
     }     /* end if */
@@ -476,9 +470,6 @@ done:
  *
  *              Failure:        zero
  *
- * Programmer:  Quincey Koziol
- *              Aug 29 2005
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -531,7 +522,7 @@ H5O__link_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void
         case H5L_TYPE_EXTERNAL:
         case H5L_TYPE_MAX:
         default: /* Default is user-defined link type */
-            HDassert(lnk->type >= H5L_TYPE_UD_MIN);
+            assert(lnk->type >= H5L_TYPE_UD_MIN);
             ret_value += 2 +             /* User-defined data size */
                          lnk->u.ud.size; /* User-defined data */
             break;
@@ -548,9 +539,6 @@ H5O__link_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Monday, August 29, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -581,9 +569,6 @@ H5O__link_reset(void *_mesg)
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Monday, August 29, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -593,7 +578,7 @@ H5O__link_free(void *_mesg)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(lnk);
+    assert(lnk);
 
     lnk = H5FL_FREE(H5O_link_t, lnk);
 
@@ -607,9 +592,6 @@ H5O__link_free(void *_mesg)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Monday, August 29, 2005
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -622,8 +604,8 @@ H5O_link_delete(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, void *_mesg)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* check args */
-    HDassert(f);
-    HDassert(lnk);
+    assert(f);
+    assert(lnk);
 
     /* Check for adjusting the link count when the link is removed */
     /* Adjust the reference count of the object when a hard link is removed */
@@ -633,12 +615,12 @@ H5O_link_delete(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, void *_mesg)
         /* Construct object location for object, in order to decrement it's ref count */
         H5O_loc_reset(&oloc);
         oloc.file = f;
-        HDassert(H5F_addr_defined(lnk->u.hard.addr));
+        assert(H5_addr_defined(lnk->u.hard.addr));
         oloc.addr = lnk->u.hard.addr;
 
         /* Decrement the ref count for the object */
         if (H5O_link(&oloc, -1) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "unable to decrement object link count")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "unable to decrement object link count");
     } /* end if */
     /* Perform the "delete" callback when a user-defined link is removed */
     else if (lnk->type >= H5L_TYPE_UD_MIN) {
@@ -646,24 +628,24 @@ H5O_link_delete(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, void *_mesg)
 
         /* Get the link class for this type of link. */
         if (NULL == (link_class = H5L_find_class(lnk->type)))
-            HGOTO_ERROR(H5E_OHDR, H5E_NOTREGISTERED, FAIL, "link class not registered")
+            HGOTO_ERROR(H5E_OHDR, H5E_NOTREGISTERED, FAIL, "link class not registered");
 
         /* Check for delete callback */
         if (link_class->del_func) {
             /* Get a file ID for the file the link is in */
             if ((file_id = H5F_get_id(f)) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to get file ID")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to get file ID");
 
             /* Call user-defined link's 'delete' callback */
             if ((link_class->del_func)(lnk->name, file_id, lnk->u.ud.udata, lnk->u.ud.size) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CALLBACK, FAIL, "link deletion callback returned failure")
+                HGOTO_ERROR(H5E_OHDR, H5E_CALLBACK, FAIL, "link deletion callback returned failure");
         } /* end if */
     }     /* end if */
 
 done:
     /* Release the file ID */
     if (file_id > 0 && H5I_dec_ref(file_id) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEFILE, FAIL, "can't close file")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTCLOSEFILE, FAIL, "can't close file");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_link_delete() */
@@ -678,9 +660,6 @@ done:
  *
  *              Failure:        Negative
  *
- * Programmer:  Quincey Koziol
- *              Monday, June 26, 2006
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -690,8 +669,8 @@ H5O__link_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSE
     FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(deleted);
-    HDassert(cpy_info);
+    assert(deleted);
+    assert(cpy_info);
 
     /* If we are performing a 'shallow hierarchy' copy, and this link won't
      *  be included in the final group, indicate that it should be deleted
@@ -713,9 +692,6 @@ H5O__link_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSE
  *
  *              Failure:        NULL
  *
- * Programmer:  Quincey Koziol
- *              November  7, 2005
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -729,18 +705,18 @@ H5O__link_copy_file(H5F_t H5_ATTR_UNUSED *file_src, void *native_src, H5F_t H5_A
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(link_src);
-    HDassert(cpy_info);
-    HDassert(cpy_info->max_depth < 0 || cpy_info->curr_depth < cpy_info->max_depth);
+    assert(link_src);
+    assert(cpy_info);
+    assert(cpy_info->max_depth < 0 || cpy_info->curr_depth < cpy_info->max_depth);
 
     /* Sanity check source link type */
     if (link_src->type > H5L_TYPE_SOFT && link_src->type < H5L_TYPE_UD_MIN)
-        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, NULL, "unrecognized built-in link type")
+        HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, NULL, "unrecognized built-in link type");
 
     /* Allocate "blank" link for destination */
     /* (values will be filled in during 'post copy' operation) */
     if (NULL == (ret_value = H5FL_CALLOC(H5O_link_t)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -753,9 +729,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              November  7, 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -769,17 +742,17 @@ H5O__link_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_lo
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(link_src);
-    HDassert(dst_oloc);
-    HDassert(H5F_addr_defined(dst_oloc->addr));
-    HDassert(dst_oloc->file);
-    HDassert(link_dst);
-    HDassert(cpy_info);
-    HDassert(cpy_info->max_depth < 0 || cpy_info->curr_depth < cpy_info->max_depth);
+    assert(link_src);
+    assert(dst_oloc);
+    assert(H5_addr_defined(dst_oloc->addr));
+    assert(dst_oloc->file);
+    assert(link_dst);
+    assert(cpy_info);
+    assert(cpy_info->max_depth < 0 || cpy_info->curr_depth < cpy_info->max_depth);
 
     /* Copy the link (and the object it points to) */
     if (H5L__link_copy_file(dst_oloc->file, link_src, src_oloc, link_dst, cpy_info) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy link")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy link");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -792,9 +765,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Aug 29 2005
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -806,37 +776,37 @@ H5O__link_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int in
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(f);
-    HDassert(lnk);
-    HDassert(stream);
-    HDassert(indent >= 0);
-    HDassert(fwidth >= 0);
+    assert(f);
+    assert(lnk);
+    assert(stream);
+    assert(indent >= 0);
+    assert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth, "Link Type:",
-              (lnk->type == H5L_TYPE_HARD
-                   ? "Hard"
-                   : (lnk->type == H5L_TYPE_SOFT
-                          ? "Soft"
-                          : (lnk->type == H5L_TYPE_EXTERNAL
-                                 ? "External"
-                                 : (lnk->type >= H5L_TYPE_UD_MIN ? "User-defined" : "Unknown")))));
+    fprintf(stream, "%*s%-*s %s\n", indent, "", fwidth, "Link Type:",
+            (lnk->type == H5L_TYPE_HARD
+                 ? "Hard"
+                 : (lnk->type == H5L_TYPE_SOFT
+                        ? "Soft"
+                        : (lnk->type == H5L_TYPE_EXTERNAL
+                               ? "External"
+                               : (lnk->type >= H5L_TYPE_UD_MIN ? "User-defined" : "Unknown")))));
 
     if (lnk->corder_valid)
-        HDfprintf(stream, "%*s%-*s %" PRId64 "\n", indent, "", fwidth, "Creation Order:", lnk->corder);
+        fprintf(stream, "%*s%-*s %" PRId64 "\n", indent, "", fwidth, "Creation Order:", lnk->corder);
 
-    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth, "Link Name Character Set:",
-              (lnk->cset == H5T_CSET_ASCII ? "ASCII" : (lnk->cset == H5T_CSET_UTF8 ? "UTF-8" : "Unknown")));
-    HDfprintf(stream, "%*s%-*s '%s'\n", indent, "", fwidth, "Link Name:", lnk->name);
+    fprintf(stream, "%*s%-*s %s\n", indent, "", fwidth, "Link Name Character Set:",
+            (lnk->cset == H5T_CSET_ASCII ? "ASCII" : (lnk->cset == H5T_CSET_UTF8 ? "UTF-8" : "Unknown")));
+    fprintf(stream, "%*s%-*s '%s'\n", indent, "", fwidth, "Link Name:", lnk->name);
 
     /* Display link-specific information */
     switch (lnk->type) {
         case H5L_TYPE_HARD:
-            HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
-                      "Object address:", lnk->u.hard.addr);
+            fprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
+                    "Object address:", lnk->u.hard.addr);
             break;
 
         case H5L_TYPE_SOFT:
-            HDfprintf(stream, "%*s%-*s '%s'\n", indent, "", fwidth, "Link Value:", lnk->u.soft.name);
+            fprintf(stream, "%*s%-*s '%s'\n", indent, "", fwidth, "Link Value:", lnk->u.soft.name);
             break;
 
         case H5L_TYPE_ERROR:
@@ -848,17 +818,17 @@ H5O__link_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int in
                     const char *objname =
                         (const char *)lnk->u.ud.udata + (HDstrlen((const char *)lnk->u.ud.udata) + 1);
 
-                    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
-                              "External File Name:", (const char *)lnk->u.ud.udata);
-                    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth, "External Object Name:", objname);
+                    fprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
+                            "External File Name:", (const char *)lnk->u.ud.udata);
+                    fprintf(stream, "%*s%-*s %s\n", indent, "", fwidth, "External Object Name:", objname);
                 } /* end if */
                 else {
-                    HDfprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth,
-                              "User-Defined Link Size:", lnk->u.ud.size);
+                    fprintf(stream, "%*s%-*s %zu\n", indent, "", fwidth,
+                            "User-Defined Link Size:", lnk->u.ud.size);
                 } /* end else */
             }     /* end if */
             else
-                HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "unrecognized link type")
+                HGOTO_ERROR(H5E_SYM, H5E_BADVALUE, FAIL, "unrecognized link type");
             break;
     } /* end switch */
 
