@@ -82,7 +82,7 @@ H5PL__get_plugin_control_mask(unsigned int *mask /*out*/)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args - Just assert on package functions */
-    HDassert(mask);
+    assert(mask);
 
     /* Return the mask */
     *mask = H5PL_plugin_control_mask_g;
@@ -148,11 +148,11 @@ H5PL_init(void)
 
     /* Create the table of previously-loaded plugins */
     if (H5PL__create_plugin_cache() < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINIT, FAIL, "can't create plugin cache")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINIT, FAIL, "can't create plugin cache");
 
     /* Create the table of search paths for dynamic libraries */
     if (H5PL__create_path_table() < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINIT, FAIL, "can't create plugin search path table")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINIT, FAIL, "can't create plugin search path table");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -183,13 +183,13 @@ H5PL_term_package(void)
      * We need to bump the return value if we did any real work here.
      */
     if (H5PL__close_plugin_cache(&already_closed) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing plugin cache")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing plugin cache");
     if (!already_closed)
         ret_value++;
 
     /* Close the search path table and free the paths */
     if (H5PL__close_path_table() < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing search path table")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, (-1), "problem closing search path table");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -223,24 +223,24 @@ H5PL_load(H5PL_type_t type, const H5PL_key_t *key)
     switch (type) {
         case H5PL_TYPE_FILTER:
             if ((H5PL_plugin_control_mask_g & H5PL_FILTER_PLUGIN) == 0)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "filter plugins disabled")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "filter plugins disabled");
             break;
 
         case H5PL_TYPE_VOL:
             if ((H5PL_plugin_control_mask_g & H5PL_VOL_PLUGIN) == 0)
                 HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL,
-                            "Virtual Object Layer (VOL) driver plugins disabled")
+                            "Virtual Object Layer (VOL) driver plugins disabled");
             break;
 
         case H5PL_TYPE_VFD:
             if ((H5PL_plugin_control_mask_g & H5PL_VFD_PLUGIN) == 0)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "Virtual File Driver (VFD) plugins disabled")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "Virtual File Driver (VFD) plugins disabled");
             break;
 
         case H5PL_TYPE_ERROR:
         case H5PL_TYPE_NONE:
         default:
-            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "Invalid plugin type specified")
+            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, NULL, "Invalid plugin type specified");
     }
 
     /* Set up the search parameters */
@@ -249,14 +249,14 @@ H5PL_load(H5PL_type_t type, const H5PL_key_t *key)
 
     /* Search in the table of already loaded plugin libraries */
     if (H5PL__find_plugin_in_cache(&search_params, &found, &plugin_info) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, NULL, "search in plugin cache failed")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, NULL, "search in plugin cache failed");
 
     /* If not found, try iterating through the path table to find an appropriate plugin */
     if (!found)
         if (H5PL__find_plugin_in_path_table(&search_params, &found, &plugin_info) < 0)
             HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, NULL,
                         "can't find plugin in the paths either set by HDF5_PLUGIN_PATH, or default location, "
-                        "or set by H5PLxxx functions")
+                        "or set by H5PLxxx functions");
 
     /* Set the return value we found the plugin */
     if (found)
@@ -264,7 +264,7 @@ H5PL_load(H5PL_type_t type, const H5PL_key_t *key)
     else
         HGOTO_ERROR(H5E_PLUGIN, H5E_NOTFOUND, NULL,
                     "can't find plugin. Check either HDF5_VOL_CONNECTOR, HDF5_PLUGIN_PATH, default location, "
-                    "or path set by H5PLxxx functions")
+                    "or path set by H5PLxxx functions");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -329,11 +329,11 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(path);
+    assert(path);
     if (type == H5PL_TYPE_NONE)
-        HDassert(!key);
-    HDassert(success);
-    HDassert(plugin_info);
+        assert(!key);
+    assert(success);
+    assert(plugin_info);
 
     /* Initialize out parameters */
     *success     = FALSE;
@@ -346,25 +346,25 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
      */
     if (NULL == (handle = H5PL_OPEN_DLIB(path))) {
         H5PL_CLR_ERROR; /* clear error */
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
     }
 
     /* Return a handle for the function H5PLget_plugin_type in the dynamic library.
      * The plugin library is supposed to define this function.
      */
     if (NULL == (get_plugin_type = (H5PL_get_plugin_type_t)H5PL_GET_LIB_FUNC(handle, "H5PLget_plugin_type")))
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
 
     /* Return a handle for the function H5PLget_plugin_info in the dynamic library.
      * The plugin library is supposed to define this function.
      */
     if (NULL == (get_plugin_info = (H5PL_get_plugin_info_t)H5PL_GET_LIB_FUNC(handle, "H5PLget_plugin_info")))
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
 
     /* Check the plugin type and return if it doesn't match the one passed in */
     loaded_plugin_type = (H5PL_type_t)(*get_plugin_type)();
     if ((type != H5PL_TYPE_NONE) && (type != loaded_plugin_type))
-        HGOTO_DONE(SUCCEED)
+        HGOTO_DONE(SUCCEED);
 
     /* Get the plugin information */
     switch (loaded_plugin_type) {
@@ -373,7 +373,7 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
 
             /* Get the plugin info */
             if (NULL == (filter_info = (const H5Z_class2_t *)(*get_plugin_info)()))
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get filter info from plugin")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get filter info from plugin");
 
             /* Setup temporary plugin key if one wasn't supplied */
             if (!key) {
@@ -397,7 +397,7 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
 
             /* Get the plugin info */
             if (NULL == (cls = (const void *)(*get_plugin_info)()))
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get VOL connector info from plugin")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get VOL connector info from plugin");
 
             /* Setup temporary plugin key if one wasn't supplied */
             if (!key) {
@@ -408,7 +408,7 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
 
             /* Ask VOL interface if this class is the one we are looking for and is compatible, etc */
             if (H5VL_check_plugin_load(cls, key, success) < 0)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, FAIL, "VOL connector compatibility check failed")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, FAIL, "VOL connector compatibility check failed");
 
             /* Check for finding the correct plugin */
             if (*success) {
@@ -425,7 +425,7 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
 
             /* Get the plugin info */
             if (NULL == (cls = (const void *)(*get_plugin_info)()))
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get VFD info from plugin")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "can't get VFD info from plugin");
 
             /* Setup temporary plugin key if one wasn't supplied */
             if (!key) {
@@ -436,7 +436,7 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
 
             /* Ask VFD interface if this class is the one we are looking for and is compatible, etc */
             if (H5FD_check_plugin_load(cls, key, success) < 0)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, FAIL, "VFD compatibility check failed")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTLOAD, FAIL, "VFD compatibility check failed");
 
             /* Check for finding the correct plugin */
             if (*success) {
@@ -451,18 +451,18 @@ H5PL__open(const char *path, H5PL_type_t type, const H5PL_key_t *key, hbool_t *s
         case H5PL_TYPE_ERROR:
         case H5PL_TYPE_NONE:
         default:
-            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "Invalid plugin type specified")
+            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "Invalid plugin type specified");
     } /* end switch */
 
     /* If we found the correct plugin, store it in the cache */
     if (*success)
         if (H5PL__add_plugin(loaded_plugin_type, key, handle))
-            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to add new plugin to plugin cache")
+            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to add new plugin to plugin cache");
 
 done:
     if (!(*success) && handle)
         if (H5PL__close(handle) < 0)
-            HDONE_ERROR(H5E_PLUGIN, H5E_CLOSEERROR, FAIL, "can't close dynamic library")
+            HDONE_ERROR(H5E_PLUGIN, H5E_CLOSEERROR, FAIL, "can't close dynamic library");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5PL__open() */
