@@ -10,8 +10,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Quincey Koziol
- *
+/*
  * Purpose:	Generic Property Functions
  */
 
@@ -74,9 +73,6 @@ typedef struct {
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Sunday, July 29, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -90,8 +86,8 @@ H5P__encode_size_t(const void *value, void **_pp, size_t *size)
 
     /* Sanity checks */
     HDcompile_assert(sizeof(size_t) <= sizeof(uint64_t));
-    HDassert(enc_size < 256);
-    HDassert(size);
+    assert(enc_size < 256);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the size */
@@ -115,9 +111,6 @@ H5P__encode_size_t(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Mohamad Chaarawi
- *                 August 07, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -131,8 +124,8 @@ H5P__encode_hsize_t(const void *value, void **_pp, size_t *size)
 
     /* Sanity checks */
     HDcompile_assert(sizeof(hsize_t) <= sizeof(uint64_t));
-    HDassert(enc_size < 256);
-    HDassert(size);
+    assert(enc_size < 256);
+    assert(size);
 
     if (NULL != *pp) {
         *(*pp)++ = (uint8_t)enc_size;
@@ -155,9 +148,6 @@ H5P__encode_hsize_t(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Sunday, July 29, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -168,15 +158,15 @@ H5P__encode_unsigned(const void *value, void **_pp, size_t *size)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the size */
         *(*pp)++ = (uint8_t)sizeof(unsigned);
 
         /* Encode the value */
-        H5_ENCODE_UNSIGNED(*pp, *(const unsigned *)value)
+        H5_ENCODE_UNSIGNED(*pp, *(const unsigned *)value);
     } /* end if */
 
     /* Set size needed for encoding */
@@ -193,9 +183,6 @@ H5P__encode_unsigned(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Mohamad Chaarawi
- *                 August 07, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -206,8 +193,8 @@ H5P__encode_uint8_t(const void *value, void **_pp, size_t *size)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the value */
@@ -228,9 +215,6 @@ H5P__encode_uint8_t(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 August 15, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -241,8 +225,8 @@ H5P__encode_hbool_t(const void *value, void **_pp, size_t *size)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp)
         /* Encode the value */
@@ -262,9 +246,6 @@ H5P__encode_hbool_t(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Sunday, July 29, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -275,15 +256,15 @@ H5P__encode_double(const void *value, void **_pp, size_t *size)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the size */
         *(*pp)++ = (uint8_t)sizeof(double);
 
         /* Encode the value */
-        H5_ENCODE_DOUBLE(*pp, *(const double *)value)
+        H5_ENCODE_DOUBLE(*pp, *(const double *)value);
     } /* end if */
 
     /* Set size needed for encoding */
@@ -321,8 +302,8 @@ H5P__encode_cb(H5P_genprop_t *prop, void *_udata)
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(prop);
-    HDassert(udata);
+    assert(prop);
+    assert(udata);
 
     /* Check if this property can be encoded */
     if (prop->encode) {
@@ -340,7 +321,7 @@ H5P__encode_cb(H5P_genprop_t *prop, void *_udata)
         /* Encode (or not, if *(udata->pp) is NULL) the property value */
         prop_value_len = 0;
         if ((prop->encode)(prop->value, udata->pp, &prop_value_len) < 0)
-            HGOTO_ERROR(H5E_PLIST, H5E_CANTENCODE, H5_ITER_ERROR, "property encoding routine failed")
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTENCODE, H5_ITER_ERROR, "property encoding routine failed");
         *(udata->enc_size_ptr) += prop_value_len;
     } /* end if */
 
@@ -385,7 +366,7 @@ H5P__encode(const H5P_genplist_t *plist, hbool_t enc_all_prop, void *buf, size_t
 
     /* Sanity check */
     if (NULL == nalloc)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "bad allocation size pointer")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "bad allocation size pointer");
 
     /* If the buffer is NULL, then this call to H5P__encode will return how much
      * space is needed to encode a property.
@@ -411,7 +392,7 @@ H5P__encode(const H5P_genplist_t *plist, hbool_t enc_all_prop, void *buf, size_t
     /* Iterate over all properties in property list, encoding them */
     idx = 0;
     if (H5P__iterate_plist(plist, enc_all_prop, &idx, H5P__encode_cb, &udata) < 0)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADITER, FAIL, "can't iterate over properties")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADITER, FAIL, "can't iterate over properties");
 
     /* Encode a terminator for list of properties */
     if (encode)
@@ -433,9 +414,6 @@ done:
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -450,13 +428,13 @@ H5P__decode_size_t(const void **_pp, void *_value)
 
     /* Sanity check */
     HDcompile_assert(sizeof(size_t) <= sizeof(uint64_t));
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
-    HDassert(enc_size < 256);
+    assert(enc_size < 256);
 
     /* Decode the value */
     UINT64DECODE_VAR(*pp, enc_value, enc_size);
@@ -473,9 +451,6 @@ H5P__decode_size_t(const void **_pp, void *_value)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Mohamad Chaarawi
- *                 August 07, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -490,13 +465,13 @@ H5P__decode_hsize_t(const void **_pp, void *_value)
 
     /* Sanity check */
     HDcompile_assert(sizeof(hsize_t) <= sizeof(uint64_t));
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
-    HDassert(enc_size < 256);
+    assert(enc_size < 256);
 
     /* Decode the value */
     UINT64DECODE_VAR(*pp, enc_value, enc_size);
@@ -513,9 +488,6 @@ H5P__decode_hsize_t(const void **_pp, void *_value)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -529,16 +501,16 @@ H5P__decode_unsigned(const void **_pp, void *_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
     if (enc_size != sizeof(unsigned))
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "unsigned value can't be decoded")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "unsigned value can't be decoded");
 
-    H5_DECODE_UNSIGNED(*pp, *value)
+    H5_DECODE_UNSIGNED(*pp, *value);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -552,9 +524,6 @@ done:
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -567,9 +536,9 @@ H5P__decode_uint8_t(const void **_pp, void *_value)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the value */
     *value = *(*pp)++;
@@ -585,9 +554,6 @@ H5P__decode_uint8_t(const void **_pp, void *_value)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Wednesday, August 15, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -600,9 +566,9 @@ H5P__decode_hbool_t(const void **_pp, void *_value)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the value */
     *value = (hbool_t) * (*pp)++;
@@ -618,9 +584,6 @@ H5P__decode_hbool_t(const void **_pp, void *_value)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -634,16 +597,16 @@ H5P__decode_double(const void **_pp, void *_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
     if (enc_size != sizeof(double))
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "double value can't be decoded")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "double value can't be decoded");
 
-    H5_DECODE_DOUBLE(*pp, *value)
+    H5_DECODE_DOUBLE(*pp, *value);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -688,18 +651,18 @@ H5P__decode(const void *buf)
 
     /* Sanity check */
     if (NULL == p)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "decode buffer is NULL")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "decode buffer is NULL");
 
     /* Get the version number of the encoded property list */
     vers = (uint8_t)*p++;
     if ((uint8_t)H5P_ENCODE_VERS != vers)
         HGOTO_ERROR(H5E_PLIST, H5E_VERSION, FAIL, "bad version # of encoded information, expected %u, got %u",
-                    (unsigned)H5P_ENCODE_VERS, (unsigned)vers)
+                    (unsigned)H5P_ENCODE_VERS, (unsigned)vers);
 
     /* Get the type of the property list */
     type = (H5P_plist_type_t)*p++;
     if (type <= H5P_TYPE_USER || type >= H5P_TYPE_MAX_TYPE)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADRANGE, FAIL, "bad type of encoded information: %u", (unsigned)type)
+        HGOTO_ERROR(H5E_PLIST, H5E_BADRANGE, FAIL, "bad type of encoded information: %u", (unsigned)type);
 
     /* Create new property list of the specified type */
     if ((plist_id = H5P__new_plist_of_type(type)) < 0)
@@ -707,7 +670,7 @@ H5P__decode(const void *buf)
 
     /* Get the property list object */
     if (NULL == (plist = (H5P_genplist_t *)H5I_object(plist_id)))
-        HGOTO_ERROR(H5E_PLIST, H5E_BADTYPE, FAIL, "not a property class")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADTYPE, FAIL, "not a property class");
 
     /* Loop over encoded properties, deserializing their values */
     while (p) {
@@ -724,12 +687,12 @@ H5P__decode(const void *buf)
 
         /* Find property with name */
         if (NULL == (prop = H5P__find_prop_plist(plist, name)))
-            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "property doesn't exist: '%s'", name)
+            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "property doesn't exist: '%s'", name);
 
         /* Check if we should increase the size of the value buffer */
         if (prop->size > value_buf_size) {
             if (NULL == (value_buf = H5MM_realloc(value_buf, prop->size)))
-                HGOTO_ERROR(H5E_PLIST, H5E_CANTALLOC, FAIL, "decoding buffer allocation failed")
+                HGOTO_ERROR(H5E_PLIST, H5E_CANTALLOC, FAIL, "decoding buffer allocation failed");
             value_buf_size = prop->size;
         } /* end if */
 
@@ -737,14 +700,14 @@ H5P__decode(const void *buf)
         if (prop->decode) {
             if ((prop->decode)((const void **)&p, value_buf) < 0)
                 HGOTO_ERROR(H5E_PLIST, H5E_CANTDECODE, FAIL,
-                            "property decoding routine failed, property: '%s'", name)
+                            "property decoding routine failed, property: '%s'", name);
         } /* end if */
         else
-            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "no decode callback for property: '%s'", name)
+            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "no decode callback for property: '%s'", name);
 
         /* Set the value for the property */
         if (H5P_poke(plist, name, value_buf) < 0)
-            HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "unable to set value for property: '%s'", name)
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "unable to set value for property: '%s'", name);
     } /* end while */
 
     /* Set return value */
@@ -759,7 +722,7 @@ done:
     if (ret_value < 0) {
         if (plist_id > 0 && H5I_dec_ref(plist_id) < 0)
             HDONE_ERROR(H5E_PLIST, H5E_CANTCLOSEOBJ, FAIL,
-                        "unable to close partially initialized property list")
+                        "unable to close partially initialized property list");
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
