@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5SMcache.c
- *			Nov 13 2006
- *			James Laird
  *
  * Purpose:		Implement shared message metadata cache methods.
  *
@@ -121,9 +119,6 @@ const H5AC_class_t H5AC_SOHM_LIST[1] = {{
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -134,9 +129,9 @@ H5SM__cache_table_get_initial_load_size(void *_udata, size_t *image_len)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(udata);
-    HDassert(udata->f);
-    HDassert(image_len);
+    assert(udata);
+    assert(udata->f);
+    assert(image_len);
 
     /* Set the image length size */
     *image_len = H5SM_TABLE_SIZE(udata->f);
@@ -153,8 +148,6 @@ H5SM__cache_table_get_initial_load_size(void *_udata, size_t *image_len)
  * Return:      Success:        TRUE/FALSE
  *              Failure:        Negative
  *
- * Programmer: 	Vailin Choi; Aug 2015
- *
  *-------------------------------------------------------------------------
  */
 htri_t
@@ -168,7 +161,7 @@ H5SM__cache_table_verify_chksum(const void *_image, size_t len, void H5_ATTR_UNU
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(image);
+    assert(image);
 
     /* Get stored and computed checksums */
     H5F_get_checksums(image, len, &stored_chksum, &computed_chksum);
@@ -190,9 +183,6 @@ H5SM__cache_table_verify_chksum(const void *_image, size_t len, void H5_ATTR_UNU
  * Return:      Success:        Pointer to in core representation
  *              Failure:        NULL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -210,47 +200,47 @@ H5SM__cache_table_deserialize(const void *_image, size_t H5_ATTR_NDEBUG_UNUSED l
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(image);
-    HDassert(len > 0);
-    HDassert(udata);
-    HDassert(udata->f);
+    assert(image);
+    assert(len > 0);
+    assert(udata);
+    assert(udata->f);
     f = udata->f;
-    HDassert(dirty);
+    assert(dirty);
 
     /* Verify that we're reading version 0 of the table; this is the only
      * version defined so far.
      */
-    HDassert(H5F_SOHM_VERS(f) == HDF5_SHAREDHEADER_VERSION);
+    assert(H5F_SOHM_VERS(f) == HDF5_SHAREDHEADER_VERSION);
 
     /* Allocate space for the master table in memory */
     if (NULL == (table = H5FL_CALLOC(H5SM_master_table_t)))
-        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* Read number of indexes and version from file superblock */
     table->num_indexes = H5F_SOHM_NINDEXES(f);
-    HDassert(table->num_indexes > 0);
+    assert(table->num_indexes > 0);
 
     /* Compute the size of the SOHM table header on disk.  This is the "table"
      * itself plus each index within the table
      */
     table->table_size = H5SM_TABLE_SIZE(f);
-    HDassert(table->table_size == len);
+    assert(table->table_size == len);
 
     /* Check magic number */
-    if (HDmemcmp(image, H5SM_TABLE_MAGIC, (size_t)H5_SIZEOF_MAGIC) != 0)
-        HGOTO_ERROR(H5E_SOHM, H5E_CANTLOAD, NULL, "bad SOHM table signature")
+    if (memcmp(image, H5SM_TABLE_MAGIC, (size_t)H5_SIZEOF_MAGIC) != 0)
+        HGOTO_ERROR(H5E_SOHM, H5E_CANTLOAD, NULL, "bad SOHM table signature");
     image += H5_SIZEOF_MAGIC;
 
     /* Allocate space for the index headers in memory*/
     if (NULL == (table->indexes =
                      (H5SM_index_header_t *)H5FL_ARR_MALLOC(H5SM_index_header_t, (size_t)table->num_indexes)))
-        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "memory allocation failed for SOHM indexes")
+        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "memory allocation failed for SOHM indexes");
 
     /* Read in the index headers */
     for (u = 0; u < table->num_indexes; ++u) {
         /* Verify correct version of index list */
         if (H5SM_LIST_VERSION != *image++)
-            HGOTO_ERROR(H5E_SOHM, H5E_VERSION, NULL, "bad shared message list version number")
+            HGOTO_ERROR(H5E_SOHM, H5E_VERSION, NULL, "bad shared message list version number");
 
         /* Type of the index (list or B-tree) */
         table->indexes[u].index_type = (H5SM_index_type_t)*image++;
@@ -286,7 +276,7 @@ H5SM__cache_table_deserialize(const void *_image, size_t H5_ATTR_NDEBUG_UNUSED l
     UINT32DECODE(image, stored_chksum);
 
     /* Sanity check */
-    HDassert((size_t)(image - (const uint8_t *)_image) == table->table_size);
+    assert((size_t)(image - (const uint8_t *)_image) == table->table_size);
 
     /* Set return value */
     ret_value = table;
@@ -294,7 +284,7 @@ H5SM__cache_table_deserialize(const void *_image, size_t H5_ATTR_NDEBUG_UNUSED l
 done:
     if (!ret_value && table)
         if (H5SM__table_free(table) < 0)
-            HDONE_ERROR(H5E_SOHM, H5E_CANTFREE, NULL, "unable to destroy sohm table")
+            HDONE_ERROR(H5E_SOHM, H5E_CANTFREE, NULL, "unable to destroy sohm table");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5SM__cache_table_deserialize() */
@@ -309,9 +299,6 @@ done:
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -323,10 +310,9 @@ H5SM__cache_table_image_len(const void *_thing, size_t *image_len)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(table);
-    HDassert(table->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(table->cache_info.type == H5AC_SOHM_TABLE);
-    HDassert(image_len);
+    assert(table);
+    assert(table->cache_info.type == H5AC_SOHM_TABLE);
+    assert(image_len);
 
     *image_len = table->table_size;
 
@@ -342,9 +328,6 @@ H5SM__cache_table_image_len(const void *_thing, size_t *image_len)
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -358,17 +341,16 @@ H5SM__cache_table_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_NDEBUG_
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(image);
-    HDassert(table);
-    HDassert(table->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(table->cache_info.type == H5AC_SOHM_TABLE);
-    HDassert(table->table_size == len);
+    assert(f);
+    assert(image);
+    assert(table);
+    assert(table->cache_info.type == H5AC_SOHM_TABLE);
+    assert(table->table_size == len);
 
     /* Verify that we're writing version 0 of the table; this is the only
      * version defined so far.
      */
-    HDassert(H5F_SOHM_VERS(f) == HDF5_SHAREDHEADER_VERSION);
+    assert(H5F_SOHM_VERS(f) == HDF5_SHAREDHEADER_VERSION);
 
     /* Encode magic number */
     H5MM_memcpy(image, H5SM_TABLE_MAGIC, (size_t)H5_SIZEOF_MAGIC);
@@ -409,7 +391,7 @@ H5SM__cache_table_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_NDEBUG_
     UINT32ENCODE(image, computed_chksum);
 
     /* sanity check */
-    HDassert((size_t)(image - ((uint8_t *)_image)) == table->table_size);
+    assert((size_t)(image - ((uint8_t *)_image)) == table->table_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5SM__cache_table_serialize() */
@@ -423,16 +405,9 @@ H5SM__cache_table_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_NDEBUG_
  *
  * Purpose:	Free memory used by the SOHM table.
  *
- * Note:	The metadata cache sets the object's cache_info.magic to
- *		H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC before calling a free_icr
- *		callback (checked in assert).
- *
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -444,13 +419,12 @@ H5SM__cache_table_free_icr(void *_thing)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(table);
-    HDassert(table->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC);
-    HDassert(table->cache_info.type == H5AC_SOHM_TABLE);
+    assert(table);
+    assert(table->cache_info.type == H5AC_SOHM_TABLE);
 
     /* Destroy Shared Object Header Message table */
     if (H5SM__table_free(table) < 0)
-        HGOTO_ERROR(H5E_SOHM, H5E_CANTRELEASE, FAIL, "unable to free shared message table")
+        HGOTO_ERROR(H5E_SOHM, H5E_CANTRELEASE, FAIL, "unable to free shared message table");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -466,9 +440,6 @@ done:
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -479,10 +450,10 @@ H5SM__cache_list_get_initial_load_size(void *_udata, size_t *image_len)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(udata);
-    HDassert(udata->header);
-    HDassert(udata->header->list_size > 0);
-    HDassert(image_len);
+    assert(udata);
+    assert(udata->header);
+    assert(udata->header->list_size > 0);
+    assert(image_len);
 
     /* Set the image length size */
     *image_len = udata->header->list_size;
@@ -499,8 +470,6 @@ H5SM__cache_list_get_initial_load_size(void *_udata, size_t *image_len)
  * Return:      Success:        TRUE/FALSE
  *              Failure:        Negative
  *
- * Programmer:	Vailin Choi; Aug 2015
- *
  *-------------------------------------------------------------------------
  */
 htri_t
@@ -516,8 +485,8 @@ H5SM__cache_list_verify_chksum(const void *_image, size_t H5_ATTR_UNUSED len, vo
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(image);
-    HDassert(udata);
+    assert(image);
+    assert(udata);
 
     /* Exact size with checksum at the end */
     chk_size = H5SM_LIST_SIZE(udata->f, udata->header->num_messages);
@@ -541,9 +510,6 @@ H5SM__cache_list_verify_chksum(const void *_image, size_t H5_ATTR_UNUSED len, vo
  * Return:      Success:        Pointer to in core representation
  *              Failure:        NULL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -561,33 +527,33 @@ H5SM__cache_list_deserialize(const void *_image, size_t H5_ATTR_NDEBUG_UNUSED le
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(image);
-    HDassert(len > 0);
-    HDassert(udata);
-    HDassert(udata->header);
-    HDassert(udata->header->list_size == len);
-    HDassert(dirty);
+    assert(image);
+    assert(len > 0);
+    assert(udata);
+    assert(udata->header);
+    assert(udata->header->list_size == len);
+    assert(dirty);
 
     /* Allocate space for the SOHM list data structure */
     if (NULL == (list = H5FL_MALLOC(H5SM_list_t)))
-        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "memory allocation failed")
-    HDmemset(&list->cache_info, 0, sizeof(H5AC_info_t));
+        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "memory allocation failed");
+    memset(&list->cache_info, 0, sizeof(H5AC_info_t));
 
     /* Allocate list in memory as an array*/
     if (NULL == (list->messages = (H5SM_sohm_t *)H5FL_ARR_MALLOC(H5SM_sohm_t, udata->header->list_max)))
-        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "file allocation failed for SOHM list")
+        HGOTO_ERROR(H5E_SOHM, H5E_NOSPACE, NULL, "file allocation failed for SOHM list");
     list->header = udata->header;
 
     /* Check magic number */
-    if (HDmemcmp(image, H5SM_LIST_MAGIC, (size_t)H5_SIZEOF_MAGIC) != 0)
-        HGOTO_ERROR(H5E_SOHM, H5E_CANTLOAD, NULL, "bad SOHM list signature")
+    if (memcmp(image, H5SM_LIST_MAGIC, (size_t)H5_SIZEOF_MAGIC) != 0)
+        HGOTO_ERROR(H5E_SOHM, H5E_CANTLOAD, NULL, "bad SOHM list signature");
     image += H5_SIZEOF_MAGIC;
 
     /* Read messages into the list array */
     ctx.sizeof_addr = H5F_SIZEOF_ADDR(udata->f);
     for (u = 0; u < udata->header->num_messages; u++) {
         if (H5SM__message_decode(image, &(list->messages[u]), &ctx) < 0)
-            HGOTO_ERROR(H5E_SOHM, H5E_CANTLOAD, NULL, "can't decode shared message")
+            HGOTO_ERROR(H5E_SOHM, H5E_CANTLOAD, NULL, "can't decode shared message");
 
         image += H5SM_SOHM_ENTRY_SIZE(udata->f);
     } /* end for */
@@ -598,7 +564,7 @@ H5SM__cache_list_deserialize(const void *_image, size_t H5_ATTR_NDEBUG_UNUSED le
     UINT32DECODE(image, stored_chksum);
 
     /* Sanity check */
-    HDassert((size_t)(image - (const uint8_t *)_image) <= udata->header->list_size);
+    assert((size_t)(image - (const uint8_t *)_image) <= udata->header->list_size);
 
     /* Initialize the rest of the array */
     for (u = udata->header->num_messages; u < udata->header->list_max; u++)
@@ -625,9 +591,6 @@ done:
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -638,11 +601,10 @@ H5SM__cache_list_image_len(const void *_thing, size_t *image_len)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
-    HDassert(list);
-    HDassert(list->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(list->cache_info.type == H5AC_SOHM_LIST);
-    HDassert(list->header);
-    HDassert(image_len);
+    assert(list);
+    assert(list->cache_info.type == H5AC_SOHM_LIST);
+    assert(list->header);
+    assert(image_len);
 
     *image_len = list->header->list_size;
 
@@ -658,9 +620,6 @@ H5SM__cache_list_image_len(const void *_thing, size_t *image_len)
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -677,13 +636,12 @@ H5SM__cache_list_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_NDEBUG_U
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(image);
-    HDassert(list);
-    HDassert(list->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(list->cache_info.type == H5AC_SOHM_LIST);
-    HDassert(list->header);
-    HDassert(list->header->list_size == len);
+    assert(f);
+    assert(image);
+    assert(list);
+    assert(list->cache_info.type == H5AC_SOHM_LIST);
+    assert(list->header);
+    assert(list->header->list_size == len);
 
     /* Encode magic number */
     H5MM_memcpy(image, H5SM_LIST_MAGIC, (size_t)H5_SIZEOF_MAGIC);
@@ -695,24 +653,24 @@ H5SM__cache_list_serialize(const H5F_t *f, void *_image, size_t H5_ATTR_NDEBUG_U
     for (u = 0; ((u < list->header->list_max) && (mesgs_serialized < list->header->num_messages)); u++) {
         if (list->messages[u].location != H5SM_NO_LOC) {
             if (H5SM__message_encode(image, &(list->messages[u]), &ctx) < 0)
-                HGOTO_ERROR(H5E_SOHM, H5E_CANTFLUSH, FAIL, "unable to serialize shared message")
+                HGOTO_ERROR(H5E_SOHM, H5E_CANTFLUSH, FAIL, "unable to serialize shared message");
 
             image += H5SM_SOHM_ENTRY_SIZE(f);
             ++mesgs_serialized;
         } /* end if */
     }     /* end for */
 
-    HDassert(mesgs_serialized == list->header->num_messages);
+    assert(mesgs_serialized == list->header->num_messages);
 
     /* Compute checksum on buffer */
     computed_chksum = H5_checksum_metadata(_image, (size_t)(image - (uint8_t *)_image), 0);
     UINT32ENCODE(image, computed_chksum);
 
     /* sanity check */
-    HDassert((size_t)(image - (uint8_t *)_image) <= list->header->list_size);
+    assert((size_t)(image - (uint8_t *)_image) <= list->header->list_size);
 
     /* Clear memory */
-    HDmemset(image, 0, (list->header->list_size - (size_t)(image - (uint8_t *)_image)));
+    memset(image, 0, (list->header->list_size - (size_t)(image - (uint8_t *)_image)));
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -727,16 +685,9 @@ done:
  *
  * Purpose:	Free all memory used by the list.
  *
- * Note:	The metadata cache sets the object's cache_info.magic to
- *		H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC before calling a free_icr
- *		callback (checked in assert).
- *
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              7/28/14
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -748,13 +699,12 @@ H5SM__cache_list_free_icr(void *_thing)
     FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(list);
-    HDassert(list->cache_info.magic == H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC);
-    HDassert(list->cache_info.type == H5AC_SOHM_LIST);
+    assert(list);
+    assert(list->cache_info.type == H5AC_SOHM_LIST);
 
     /* Destroy Shared Object Header Message list */
     if (H5SM__list_free(list) < 0)
-        HGOTO_ERROR(H5E_SOHM, H5E_CANTRELEASE, FAIL, "unable to free shared message list")
+        HGOTO_ERROR(H5E_SOHM, H5E_CANTRELEASE, FAIL, "unable to free shared message list");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
