@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol
- *              Tuesday, June 16, 1998
- *
  * Purpose:	"All" selection dataspace I/O functions.
  */
 
@@ -50,7 +47,7 @@ static herr_t   H5S__all_release(H5S_t *space);
 static htri_t   H5S__all_is_valid(const H5S_t *space);
 static hssize_t H5S__all_serial_size(H5S_t *space);
 static herr_t   H5S__all_serialize(H5S_t *space, uint8_t **p);
-static herr_t   H5S__all_deserialize(H5S_t **space, const uint8_t **p);
+static herr_t   H5S__all_deserialize(H5S_t **space, const uint8_t **p, const size_t p_size, hbool_t skip);
 static herr_t   H5S__all_bounds(const H5S_t *space, hsize_t *start, hsize_t *end);
 static herr_t   H5S__all_offset(const H5S_t *space, hsize_t *off);
 static int      H5S__all_unlim_dim(const H5S_t *space);
@@ -137,9 +134,6 @@ static const H5S_sel_iter_class_t H5S_sel_iter_all[1] = {{
  *
  * Return:	Non-negative on success, negative on failure.
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, June 16, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -148,8 +142,8 @@ H5S__all_iter_init(H5S_t H5_ATTR_UNUSED *space, H5S_sel_iter_t *iter)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space && H5S_SEL_ALL == H5S_GET_SELECT_TYPE(space));
-    HDassert(iter);
+    assert(space && H5S_SEL_ALL == H5S_GET_SELECT_TYPE(space));
+    assert(iter);
 
     /* Start at the upper left location */
     iter->u.all.elmt_offset = 0;
@@ -169,9 +163,6 @@ H5S__all_iter_init(H5S_t H5_ATTR_UNUSED *space, H5S_sel_iter_t *iter)
  *
  * Return:	Non-negative on success, negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, April 22, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -182,12 +173,12 @@ H5S__all_iter_coords(const H5S_sel_iter_t *iter, hsize_t *coords)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(iter);
-    HDassert(coords);
+    assert(iter);
+    assert(coords);
 
     /* Calculate the coordinates for the current iterator offset */
     if (H5VM_array_calc(iter->u.all.elmt_offset, iter->rank, iter->dims, coords) < 0)
-        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTGET, FAIL, "can't retrieve coordinates")
+        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTGET, FAIL, "can't retrieve coordinates");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -201,9 +192,6 @@ done:
  *
  * Return:	Non-negative on success, negative on failure
  *
- * Programmer:	Quincey Koziol
- *              Monday, June 2, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -214,9 +202,9 @@ H5S__all_iter_block(const H5S_sel_iter_t *iter, hsize_t *start, hsize_t *end)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(iter);
-    HDassert(start);
-    HDassert(end);
+    assert(iter);
+    assert(start);
+    assert(end);
 
     for (u = 0; u < iter->rank; u++) {
         /* Set the start of the 'all' block */
@@ -238,9 +226,6 @@ H5S__all_iter_block(const H5S_sel_iter_t *iter, hsize_t *start, hsize_t *end)
  *
  * Return:	Non-negative number of elements on success, zero on failure
  *
- * Programmer:	Quincey Koziol
- *              Tuesday, June 16, 1998
- *
  *-------------------------------------------------------------------------
  */
 static hsize_t
@@ -249,7 +234,7 @@ H5S__all_iter_nelmts(const H5S_sel_iter_t *iter)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(iter);
+    assert(iter);
 
     FUNC_LEAVE_NOAPI(iter->elmt_left)
 } /* end H5S__all_iter_nelmts() */
@@ -277,7 +262,7 @@ H5S__all_iter_has_next_block(const H5S_sel_iter_t H5_ATTR_UNUSED *iter)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(iter);
+    assert(iter);
 
     FUNC_LEAVE_NOAPI(FALSE)
 } /* end H5S__all_iter_has_next_block() */
@@ -306,8 +291,8 @@ H5S__all_iter_next(H5S_sel_iter_t *iter, size_t nelem)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(iter);
-    HDassert(nelem > 0);
+    assert(iter);
+    assert(nelem > 0);
 
     /* Increment the iterator */
     iter->u.all.elmt_offset += nelem;
@@ -339,7 +324,7 @@ H5S__all_iter_next_block(H5S_sel_iter_t H5_ATTR_UNUSED *iter)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(iter);
+    assert(iter);
 
     FUNC_LEAVE_NOAPI(FAIL)
 } /* end H5S__all_iter_next_block() */
@@ -382,18 +367,18 @@ H5S__all_iter_get_seq_list(H5S_sel_iter_t *iter, size_t H5_ATTR_UNUSED maxseq, s
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(iter);
-    HDassert(maxseq > 0);
-    HDassert(maxelem > 0);
-    HDassert(nseq);
-    HDassert(nelem);
-    HDassert(off);
-    HDassert(len);
+    assert(iter);
+    assert(maxseq > 0);
+    assert(maxelem > 0);
+    assert(nseq);
+    assert(nelem);
+    assert(off);
+    assert(len);
 
     /* Determine the actual number of elements to use */
     H5_CHECK_OVERFLOW(iter->elmt_left, hsize_t, size_t);
     elem_used = MIN(maxelem, (size_t)iter->elmt_left);
-    HDassert(elem_used > 0);
+    assert(elem_used > 0);
 
     /* Compute the offset in the dataset */
     off[0] = iter->u.all.byte_offset;
@@ -436,7 +421,7 @@ H5S__all_iter_release(H5S_sel_iter_t H5_ATTR_UNUSED *iter)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(iter);
+    assert(iter);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5S__all_iter_release() */
@@ -464,7 +449,7 @@ H5S__all_release(H5S_t *space)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space);
+    assert(space);
 
     /* Reset the number of elements in the selection */
     space->select.num_elem = 0;
@@ -497,8 +482,8 @@ H5S__all_copy(H5S_t *dst, const H5S_t H5_ATTR_UNUSED *src, hbool_t H5_ATTR_UNUSE
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(src);
-    HDassert(dst);
+    assert(src);
+    assert(dst);
 
     /* Set number of elements in selection */
     dst->select.num_elem = (hsize_t)H5S_GET_EXTENT_NPOINTS(dst);
@@ -531,7 +516,7 @@ H5S__all_is_valid(const H5S_t H5_ATTR_UNUSED *space)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(space);
+    assert(space);
 
     FUNC_LEAVE_NOAPI(TRUE)
 } /* end H5S__all_is_valid() */
@@ -560,7 +545,7 @@ H5S__all_serial_size(H5S_t H5_ATTR_UNUSED *space)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(space);
+    assert(space);
 
     /* Basic number of bytes required to serialize point selection:
      *  <type (4 bytes)> + <version (4 bytes)> + <padding (4 bytes)> +
@@ -598,9 +583,9 @@ H5S__all_serialize(H5S_t *space, uint8_t **p)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space);
-    HDassert(p);
-    HDassert(pp);
+    assert(space);
+    assert(p);
+    assert(pp);
 
     /* Store the preamble information */
     UINT32ENCODE(pp, (uint32_t)H5S_GET_SELECT_TYPE(space)); /* Store the type of selection */
@@ -637,17 +622,17 @@ H5S__all_serialize(H5S_t *space, uint8_t **p)
  REVISION LOG
 --------------------------------------------------------------------------*/
 static herr_t
-H5S__all_deserialize(H5S_t **space, const uint8_t **p)
+H5S__all_deserialize(H5S_t **space, const uint8_t **p, const size_t p_size, hbool_t skip)
 {
-    uint32_t version;           /* Version number */
-    H5S_t   *tmp_space = NULL;  /* Pointer to actual dataspace to use,
-                                   either *space or a newly allocated one */
-    herr_t ret_value = SUCCEED; /* return value */
-
+    uint32_t version;                           /* Version number */
+    H5S_t   *tmp_space = NULL;                  /* Pointer to actual dataspace to use,
+                                                   either *space or a newly allocated one */
+    herr_t         ret_value = SUCCEED;         /* return value */
+    const uint8_t *p_end     = *p + p_size - 1; /* Pointer to last valid byte in buffer */
     FUNC_ENTER_PACKAGE
 
-    HDassert(p);
-    HDassert(*p);
+    assert(p);
+    assert(*p);
 
     /* As part of the efforts to push all selection-type specific coding
        to the callbacks, the coding for the allocation of a null dataspace
@@ -657,23 +642,27 @@ H5S__all_deserialize(H5S_t **space, const uint8_t **p)
     /* Allocate space if not provided */
     if (!*space) {
         if (NULL == (tmp_space = H5S_create(H5S_SIMPLE)))
-            HGOTO_ERROR(H5E_DATASPACE, H5E_CANTCREATE, FAIL, "can't create dataspace")
+            HGOTO_ERROR(H5E_DATASPACE, H5E_CANTCREATE, FAIL, "can't create dataspace");
     } /* end if */
     else
         tmp_space = *space;
 
     /* Decode version */
+    if (H5_IS_KNOWN_BUFFER_OVERFLOW(skip, *p, sizeof(uint32_t), p_end))
+        HGOTO_ERROR(H5E_DATASPACE, H5E_OVERFLOW, FAIL, "buffer overflow while decoding selection version");
     UINT32DECODE(*p, version);
 
     if (version < H5S_ALL_VERSION_1 || version > H5S_ALL_VERSION_LATEST)
-        HGOTO_ERROR(H5E_DATASPACE, H5E_BADVALUE, FAIL, "bad version number for all selection")
+        HGOTO_ERROR(H5E_DATASPACE, H5E_BADVALUE, FAIL, "bad version number for all selection");
 
     /* Skip over the remainder of the header */
+    if (H5_IS_KNOWN_BUFFER_OVERFLOW(skip, *p, 8, p_end))
+        HGOTO_ERROR(H5E_DATASPACE, H5E_OVERFLOW, FAIL, "buffer overflow while decoding header");
     *p += 8;
 
     /* Change to "all" selection */
     if (H5S_select_all(tmp_space, TRUE) < 0)
-        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTDELETE, FAIL, "can't change selection")
+        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTDELETE, FAIL, "can't change selection");
 
     /* Return space to the caller if allocated */
     if (!*space)
@@ -683,7 +672,7 @@ done:
     /* Free temporary space if not passed to caller (only happens on error) */
     if (!*space && tmp_space)
         if (H5S_close(tmp_space) < 0)
-            HDONE_ERROR(H5E_DATASPACE, H5E_CANTFREE, FAIL, "can't close dataspace")
+            HDONE_ERROR(H5E_DATASPACE, H5E_CANTFREE, FAIL, "can't close dataspace");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5S__all_deserialize() */
@@ -721,9 +710,9 @@ H5S__all_bounds(const H5S_t *space, hsize_t *start, hsize_t *end)
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(space);
-    HDassert(start);
-    HDassert(end);
+    assert(space);
+    assert(start);
+    assert(end);
 
     /* Get the dataspace extent rank */
     rank = space->extent.rank;
@@ -762,8 +751,8 @@ H5S__all_offset(const H5S_t H5_ATTR_UNUSED *space, hsize_t *offset)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(space);
-    HDassert(offset);
+    assert(space);
+    assert(offset);
 
     /* 'All' selections always start at offset 0 */
     *offset = 0;
@@ -823,7 +812,7 @@ H5S__all_is_contiguous(const H5S_t H5_ATTR_UNUSED *space)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(space);
+    assert(space);
 
     FUNC_LEAVE_NOAPI(TRUE)
 } /* end H5S__all_is_contiguous() */
@@ -851,7 +840,7 @@ H5S__all_is_single(const H5S_t H5_ATTR_UNUSED *space)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(space);
+    assert(space);
 
     FUNC_LEAVE_NOAPI(TRUE)
 } /* end H5S__all_is_single() */
@@ -881,7 +870,7 @@ H5S__all_is_regular(H5S_t H5_ATTR_UNUSED *space)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space);
+    assert(space);
 
     FUNC_LEAVE_NOAPI(TRUE)
 } /* end H5S__all_is_regular() */
@@ -915,8 +904,8 @@ H5S__all_shape_same(H5S_t *space1, H5S_t *space2)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space1);
-    HDassert(space2);
+    assert(space1);
+    assert(space2);
 
     /* Initialize dataspace dims */
     space1_dim = (int)space1->extent.rank - 1;
@@ -929,7 +918,7 @@ H5S__all_shape_same(H5S_t *space1, H5S_t *space2)
      */
     while (space2_dim >= 0) {
         if (space1->extent.size[space1_dim] != space2->extent.size[space2_dim])
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(FALSE);
 
         space1_dim--;
         space2_dim--;
@@ -940,7 +929,7 @@ H5S__all_shape_same(H5S_t *space1, H5S_t *space2)
      */
     while (space1_dim >= 0) {
         if (space1->extent.size[space1_dim] != 1)
-            HGOTO_DONE(FALSE)
+            HGOTO_DONE(FALSE);
 
         space1_dim--;
     } /* end while */
@@ -975,10 +964,10 @@ H5S__all_intersect_block(H5S_t H5_ATTR_UNUSED *space, const hsize_t H5_ATTR_UNUS
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(space);
-    HDassert(H5S_SEL_ALL == H5S_GET_SELECT_TYPE(space));
-    HDassert(start);
-    HDassert(end);
+    assert(space);
+    assert(H5S_SEL_ALL == H5S_GET_SELECT_TYPE(space));
+    assert(start);
+    assert(end);
 
     FUNC_LEAVE_NOAPI(TRUE)
 } /* end H5S__all_intersect_block() */
@@ -1007,8 +996,8 @@ H5S__all_adjust_u(H5S_t H5_ATTR_UNUSED *space, const hsize_t H5_ATTR_UNUSED *off
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space);
-    HDassert(offset);
+    assert(space);
+    assert(offset);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5S__all_adjust_u() */
@@ -1037,8 +1026,8 @@ H5S__all_adjust_s(H5S_t H5_ATTR_UNUSED *space, const hssize_t H5_ATTR_UNUSED *of
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space);
-    HDassert(offset);
+    assert(space);
+    assert(offset);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5S__all_adjust_s() */
@@ -1051,9 +1040,6 @@ H5S__all_adjust_s(H5S_t H5_ATTR_UNUSED *space, const hssize_t H5_ATTR_UNUSED *of
  *
  * Return:	Non-negative on success, negative on failure.
  *
- * Programmer:	Quincey Koziol
- *              Sunday, July 18, 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1062,8 +1048,8 @@ H5S__all_project_scalar(const H5S_t H5_ATTR_UNUSED *space, hsize_t *offset)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args */
-    HDassert(space && H5S_SEL_ALL == H5S_GET_SELECT_TYPE(space));
-    HDassert(offset);
+    assert(space && H5S_SEL_ALL == H5S_GET_SELECT_TYPE(space));
+    assert(offset);
 
     /* Set offset of selection in projected buffer */
     *offset = 0;
@@ -1079,9 +1065,6 @@ H5S__all_project_scalar(const H5S_t H5_ATTR_UNUSED *space, hsize_t *offset)
  *
  * Return:	Non-negative on success, negative on failure.
  *
- * Programmer:	Quincey Koziol
- *              Sunday, July 18, 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1093,13 +1076,13 @@ H5S__all_project_simple(const H5S_t H5_ATTR_UNUSED *base_space, H5S_t *new_space
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(base_space && H5S_SEL_ALL == H5S_GET_SELECT_TYPE(base_space));
-    HDassert(new_space);
-    HDassert(offset);
+    assert(base_space && H5S_SEL_ALL == H5S_GET_SELECT_TYPE(base_space));
+    assert(new_space);
+    assert(offset);
 
     /* Select the entire new space */
     if (H5S_select_all(new_space, TRUE) < 0)
-        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTSET, FAIL, "unable to set all selection")
+        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTSET, FAIL, "unable to set all selection");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -1131,12 +1114,12 @@ H5S_select_all(H5S_t *space, hbool_t rel_prev)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check args */
-    HDassert(space);
+    assert(space);
 
     /* Remove current selection first */
     if (rel_prev)
         if (H5S_SELECT_RELEASE(space) < 0)
-            HGOTO_ERROR(H5E_DATASPACE, H5E_CANTDELETE, FAIL, "can't release selection")
+            HGOTO_ERROR(H5E_DATASPACE, H5E_CANTDELETE, FAIL, "can't release selection");
 
     /* Set number of elements in selection */
     space->select.num_elem = (hsize_t)H5S_GET_EXTENT_NPOINTS(space);
@@ -1176,11 +1159,11 @@ H5Sselect_all(hid_t spaceid)
 
     /* Check args */
     if (NULL == (space = (H5S_t *)H5I_object_verify(spaceid, H5I_DATASPACE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace");
 
     /* Call internal routine to do the work */
     if (H5S_select_all(space, TRUE) < 0)
-        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTDELETE, FAIL, "can't change selection")
+        HGOTO_ERROR(H5E_DATASPACE, H5E_CANTDELETE, FAIL, "can't change selection");
 
 done:
     FUNC_LEAVE_API(ret_value)
