@@ -10,9 +10,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Quincey Koziol
- *              Saturday, May 31, 2003
- *
+/*
  * Purpose:	Dataspace selection testing functions.
  */
 
@@ -87,12 +85,12 @@ H5S__get_rebuild_status_test(hid_t space_id, H5S_diminfo_valid_t *status1, H5S_d
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(status1);
-    HDassert(status2);
+    assert(status1);
+    assert(status2);
 
     /* Get dataspace structures */
     if (NULL == (space = (H5S_t *)H5I_object_verify(space_id, H5I_DATASPACE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace");
 
     *status1 = space->select.sel_info.hslab->diminfo_valid;
 
@@ -134,11 +132,11 @@ H5S__get_diminfo_status_test(hid_t space_id, H5S_diminfo_valid_t *status)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(status);
+    assert(status);
 
     /* Get dataspace structures */
     if (NULL == (space = (H5S_t *)H5I_object_verify(space_id, H5I_DATASPACE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace");
 
     *status = space->select.sel_info.hslab->diminfo_valid;
 
@@ -174,7 +172,7 @@ H5S__check_spans_tail_ptr(const H5S_hyper_span_info_t *span_lst)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(span_lst);
+    assert(span_lst);
 
     cur_elem = span_lst->head;
     while (cur_elem) {
@@ -184,13 +182,13 @@ H5S__check_spans_tail_ptr(const H5S_hyper_span_info_t *span_lst)
         if (NULL != cur_elem->down)
             if ((ret_value = H5S__check_spans_tail_ptr(cur_elem->down)) < 0)
                 HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                            "the selection has inconsistent tail pointers")
+                            "the selection has inconsistent tail pointers");
 
         cur_elem = cur_elem->next;
     } /* end while */
     if (actual_tail != span_lst->tail)
         HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                    "the selection has inconsistent tail pointers")
+                    "the selection has inconsistent tail pointers");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -223,7 +221,7 @@ H5S__check_points_tail_ptr(const H5S_pnt_list_t *pnt_lst)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(pnt_lst);
+    assert(pnt_lst);
 
     cur_elem = pnt_lst->head;
     while (cur_elem) {
@@ -232,7 +230,7 @@ H5S__check_points_tail_ptr(const H5S_pnt_list_t *pnt_lst)
     } /* end while */
     if (actual_tail != pnt_lst->tail)
         HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                    "the selection has inconsistent tail pointers")
+                    "the selection has inconsistent tail pointers");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -268,7 +266,7 @@ H5S__check_internal_consistency(const H5S_t *space)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(space);
+    assert(space);
 
     if (space->select.type->type == H5S_SEL_NONE)
         HGOTO_DONE(ret_value);
@@ -281,7 +279,7 @@ H5S__check_internal_consistency(const H5S_t *space)
 
     /* Check the bound box */
     if (H5S_get_select_bounds(space, low_bounds, high_bounds) < 0)
-        HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL, "the bound box could not be retrieved")
+        HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL, "the bound box could not be retrieved");
 
     if (space->select.type->type == H5S_SEL_HYPERSLABS) {
         H5S_hyper_sel_t *hslab = space->select.sel_info.hslab;
@@ -291,11 +289,11 @@ H5S__check_internal_consistency(const H5S_t *space)
                 if ((hsize_t)((hssize_t)hslab->diminfo.low_bounds[u] + space->select.offset[u]) !=
                     low_bounds[u])
                     HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                                "the lower bound box of the selection is inconsistent")
+                                "the lower bound box of the selection is inconsistent");
                 if ((hsize_t)((hssize_t)hslab->diminfo.high_bounds[u] + space->select.offset[u]) !=
                     high_bounds[u])
                     HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                                "the higher bound box of the selection is inconsistent")
+                                "the higher bound box of the selection is inconsistent");
             } /* end for */
         }     /* end if */
         else {
@@ -303,11 +301,11 @@ H5S__check_internal_consistency(const H5S_t *space)
                 if ((hsize_t)((hssize_t)hslab->span_lst->low_bounds[u] + space->select.offset[u]) !=
                     low_bounds[u])
                     HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                                "the lower bound box of the selection is inconsistent")
+                                "the lower bound box of the selection is inconsistent");
                 if ((hsize_t)((hssize_t)hslab->span_lst->high_bounds[u] + space->select.offset[u]) !=
                     high_bounds[u])
                     HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                                "the higher bound box of the selection is inconsistent")
+                                "the higher bound box of the selection is inconsistent");
             } /* end for */
         }     /* end else */
 
@@ -315,7 +313,7 @@ H5S__check_internal_consistency(const H5S_t *space)
         if ((NULL != hslab) && (NULL != hslab->span_lst))
             if (H5S__check_spans_tail_ptr(hslab->span_lst) < 0)
                 HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                            "the selection has inconsistent tail pointers")
+                            "the selection has inconsistent tail pointers");
     } /* end if */
     else if (space->select.type->type == H5S_SEL_POINTS) {
         H5S_pnt_list_t *pnt_lst = space->select.sel_info.pnt_lst;
@@ -323,7 +321,7 @@ H5S__check_internal_consistency(const H5S_t *space)
         if (NULL != pnt_lst)
             if (H5S__check_points_tail_ptr(pnt_lst) < 0)
                 HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                            "the selection has inconsistent tail pointers")
+                            "the selection has inconsistent tail pointers");
     } /* end else-if */
 
 done:
@@ -359,12 +357,12 @@ H5S__internal_consistency_test(hid_t space_id)
 
     /* Get dataspace structures */
     if (NULL == (space = (H5S_t *)H5I_object_verify(space_id, H5I_DATASPACE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace");
 
     /* Check if the dataspace selections are the same shape */
     if (FAIL == H5S__check_internal_consistency(space))
         HGOTO_ERROR(H5E_DATASPACE, H5E_INCONSISTENTSTATE, FAIL,
-                    "The dataspace has inconsistent internal state")
+                    "The dataspace has inconsistent internal state");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
