@@ -75,9 +75,6 @@
  * Return:	Success:	ID of new array datatype
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, Oct 17, 2007
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -93,27 +90,27 @@ H5Tarray_create2(hid_t base_id, unsigned ndims, const hsize_t dim[/* ndims */])
 
     /* Check args */
     if (ndims < 1 || ndims > H5S_MAX_RANK)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "invalid dimensionality")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "invalid dimensionality");
     if (!dim)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "no dimensions specified")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "no dimensions specified");
     for (u = 0; u < ndims; u++)
         if (!(dim[u] > 0))
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "zero-sized dimension specified")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "zero-sized dimension specified");
     if (NULL == (base = (H5T_t *)H5I_object_verify(base_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not an valid base datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not an valid base datatype");
 
     /* Create the array datatype */
     if (NULL == (dt = H5T__array_create(base, ndims, dim)))
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to create datatype")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to create datatype");
 
     /* Register the type */
     if ((ret_value = H5I_register(H5I_DATATYPE, dt, TRUE)) < 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register datatype")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register datatype");
 
 done:
     if (ret_value < 0)
         if (dt && H5T_close_real(dt) < 0)
-            HDONE_ERROR(H5E_DATATYPE, H5E_CANTRELEASE, H5I_INVALID_HID, "can't release datatype")
+            HDONE_ERROR(H5E_DATATYPE, H5E_CANTRELEASE, H5I_INVALID_HID, "can't release datatype");
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tarray_create2() */
@@ -130,9 +127,6 @@ done:
  * Return:	Success:	ID of new array data type
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, Oct 26, 2000
- *
  *-------------------------------------------------------------------------
  */
 H5T_t *
@@ -143,18 +137,18 @@ H5T__array_create(H5T_t *base, unsigned ndims, const hsize_t dim[/* ndims */])
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(base);
-    HDassert(ndims <= H5S_MAX_RANK);
-    HDassert(dim);
+    assert(base);
+    assert(ndims <= H5S_MAX_RANK);
+    assert(dim);
 
     /* Build new type */
     if (NULL == (ret_value = H5T__alloc()))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
     ret_value->shared->type = H5T_ARRAY;
 
     /* Copy the base type of the array */
     if (NULL == (ret_value->shared->parent = H5T_copy(base, H5T_COPY_ALL)))
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOPY, NULL, "unable to copy base datatype")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOPY, NULL, "unable to copy base datatype");
 
     /* Set the array parameters */
     ret_value->shared->u.array.ndims = ndims;
@@ -187,9 +181,6 @@ done:
  * Return:	Success:	Number of dimensions of the array datatype
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Monday, November 6, 2000
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -203,9 +194,9 @@ H5Tget_array_ndims(hid_t type_id)
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype object");
     if (dt->shared->type != H5T_ARRAY)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an array datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an array datatype");
 
     /* Retrieve the number of dimensions */
     ret_value = H5T__get_array_ndims(dt);
@@ -223,9 +214,6 @@ done:
  * Return:	Success:	Number of dimensions of the array datatype
  *		Failure:	Negative
  *
- * Programmer:	Raymond Lu
- *              October 10, 2002
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -233,8 +221,8 @@ H5T__get_array_ndims(const H5T_t *dt)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(dt);
-    HDassert(dt->shared->type == H5T_ARRAY);
+    assert(dt);
+    assert(dt->shared->type == H5T_ARRAY);
 
     /* Retrieve the number of dimensions */
     FUNC_LEAVE_NOAPI((int)dt->shared->u.array.ndims)
@@ -248,9 +236,6 @@ H5T__get_array_ndims(const H5T_t *dt)
  * Return:	Success:	Number of dimensions of the array type
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, October 17, 2007
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -264,13 +249,13 @@ H5Tget_array_dims2(hid_t type_id, hsize_t dims[] /*out*/)
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype object");
     if (dt->shared->type != H5T_ARRAY)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an array datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an array datatype");
 
     /* Retrieve the sizes of the dimensions */
     if ((ret_value = H5T__get_array_dims(dt, dims)) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unable to get dimension sizes")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unable to get dimension sizes");
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tget_array_dims2() */
@@ -284,9 +269,6 @@ done:
  * Return:	Success:	Number of dimensions of the array type
  *		Failure:	Negative
  *
- * Programmer:  Raymond Lu
- *              October 10, 2002
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -296,8 +278,8 @@ H5T__get_array_dims(const H5T_t *dt, hsize_t dims[])
 
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(dt);
-    HDassert(dt->shared->type == H5T_ARRAY);
+    assert(dt);
+    assert(dt->shared->type == H5T_ARRAY);
 
     /* Retrieve the sizes of the dimensions */
     if (dims)
@@ -324,9 +306,6 @@ H5T__get_array_dims(const H5T_t *dt, hsize_t dims[])
  * Return:	Success:	ID of new array datatype
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Thursday, Oct 26, 2000
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -343,27 +322,27 @@ H5Tarray_create1(hid_t base_id, int ndims, const hsize_t dim[/* ndims */],
 
     /* Check args */
     if (ndims < 1 || ndims > H5S_MAX_RANK)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "invalid dimensionality")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "invalid dimensionality");
     if (!dim)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "no dimensions specified")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "no dimensions specified");
     for (u = 0; u < (unsigned)ndims; u++)
         if (!(dim[u] > 0))
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "zero-sized dimension specified")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "zero-sized dimension specified");
     if (NULL == (base = (H5T_t *)H5I_object_verify(base_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not an valid base datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not an valid base datatype");
 
     /* Create the array datatype */
     if (NULL == (dt = H5T__array_create(base, (unsigned)ndims, dim)))
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to create datatype")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to create datatype");
 
     /* Register the type */
     if ((ret_value = H5I_register(H5I_DATATYPE, dt, TRUE)) < 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register datatype")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register datatype");
 
 done:
     if (ret_value < 0)
         if (dt && H5T_close_real(dt) < 0)
-            HDONE_ERROR(H5E_DATATYPE, H5E_CANTRELEASE, H5I_INVALID_HID, "can't release datatype")
+            HDONE_ERROR(H5E_DATATYPE, H5E_CANTRELEASE, H5I_INVALID_HID, "can't release datatype");
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tarray_create1() */
@@ -376,9 +355,6 @@ done:
  * Return:	Success:	Number of dimensions of the array type
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *              Monday, November 6, 2000
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -392,13 +368,13 @@ H5Tget_array_dims1(hid_t type_id, hsize_t dims[] /*out*/, int H5_ATTR_UNUSED per
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype object");
     if (dt->shared->type != H5T_ARRAY)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an array datatype")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an array datatype");
 
     /* Retrieve the sizes of the dimensions */
     if ((ret_value = H5T__get_array_dims(dt, dims)) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unable to get dimension sizes")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unable to get dimension sizes");
 
 done:
     FUNC_LEAVE_API(ret_value)
