@@ -37,9 +37,6 @@ static herr_t H5T__enum_valueof(const H5T_t *dt, const char *name, void *value /
  *
  *		Failure:	Negative
  *
- * Programmer:	Robb Matzke
- *              Tuesday, December 22, 1998
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -55,15 +52,15 @@ H5Tenum_create(hid_t parent_id)
     /* Check args */
     if (NULL == (parent = (H5T_t *)H5I_object_verify(parent_id, H5I_DATATYPE)) ||
         H5T_INTEGER != parent->shared->type)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not an integer data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not an integer data type");
 
     /* Build new type */
     if (NULL == (dt = H5T__enum_create(parent)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, H5I_INVALID_HID, "cannot create enum type")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, H5I_INVALID_HID, "cannot create enum type");
 
     /* Register the type */
     if ((ret_value = H5I_register(H5I_DATATYPE, dt, TRUE)) < 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register data type ID")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register data type ID");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -80,9 +77,6 @@ done:
  *
  *		Failure:        NULL
  *
- * Programmer:	Raymond Lu
- *              October 9, 2002
- *
  *-------------------------------------------------------------------------
  */
 H5T_t *
@@ -92,14 +86,14 @@ H5T__enum_create(const H5T_t *parent)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(parent);
+    assert(parent);
 
     /* Build new type */
     if (NULL == (ret_value = H5T__alloc()))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
     ret_value->shared->type   = H5T_ENUM;
     ret_value->shared->parent = H5T_copy(parent, H5T_COPY_ALL);
-    HDassert(ret_value->shared->parent);
+    assert(ret_value->shared->parent);
     ret_value->shared->size = ret_value->shared->parent->shared->size;
 
 done:
@@ -120,9 +114,6 @@ done:
  *
  *		Failure:	negative
  *
- * Programmer:	Robb Matzke
- *              Wednesday, December 23, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -136,17 +127,17 @@ H5Tenum_insert(hid_t type, const char *name, const void *value)
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type");
     if (H5T_ENUM != dt->shared->type)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an enumeration data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an enumeration data type");
     if (!name || !*name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name specified")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name specified");
     if (!value)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no value specified")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no value specified");
 
     /* Do work */
     if (H5T__enum_insert(dt, name, value) < 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to insert new enumeration member")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to insert new enumeration member");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -164,9 +155,6 @@ done:
  *
  *		Failure:	negative
  *
- * Programmer:	Robb Matzke
- *              Wednesday, December 23, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -177,17 +165,16 @@ H5T__enum_insert(const H5T_t *dt, const char *name, const void *value)
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(dt);
-    HDassert(name && *name);
-    HDassert(value);
+    assert(dt);
+    assert(name && *name);
+    assert(value);
 
     /* The name and value had better not already exist */
     for (i = 0; i < dt->shared->u.enumer.nmembs; i++) {
         if (!HDstrcmp(dt->shared->u.enumer.name[i], name))
-            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "name redefinition")
-        if (!HDmemcmp((uint8_t *)dt->shared->u.enumer.value + (i * dt->shared->size), value,
-                      dt->shared->size))
-            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "value redefinition")
+            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "name redefinition");
+        if (!memcmp((uint8_t *)dt->shared->u.enumer.value + (i * dt->shared->size), value, dt->shared->size))
+            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "value redefinition");
     }
 
     /* Increase table sizes */
@@ -197,11 +184,11 @@ H5T__enum_insert(const H5T_t *dt, const char *name, const void *value)
         unsigned n = MAX(32, 2 * dt->shared->u.enumer.nalloc);
 
         if (NULL == (names = (char **)H5MM_realloc(dt->shared->u.enumer.name, n * sizeof(char *))))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
         dt->shared->u.enumer.name = names;
 
         if (NULL == (values = (uint8_t *)H5MM_realloc(dt->shared->u.enumer.value, n * dt->shared->size)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
         dt->shared->u.enumer.value  = values;
         dt->shared->u.enumer.nalloc = n;
     }
@@ -226,9 +213,6 @@ done:
  *
  *		Failure:	negative, VALUE memory is undefined.
  *
- * Programmer:	Robb Matzke
- *              Wednesday, December 23, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -241,16 +225,16 @@ H5Tget_member_value(hid_t type, unsigned membno, void *value /*out*/)
     H5TRACE3("e", "iIux", type, membno, value);
 
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type");
     if (H5T_ENUM != dt->shared->type)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "operation not defined for data type class")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "operation not defined for data type class");
     if (membno >= dt->shared->u.enumer.nmembs)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid member number")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid member number");
     if (!value)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "null value buffer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "null value buffer");
 
     if (H5T__get_member_value(dt, membno, value) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get member value")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get member value");
 done:
     FUNC_LEAVE_API(ret_value)
 }
@@ -266,9 +250,6 @@ done:
  *
  *		Failure:	negative, VALUE memory is undefined.
  *
- * Programmer:	Raymond Lu
- *              October 9, 2002
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -276,8 +257,8 @@ H5T__get_member_value(const H5T_t *dt, unsigned membno, void *value /*out*/)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(dt);
-    HDassert(value);
+    assert(dt);
+    assert(value);
 
     H5MM_memcpy(value, (uint8_t *)dt->shared->u.enumer.value + (membno * dt->shared->size), dt->shared->size);
 
@@ -299,9 +280,6 @@ H5T__get_member_value(const H5T_t *dt, unsigned membno, void *value /*out*/)
  *		Failure:	Negative, first character of NAME is set to
  *				null if SIZE allows it.
  *
- * Programmer:	Robb Matzke
- *              Monday, January  4, 1999
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -315,16 +293,16 @@ H5Tenum_nameof(hid_t type, const void *value, char *name /*out*/, size_t size)
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type");
     if (H5T_ENUM != dt->shared->type)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an enumeration data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an enumeration data type");
     if (!value)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no value supplied")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no value supplied");
     if (!name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name buffer supplied")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name buffer supplied");
 
     if (NULL == H5T__enum_nameof(dt, value, name, size))
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "nameof query failed")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "nameof query failed");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -348,9 +326,6 @@ done:
  *
  *		Failure:	NULL, name[0] is set to null.
  *
- * Programmer:	Robb Matzke
- *              Monday, January  4, 1999
- *
  *-------------------------------------------------------------------------
  */
 static char *
@@ -365,30 +340,30 @@ H5T__enum_nameof(const H5T_t *dt, const void *value, char *name /*out*/, size_t
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(dt && H5T_ENUM == dt->shared->type);
-    HDassert(value);
-    HDassert(name || 0 == size);
+    assert(dt && H5T_ENUM == dt->shared->type);
+    assert(value);
+    assert(name || 0 == size);
 
     if (name && size > 0)
         *name = '\0';
 
     /* Sanity check */
     if (dt->shared->u.enumer.nmembs == 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, NULL, "datatype has no members")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, NULL, "datatype has no members");
 
     /* Do a binary search over the values to find the correct one.  Do sorting
      * and search on the copied datatype to protect the original order. */
     if (NULL == (copied_dt = H5T_copy(dt, H5T_COPY_ALL)))
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, NULL, "unable to copy data type")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, NULL, "unable to copy data type");
     if (H5T__sort_value(copied_dt, NULL) < 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOMPARE, NULL, "value sort failed")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOMPARE, NULL, "value sort failed");
 
     lt = 0;
     rt = copied_dt->shared->u.enumer.nmembs;
     while (lt < rt) {
         md  = (lt + rt) / 2;
-        cmp = HDmemcmp(value, (uint8_t *)copied_dt->shared->u.enumer.value + (md * copied_dt->shared->size),
-                       copied_dt->shared->size);
+        cmp = memcmp(value, (uint8_t *)copied_dt->shared->u.enumer.value + (md * copied_dt->shared->size),
+                     copied_dt->shared->size);
         if (cmp < 0)
             rt = md;
         else if (cmp > 0)
@@ -399,7 +374,7 @@ H5T__enum_nameof(const H5T_t *dt, const void *value, char *name /*out*/, size_t
 
     /* Value was not yet defined. This fixes bug # 774, 2002/06/05 EIP */
     if (cmp != 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, NULL, "value is currently not defined")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, NULL, "value is currently not defined");
 
     /* Save result name */
     if (!name) {
@@ -409,7 +384,7 @@ H5T__enum_nameof(const H5T_t *dt, const void *value, char *name /*out*/, size_t
     } /* end if */
     HDstrncpy(name, copied_dt->shared->u.enumer.name[md], size);
     if (HDstrlen(copied_dt->shared->u.enumer.name[md]) >= size)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_NOSPACE, NULL, "name has been truncated")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_NOSPACE, NULL, "name has been truncated");
 
     /* Set return value */
     ret_value = name;
@@ -436,9 +411,6 @@ done:
  *
  *		Failure:	Negative
  *
- * Programmer:	Robb Matzke
- *              Monday, January  4, 1999
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -452,16 +424,16 @@ H5Tenum_valueof(hid_t type, const char *name, void *value /*out*/)
 
     /* Check args */
     if (NULL == (dt = (H5T_t *)H5I_object_verify(type, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type");
     if (H5T_ENUM != dt->shared->type)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an enumeration data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not an enumeration data type");
     if (!name || !*name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name");
     if (!value)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no value buffer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no value buffer");
 
     if (H5T__enum_valueof(dt, name, value) < 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "valueof query failed")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "valueof query failed");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -479,9 +451,6 @@ done:
  *
  *		Failure:	Negative, VALUE is undefined.
  *
- * Programmer:	Robb Matzke
- *              Monday, January  4, 1999
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -495,20 +464,20 @@ H5T__enum_valueof(const H5T_t *dt, const char *name, void *value /*out*/)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(dt && H5T_ENUM == dt->shared->type);
-    HDassert(name && *name);
-    HDassert(value);
+    assert(dt && H5T_ENUM == dt->shared->type);
+    assert(name && *name);
+    assert(value);
 
     /* Sanity check */
     if (dt->shared->u.enumer.nmembs == 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, FAIL, "datatype has no members")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, FAIL, "datatype has no members");
 
     /* Do a binary search over the names to find the correct one.  Do sorting
      * and search on the copied datatype to protect the original order. */
     if (NULL == (copied_dt = H5T_copy(dt, H5T_COPY_ALL)))
         HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to copy data type");
     if (H5T__sort_name(copied_dt, NULL) < 0)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_CANTCOMPARE, FAIL, "value sort failed")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_CANTCOMPARE, FAIL, "value sort failed");
 
     lt = 0;
     rt = copied_dt->shared->u.enumer.nmembs;
@@ -528,7 +497,7 @@ H5T__enum_valueof(const H5T_t *dt, const char *name, void *value /*out*/)
     }
     /* Value was not yet defined. This fixes bug # 774, 2002/06/05 EIP */
     if (cmp != 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, FAIL, "string doesn't exist in the enumeration type")
+        HGOTO_ERROR(H5E_DATATYPE, H5E_NOTFOUND, FAIL, "string doesn't exist in the enumeration type");
 
     H5MM_memcpy(value, (uint8_t *)copied_dt->shared->u.enumer.value + (md * copied_dt->shared->size),
                 copied_dt->shared->size);
@@ -536,7 +505,7 @@ H5T__enum_valueof(const H5T_t *dt, const char *name, void *value /*out*/)
 done:
     if (copied_dt)
         if (H5T_close_real(copied_dt) < 0)
-            HDONE_ERROR(H5E_DATATYPE, H5E_CANTCLOSEOBJ, FAIL, "unable to close data type")
+            HDONE_ERROR(H5E_DATATYPE, H5E_CANTCLOSEOBJ, FAIL, "unable to close data type");
 
     FUNC_LEAVE_NOAPI(ret_value)
 }
