@@ -91,11 +91,11 @@ H5VLregister_connector(const H5VL_class_t *cls, hid_t vipl_id)
     if (H5P_DEFAULT == vipl_id)
         vipl_id = H5P_VOL_INITIALIZE_DEFAULT;
     else if (TRUE != H5P_isa_class(vipl_id, H5P_VOL_INITIALIZE))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a VOL initialize property list")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a VOL initialize property list");
 
     /* Register connector */
     if ((ret_value = H5VL__register_connector_by_class(cls, TRUE, vipl_id)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register VOL connector")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register VOL connector");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -128,20 +128,20 @@ H5VLregister_connector_by_name(const char *name, hid_t vipl_id)
 
     /* Check arguments */
     if (!name)
-        HGOTO_ERROR(H5E_ARGS, H5E_UNINITIALIZED, H5I_INVALID_HID, "null VOL connector name is disallowed")
+        HGOTO_ERROR(H5E_ARGS, H5E_UNINITIALIZED, H5I_INVALID_HID, "null VOL connector name is disallowed");
     if (0 == HDstrlen(name))
         HGOTO_ERROR(H5E_ARGS, H5E_UNINITIALIZED, H5I_INVALID_HID,
-                    "zero-length VOL connector name is disallowed")
+                    "zero-length VOL connector name is disallowed");
 
     /* Check VOL initialization property list */
     if (H5P_DEFAULT == vipl_id)
         vipl_id = H5P_VOL_INITIALIZE_DEFAULT;
     else if (TRUE != H5P_isa_class(vipl_id, H5P_VOL_INITIALIZE))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a VOL initialize property list")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a VOL initialize property list");
 
     /* Register connector */
     if ((ret_value = H5VL__register_connector_by_name(name, TRUE, vipl_id)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register VOL connector")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register VOL connector");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -175,17 +175,17 @@ H5VLregister_connector_by_value(H5VL_class_value_t value, hid_t vipl_id)
     /* Check arguments */
     if (value < 0)
         HGOTO_ERROR(H5E_ARGS, H5E_UNINITIALIZED, H5I_INVALID_HID,
-                    "negative VOL connector value is disallowed")
+                    "negative VOL connector value is disallowed");
 
     /* Check VOL initialization property list */
     if (H5P_DEFAULT == vipl_id)
         vipl_id = H5P_VOL_INITIALIZE_DEFAULT;
     else if (TRUE != H5P_isa_class(vipl_id, H5P_VOL_INITIALIZE))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a VOL initialize property list")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a VOL initialize property list");
 
     /* Register connector */
     if ((ret_value = H5VL__register_connector_by_value(value, TRUE, vipl_id)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register VOL connector")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register VOL connector");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -201,9 +201,6 @@ done:
  *              0 if a VOL connector with that name has NOT been registered
  *              <0 on errors
  *
- * Programmer:  Dana Robinson
- *              June 17, 2017
- *
  *-------------------------------------------------------------------------
  */
 htri_t
@@ -216,7 +213,7 @@ H5VLis_connector_registered_by_name(const char *name)
 
     /* Check if connector with this name is registered */
     if ((ret_value = H5VL__is_connector_registered_by_name(name)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't check for VOL")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't check for VOL");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -244,7 +241,7 @@ H5VLis_connector_registered_by_value(H5VL_class_value_t connector_value)
 
     /* Check if connector with this value is registered */
     if ((ret_value = H5VL__is_connector_registered_by_value(connector_value)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't check for VOL")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't check for VOL");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -260,9 +257,6 @@ done:
  *
  *              H5I_INVALID_HID on error.
  *
- * Programmer:  Dana Robinson
- *              June 17, 2017
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -275,7 +269,7 @@ H5VLget_connector_id(hid_t obj_id)
 
     /* Get connector ID */
     if ((ret_value = H5VL__get_connector_id(obj_id, TRUE)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -293,9 +287,6 @@ done:
  *              H5I_INVALID_HID on error or if a VOL connector of that
  *              name has not been registered.
  *
- * Programmer:  Dana Robinson
- *              June 17, 2017
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -308,7 +299,7 @@ H5VLget_connector_id_by_name(const char *name)
 
     /* Get connector ID with this name */
     if ((ret_value = H5VL__get_connector_id_by_name(name, TRUE)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -338,7 +329,7 @@ H5VLget_connector_id_by_value(H5VL_class_value_t connector_value)
 
     /* Get connector ID with this value */
     if ((ret_value = H5VL__get_connector_id_by_value(connector_value, TRUE)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -369,7 +360,7 @@ H5VLpeek_connector_id_by_name(const char *name)
 
     /* Get connector ID with this name */
     if ((ret_value = H5VL__peek_connector_id_by_name(name)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -400,7 +391,7 @@ H5VLpeek_connector_id_by_value(H5VL_class_value_t value)
 
     /* Get connector ID with this value */
     if ((ret_value = H5VL__peek_connector_id_by_value(value)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, H5I_INVALID_HID, "can't get VOL id");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -433,7 +424,7 @@ H5VLget_connector_name(hid_t obj_id, char *name /*out*/, size_t size)
 
     /* Call internal routine */
     if ((ret_value = H5VL__get_connector_name(obj_id, name, size)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "Can't get connector name")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "Can't get connector name");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -462,11 +453,11 @@ H5VLclose(hid_t vol_id)
 
     /* Check args */
     if (NULL == H5I_object_verify(vol_id, H5I_VOL))
-        HGOTO_ERROR(H5E_VOL, H5E_BADTYPE, FAIL, "not a VOL connector")
+        HGOTO_ERROR(H5E_VOL, H5E_BADTYPE, FAIL, "not a VOL connector");
 
     /* Decrement the ref count on the ID, possibly releasing the VOL connector */
     if (H5I_dec_app_ref(vol_id) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to close VOL connector ID")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to close VOL connector ID");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -500,22 +491,22 @@ H5VLunregister_connector(hid_t vol_id)
 
     /* Check arguments */
     if (NULL == H5I_object_verify(vol_id, H5I_VOL))
-        HGOTO_ERROR(H5E_VOL, H5E_BADTYPE, FAIL, "not a VOL connector ID")
+        HGOTO_ERROR(H5E_VOL, H5E_BADTYPE, FAIL, "not a VOL connector ID");
 
     /* For the time being, we disallow unregistering the native VOL connector */
     if (H5I_INVALID_HID == (native_id = H5VL__get_connector_id_by_name(H5VL_NATIVE_NAME, FALSE)))
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "unable to find the native VOL connector ID")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "unable to find the native VOL connector ID");
     if (vol_id == native_id)
-        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, FAIL, "unregistering the native VOL connector is not allowed")
+        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, FAIL, "unregistering the native VOL connector is not allowed");
 
     /* The H5VL_class_t struct will be freed by this function */
     if (H5I_dec_app_ref(vol_id) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to unregister VOL connector")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to unregister VOL connector");
 
 done:
     if (native_id != H5I_INVALID_HID)
         if (H5I_dec_ref(native_id) < 0)
-            HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to decrement count on native_id")
+            HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to decrement count on native_id");
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5VLunregister_connector() */
@@ -545,13 +536,13 @@ H5VLcmp_connector_cls(int *cmp, hid_t connector_id1, hid_t connector_id2)
 
     /* Check args and get class pointers */
     if (NULL == (cls1 = (H5VL_class_t *)H5I_object_verify(connector_id1, H5I_VOL)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a VOL connector ID")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a VOL connector ID");
     if (NULL == (cls2 = (H5VL_class_t *)H5I_object_verify(connector_id2, H5I_VOL)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a VOL connector ID")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a VOL connector ID");
 
     /* Compare the two VOL connector classes */
     if (H5VL_cmp_connector_cls(cmp, cls1, cls2) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTCOMPARE, FAIL, "can't compare connector classes")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTCOMPARE, FAIL, "can't compare connector classes");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -612,14 +603,14 @@ H5VLwrap_register(void *obj, H5I_type_t type)
         case H5I_EVENTSET:
         case H5I_NTYPES:
         default:
-            HGOTO_ERROR(H5E_VOL, H5E_BADRANGE, H5I_INVALID_HID, "invalid type number")
+            HGOTO_ERROR(H5E_VOL, H5E_BADRANGE, H5I_INVALID_HID, "invalid type number");
     } /* end switch */
     if (NULL == obj)
-        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, H5I_INVALID_HID, "obj is NULL")
+        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, H5I_INVALID_HID, "obj is NULL");
 
     /* Wrap the object and register an ID for it */
     if ((ret_value = H5VL_wrap_register(type, obj, TRUE)) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to wrap object")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to wrap object");
 
 done:
     FUNC_LEAVE_API_NOINIT(ret_value)
@@ -649,7 +640,7 @@ H5VLobject(hid_t id)
 
     /* Retrieve the object pointer for the ID */
     if (NULL == (ret_value = H5VL_object(id)))
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, NULL, "unable to retrieve object")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, NULL, "unable to retrieve object");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -675,14 +666,14 @@ H5VLobject_is_native(hid_t obj_id, hbool_t *is_native)
     H5TRACE2("e", "i*b", obj_id, is_native);
 
     if (!is_native)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "`is_native` argument is NULL")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "`is_native` argument is NULL");
 
     /* Get the location object for the ID */
     if (NULL == (vol_obj = H5VL_vol_object(obj_id)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier");
 
     if (H5VL_object_is_native(vol_obj, is_native) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't determine if object is a native connector object")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't determine if object is a native connector object");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -712,34 +703,34 @@ H5VLget_file_type(void *file_obj, hid_t connector_id, hid_t dtype_id)
 
     /* Check args */
     if (!file_obj)
-        HGOTO_ERROR(H5E_ARGS, H5E_UNINITIALIZED, FAIL, "no file object supplied")
+        HGOTO_ERROR(H5E_ARGS, H5E_UNINITIALIZED, FAIL, "no file object supplied");
     if (NULL == (dtype = (H5T_t *)H5I_object_verify(dtype_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data type");
 
     /* Create VOL object for file if necessary (force_conv will be TRUE if and
      * only if file needs to be passed to H5T_set_loc) */
     if (H5T_GET_FORCE_CONV(dtype) &&
         (NULL == (file_vol_obj = H5VL_create_object_using_vol_id(H5I_FILE, file_obj, connector_id))))
-        HGOTO_ERROR(H5E_VOL, H5E_CANTCREATE, FAIL, "can't create VOL object")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTCREATE, FAIL, "can't create VOL object");
 
     /* Copy the datatype */
     if (NULL == (file_type = H5T_copy(dtype, H5T_COPY_TRANSIENT)))
-        HGOTO_ERROR(H5E_VOL, H5E_CANTCOPY, FAIL, "unable to copy datatype")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTCOPY, FAIL, "unable to copy datatype");
 
     /* Register file type id */
     if ((file_type_id = H5I_register(H5I_DATATYPE, file_type, FALSE)) < 0) {
         (void)H5T_close_real(file_type);
-        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, FAIL, "unable to register file datatype")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, FAIL, "unable to register file datatype");
     } /* end if */
 
     /* Set the location of the datatype to be in the file */
     if (H5T_set_loc(file_type, file_vol_obj, H5T_LOC_DISK) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTINIT, FAIL, "can't set datatype location")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTINIT, FAIL, "can't set datatype location");
 
     /* Release our reference to file_type */
     if (file_vol_obj) {
         if (H5VL_free_object(file_vol_obj) < 0)
-            HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to free VOL object")
+            HGOTO_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to free VOL object");
         file_vol_obj = NULL;
     } /* end if */
 
@@ -750,9 +741,9 @@ done:
     /* Cleanup on error */
     if (ret_value < 0) {
         if (file_vol_obj && H5VL_free_object(file_vol_obj) < 0)
-            HDONE_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to free VOL object")
+            HDONE_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to free VOL object");
         if (file_type_id >= 0 && H5I_dec_ref(file_type_id) < 0)
-            HDONE_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to close file datatype")
+            HDONE_ERROR(H5E_VOL, H5E_CANTDEC, FAIL, "unable to close file datatype");
     } /* end if */
 
     FUNC_LEAVE_API(ret_value)
@@ -770,9 +761,6 @@ done:
  * Return:      Success:    Non-negative, *state set
  *              Failure:    Negative, *state unset
  *
- * Programmer:  Quincey Koziol
- *              Thursday, January 10, 2019
- *
  *---------------------------------------------------------------------------
  */
 herr_t
@@ -786,11 +774,11 @@ H5VLretrieve_lib_state(void **state /*out*/)
 
     /* Check args */
     if (NULL == state)
-        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, FAIL, "invalid state pointer")
+        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, FAIL, "invalid state pointer");
 
     /* Retrieve the library state */
     if (H5VL_retrieve_lib_state(state) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't retrieve library state")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't retrieve library state");
 
 done:
     FUNC_LEAVE_API_NOINIT(ret_value)
@@ -807,9 +795,6 @@ done:
  * Return:      Success:    Non-negative
  *              Failure:    Negative
  *
- * Programmer:  Quincey Koziol
- *              Friday, February 5, 2021
- *
  *---------------------------------------------------------------------------
  */
 herr_t
@@ -823,7 +808,7 @@ H5VLstart_lib_state(void)
 
     /* Start a new library state */
     if (H5VL_start_lib_state() < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTSET, FAIL, "can't start new library state")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTSET, FAIL, "can't start new library state");
 
 done:
     FUNC_LEAVE_API_NOINIT(ret_value)
@@ -840,9 +825,6 @@ done:
  * Return:      Success:    Non-negative
  *              Failure:    Negative
  *
- * Programmer:  Quincey Koziol
- *              Thursday, January 10, 2019
- *
  *---------------------------------------------------------------------------
  */
 herr_t
@@ -856,11 +838,11 @@ H5VLrestore_lib_state(const void *state)
 
     /* Check args */
     if (NULL == state)
-        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, FAIL, "invalid state pointer")
+        HGOTO_ERROR(H5E_VOL, H5E_BADVALUE, FAIL, "invalid state pointer");
 
     /* Restore the library state */
     if (H5VL_restore_lib_state(state) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTSET, FAIL, "can't restore library state")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTSET, FAIL, "can't restore library state");
 
 done:
     FUNC_LEAVE_API_NOINIT(ret_value)
@@ -882,9 +864,6 @@ done:
  * Return:      Success:    Non-negative
  *              Failure:    Negative
  *
- * Programmer:  Quincey Koziol
- *              Saturday, February 23, 2019
- *
  *---------------------------------------------------------------------------
  */
 herr_t
@@ -898,7 +877,7 @@ H5VLfinish_lib_state(void)
 
     /* Reset the library state */
     if (H5VL_finish_lib_state() < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTRESET, FAIL, "can't reset library state")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTRESET, FAIL, "can't reset library state");
 
 done:
     FUNC_LEAVE_API_NOINIT(ret_value)
@@ -918,9 +897,6 @@ done:
  * Return:      Success:    Non-negative
  *              Failure:    Negative
  *
- * Programmer:  Quincey Koziol
- *              Thursday, January 10, 2019
- *
  *---------------------------------------------------------------------------
  */
 herr_t
@@ -933,11 +909,11 @@ H5VLfree_lib_state(void *state)
 
     /* Check args */
     if (NULL == state)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid state pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid state pointer");
 
     /* Free the library state */
     if (H5VL_free_lib_state(state) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTRELEASE, FAIL, "can't free library state")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTRELEASE, FAIL, "can't free library state");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -966,13 +942,13 @@ H5VLquery_optional(hid_t obj_id, H5VL_subclass_t subcls, int opt_type, uint64_t
 
     /* Check args */
     if (NULL == flags)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid 'flags' pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid 'flags' pointer");
     if (NULL == (vol_obj = H5VL_vol_object(obj_id)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier");
 
     /* Query the connector */
     if (H5VL_introspect_opt_query(vol_obj, subcls, opt_type, flags) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "unable to query VOL connector operation")
+        HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "unable to query VOL connector operation");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -1017,20 +993,20 @@ H5VLregister_opt_operation(H5VL_subclass_t subcls, const char *op_name, int *op_
 
     /* Check args */
     if (NULL == op_val)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_val pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_val pointer");
     if (NULL == op_name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name pointer");
     if ('\0' == *op_name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name string")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name string");
     if (!((H5VL_SUBCLS_ATTR == subcls) || (H5VL_SUBCLS_DATASET == subcls) ||
           (H5VL_SUBCLS_DATATYPE == subcls) || (H5VL_SUBCLS_FILE == subcls) || (H5VL_SUBCLS_GROUP == subcls) ||
           (H5VL_SUBCLS_OBJECT == subcls) || (H5VL_SUBCLS_LINK == subcls) || (H5VL_SUBCLS_REQUEST == subcls)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid VOL subclass type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid VOL subclass type");
 
     /* Register the operation */
     if (H5VL__register_opt_operation(subcls, op_name, op_val) < 0)
         HGOTO_ERROR(H5E_VOL, H5E_CANTREGISTER, FAIL, "can't register dynamic optional operation: '%s'",
-                    op_name)
+                    op_name);
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -1056,19 +1032,19 @@ H5VLfind_opt_operation(H5VL_subclass_t subcls, const char *op_name, int *op_val
 
     /* Check args */
     if (NULL == op_val)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_val pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_val pointer");
     if (NULL == op_name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name pointer");
     if ('\0' == *op_name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name string")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name string");
     if (!((H5VL_SUBCLS_ATTR == subcls) || (H5VL_SUBCLS_DATASET == subcls) ||
           (H5VL_SUBCLS_DATATYPE == subcls) || (H5VL_SUBCLS_FILE == subcls) || (H5VL_SUBCLS_GROUP == subcls) ||
           (H5VL_SUBCLS_OBJECT == subcls) || (H5VL_SUBCLS_LINK == subcls) || (H5VL_SUBCLS_REQUEST == subcls)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid VOL subclass type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid VOL subclass type");
 
     /* Find the operation */
     if (H5VL__find_opt_operation(subcls, op_name, op_val) < 0)
-        HGOTO_ERROR(H5E_VOL, H5E_NOTFOUND, FAIL, "can't find dynamic optional operation: '%s'", op_name)
+        HGOTO_ERROR(H5E_VOL, H5E_NOTFOUND, FAIL, "can't find dynamic optional operation: '%s'", op_name);
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -1094,18 +1070,18 @@ H5VLunregister_opt_operation(H5VL_subclass_t subcls, const char *op_name)
 
     /* Check args */
     if (NULL == op_name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name pointer")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name pointer");
     if ('\0' == *op_name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name string")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid op_name string");
     if (!((H5VL_SUBCLS_ATTR == subcls) || (H5VL_SUBCLS_DATASET == subcls) ||
           (H5VL_SUBCLS_DATATYPE == subcls) || (H5VL_SUBCLS_FILE == subcls) || (H5VL_SUBCLS_GROUP == subcls) ||
           (H5VL_SUBCLS_OBJECT == subcls) || (H5VL_SUBCLS_LINK == subcls) || (H5VL_SUBCLS_REQUEST == subcls)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid VOL subclass type")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid VOL subclass type");
 
     /* Unregister the operation */
     if (H5VL__unregister_opt_operation(subcls, op_name) < 0)
         HGOTO_ERROR(H5E_VOL, H5E_CANTREMOVE, FAIL, "can't unregister dynamic optional operation: '%s'",
-                    op_name)
+                    op_name);
 
 done:
     FUNC_LEAVE_API(ret_value)
