@@ -91,7 +91,7 @@ H5VL__native_file_create(const char *name, unsigned flags, hid_t fcpl_id, hid_t
 
     /* Create the file */
     if (NULL == (new_file = H5F_open(name, flags, fcpl_id, fapl_id)))
-        HGOTO_ERROR(H5E_FILE, H5E_CANTOPENFILE, NULL, "unable to create file")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTOPENFILE, NULL, "unable to create file");
     new_file->id_exists = TRUE;
 
     ret_value = (void *)new_file;
@@ -99,7 +99,7 @@ H5VL__native_file_create(const char *name, unsigned flags, hid_t fcpl_id, hid_t
 done:
     if (NULL == ret_value && new_file)
         if (H5F__close(new_file) < 0)
-            HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, NULL, "problems closing file")
+            HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, NULL, "problems closing file");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5VL__native_file_create() */
@@ -125,14 +125,14 @@ H5VL__native_file_open(const char *name, unsigned flags, hid_t fapl_id, hid_t H5
 
     /* Open the file */
     if (NULL == (new_file = H5F_open(name, flags, H5P_FILE_CREATE_DEFAULT, fapl_id)))
-        HGOTO_ERROR(H5E_FILE, H5E_CANTOPENFILE, NULL, "unable to open file")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTOPENFILE, NULL, "unable to open file");
     new_file->id_exists = TRUE;
 
     ret_value = (void *)new_file;
 
 done:
     if (NULL == ret_value && new_file && H5F_try_close(new_file, NULL) < 0)
-        HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, NULL, "problems closing file")
+        HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, NULL, "problems closing file");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5VL__native_file_open() */
@@ -159,7 +159,7 @@ H5VL__native_file_get(void *obj, H5VL_file_get_args_t *args, hid_t H5_ATTR_UNUSE
         /* "get container info" */
         case H5VL_FILE_GET_CONT_INFO: {
             if (H5F__get_cont_info((H5F_t *)obj, args->args.get_cont_info.info) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get file container info")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get file container info");
 
             break;
         }
@@ -167,7 +167,7 @@ H5VL__native_file_get(void *obj, H5VL_file_get_args_t *args, hid_t H5_ATTR_UNUSE
         /* H5Fget_access_plist */
         case H5VL_FILE_GET_FAPL: {
             if ((args->args.get_fapl.fapl_id = H5F_get_access_plist((H5F_t *)obj, TRUE)) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get file access property list")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get file access property list");
 
             break;
         }
@@ -178,11 +178,11 @@ H5VL__native_file_get(void *obj, H5VL_file_get_args_t *args, hid_t H5_ATTR_UNUSE
 
             f = (H5F_t *)obj;
             if (NULL == (plist = (H5P_genplist_t *)H5I_object(f->shared->fcpl_id)))
-                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a property list")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a property list");
 
             /* Create the property list object to return */
             if ((args->args.get_fcpl.fcpl_id = H5P_copy_plist(plist, TRUE)) < 0)
-                HGOTO_ERROR(H5E_PLIST, H5E_CANTINIT, FAIL, "unable to copy file creation properties")
+                HGOTO_ERROR(H5E_PLIST, H5E_CANTINIT, FAIL, "unable to copy file creation properties");
 
             break;
         }
@@ -228,7 +228,7 @@ H5VL__native_file_get(void *obj, H5VL_file_get_args_t *args, hid_t H5_ATTR_UNUSE
             H5VL_file_get_name_args_t *file_args = &args->args.get_name;
 
             if (H5VL_native_get_file_struct(obj, file_args->type, &f) < 0)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
 
             /* Get length of file name */
             *file_args->file_name_len = HDstrlen(H5F_OPEN_NAME(f));
@@ -248,7 +248,7 @@ H5VL__native_file_get(void *obj, H5VL_file_get_args_t *args, hid_t H5_ATTR_UNUSE
         case H5VL_FILE_GET_OBJ_COUNT: {
             if (H5F_get_obj_count((H5F_t *)obj, args->args.get_obj_count.types, TRUE,
                                   args->args.get_obj_count.count) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve object count")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve object count");
 
             break;
         }
@@ -259,13 +259,13 @@ H5VL__native_file_get(void *obj, H5VL_file_get_args_t *args, hid_t H5_ATTR_UNUSE
 
             if (H5F_get_obj_ids((H5F_t *)obj, file_args->types, file_args->max_objs, file_args->oid_list,
                                 TRUE, file_args->count) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve object IDs")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve object IDs");
 
             break;
         }
 
         default:
-            HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't get this type of information")
+            HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't get this type of information");
     } /* end switch */
 
 done:
@@ -296,7 +296,7 @@ H5VL__native_file_specific(void *obj, H5VL_file_specific_args_t *args, hid_t H5_
 
             /* Get the file for the object */
             if (H5VL_native_get_file_struct(obj, args->args.flush.obj_type, &f) < 0)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
 
             /* Nothing to do if the file is read only. This determination is
              * made at the shared open(2) flags level, implying that opening a
@@ -309,13 +309,13 @@ H5VL__native_file_specific(void *obj, H5VL_file_specific_args_t *args, hid_t H5_
                 if (H5F_SCOPE_GLOBAL == args->args.flush.scope) {
                     /* Call the flush routine for mounted file hierarchies */
                     if (H5F_flush_mounts(f) < 0)
-                        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush mounted file hierarchy")
+                        HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush mounted file hierarchy");
                 } /* end if */
                 else {
                     /* Call the flush routine, for this file */
                     if (H5F__flush(f) < 0)
                         HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL,
-                                    "unable to flush file's cached information")
+                                    "unable to flush file's cached information");
                 } /* end else */
             }     /* end if */
 
@@ -328,7 +328,7 @@ H5VL__native_file_specific(void *obj, H5VL_file_specific_args_t *args, hid_t H5_
 
             /* Reopen the file through the VOL connector */
             if (NULL == (new_file = H5F__reopen((H5F_t *)obj)))
-                HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to reopen file")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to reopen file");
             new_file->id_exists = TRUE;
 
             /* Set 'out' value */
@@ -343,7 +343,7 @@ H5VL__native_file_specific(void *obj, H5VL_file_specific_args_t *args, hid_t H5_
 
             if ((result = H5F__is_hdf5(args->args.is_accessible.filename, args->args.is_accessible.fapl_id)) <
                 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "error in HDF5 file check")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "error in HDF5 file check");
 
             /* Set 'out' value */
             *args->args.is_accessible.accessible = (hbool_t)result;
@@ -354,7 +354,7 @@ H5VL__native_file_specific(void *obj, H5VL_file_specific_args_t *args, hid_t H5_
         /* H5Fdelete */
         case H5VL_FILE_DELETE: {
             if (H5F__delete(args->args.del.filename, args->args.del.fapl_id) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTDELETEFILE, FAIL, "error in HDF5 file deletion")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTDELETEFILE, FAIL, "error in HDF5 file deletion");
 
             break;
         }
@@ -371,7 +371,7 @@ H5VL__native_file_specific(void *obj, H5VL_file_specific_args_t *args, hid_t H5_
         }
 
         default:
-            HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "invalid specific operation")
+            HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "invalid specific operation");
     } /* end switch */
 
 done:
@@ -405,7 +405,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
 
             /* Get the actual file size & base address */
             if (H5F__get_max_eof_eoa(f, &max_eof_eoa) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "file can't get max eof/eoa ")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "file can't get max eof/eoa ");
             base_addr = H5FD_get_base_addr(f->shared->lf);
 
             /* Convert relative base address for file to absolute address */
@@ -420,7 +420,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
 
             /* Get file image */
             if (H5F__get_file_image(f, gfi_args->buf, gfi_args->buf_size, gfi_args->image_len) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "get file image failed")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "get file image failed");
 
             break;
         }
@@ -431,7 +431,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
 
             /* Get the actual amount of free space in the file */
             if (H5MF_get_freespace(f, gfs_args->size, NULL) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to check free space for file")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to check free space for file");
 
             break;
         }
@@ -443,7 +443,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
             /* Go get the free-space section information in the file */
             if (H5MF_get_free_sections(f, gfs_args->type, gfs_args->nsects, gfs_args->sect_info,
                                        gfs_args->sect_count) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to check free space for file")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to check free space for file");
 
             break;
         }
@@ -456,11 +456,11 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
              * for the top file in a mount hierarchy.
              */
             if (H5VL_native_get_file_struct(obj, gfi_args->type, &f) < 0)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "could not get a file struct")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "could not get a file struct");
 
             /* Get the file info */
             if (H5F__get_info(f, gfi_args->finfo) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to retrieve file info")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to retrieve file info");
 
             break;
         }
@@ -469,7 +469,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_GET_MDC_CONF: {
             /* Get the metadata cache configuration */
             if (H5AC_get_cache_auto_resize_config(f->shared->cache, opt_args->get_mdc_config.config) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata cache configuration")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata cache configuration");
 
             break;
         }
@@ -478,7 +478,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_GET_MDC_HR: {
             /* Get the current hit rate */
             if (H5AC_get_cache_hit_rate(f->shared->cache, opt_args->get_mdc_hit_rate.hit_rate) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata cache hit rate")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata cache hit rate");
 
             break;
         }
@@ -490,7 +490,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
             /* Get the size data */
             if (H5AC_get_cache_size(f->shared->cache, gms_args->max_size, gms_args->min_clean_size,
                                     gms_args->cur_size, gms_args->cur_num_entries) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata cache size")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata cache size");
 
             break;
         }
@@ -501,7 +501,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
 
             /* Retrieve the VFD handle for the file */
             if (H5F_get_vfd_handle(f, gvh_args->fapl_id, gvh_args->file_handle) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve VFD handle")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve VFD handle");
 
             break;
         }
@@ -511,7 +511,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
             /* Release the EFC */
             if (f->shared->efc)
                 if (H5F__efc_release(f->shared->efc) < 0)
-                    HGOTO_ERROR(H5E_FILE, H5E_CANTRELEASE, FAIL, "can't release external file cache")
+                    HGOTO_ERROR(H5E_FILE, H5E_CANTRELEASE, FAIL, "can't release external file cache");
 
             break;
         }
@@ -520,7 +520,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_RESET_MDC_HIT_RATE: {
             /* Reset the hit rate statistic */
             if (H5AC_reset_cache_hit_rate_stats(f->shared->cache) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't reset cache hit rate")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't reset cache hit rate");
 
             break;
         }
@@ -529,7 +529,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_SET_MDC_CONFIG: {
             /* Set the metadata cache configuration  */
             if (H5AC_set_cache_auto_resize_config(f->shared->cache, opt_args->set_mdc_config.config) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set metadata cache configuration")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set metadata cache configuration");
 
             break;
         }
@@ -537,7 +537,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         /* H5Fget_metadata_read_retry_info */
         case H5VL_NATIVE_FILE_GET_METADATA_READ_RETRY_INFO: {
             if (H5F_get_metadata_read_retry_info(f, opt_args->get_metadata_read_retry_info.info) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata read retry info")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get metadata read retry info");
 
             break;
         }
@@ -545,7 +545,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         /* H5Fstart_swmr_write */
         case H5VL_NATIVE_FILE_START_SWMR_WRITE: {
             if (H5F__start_swmr_write(f) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't start SWMR write")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't start SWMR write");
 
             break;
         }
@@ -554,7 +554,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_START_MDC_LOGGING: {
             /* Call mdc logging function */
             if (H5C_start_logging(f->shared->cache) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_LOGGING, FAIL, "unable to start mdc logging")
+                HGOTO_ERROR(H5E_FILE, H5E_LOGGING, FAIL, "unable to start mdc logging");
 
             break;
         }
@@ -563,7 +563,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_STOP_MDC_LOGGING: {
             /* Call mdc logging function */
             if (H5C_stop_logging(f->shared->cache) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_LOGGING, FAIL, "unable to stop mdc logging")
+                HGOTO_ERROR(H5E_FILE, H5E_LOGGING, FAIL, "unable to stop mdc logging");
 
             break;
         }
@@ -575,7 +575,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
             /* Call mdc logging function */
             if (H5C_get_logging_status(f->shared->cache, gmls_args->is_enabled,
                                        gmls_args->is_currently_logging) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_LOGGING, FAIL, "unable to get logging status")
+                HGOTO_ERROR(H5E_FILE, H5E_LOGGING, FAIL, "unable to get logging status");
 
             break;
         }
@@ -584,7 +584,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_FORMAT_CONVERT: {
             /* Convert the format */
             if (H5F__format_convert(f) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTCONVERT, FAIL, "can't convert file format")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTCONVERT, FAIL, "can't convert file format");
 
             break;
         }
@@ -593,11 +593,11 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_RESET_PAGE_BUFFERING_STATS: {
             /* Sanity check */
             if (NULL == f->shared->page_buf)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "page buffering not enabled on file")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "page buffering not enabled on file");
 
             /* Reset the statistics */
             if (H5PB_reset_stats(f->shared->page_buf) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't reset stats for page buffering")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't reset stats for page buffering");
 
             break;
         }
@@ -608,12 +608,12 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
 
             /* Sanity check */
             if (NULL == f->shared->page_buf)
-                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "page buffering not enabled on file")
+                HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "page buffering not enabled on file");
 
             /* Get the statistics */
             if (H5PB_get_stats(f->shared->page_buf, gpbs_args->accesses, gpbs_args->hits, gpbs_args->misses,
                                gpbs_args->evictions, gpbs_args->bypasses) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve stats for page buffering")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve stats for page buffering");
 
             break;
         }
@@ -624,7 +624,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
 
             /* Go get the address and size of the cache image */
             if (H5AC_get_mdc_image_info(f->shared->cache, gmii_args->addr, gmii_args->len) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve cache image info")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't retrieve cache image info");
 
             break;
         }
@@ -637,11 +637,11 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
             /* We might introduce a new feature flag in the future */
             if (!H5F_HAS_FEATURE(f, H5FD_FEAT_SUPPORTS_SWMR_IO))
                 HGOTO_ERROR(H5E_FILE, H5E_BADVALUE, FAIL,
-                            "must use a SWMR-compatible VFD for this public routine")
+                            "must use a SWMR-compatible VFD for this public routine");
 
             /* The real work */
             if (HADDR_UNDEF == (rel_eoa = H5F_get_eoa(f, H5FD_MEM_DEFAULT)))
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "get_eoa request failed")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "get_eoa request failed");
 
             /* Set return value */
             /* (Note compensating for base address subtraction in internal routine) */
@@ -658,15 +658,15 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
             /* We might introduce a new feature flag in the future */
             if (!H5F_HAS_FEATURE(f, H5FD_FEAT_SUPPORTS_SWMR_IO))
                 HGOTO_ERROR(H5E_FILE, H5E_BADVALUE, FAIL,
-                            "must use a SWMR-compatible VFD for this public routine")
+                            "must use a SWMR-compatible VFD for this public routine");
 
             /* Get the maximum of EOA and EOF */
             if (H5F__get_max_eof_eoa(f, &max_eof_eoa) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "file can't get max eof/eoa ")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "file can't get max eof/eoa ");
 
             /* Set EOA to the maximum value + increment */
             if (H5F__set_eoa(f, H5FD_MEM_DEFAULT, max_eof_eoa + opt_args->increment_filesize.increment) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "driver set_eoa request failed")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "driver set_eoa request failed");
 
             break;
         }
@@ -677,7 +677,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
 
             /* Call internal set_libver_bounds function */
             if (H5F__set_libver_bounds(f, slb_args->low, slb_args->high) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "cannot set low/high bounds")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "cannot set low/high bounds");
 
             break;
         }
@@ -693,7 +693,7 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_SET_MIN_DSET_OHDR_FLAG: {
             if (H5F_set_min_dset_ohdr(f, opt_args->set_min_dset_ohdr_flag.minimize) < 0)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL,
-                            "cannot set file's dataset object header minimization flag")
+                            "cannot set file's dataset object header minimization flag");
 
             break;
         }
@@ -720,12 +720,12 @@ H5VL__native_file_optional(void *obj, H5VL_optional_args_t *args, hid_t H5_ATTR_
         case H5VL_NATIVE_FILE_POST_OPEN: {
             /* Call package routine */
             if (H5F__post_open(f) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "can't finish opening file")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "can't finish opening file");
             break;
         }
 
         default:
-            HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "invalid optional operation")
+            HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "invalid optional operation");
     } /* end switch */
 
 done:
@@ -753,7 +753,7 @@ H5VL__native_file_close(void *file, hid_t H5_ATTR_UNUSED dxpl_id, void H5_ATTR_U
     FUNC_ENTER_PACKAGE
 
     /* This routine should only be called when a file ID's ref count drops to zero */
-    HDassert(f->shared == NULL || H5F_ID_EXISTS(f));
+    assert(f->shared == NULL || H5F_ID_EXISTS(f));
 
     if (f->shared == NULL)
         f = H5FL_FREE(H5F_t, f);
@@ -768,19 +768,19 @@ H5VL__native_file_close(void *file, hid_t H5_ATTR_UNUSED dxpl_id, void H5_ATTR_U
         if ((H5F_NREFS(f) > 1) && (H5F_INTENT(f) & H5F_ACC_RDWR)) {
             /* Get the file ID corresponding to the H5F_t struct */
             if (H5I_find_id(f, H5I_FILE, &file_id) < 0 || H5I_INVALID_HID == file_id)
-                HGOTO_ERROR(H5E_ID, H5E_CANTGET, FAIL, "invalid ID")
+                HGOTO_ERROR(H5E_ID, H5E_CANTGET, FAIL, "invalid ID");
 
             /* Get the number of references outstanding for this file ID */
             if ((nref = H5I_get_ref(file_id, FALSE)) < 0)
-                HGOTO_ERROR(H5E_ID, H5E_CANTGET, FAIL, "can't get ID ref count")
+                HGOTO_ERROR(H5E_ID, H5E_CANTGET, FAIL, "can't get ID ref count");
             if (nref == 1)
                 if (H5F__flush(f) < 0)
-                    HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush cache")
+                    HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush cache");
         } /* end if */
 
         /* Close the file */
         if (H5F__close(f) < 0)
-            HGOTO_ERROR(H5E_FILE, H5E_CANTDEC, FAIL, "can't close file")
+            HGOTO_ERROR(H5E_FILE, H5E_CANTDEC, FAIL, "can't close file");
     }
 
 done:
