@@ -80,13 +80,13 @@ H5VL__native_object_open(void *obj, const H5VL_loc_params_t *loc_params, H5I_typ
     FUNC_ENTER_PACKAGE
 
     if (H5G_loc_real(obj, loc_params->obj_type, &loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "not a file or file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "not a file or file object");
 
     switch (loc_params->type) {
         case H5VL_OBJECT_BY_NAME: {
             /* Open the object */
             if (NULL == (ret_value = H5O_open_name(&loc, loc_params->loc_data.loc_by_name.name, opened_type)))
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, NULL, "unable to open object by name")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, NULL, "unable to open object by name");
             break;
         }
 
@@ -96,7 +96,7 @@ H5VL__native_object_open(void *obj, const H5VL_loc_params_t *loc_params, H5I_typ
                                                       loc_params->loc_data.loc_by_idx.idx_type,
                                                       loc_params->loc_data.loc_by_idx.order,
                                                       loc_params->loc_data.loc_by_idx.n, opened_type)))
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, NULL, "unable to open object by index")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, NULL, "unable to open object by index");
             break;
         }
 
@@ -107,17 +107,17 @@ H5VL__native_object_open(void *obj, const H5VL_loc_params_t *loc_params, H5I_typ
             /* Decode token */
             if (H5VL_native_token_to_addr(loc.oloc->file, H5I_FILE, token, &addr) < 0)
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTUNSERIALIZE, NULL,
-                            "can't deserialize object token into address")
+                            "can't deserialize object token into address");
 
             /* Open the object */
             if (NULL == (ret_value = H5O__open_by_addr(&loc, addr, opened_type)))
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, NULL, "unable to open object by address")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, NULL, "unable to open object by address");
             break;
         }
 
         case H5VL_OBJECT_BY_SELF:
         default:
-            HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, NULL, "unknown open parameters")
+            HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, NULL, "unknown open parameters");
     } /* end switch */
 
 done:
@@ -147,13 +147,13 @@ H5VL__native_object_copy(void *src_obj, const H5VL_loc_params_t *loc_params1, co
 
     /* get location for objects */
     if (H5G_loc_real(src_obj, loc_params1->obj_type, &src_loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
     if (H5G_loc_real(dst_obj, loc_params2->obj_type, &dst_loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
 
     /* Copy the object */
     if ((ret_value = H5O__copy(&src_loc, src_name, &dst_loc, dst_name, ocpypl_id, lcpl_id)) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTCOPY, FAIL, "unable to copy object");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -178,7 +178,7 @@ H5VL__native_object_get(void *obj, const H5VL_loc_params_t *loc_params, H5VL_obj
     FUNC_ENTER_PACKAGE
 
     if (H5G_loc_real(obj, loc_params->obj_type, &loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
 
     switch (args->op_type) {
 
@@ -194,7 +194,7 @@ H5VL__native_object_get(void *obj, const H5VL_loc_params_t *loc_params, H5VL_obj
                 loc.oloc->file->id_exists = TRUE;
             }
             else
-                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown get_file parameters")
+                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown get_file parameters");
 
             break;
         }
@@ -205,7 +205,7 @@ H5VL__native_object_get(void *obj, const H5VL_loc_params_t *loc_params, H5VL_obj
                 /* Retrieve object's name */
                 if (H5G_get_name(&loc, args->args.get_name.buf, args->args.get_name.buf_size,
                                  args->args.get_name.name_len, NULL) < 0)
-                    HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't retrieve object name")
+                    HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't retrieve object name");
             } /* end if */
             else if (loc_params->type == H5VL_OBJECT_BY_TOKEN) {
                 H5O_loc_t   obj_oloc; /* Object location */
@@ -218,15 +218,15 @@ H5VL__native_object_get(void *obj, const H5VL_loc_params_t *loc_params, H5VL_obj
                 /* Decode token */
                 if (H5VL_native_token_to_addr(obj_oloc.file, H5I_FILE, token, &obj_oloc.addr) < 0)
                     HGOTO_ERROR(H5E_OHDR, H5E_CANTUNSERIALIZE, FAIL,
-                                "can't deserialize object token into address")
+                                "can't deserialize object token into address");
 
                 /* Retrieve object's name */
                 if (H5G_get_name_by_addr(loc.oloc->file, &obj_oloc, args->args.get_name.buf,
                                          args->args.get_name.buf_size, args->args.get_name.name_len) < 0)
-                    HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't determine object name")
+                    HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't determine object name");
             } /* end else-if */
             else
-                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown get_name parameters")
+                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown get_name parameters");
 
             break;
         }
@@ -245,15 +245,15 @@ H5VL__native_object_get(void *obj, const H5VL_loc_params_t *loc_params, H5VL_obj
                 /* Decode token */
                 if (H5VL_native_token_to_addr(obj_oloc.file, H5I_FILE, token, &obj_oloc.addr) < 0)
                     HGOTO_ERROR(H5E_OHDR, H5E_CANTUNSERIALIZE, FAIL,
-                                "can't deserialize object token into address")
+                                "can't deserialize object token into address");
 
                 /* Get the # of links for object, and its type */
                 /* (To check to make certain that this object hasn't been deleted) */
                 if (H5O_get_rc_and_type(&obj_oloc, &rc, args->args.get_type.obj_type) < 0 || 0 == rc)
-                    HGOTO_ERROR(H5E_REFERENCE, H5E_LINKCOUNT, FAIL, "dereferencing deleted object")
+                    HGOTO_ERROR(H5E_REFERENCE, H5E_LINKCOUNT, FAIL, "dereferencing deleted object");
             }
             else
-                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown get_type parameters")
+                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown get_type parameters");
 
             break;
         }
@@ -262,12 +262,12 @@ H5VL__native_object_get(void *obj, const H5VL_loc_params_t *loc_params, H5VL_obj
         case H5VL_OBJECT_GET_INFO: {
             if (loc_params->type == H5VL_OBJECT_BY_SELF) {
                 if (H5G_loc_info(&loc, ".", args->args.get_info.oinfo, args->args.get_info.fields) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found");
             } /* end if */
             else if (loc_params->type == H5VL_OBJECT_BY_NAME) {
                 if (H5G_loc_info(&loc, loc_params->loc_data.loc_by_name.name, args->args.get_info.oinfo,
                                  args->args.get_info.fields) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found");
             } /* end else-if */
             else if (loc_params->type == H5VL_OBJECT_BY_IDX) {
                 H5G_loc_t  obj_loc;  /* Location used to open group */
@@ -284,26 +284,26 @@ H5VL__native_object_get(void *obj, const H5VL_loc_params_t *loc_params, H5VL_obj
                                         loc_params->loc_data.loc_by_idx.idx_type,
                                         loc_params->loc_data.loc_by_idx.order,
                                         loc_params->loc_data.loc_by_idx.n, &obj_loc /*out*/) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "group not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "group not found");
 
                 /* Retrieve the object's information */
                 if (H5O_get_info(obj_loc.oloc, args->args.get_info.oinfo, args->args.get_info.fields) < 0) {
                     H5G_loc_free(&obj_loc);
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't retrieve object info")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't retrieve object info");
                 } /* end if */
 
                 /* Release the object location */
                 if (H5G_loc_free(&obj_loc) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "can't free location")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "can't free location");
             } /* end else-if */
             else
-                HGOTO_ERROR(H5E_OHDR, H5E_UNSUPPORTED, FAIL, "unknown get info parameters")
+                HGOTO_ERROR(H5E_OHDR, H5E_UNSUPPORTED, FAIL, "unknown get info parameters");
 
             break;
         }
 
         default:
-            HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't get this type of information from object")
+            HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't get this type of information from object");
     } /* end switch */
 
 done:
@@ -330,13 +330,13 @@ H5VL__native_object_specific(void *obj, const H5VL_loc_params_t *loc_params,
     FUNC_ENTER_PACKAGE
 
     if (H5G_loc_real(obj, loc_params->obj_type, &loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
 
     switch (args->op_type) {
         /* H5Oincr_refcount / H5Odecr_refcount */
         case H5VL_OBJECT_CHANGE_REF_COUNT: {
             if (H5O_link(loc.oloc, args->args.change_rc.delta) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_LINKCOUNT, FAIL, "modifying object link count failed")
+                HGOTO_ERROR(H5E_OHDR, H5E_LINKCOUNT, FAIL, "modifying object link count failed");
 
             break;
         }
@@ -347,10 +347,10 @@ H5VL__native_object_specific(void *obj, const H5VL_loc_params_t *loc_params,
                 /* Check if the object exists */
                 if (H5G_loc_exists(&loc, loc_params->loc_data.loc_by_name.name, args->args.exists.exists) < 0)
                     HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to determine if '%s' exists",
-                                loc_params->loc_data.loc_by_name.name)
+                                loc_params->loc_data.loc_by_name.name);
             } /* end if */
             else
-                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown object exists parameters")
+                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown object exists parameters");
 
             break;
         }
@@ -369,20 +369,20 @@ H5VL__native_object_specific(void *obj, const H5VL_loc_params_t *loc_params,
 
                 /* Find the object */
                 if (H5G_loc_find(&loc, loc_params->loc_data.loc_by_name.name, &obj_loc) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found");
 
                 /* Encode token */
                 if (H5VL_native_addr_to_token(loc.oloc->file, H5I_FILE, obj_loc.oloc->addr,
                                               args->args.lookup.token_ptr) < 0)
                     HGOTO_ERROR(H5E_OHDR, H5E_CANTSERIALIZE, FAIL,
-                                "can't serialize address into object token")
+                                "can't serialize address into object token");
 
                 /* Release the object location */
                 if (H5G_loc_free(&obj_loc) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "can't free location")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "can't free location");
             } /* end if */
             else
-                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown object exists parameters")
+                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown object exists parameters");
             break;
         }
 
@@ -394,13 +394,13 @@ H5VL__native_object_specific(void *obj, const H5VL_loc_params_t *loc_params,
             if (loc_params->type == H5VL_OBJECT_BY_SELF) {
                 if ((ret_value = H5O__visit(&loc, ".", visit_args->idx_type, visit_args->order,
                                             visit_args->op, visit_args->op_data, visit_args->fields)) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "object visitation failed")
+                    HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "object visitation failed");
             } /* end if */
             else if (loc_params->type == H5VL_OBJECT_BY_NAME) {
                 if ((ret_value = H5O__visit(&loc, loc_params->loc_data.loc_by_name.name, visit_args->idx_type,
                                             visit_args->order, visit_args->op, visit_args->op_data,
                                             visit_args->fields)) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "object visitation failed")
+                    HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "object visitation failed");
             } /* end else-if */
             else
                 HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown object visit params");
@@ -411,7 +411,7 @@ H5VL__native_object_specific(void *obj, const H5VL_loc_params_t *loc_params,
         case H5VL_OBJECT_FLUSH: {
             /* Flush the object's metadata */
             if (H5O_flush(loc.oloc, args->args.flush.obj_id) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object");
 
             break;
         }
@@ -419,13 +419,13 @@ H5VL__native_object_specific(void *obj, const H5VL_loc_params_t *loc_params,
         case H5VL_OBJECT_REFRESH: {
             /* Refresh the metadata */
             if (H5O_refresh_metadata(loc.oloc, args->args.refresh.obj_id) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object");
 
             break;
         }
 
         default:
-            HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't recognize this operation type")
+            HGOTO_ERROR(H5E_VOL, H5E_CANTGET, FAIL, "can't recognize this operation type");
     } /* end switch */
 
 done:
@@ -452,7 +452,7 @@ H5VL__native_object_optional(void *obj, const H5VL_loc_params_t *loc_params, H5V
     FUNC_ENTER_PACKAGE
 
     if (H5G_loc_real(obj, loc_params->obj_type, &loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file or file object");
 
     switch (args->op_type) {
         /* H5Oget_comment / H5Oget_comment_by_name */
@@ -462,15 +462,15 @@ H5VL__native_object_optional(void *obj, const H5VL_loc_params_t *loc_params, H5V
             /* Retrieve the object's comment */
             if (loc_params->type == H5VL_OBJECT_BY_SELF) { /* H5Oget_comment */
                 if (H5G_loc_get_comment(&loc, ".", gc_args->buf, gc_args->buf_size, gc_args->comment_len) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't get comment for object")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't get comment for object");
             }                                                   /* end if */
             else if (loc_params->type == H5VL_OBJECT_BY_NAME) { /* H5Oget_comment_by_name */
                 if (H5G_loc_get_comment(&loc, loc_params->loc_data.loc_by_name.name, gc_args->buf,
                                         gc_args->buf_size, gc_args->comment_len) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't get comment for object")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't get comment for object");
             } /* end else-if */
             else
-                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown set_coment parameters")
+                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown set_coment parameters");
 
             break;
         }
@@ -479,15 +479,15 @@ H5VL__native_object_optional(void *obj, const H5VL_loc_params_t *loc_params, H5V
         case H5VL_NATIVE_OBJECT_SET_COMMENT: {
             if (loc_params->type == H5VL_OBJECT_BY_SELF) { /* H5Oset_comment */
                 if (H5G_loc_set_comment(&loc, ".", opt_args->set_comment.comment) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found");
             }                                                   /* end if */
             else if (loc_params->type == H5VL_OBJECT_BY_NAME) { /* H5Oset_comment_by_name */
                 if (H5G_loc_set_comment(&loc, loc_params->loc_data.loc_by_name.name,
                                         opt_args->set_comment.comment) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found");
             } /* end else-if */
             else
-                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown set_coment parameters")
+                HGOTO_ERROR(H5E_VOL, H5E_UNSUPPORTED, FAIL, "unknown set_coment parameters");
 
             break;
         }
@@ -523,12 +523,12 @@ H5VL__native_object_optional(void *obj, const H5VL_loc_params_t *loc_params, H5V
             /* Use the original H5Oget_info code to get the data */
             if (loc_params->type == H5VL_OBJECT_BY_SELF) {
                 if (H5G_loc_native_info(&loc, ".", gni_args->ninfo, gni_args->fields) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found");
             }                                                   /* end if */
             else if (loc_params->type == H5VL_OBJECT_BY_NAME) { /* H5Oget_info_by_name */
                 if (H5G_loc_native_info(&loc, loc_params->loc_data.loc_by_name.name, gni_args->ninfo,
                                         gni_args->fields) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "object not found");
             }                                                  /* end else-if */
             else if (loc_params->type == H5VL_OBJECT_BY_IDX) { /* H5Oget_info_by_idx */
                 H5G_loc_t  obj_loc;                            /* Location used to open group */
@@ -545,19 +545,19 @@ H5VL__native_object_optional(void *obj, const H5VL_loc_params_t *loc_params, H5V
                                         loc_params->loc_data.loc_by_idx.idx_type,
                                         loc_params->loc_data.loc_by_idx.order,
                                         loc_params->loc_data.loc_by_idx.n, &obj_loc /*out*/) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "group not found")
+                    HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "group not found");
 
                 if (H5O_get_native_info(obj_loc.oloc, gni_args->ninfo, gni_args->fields) < 0) {
                     H5G_loc_free(&obj_loc);
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't retrieve object info")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't retrieve object info");
                 } /* end if */
 
                 /* Release the object location */
                 if (H5G_loc_free(&obj_loc) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "can't free location")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTRELEASE, FAIL, "can't free location");
             } /* end else-if */
             else
-                HGOTO_ERROR(H5E_OHDR, H5E_UNSUPPORTED, FAIL, "unknown get info parameters")
+                HGOTO_ERROR(H5E_OHDR, H5E_UNSUPPORTED, FAIL, "unknown get info parameters");
 
             break;
         }
