@@ -10,11 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- * Programmer:  Robb Matzke
- *              Friday, August 27, 1999
- */
-
 #include "H5Zmodule.h" /* This source code file is part of the H5Z module */
 
 #include "H5private.h"   /* Generic Functions			*/
@@ -58,9 +53,6 @@ const H5Z_class2_t H5Z_DEFLATE[1] = {{
  * Return:	Success: Size of buffer filtered
  *		Failure: 0
  *
- * Programmer:	Robb Matzke
- *              Thursday, April 16, 1998
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -74,13 +66,13 @@ H5Z__filter_deflate(unsigned flags, size_t cd_nelmts, const unsigned cd_values[]
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(*buf_size > 0);
-    HDassert(buf);
-    HDassert(*buf);
+    assert(*buf_size > 0);
+    assert(buf);
+    assert(*buf);
 
     /* Check arguments */
     if (cd_nelmts != 1 || cd_values[0] > 9)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid deflate aggression level")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid deflate aggression level");
 
     if (flags & H5Z_FLAG_REVERSE) {
         /* Input; uncompress */
@@ -89,10 +81,10 @@ H5Z__filter_deflate(unsigned flags, size_t cd_nelmts, const unsigned cd_values[]
 
         /* Allocate space for the compressed buffer */
         if (NULL == (outbuf = H5MM_malloc(nalloc)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, 0, "memory allocation failed for deflate uncompression")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, 0, "memory allocation failed for deflate uncompression");
 
         /* Set the uncompression parameters */
-        HDmemset(&z_strm, 0, sizeof(z_strm));
+        memset(&z_strm, 0, sizeof(z_strm));
         z_strm.next_in = (Bytef *)*buf;
         H5_CHECKED_ASSIGN(z_strm.avail_in, unsigned, nbytes, size_t);
         z_strm.next_out = (Bytef *)outbuf;
@@ -100,7 +92,7 @@ H5Z__filter_deflate(unsigned flags, size_t cd_nelmts, const unsigned cd_values[]
 
         /* Initialize the uncompression routines */
         if (Z_OK != inflateInit(&z_strm))
-            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "inflateInit() failed")
+            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "inflateInit() failed");
 
         /* Loop to uncompress the buffer */
         do {
@@ -114,7 +106,7 @@ H5Z__filter_deflate(unsigned flags, size_t cd_nelmts, const unsigned cd_values[]
             /* Check for error */
             if (Z_OK != status) {
                 (void)inflateEnd(&z_strm);
-                HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "inflate() failed")
+                HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "inflate() failed");
             }
             else {
                 /* If we're not done and just ran out of buffer space, get more */
@@ -126,7 +118,7 @@ H5Z__filter_deflate(unsigned flags, size_t cd_nelmts, const unsigned cd_values[]
                     if (NULL == (new_outbuf = H5MM_realloc(outbuf, nalloc))) {
                         (void)inflateEnd(&z_strm);
                         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, 0,
-                                    "memory allocation failed for deflate uncompression")
+                                    "memory allocation failed for deflate uncompression");
                     } /* end if */
                     outbuf = new_outbuf;
 
@@ -166,7 +158,7 @@ H5Z__filter_deflate(unsigned flags, size_t cd_nelmts, const unsigned cd_values[]
 
         /* Allocate output (compressed) buffer */
         if (NULL == (outbuf = H5MM_malloc(z_dst_nbytes)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, 0, "unable to allocate deflate destination buffer")
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, 0, "unable to allocate deflate destination buffer");
         z_dst = (Bytef *)outbuf;
 
         /* Perform compression from the source to the destination buffer */
@@ -174,11 +166,11 @@ H5Z__filter_deflate(unsigned flags, size_t cd_nelmts, const unsigned cd_values[]
 
         /* Check for various zlib errors */
         if (Z_BUF_ERROR == status)
-            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "overflow")
+            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "overflow");
         else if (Z_MEM_ERROR == status)
-            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "deflate memory error")
+            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "deflate memory error");
         else if (Z_OK != status)
-            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "other deflate error")
+            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, 0, "other deflate error");
         /* Successfully uncompressed the buffer */
         else {
             /* Free the input buffer */
