@@ -43,8 +43,6 @@ static hsize_t bigio_count_g = H5_MAX_MPI_COUNT;
  *
  * Return:    The current/previous value of bigio_count_g.
  *
- * Programmer: Richard Warren,  March 10, 2017
- *
  *-------------------------------------------------------------------------
  */
 hsize_t
@@ -66,11 +64,9 @@ H5_mpi_set_bigio_count(hsize_t new_count)
  *
  * Return:    The current/previous value of bigio_count_g.
  *
- * Programmer: Richard Warren,  October 7, 2019
- *
  *-------------------------------------------------------------------------
  */
-hsize_t
+H5_ATTR_PURE hsize_t
 H5_mpi_get_bigio_count(void)
 {
     return bigio_count_g;
@@ -101,7 +97,7 @@ H5_mpi_comm_dup(MPI_Comm comm, MPI_Comm *comm_new)
 
     /* Check arguments */
     if (!comm_new)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm_new cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm_new cannot be NULL");
 
     /* Handle MPI_COMM_NULL separately */
     if (MPI_COMM_NULL == comm) {
@@ -160,7 +156,7 @@ H5_mpi_info_dup(MPI_Info info, MPI_Info *info_new)
 
     /* Check arguments */
     if (!info_new)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info_new cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info_new cannot be NULL");
 
     /* Duplicate the MPI info */
     if (info == MPI_INFO_NULL) {
@@ -206,7 +202,7 @@ H5_mpi_comm_free(MPI_Comm *comm)
 
     /* Check arguments */
     if (!comm)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm pointer cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm pointer cannot be NULL");
 
     /* Free the communicator */
     if (MPI_COMM_WORLD != *comm && MPI_COMM_NULL != *comm)
@@ -238,7 +234,7 @@ H5_mpi_info_free(MPI_Info *info)
 
     /* Check arguments */
     if (!info)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info pointer cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info pointer cannot be NULL");
 
     /* Free the info */
     if (MPI_INFO_NULL != *info)
@@ -281,7 +277,7 @@ H5_mpi_comm_cmp(MPI_Comm comm1, MPI_Comm comm2, int *result)
 
     /* Check arguments */
     if (!result)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL");
 
     /* Set out parameter to something reasonable in case something goes wrong */
     *result = 0;
@@ -349,7 +345,7 @@ H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
 
     /* Check arguments */
     if (!result)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL");
 
     /* Check for MPI_INFO_NULL */
     if (MPI_INFO_NULL == info1 && MPI_INFO_NULL == info2) {
@@ -383,11 +379,11 @@ H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
 
             /* Allocate buffers for iteration */
             if (NULL == (key = (char *)H5MM_malloc(MPI_MAX_INFO_KEY * sizeof(char))))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
             if (NULL == (value1 = (char *)H5MM_malloc(MPI_MAX_INFO_VAL * sizeof(char))))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
             if (NULL == (value2 = (char *)H5MM_malloc(MPI_MAX_INFO_VAL * sizeof(char))))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
             /* Iterate over the keys, comparing them */
             for (i = 0; i < nkeys_1; i++) {
@@ -395,9 +391,9 @@ H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
                 same = TRUE;
 
                 /* Memset the buffers to zero */
-                HDmemset(key, 0, MPI_MAX_INFO_KEY);
-                HDmemset(value1, 0, MPI_MAX_INFO_VAL);
-                HDmemset(value2, 0, MPI_MAX_INFO_VAL);
+                memset(key, 0, MPI_MAX_INFO_KEY);
+                memset(value1, 0, MPI_MAX_INFO_VAL);
+                memset(value2, 0, MPI_MAX_INFO_VAL);
 
                 /* Get the nth key */
                 if (MPI_SUCCESS != (mpi_code = MPI_Info_get_nthkey(info1, i, key)))
@@ -410,7 +406,7 @@ H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
                     HMPI_GOTO_ERROR(FAIL, "MPI_Info_get failed", mpi_code)
 
                 /* Compare values and flags */
-                if (!flag1 || !flag2 || HDmemcmp(value1, value2, MPI_MAX_INFO_VAL)) {
+                if (!flag1 || !flag2 || memcmp(value1, value2, MPI_MAX_INFO_VAL)) {
                     same = FALSE;
                     break;
                 }
@@ -450,8 +446,6 @@ done:
  *
  *              *new_type    the new datatype created
  *
- * Programmer:  Mohamad Chaarawi
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -639,9 +633,9 @@ H5_mpio_gatherv_alloc(void *send_buf, int send_count, MPI_Datatype send_type, co
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(send_buf || send_count == 0);
+    assert(send_buf || send_count == 0);
     if (allgather || (mpi_rank == root))
-        HDassert(out_buf && out_buf_num_entries);
+        assert(out_buf && out_buf_num_entries);
 
         /* Retrieve the extent of the MPI Datatype being used */
 #if H5_CHECK_MPI_VERSION(3, 0)
@@ -652,7 +646,7 @@ H5_mpio_gatherv_alloc(void *send_buf, int send_count, MPI_Datatype send_type, co
         HMPI_GOTO_ERROR(FAIL, "MPI_Type_get_extent(_x) failed", mpi_code)
 
     if (type_extent < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "MPI recv_type had a negative extent")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "MPI recv_type had a negative extent");
 
     /*
      * Calculate the total size of the buffer being
@@ -668,11 +662,11 @@ H5_mpio_gatherv_alloc(void *send_buf, int send_count, MPI_Datatype send_type, co
 
         /* If our buffer size is 0, there's nothing to do */
         if (buf_size == 0)
-            HGOTO_DONE(SUCCEED)
+            HGOTO_DONE(SUCCEED);
 
         if (NULL == (recv_buf = H5MM_malloc(buf_size)))
             /* Push an error, but still participate in collective gather operation */
-            HDONE_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "couldn't allocate receive buffer")
+            HDONE_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "couldn't allocate receive buffer");
     }
 
     /* Perform gather operation */
@@ -725,9 +719,9 @@ H5_mpio_gatherv_alloc_simple(void *send_buf, int send_count, MPI_Datatype send_t
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(send_buf || send_count == 0);
+    assert(send_buf || send_count == 0);
     if (allgather || (mpi_rank == root))
-        HDassert(out_buf && out_buf_num_entries);
+        assert(out_buf && out_buf_num_entries);
 
     /*
      * Allocate array to store the receive counts of each rank, as well as
@@ -741,7 +735,7 @@ H5_mpio_gatherv_alloc_simple(void *send_buf, int send_count, MPI_Datatype send_t
             (recv_counts_disps_array = H5MM_malloc(2 * (size_t)mpi_size * sizeof(*recv_counts_disps_array))))
             /* Push an error, but still participate in collective gather operation */
             HDONE_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL,
-                        "couldn't allocate receive counts and displacements array")
+                        "couldn't allocate receive counts and displacements array");
     }
 
     /* Collect each rank's send count to interested ranks */
@@ -772,7 +766,7 @@ H5_mpio_gatherv_alloc_simple(void *send_buf, int send_count, MPI_Datatype send_t
     if (H5_mpio_gatherv_alloc(send_buf, send_count, send_type, recv_counts_disps_array,
                               &recv_counts_disps_array[mpi_size], recv_type, allgather, root, comm, mpi_rank,
                               mpi_size, out_buf, out_buf_num_entries) < 0)
-        HGOTO_ERROR(H5E_LIB, H5E_CANTGATHER, FAIL, "can't gather data")
+        HGOTO_ERROR(H5E_LIB, H5E_CANTGATHER, FAIL, "can't gather data");
 
 done:
     if (recv_counts_disps_array)
@@ -794,8 +788,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Houjun Tang,  April 7, 2022
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -803,30 +795,31 @@ H5_mpio_get_file_sync_required(MPI_File fh, hbool_t *file_sync_required)
 {
     MPI_Info info_used;
     int      flag;
+    char    *sync_env_var;
     char     value[MPI_MAX_INFO_VAL];
     herr_t   ret_value = SUCCEED;
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(file_sync_required);
+    assert(file_sync_required);
 
     *file_sync_required = FALSE;
 
     if (MPI_SUCCESS != MPI_File_get_info(fh, &info_used))
-        HGOTO_ERROR(H5E_LIB, H5E_CANTGET, FAIL, "can't get MPI info")
+        HGOTO_ERROR(H5E_LIB, H5E_CANTGET, FAIL, "can't get MPI info");
 
     if (MPI_SUCCESS !=
         MPI_Info_get(info_used, "romio_visibility_immediate", MPI_MAX_INFO_VAL - 1, value, &flag))
-        HGOTO_ERROR(H5E_LIB, H5E_CANTGET, FAIL, "can't get MPI info")
+        HGOTO_ERROR(H5E_LIB, H5E_CANTGET, FAIL, "can't get MPI info");
 
     if (flag && !HDstrcmp(value, "false"))
         *file_sync_required = TRUE;
 
     if (MPI_SUCCESS != MPI_Info_free(&info_used))
-        HGOTO_ERROR(H5E_LIB, H5E_CANTFREE, FAIL, "can't free MPI info")
+        HGOTO_ERROR(H5E_LIB, H5E_CANTFREE, FAIL, "can't free MPI info");
 
     /* Force setting the flag via env variable (temp solution before the flag is implemented in MPI) */
-    char *sync_env_var = HDgetenv("HDF5_DO_MPI_FILE_SYNC");
+    sync_env_var = HDgetenv("HDF5_DO_MPI_FILE_SYNC");
     if (sync_env_var && (!HDstrcmp(sync_env_var, "TRUE") || !HDstrcmp(sync_env_var, "1")))
         *file_sync_required = TRUE;
     if (sync_env_var && (!HDstrcmp(sync_env_var, "FALSE") || !HDstrcmp(sync_env_var, "0")))
