@@ -5,7 +5,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -73,8 +73,7 @@ test_one_dataset_io(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH)) {
         SKIPPED();
-        HDprintf(
-            "    API functions for basic file, dataset, or flush aren't supported with this connector\n");
+        printf("    API functions for basic file, dataset, or flush aren't supported with this connector\n");
         return 0;
     }
 
@@ -135,7 +134,7 @@ test_one_dataset_io(void)
                 for (j = 0; j < 10; j++)
                     if (wbuf[i][j] != rbuf[i][j]) {
                         H5_FAILED();
-                        HDprintf("    data verification failed\n");
+                        printf("    data verification failed\n");
                         PART_ERROR(single_dset_eswait);
                     } /* end if */
 
@@ -177,7 +176,7 @@ test_one_dataset_io(void)
                 for (j = 0; j < 10; j++)
                     if (wbuf[i][j] != rbuf[i][j]) {
                         H5_FAILED();
-                        HDprintf("    data verification failed\n");
+                        printf("    data verification failed\n");
                         PART_ERROR(single_dset_dclose);
                     } /* end if */
 
@@ -222,7 +221,7 @@ test_one_dataset_io(void)
                 for (j = 0; j < 10; j++)
                     if (wbuf[i][j] != rbuf[i][j]) {
                         H5_FAILED();
-                        HDprintf("    data verification failed\n");
+                        printf("    data verification failed\n");
                         PART_ERROR(single_dset_dflush);
                     } /* end if */
 
@@ -276,7 +275,7 @@ test_one_dataset_io(void)
                 for (j = 0; j < 10; j++)
                     if (wbuf[i][j] != rbuf[i][j]) {
                         H5_FAILED();
-                        HDprintf("    data verification failed\n");
+                        printf("    data verification failed\n");
                         PART_ERROR(single_dset_fclose);
                     } /* end if */
 
@@ -312,7 +311,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_one_dataset_io() */
@@ -341,8 +340,7 @@ test_multi_dataset_io(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH)) {
         SKIPPED();
-        HDprintf(
-            "    API functions for basic file, dataset, or flush aren't supported with this connector\n");
+        printf("    API functions for basic file, dataset, or flush aren't supported with this connector\n");
         return 0;
     }
 
@@ -432,7 +430,7 @@ test_multi_dataset_io(void)
                     for (k = 0; k < 10; k++)
                         if (wbuf[i][j][k] != rbuf[i][j][k]) {
                             H5_FAILED();
-                            HDprintf("    data verification failed\n");
+                            printf("    data verification failed\n");
                             PART_ERROR(multi_dset_open);
                         } /* end if */
 
@@ -526,7 +524,7 @@ test_multi_dataset_io(void)
                     for (k = 0; k < 10; k++)
                         if (wbuf[i][j][k] != rbuf[i][j][k]) {
                             H5_FAILED();
-                            HDprintf("    data verification failed\n");
+                            printf("    data verification failed\n");
                             PART_ERROR(multi_dset_close);
                         } /* end if */
 
@@ -566,7 +564,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_multi_dataset_io() */
@@ -596,8 +594,7 @@ test_multi_file_dataset_io(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH)) {
         SKIPPED();
-        HDprintf(
-            "    API functions for basic file, dataset, or flush aren't supported with this connector\n");
+        printf("    API functions for basic file, dataset, or flush aren't supported with this connector\n");
         return 0;
     }
 
@@ -673,7 +670,7 @@ test_multi_file_dataset_io(void)
                     for (k = 0; k < 10; k++)
                         if (wbuf[i][j][k] != rbuf[i][j][k]) {
                             H5_FAILED();
-                            HDprintf("    data verification failed\n");
+                            printf("    data verification failed\n");
                             PART_ERROR(multi_file_dset_open);
                         } /* end if */
 
@@ -744,7 +741,7 @@ test_multi_file_dataset_io(void)
                     for (k = 0; k < 10; k++)
                         if (wbuf[i][j][k] != rbuf[i][j][k]) {
                             H5_FAILED();
-                            HDprintf("    data verification failed\n");
+                            printf("    data verification failed\n");
                             PART_ERROR(multi_file_dset_dclose);
                         } /* end if */
 
@@ -838,7 +835,7 @@ test_multi_file_dataset_io(void)
                     for (k = 0; k < 10; k++)
                         if (wbuf[i][j][k] != rbuf[i][j][k]) {
                             H5_FAILED();
-                            HDprintf("    data verification failed\n");
+                            printf("    data verification failed\n");
                             PART_ERROR(multi_file_dset_fclose);
                         } /* end if */
 
@@ -876,7 +873,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_multi_file_dataset_io() */
@@ -907,8 +904,7 @@ test_multi_file_grp_dset_io(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC)) {
         SKIPPED();
-        HDprintf(
-            "    API functions for basic file, group, or dataset aren't supported with this connector\n");
+        printf("    API functions for basic file, group, or dataset aren't supported with this connector\n");
         return 0;
     }
 
@@ -1028,7 +1024,7 @@ test_multi_file_grp_dset_io(void)
                     for (k = 0; k < 10; k++)
                         if (wbuf[i][j][k] != rbuf[i][j][k]) {
                             H5_FAILED();
-                            HDprintf("    data verification failed\n");
+                            printf("    data verification failed\n");
                             PART_ERROR(multi_file_grp_dset_no_kick);
                         } /* end if */
 
@@ -1149,7 +1145,7 @@ test_multi_file_grp_dset_io(void)
                     for (k = 0; k < 10; k++)
                         if (wbuf[i][j][k] != rbuf[i][j][k]) {
                             H5_FAILED();
-                            HDprintf("    data verification failed\n");
+                            printf("    data verification failed\n");
                             PART_ERROR(multi_file_grp_dset_kick);
                         } /* end if */
 
@@ -1186,7 +1182,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_multi_file_grp_dset_io() */
@@ -1224,8 +1220,8 @@ test_set_extent(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_MORE)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, dataset, dataset more, or flush aren't supported with "
-                 "this connector\n");
+        printf("    API functions for basic file, dataset, dataset more, or flush aren't supported with "
+               "this connector\n");
         return 0;
     }
 
@@ -1400,7 +1396,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_set_extent() */
@@ -1428,8 +1424,8 @@ test_attribute_exists(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_ATTR_BASIC)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, dataset, dataset more, attribute, or flush aren't "
-                 "supported with this connector\n");
+        printf("    API functions for basic file, dataset, dataset more, attribute, or flush aren't "
+               "supported with this connector\n");
         return 0;
     }
 
@@ -1520,7 +1516,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_attribute_io() */
@@ -1549,8 +1545,8 @@ test_attribute_io(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_ATTR_BASIC)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, dataset, dataset more, attribute, or flush aren't "
-                 "supported with this connector\n");
+        printf("    API functions for basic file, dataset, dataset more, attribute, or flush aren't "
+               "supported with this connector\n");
         return 0;
     }
 
@@ -1663,7 +1659,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_attribute_io() */
@@ -1691,7 +1687,7 @@ test_attribute_io_tconv(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_ATTR_BASIC)) {
         SKIPPED();
-        HDprintf(
+        printf(
             "    API functions for basic file, attribute, or flush aren't supported with this connector\n");
         return 0;
     }
@@ -1798,7 +1794,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_attribute_io_tconv() */
@@ -1837,7 +1833,7 @@ test_attribute_io_compound(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_ATTR_BASIC)) {
         SKIPPED();
-        HDprintf(
+        printf(
             "    API functions for basic file, attribute, or flush aren't supported with this connector\n");
         return 0;
     }
@@ -2114,7 +2110,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_attribute_io_compound() */
@@ -2141,11 +2137,10 @@ test_group(void)
 
     /* Make sure the connector supports the API functions being tested */
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
-        !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_MORE) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH) ||
-        !(vol_cap_flags_g & H5VL_CAP_FLAG_CREATION_ORDER)) {
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_MORE) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, group, group more, or creation order aren't supported "
-                 "with this connector\n");
+        printf("    API functions for basic file, group, or group more aren't supported "
+               "with this connector\n");
         return 0;
     }
 
@@ -2153,9 +2148,11 @@ test_group(void)
     if ((gcpl_id = H5Pcreate(H5P_GROUP_CREATE)) < 0)
         TEST_ERROR;
 
-    /* Track creation order */
-    if (H5Pset_link_creation_order(gcpl_id, H5P_CRT_ORDER_TRACKED | H5P_CRT_ORDER_INDEXED) < 0)
-        TEST_ERROR;
+    if (vol_cap_flags_g & H5VL_CAP_FLAG_CREATION_ORDER) {
+        /* Track creation order */
+        if (H5Pset_link_creation_order(gcpl_id, H5P_CRT_ORDER_TRACKED | H5P_CRT_ORDER_INDEXED) < 0)
+            TEST_ERROR;
+    }
 
     /* Create event stack */
     if ((es_id = H5EScreate()) < 0)
@@ -2219,10 +2216,12 @@ test_group(void)
     if (H5Gget_info_async(group_id, &info1, es_id) < 0)
         TEST_ERROR;
 
-    /* Test H5Gget_info_by_idx_async */
-    if (H5Gget_info_by_idx_async(parent_group_id, ".", H5_INDEX_CRT_ORDER, H5_ITER_INC, 1, &info2,
-                                 H5P_DEFAULT, es_id) < 0)
-        TEST_ERROR;
+    if (vol_cap_flags_g & H5VL_CAP_FLAG_CREATION_ORDER) {
+        /* Test H5Gget_info_by_idx_async */
+        if (H5Gget_info_by_idx_async(parent_group_id, ".", H5_INDEX_CRT_ORDER, H5_ITER_INC, 1, &info2,
+                                     H5P_DEFAULT, es_id) < 0)
+            TEST_ERROR;
+    }
 
     /* Test H5Gget_info_by_name_async */
     if (H5Gget_info_by_name_async(parent_group_id, "group3", &info3, H5P_DEFAULT, es_id) < 0)
@@ -2237,8 +2236,10 @@ test_group(void)
     /* Verify group infos */
     if (info1.nlinks != 0)
         FAIL_PUTS_ERROR("    incorrect number of links");
-    if (info2.nlinks != 1)
-        FAIL_PUTS_ERROR("    incorrect number of links");
+    if (vol_cap_flags_g & H5VL_CAP_FLAG_CREATION_ORDER) {
+        if (info2.nlinks != 1)
+            FAIL_PUTS_ERROR("    incorrect number of links");
+    }
     if (info3.nlinks != 2)
         FAIL_PUTS_ERROR("    incorrect number of links");
 
@@ -2276,7 +2277,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_group() */
@@ -2309,8 +2310,8 @@ test_link(void)
         !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_CREATION_ORDER)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, link, hard link, soft link, flush, or creation order "
-                 "aren't supported with this connector\n");
+        printf("    API functions for basic file, link, hard link, soft link, flush, or creation order "
+               "aren't supported with this connector\n");
         return 0;
     }
 
@@ -2473,7 +2474,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_link() */
@@ -2500,8 +2501,8 @@ test_ocopy_orefresh(void)
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_OBJECT_MORE) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_FLUSH_REFRESH)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, group, dataset, object more, flush, or refresh aren't "
-                 "supported with this connector\n");
+        printf("    API functions for basic file, group, dataset, object more, flush, or refresh aren't "
+               "supported with this connector\n");
         return 0;
     }
 
@@ -2588,7 +2589,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_ocopy_orefresh() */
@@ -2610,7 +2611,7 @@ test_file_reopen(void)
     /* Make sure the connector supports the API functions being tested */
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_MORE)) {
         SKIPPED();
-        HDprintf("    API functions for basic file or file more aren't supported with this connector\n");
+        printf("    API functions for basic file or file more aren't supported with this connector\n");
         return 0;
     }
 
@@ -2659,7 +2660,7 @@ error:
         H5ESwait(es_id, H5_API_TEST_WAIT_FOREVER, &num_in_progress, &op_failed);
         H5ESclose(es_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_file_reopen() */
@@ -2686,16 +2687,16 @@ H5_api_async_test(void)
     size_t i;
     int    nerrors;
 
-    HDprintf("**********************************************\n");
-    HDprintf("*                                            *\n");
-    HDprintf("*             API Async Tests                *\n");
-    HDprintf("*                                            *\n");
-    HDprintf("**********************************************\n\n");
+    printf("**********************************************\n");
+    printf("*                                            *\n");
+    printf("*             API Async Tests                *\n");
+    printf("*                                            *\n");
+    printf("**********************************************\n\n");
 
     /* Make sure the connector supports the API functions being tested */
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_ASYNC)) {
         SKIPPED();
-        HDprintf("    Async APIs aren't supported with this connector\n");
+        printf("    Async APIs aren't supported with this connector\n");
         return 0;
     }
 
@@ -2703,9 +2704,9 @@ H5_api_async_test(void)
         nerrors += (*async_tests[i])() ? 1 : 0;
     }
 
-    HDprintf("\n");
+    printf("\n");
 
-    HDprintf("Cleaning up testing files\n");
+    printf("Cleaning up testing files\n");
     cleanup_files();
 
     return nerrors;
@@ -2716,13 +2717,13 @@ H5_api_async_test(void)
 int
 H5_api_async_test(void)
 {
-    HDprintf("**********************************************\n");
-    HDprintf("*                                            *\n");
-    HDprintf("*             API Async Tests                *\n");
-    HDprintf("*                                            *\n");
-    HDprintf("**********************************************\n\n");
+    printf("**********************************************\n");
+    printf("*                                            *\n");
+    printf("*             API Async Tests                *\n");
+    printf("*                                            *\n");
+    printf("**********************************************\n\n");
 
-    HDprintf("SKIPPED due to no async support in HDF5 library\n");
+    printf("SKIPPED due to no async support in HDF5 library\n");
 
     return 0;
 }
