@@ -5,7 +5,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -44,20 +44,19 @@ test_open_link_without_leading_slash(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC)) {
         SKIPPED();
-        HDprintf(
-            "    API functions for basic file, group, or dataset aren't supported with this connector\n");
+        printf("    API functions for basic file, group, or dataset aren't supported with this connector\n");
         return 0;
     }
 
     if ((file_id = H5Fopen(H5_api_test_filename, H5F_ACC_RDWR, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open file\n");
+        printf("    couldn't open file\n");
         goto error;
     }
 
     if ((container_group = H5Gopen2(file_id, MISCELLANEOUS_TEST_GROUP_NAME, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open container group\n");
+        printf("    couldn't open container group\n");
         goto error;
     }
 
@@ -71,7 +70,7 @@ test_open_link_without_leading_slash(void)
     if ((dset_id = H5Dcreate2(container_group, OPEN_LINK_WITHOUT_SLASH_DSET_NAME, dset_dtype, space_id,
                               H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create dataset\n");
+        printf("    couldn't create dataset\n");
         goto error;
     }
 
@@ -86,20 +85,20 @@ test_open_link_without_leading_slash(void)
 
     if ((file_id = H5Fopen(H5_api_test_filename, H5F_ACC_RDWR, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open file\n");
+        printf("    couldn't open file\n");
         goto error;
     }
 
     if ((group_id = H5Gopen2(file_id, "/", H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open root group\n");
+        printf("    couldn't open root group\n");
         goto error;
     }
 
     if ((dset_id = H5Dopen2(group_id, MISCELLANEOUS_TEST_GROUP_NAME "/" OPEN_LINK_WITHOUT_SLASH_DSET_NAME,
                             H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open dataset\n");
+        printf("    couldn't open dataset\n");
         goto error;
     }
 
@@ -126,7 +125,7 @@ error:
         H5Gclose(container_group);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 }
@@ -149,8 +148,8 @@ test_object_creation_by_absolute_path(void)
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_LINK_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_STORED_DATATYPES)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, group, dataset, link, or stored datatype aren't "
-                 "supported with this connector\n");
+        printf("    API functions for basic file, group, dataset, link, or stored datatype aren't "
+               "supported with this connector\n");
         return 0;
     }
 
@@ -158,13 +157,13 @@ test_object_creation_by_absolute_path(void)
 
     if ((file_id = H5Fopen(H5_api_test_filename, H5F_ACC_RDWR, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open file\n");
+        printf("    couldn't open file\n");
         goto error;
     }
 
     if ((container_group = H5Gopen2(file_id, MISCELLANEOUS_TEST_GROUP_NAME, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open container group\n");
+        printf("    couldn't open container group\n");
         goto error;
     }
 
@@ -172,7 +171,7 @@ test_object_creation_by_absolute_path(void)
     if ((group_id = H5Gcreate2(container_group, OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_CONTAINER_GROUP_NAME,
                                H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create container group\n");
+        printf("    couldn't create container group\n");
         goto error;
     }
 
@@ -181,13 +180,13 @@ test_object_creation_by_absolute_path(void)
                                  "/" OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_CONTAINER_GROUP_NAME,
                                  H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't determine if link exists\n");
+        printf("    couldn't determine if link exists\n");
         goto error;
     }
 
     if (!link_exists) {
         H5_FAILED();
-        HDprintf("    container group didn't exist at the correct location\n");
+        printf("    container group didn't exist at the correct location\n");
         goto error;
     }
 
@@ -206,7 +205,7 @@ test_object_creation_by_absolute_path(void)
                                            "/" OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_SUBGROUP_NAME,
                                            H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create subgroup by absolute pathname\n");
+                printf("    couldn't create subgroup by absolute pathname\n");
                 PART_ERROR(H5Gcreate_using_absolute_path);
             }
 
@@ -216,13 +215,13 @@ test_object_creation_by_absolute_path(void)
                                          "/" OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_SUBGROUP_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Gcreate_using_absolute_path);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    subgroup didn't exist at the correct location\n");
+                printf("    subgroup didn't exist at the correct location\n");
                 PART_ERROR(H5Gcreate_using_absolute_path);
             }
 
@@ -238,13 +237,13 @@ test_object_creation_by_absolute_path(void)
             if ((fspace_id = generate_random_dataspace(OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_DSET_SPACE_RANK,
                                                        NULL, NULL, FALSE)) < 0) {
                 H5_FAILED();
-                HDprintf("    failed to generate dataspace\n");
+                printf("    failed to generate dataspace\n");
                 PART_ERROR(H5Dcreate_using_absolute_path);
             }
 
             if ((dset_dtype = generate_random_datatype(H5T_NO_CLASS, FALSE)) < 0) {
                 H5_FAILED();
-                HDprintf("    failed to generate datatype\n");
+                printf("    failed to generate datatype\n");
                 PART_ERROR(H5Dcreate_using_absolute_path);
             }
 
@@ -255,7 +254,7 @@ test_object_creation_by_absolute_path(void)
                                       "/" OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_DSET_NAME,
                                       dset_dtype, fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create dataset\n");
+                printf("    couldn't create dataset\n");
                 PART_ERROR(H5Dcreate_using_absolute_path);
             }
 
@@ -266,13 +265,13 @@ test_object_creation_by_absolute_path(void)
                                          "/" OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_DSET_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Dcreate_using_absolute_path);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    dataset didn't exist at the correct location\n");
+                printf("    dataset didn't exist at the correct location\n");
                 PART_ERROR(H5Dcreate_using_absolute_path);
             }
 
@@ -287,7 +286,7 @@ test_object_creation_by_absolute_path(void)
             /* Try to create a committed datatype in the same fashion as the preceding dataset */
             if ((dtype_id = generate_random_datatype(H5T_NO_CLASS, FALSE)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create datatype\n");
+                printf("    couldn't create datatype\n");
                 PART_ERROR(H5Tcommit_using_absolute_path);
             }
 
@@ -298,7 +297,7 @@ test_object_creation_by_absolute_path(void)
                            "/" OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_DTYPE_NAME,
                            dtype_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't commit datatype\n");
+                printf("    couldn't commit datatype\n");
                 PART_ERROR(H5Tcommit_using_absolute_path);
             }
 
@@ -309,13 +308,13 @@ test_object_creation_by_absolute_path(void)
                                          "/" OBJECT_CREATE_BY_ABSOLUTE_PATH_TEST_DTYPE_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Tcommit_using_absolute_path);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    datatype didn't exist at the correct location\n");
+                printf("    datatype didn't exist at the correct location\n");
                 PART_ERROR(H5Tcommit_using_absolute_path);
             }
 
@@ -360,7 +359,7 @@ error:
         H5Gclose(container_group);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 }
@@ -384,8 +383,8 @@ test_absolute_vs_relative_path(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_LINK_BASIC)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, group, dataset, or link aren't supported with this "
-                 "connector\n");
+        printf("    API functions for basic file, group, dataset, or link aren't supported with this "
+               "connector\n");
         return 0;
     }
 
@@ -393,13 +392,13 @@ test_absolute_vs_relative_path(void)
 
     if ((file_id = H5Fopen(H5_api_test_filename, H5F_ACC_RDWR, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open file\n");
+        printf("    couldn't open file\n");
         goto error;
     }
 
     if ((container_group = H5Gopen2(file_id, MISCELLANEOUS_TEST_GROUP_NAME, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open container group\n");
+        printf("    couldn't open container group\n");
         goto error;
     }
 
@@ -407,7 +406,7 @@ test_absolute_vs_relative_path(void)
     if ((group_id = H5Gcreate2(container_group, ABSOLUTE_VS_RELATIVE_PATH_TEST_CONTAINER_GROUP_NAME,
                                H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create container group\n");
+        printf("    couldn't create container group\n");
         goto error;
     }
 
@@ -443,7 +442,7 @@ test_absolute_vs_relative_path(void)
                                        "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET1_NAME,
                                        dset_dtype1, fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create dataset by absolute path from root\n");
+                printf("    couldn't create dataset by absolute path from root\n");
                 PART_ERROR(H5Dcreate_absolute_from_root);
             }
 
@@ -453,13 +452,13 @@ test_absolute_vs_relative_path(void)
                                          "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET1_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Dcreate_absolute_from_root);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    didn't exist at the correct location\n");
+                printf("    didn't exist at the correct location\n");
                 PART_ERROR(H5Dcreate_absolute_from_root);
             }
 
@@ -479,7 +478,7 @@ test_absolute_vs_relative_path(void)
                                        "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET4_NAME,
                                        dset_dtype4, fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create dataset by absolute path from container group\n");
+                printf("    couldn't create dataset by absolute path from container group\n");
                 PART_ERROR(H5Dcreate_absolute_from_nonroot);
             }
 
@@ -489,13 +488,13 @@ test_absolute_vs_relative_path(void)
                                          "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET4_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Dcreate_absolute_from_nonroot);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    didn't exist at the correct location\n");
+                printf("    didn't exist at the correct location\n");
                 PART_ERROR(H5Dcreate_absolute_from_nonroot);
             }
 
@@ -523,7 +522,7 @@ test_absolute_vs_relative_path(void)
             if ((dset_id5 = H5Dcreate2(group_id, ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET5_NAME, dset_dtype5,
                                        fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create dataset by relative path from container group\n");
+                printf("    couldn't create dataset by relative path from container group\n");
                 PART_ERROR(H5Dcreate_relative_from_nonroot);
             }
 
@@ -534,7 +533,7 @@ test_absolute_vs_relative_path(void)
                                        "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET2_NAME,
                                        dset_dtype2, fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create dataset by relative path from container group\n");
+                printf("    couldn't create dataset by relative path from container group\n");
                 PART_ERROR(H5Dcreate_relative_from_nonroot);
             }
 
@@ -544,13 +543,13 @@ test_absolute_vs_relative_path(void)
                                          "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET2_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Dcreate_relative_from_nonroot);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    didn't exist at the correct location\n");
+                printf("    didn't exist at the correct location\n");
                 PART_ERROR(H5Dcreate_relative_from_nonroot);
             }
 
@@ -560,13 +559,13 @@ test_absolute_vs_relative_path(void)
                                          "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET5_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Dcreate_relative_from_nonroot);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    didn't exist at the correct location\n");
+                printf("    didn't exist at the correct location\n");
                 PART_ERROR(H5Dcreate_relative_from_nonroot);
             }
 
@@ -585,7 +584,7 @@ test_absolute_vs_relative_path(void)
                                        "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET3_NAME,
                                        dset_dtype3, fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't create dataset by relative path from root with leading '.'\n");
+                printf("    couldn't create dataset by relative path from root with leading '.'\n");
                 PART_ERROR(H5Dcreate_relative_leading_dot_root);
             }
 
@@ -595,13 +594,13 @@ test_absolute_vs_relative_path(void)
                                          "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET3_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Dcreate_relative_leading_dot_root);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    didn't exist at the correct location\n");
+                printf("    didn't exist at the correct location\n");
                 PART_ERROR(H5Dcreate_relative_leading_dot_root);
             }
 
@@ -617,7 +616,7 @@ test_absolute_vs_relative_path(void)
             if ((dset_id6 = H5Dcreate2(group_id, "./" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET6_NAME, dset_dtype6,
                                        fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf(
+                printf(
                     "    couldn't create dataset by relative path from container group with leading '.'\n");
                 PART_ERROR(H5Dcreate_relative_leading_dot_nonroot);
             }
@@ -628,13 +627,13 @@ test_absolute_vs_relative_path(void)
                                          "/" ABSOLUTE_VS_RELATIVE_PATH_TEST_DSET6_NAME,
                                          H5P_DEFAULT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't determine if link exists\n");
+                printf("    couldn't determine if link exists\n");
                 PART_ERROR(H5Dcreate_relative_leading_dot_nonroot);
             }
 
             if (!link_exists) {
                 H5_FAILED();
-                HDprintf("    didn't exist at the correct location\n");
+                printf("    didn't exist at the correct location\n");
                 PART_ERROR(H5Dcreate_relative_leading_dot_nonroot);
             }
 
@@ -703,7 +702,7 @@ error:
         H5Gclose(container_group);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 }
@@ -729,8 +728,8 @@ test_dot_for_object_name(void)
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_STORED_DATATYPES)) {
         SKIPPED();
-        HDprintf("    API functions for basic file, group, dataset, or stored datatype aren't supported with "
-                 "this connector\n");
+        printf("    API functions for basic file, group, dataset, or stored datatype aren't supported with "
+               "this connector\n");
         return 0;
     }
 
@@ -738,26 +737,26 @@ test_dot_for_object_name(void)
 
     if ((file_id = H5Fopen(H5_api_test_filename, H5F_ACC_RDWR, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open file '%s'\n", H5_api_test_filename);
+        printf("    couldn't open file '%s'\n", H5_api_test_filename);
         goto error;
     }
 
     if ((container_group = H5Gopen2(file_id, MISCELLANEOUS_TEST_GROUP_NAME, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open container group '%s'\n", MISCELLANEOUS_TEST_GROUP_NAME);
+        printf("    couldn't open container group '%s'\n", MISCELLANEOUS_TEST_GROUP_NAME);
         goto error;
     }
 
     if ((subgroup_id = H5Gcreate2(container_group, DOT_AS_OBJECT_NAME_TEST_SUBGROUP_NAME, H5P_DEFAULT,
                                   H5P_DEFAULT, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create container subgroup '%s'\n", DOT_AS_OBJECT_NAME_TEST_SUBGROUP_NAME);
+        printf("    couldn't create container subgroup '%s'\n", DOT_AS_OBJECT_NAME_TEST_SUBGROUP_NAME);
         goto error;
     }
 
     if ((dspace_id = H5Screate(H5S_SCALAR)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create data space\n");
+        printf("    couldn't create data space\n");
         goto error;
     }
 
@@ -774,11 +773,11 @@ test_dot_for_object_name(void)
             {
                 group_id = H5Gcreate2(subgroup_id, ".", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
             }
-            H5E_END_TRY;
+            H5E_END_TRY
 
             if (group_id >= 0) {
                 H5_FAILED();
-                HDprintf("    a group was created with '.' as the name!\n");
+                printf("    a group was created with '.' as the name!\n");
                 PART_ERROR(H5Gcreate_dot_as_name);
             }
 
@@ -796,11 +795,11 @@ test_dot_for_object_name(void)
                 dset_id = H5Dcreate2(subgroup_id, ".", H5T_NATIVE_INT, dspace_id, H5P_DEFAULT, H5P_DEFAULT,
                                      H5P_DEFAULT);
             }
-            H5E_END_TRY;
+            H5E_END_TRY
 
             if (dset_id >= 0) {
                 H5_FAILED();
-                HDprintf("    a dataset was created with '.' as the name!\n");
+                printf("    a dataset was created with '.' as the name!\n");
                 PART_ERROR(H5Dcreate_dot_as_name);
             }
 
@@ -814,7 +813,7 @@ test_dot_for_object_name(void)
 
             if ((dtype_id = H5Tcopy(H5T_NATIVE_INT)) < 0) {
                 H5_FAILED();
-                HDprintf("    couldn't copy a native datatype\n");
+                printf("    couldn't copy a native datatype\n");
                 PART_ERROR(H5Tcommit_dot_as_name);
             }
 
@@ -823,17 +822,17 @@ test_dot_for_object_name(void)
             {
                 ret = H5Tcommit2(subgroup_id, ".", dtype_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
             }
-            H5E_END_TRY;
+            H5E_END_TRY
 
             if (ret >= 0) {
                 H5_FAILED();
-                HDprintf("    a named datatype was committed with '.' as the name!\n");
+                printf("    a named datatype was committed with '.' as the name!\n");
                 PART_ERROR(H5Tcommit_dot_as_name);
             }
 
             if (H5Tclose(dtype_id) < 0) {
                 H5_FAILED();
-                HDprintf("    failed to close datatype\n");
+                printf("    failed to close datatype\n");
                 PART_ERROR(H5Tcommit_dot_as_name);
             }
 
@@ -870,7 +869,7 @@ error:
         H5Gclose(container_group);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 }
@@ -918,8 +917,7 @@ test_symbols_in_compound_field_name(void)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC)) {
         SKIPPED();
-        HDprintf(
-            "    API functions for basic file, group, or dataset aren't supported with this connector\n");
+        printf("    API functions for basic file, group, or dataset aren't supported with this connector\n");
         return 0;
     }
 
@@ -928,20 +926,20 @@ test_symbols_in_compound_field_name(void)
 
     if ((file_id = H5Fopen(H5_api_test_filename, H5F_ACC_RDWR, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open file\n");
+        printf("    couldn't open file\n");
         goto error;
     }
 
     if ((container_group = H5Gopen2(file_id, MISCELLANEOUS_TEST_GROUP_NAME, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't open container group\n");
+        printf("    couldn't open container group\n");
         goto error;
     }
 
     if ((group_id = H5Gcreate2(container_group, COMPOUND_WITH_SYMBOLS_IN_MEMBER_NAMES_TEST_SUBGROUP_NAME,
                                H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create container sub-group\n");
+        printf("    couldn't create container sub-group\n");
         goto error;
     }
 
@@ -962,14 +960,14 @@ test_symbols_in_compound_field_name(void)
 
     if ((compound_type = H5Tcreate(H5T_COMPOUND, total_type_size)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create compound datatype\n");
+        printf("    couldn't create compound datatype\n");
         goto error;
     }
 
     for (i = 0, next_offset = 0; i < COMPOUND_WITH_SYMBOLS_IN_MEMBER_NAMES_TEST_NUM_SUBTYPES; i++) {
         if (H5Tinsert(compound_type, member_names[i], next_offset, type_pool[i]) < 0) {
             H5_FAILED();
-            HDprintf("    couldn't insert compound member %zu\n", i);
+            printf("    couldn't insert compound member %zu\n", i);
             goto error;
         }
 
@@ -986,7 +984,7 @@ test_symbols_in_compound_field_name(void)
     if ((dset_id = H5Dcreate2(group_id, COMPOUND_WITH_SYMBOLS_IN_MEMBER_NAMES_TEST_DSET_NAME, compound_type,
                               fspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
         H5_FAILED();
-        HDprintf("    couldn't create dataset\n");
+        printf("    couldn't create dataset\n");
         goto error;
     }
 
@@ -996,7 +994,7 @@ test_symbols_in_compound_field_name(void)
     if ((dset_id = H5Dopen2(group_id, COMPOUND_WITH_SYMBOLS_IN_MEMBER_NAMES_TEST_DSET_NAME, H5P_DEFAULT)) <
         0) {
         H5_FAILED();
-        HDprintf("    failed to open dataset\n");
+        printf("    failed to open dataset\n");
         goto error;
     }
 
@@ -1033,7 +1031,7 @@ error:
         H5Gclose(container_group);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 }
@@ -1044,17 +1042,17 @@ H5_api_misc_test(void)
     size_t i;
     int    nerrors;
 
-    HDprintf("**********************************************\n");
-    HDprintf("*                                            *\n");
-    HDprintf("*          API Miscellaneous Tests           *\n");
-    HDprintf("*                                            *\n");
-    HDprintf("**********************************************\n\n");
+    printf("**********************************************\n");
+    printf("*                                            *\n");
+    printf("*          API Miscellaneous Tests           *\n");
+    printf("*                                            *\n");
+    printf("**********************************************\n\n");
 
     for (i = 0, nerrors = 0; i < ARRAY_LENGTH(misc_tests); i++) {
         nerrors += (*misc_tests[i])() ? 1 : 0;
     }
 
-    HDprintf("\n");
+    printf("\n");
 
     return nerrors;
 }
