@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Neil Fortner
- *              Thursday, August 14, 2008
- *
  * Purpose: Tests closing the library after reference counts have been
  *          manipulated.
  */
@@ -54,13 +51,13 @@ typedef enum {
     T_NUMCLASSES
 } id_class_t;
 
-const char *FILENAME[] = {"app_ref", NULL};
+static const char *FILENAME[] = {"app_ref", NULL};
 
-const char *IDNAME[T_NUMCLASSES] = {"File",        "Property List", "Property Class", "Datatype",
-                                    "Dataspace",   "Dataset",       "Attribute",      "Group",
-                                    "Error Class", "Error Message", "Error Stack"};
+static const char *IDNAME[T_NUMCLASSES] = {"File",        "Property List", "Property Class", "Datatype",
+                                           "Dataspace",   "Dataset",       "Attribute",      "Group",
+                                           "Error Class", "Error Message", "Error Stack"};
 
-int rc[T_NUMCLASSES];
+static int rc[T_NUMCLASSES];
 
 void Abrt_Handler(int sig);
 
@@ -72,9 +69,9 @@ Abrt_Handler(int H5_ATTR_UNUSED sig)
 
     const char *string = " ID reference count: ";
     for (i = 0; i < T_NUMCLASSES; i++) {
-        HDfprintf(stderr, "%s%s", IDNAME[i], string);
+        fprintf(stderr, "%s%s", IDNAME[i], string);
         n = (int)(strlen(IDNAME[i]) + strlen(string));
-        HDfprintf(stderr, "%*d\n", (n < ERR_WIDTH) ? (ERR_WIDTH - n) : 0, rc[i]);
+        fprintf(stderr, "%*d\n", (n < ERR_WIDTH) ? (ERR_WIDTH - n) : 0, rc[i]);
     }
 }
 
