@@ -10,12 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- * Programmer:  Robb Matzke
- *              Wednesday, April  8, 1998
- * Modified:    Albert Cheng
- *         September 11, 2010
- */
 /*
  * The purpose of this test is to verify if a virtual file driver can handle:
  *    a. Large file (2GB)
@@ -62,12 +56,6 @@
 
 #define MAX_TRIES 100
 
-#if H5_SIZEOF_LONG_LONG >= 8
-#define GB8LL ((unsigned long long)8 * 1024 * 1024 * 1024)
-#else
-#define GB8LL 0 /*cannot do the test*/
-#endif
-
 /* Define Small, Large, Extra Large, Huge File which
  * correspond to less than 2GB, 2GB, 4GB, and tens of GB file size.
  * NO_FILE stands for "no file" to be tested.
@@ -102,9 +90,6 @@ static hsize_t values_used[WRT_N];
  *
  *            Failure:    Random value which overlaps another write
  *
- * Programmer:    Robb Matzke
- *              Tuesday, November 24, 1998
- *
  *-------------------------------------------------------------------------
  */
 static hsize_t
@@ -148,9 +133,6 @@ randll(hsize_t limit, int current_index)
  *
  *            Failure:    zero
  *
- * Programmer:    Robb Matzke
- *              Wednesday, July 15, 1998
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -189,9 +171,6 @@ is_sparse(void)
  *
  *            Failure:    zero
  *
- * Programmer:    Raymond Lu
- *              Wednesday, April 18, 2007
- *
  *-------------------------------------------------------------------------
  */
 static fsizes_t
@@ -257,9 +236,6 @@ error:
  *
  *            Failure:    zero
  *
- * Programmer:    Robb Matzke
- *              Thursday, August  6, 1998
- *
  *-------------------------------------------------------------------------
  */
 /* Disable warning for "format not a string literal" here -QAK */
@@ -282,7 +258,7 @@ enough_room(hid_t fapl)
         fd[i] = -1;
 
     /* Get file name template */
-    HDassert(H5FD_FAMILY == H5Pget_driver(fapl));
+    assert(H5FD_FAMILY == H5Pget_driver(fapl));
     h5_fixname(FILENAME[0], fapl, filename, sizeof(filename));
 
     /* Create files */
@@ -321,22 +297,19 @@ H5_GCC_CLANG_DIAG_ON("format-nonliteral")
  *
  *            Failure:    >0
  *
- * Programmer:    Robb Matzke
- *              Wednesday, April  8, 1998
- *
  *-------------------------------------------------------------------------
  */
 static int
 writer(char *filename, hid_t fapl, fsizes_t testsize, int wrt_n)
 {
     hsize_t size1[4] = {8, 1024, 1024, 1024};
-    hsize_t size2[1] = {GB8LL};
+    hsize_t size2[1] = {8LL * 1024LL * 1024LL * 1024LL};
     hsize_t hs_start[1];
     hsize_t hs_size[1];
     hid_t   file = -1, space1 = -1, space2 = -1, mem_space = -1, d1 = -1, d2 = -1;
-    int    *buf = (int *)HDmalloc(sizeof(int) * WRT_SIZE);
+    int    *buf = (int *)malloc(sizeof(int) * WRT_SIZE);
     int     i, j;
-    FILE   *out = HDfopen(DNAME, "w");
+    FILE   *out = fopen(DNAME, "w");
     hid_t   dcpl;
 
     switch (testsize) {
@@ -368,12 +341,12 @@ writer(char *filename, hid_t fapl, fsizes_t testsize, int wrt_n)
 
         case NO_FILE:
             /* what to do?? */
-            HDfprintf(stdout, "Unexpected file size of NO_FILE\n");
+            fprintf(stdout, "Unexpected file size of NO_FILE\n");
             goto error;
             break;
 
         default:
-            HDfprintf(stdout, "Unexpected file size(%d)\n", testsize);
+            fprintf(stdout, "Unexpected file size(%d)\n", testsize);
             goto error;
             break;
     }
@@ -416,7 +389,7 @@ writer(char *filename, hid_t fapl, fsizes_t testsize, int wrt_n)
     for (i = 0; i < wrt_n; i++) {
         /* start position must be at least hs_size from the end */
         hs_start[0] = randll(size2[0] - hs_size[0], i);
-        HDfprintf(out, "#%03d 0x%016" PRIxHSIZE "\n", i, hs_start[0]);
+        fprintf(out, "#%03d 0x%016" PRIxHSIZE "\n", i, hs_start[0]);
         if (H5Sselect_hyperslab(space2, H5S_SELECT_SET, hs_start, NULL, hs_size, NULL) < 0)
             goto error;
         for (j = 0; j < WRT_SIZE; j++) {
@@ -438,8 +411,8 @@ writer(char *filename, hid_t fapl, fsizes_t testsize, int wrt_n)
         goto error;
     if (H5Fclose(file) < 0)
         goto error;
-    HDfree(buf);
-    HDfclose(out);
+    free(buf);
+    fclose(out);
     PASSED();
     return 0;
 
@@ -453,11 +426,11 @@ error:
         H5Sclose(mem_space);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (buf)
-        HDfree(buf);
+        free(buf);
     if (out)
-        HDfclose(out);
+        fclose(out);
     return 1;
 }
 
@@ -470,9 +443,6 @@ error:
  *
  *            Failure:    >0
  *
- * Programmer:    Robb Matzke
- *              Friday, April 10, 1998
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -483,11 +453,11 @@ reader(char *filename, hid_t fapl)
     char    ln[128], *s;
     hsize_t hs_offset[1];
     hsize_t hs_size[1] = {WRT_SIZE};
-    int    *buf        = (int *)HDmalloc(sizeof(int) * WRT_SIZE);
+    int    *buf        = (int *)malloc(sizeof(int) * WRT_SIZE);
     int     i, j, zero, wrong, nerrors = 0;
 
     /* Open script file */
-    script = HDfopen(DNAME, "r");
+    script = fopen(DNAME, "r");
 
     /* Open HDF5 file */
     if ((file = H5Fopen(filename, H5F_ACC_RDONLY, fapl)) < 0)
@@ -507,10 +477,10 @@ reader(char *filename, hid_t fapl)
     while (HDfgets(ln, (int)sizeof(ln), script)) {
         if ('#' != ln[0])
             break;
-        i            = (int)HDstrtol(ln + 1, &s, 10);
-        hs_offset[0] = HDstrtoull(s, NULL, 0);
-        HDfprintf(stdout, "#%03d 0x%016" PRIxHSIZE "%47s", i, hs_offset[0], "");
-        HDfflush(stdout);
+        i            = (int)strtol(ln + 1, &s, 10);
+        hs_offset[0] = strtoull(s, NULL, 0);
+        fprintf(stdout, "#%03d 0x%016" PRIxHSIZE "%47s", i, hs_offset[0], "");
+        fflush(stdout);
 
         if (H5Sselect_hyperslab(fspace, H5S_SELECT_SET, hs_offset, NULL, hs_size, NULL) < 0)
             FAIL_STACK_ERROR;
@@ -526,7 +496,7 @@ reader(char *filename, hid_t fapl)
         }
         if (zero) {
             H5_FAILED();
-            HDprintf("    %d zero%s\n", zero, 1 == zero ? "" : "s");
+            printf("    %d zero%s\n", zero, 1 == zero ? "" : "s");
         }
         else if (wrong) {
             SKIPPED();
@@ -546,8 +516,8 @@ reader(char *filename, hid_t fapl)
         FAIL_STACK_ERROR;
     if (H5Fclose(file) < 0)
         FAIL_STACK_ERROR;
-    HDfree(buf);
-    HDfclose(script);
+    free(buf);
+    fclose(script);
 
     return nerrors;
 
@@ -559,11 +529,11 @@ error:
         H5Sclose(fspace);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (buf)
-        HDfree(buf);
+        free(buf);
     if (script)
-        HDfclose(script);
+        fclose(script);
     return 1;
 }
 
@@ -574,26 +544,23 @@ error:
  *
  * Return:    void
  *
- * Programmer:    Albert Chent
- *              Mar 28, 2002
- *
  *-------------------------------------------------------------------------
  */
 static void
 usage(void)
 {
-    HDfprintf(stdout,
-              "Usage: big [-h] [-c] [-fsize <fsize>}\n"
-              "\t-h\tPrint the help page\n"
-              "\t-c\tFile system Checking skipped.  Caution: this test generates\n"
-              "\t\tmany big files and may fill up the file system.\n"
-              "\t-fsize\tChange family size default to <fsize> where <fsize> is\n"
-              "\t\ta positive float point number.  Default value is %" PRIuHSIZE ".\n"
-              "Examples:\n"
-              "\t big -fsize 2.1e9 \t# test with file size just under 2GB\n"
-              "\t big -fsize 2.2e9 \t# test with file size just above 2GB\n"
-              "\t Be sure the file system can support the file size requested\n",
-              (hsize_t)FAMILY_SIZE);
+    fprintf(stdout,
+            "Usage: big [-h] [-c] [-fsize <fsize>}\n"
+            "\t-h\tPrint the help page\n"
+            "\t-c\tFile system Checking skipped.  Caution: this test generates\n"
+            "\t\tmany big files and may fill up the file system.\n"
+            "\t-fsize\tChange family size default to <fsize> where <fsize> is\n"
+            "\t\ta positive float point number.  Default value is %" PRIuHSIZE ".\n"
+            "Examples:\n"
+            "\t big -fsize 2.1e9 \t# test with file size just under 2GB\n"
+            "\t big -fsize 2.2e9 \t# test with file size just above 2GB\n"
+            "\t Be sure the file system can support the file size requested\n",
+            (hsize_t)FAMILY_SIZE);
 }
 
 static int
@@ -604,7 +571,7 @@ test_sec2(hid_t fapl)
 
     testsize = supports_big();
     if (testsize == NO_FILE) {
-        HDfprintf(stdout, "Test for sec2 is skipped because file system does not support big files.\n");
+        fprintf(stdout, "Test for sec2 is skipped because file system does not support big files.\n");
         goto quit;
     }
     /* Test big file with the SEC2 driver */
@@ -639,7 +606,7 @@ test_stdio(hid_t fapl)
 
     testsize = supports_big();
     if (testsize == NO_FILE) {
-        HDfprintf(stdout, "Test for stdio is skipped because file system does not support big files.\n");
+        fprintf(stdout, "Test for stdio is skipped because file system does not support big files.\n");
         goto quit;
     }
     HDputs("\nTesting big file with the STDIO Driver ");
@@ -661,12 +628,12 @@ quit:
     /* Clean up the test file */
     h5_clean_files(FILENAME, fapl);
     HDremove(DNAME);
-    HDfflush(stdout);
+    fflush(stdout);
     return 0;
 
 error:
     HDputs("*** TEST FAILED ***");
-    HDfflush(stdout);
+    fflush(stdout);
     return 1;
 } /* end test_stdio() */
 
@@ -689,12 +656,6 @@ test_family(hid_t fapl)
          * because we would generate multi-gigabyte files.
          */
         HDputs("Checking if file system is adequate for this test...");
-        if (sizeof(long long) < 8 || 0 == GB8LL) {
-            HDputs("Test skipped because sizeof(long long) is too small. This");
-            HDputs("hardware apparently doesn't support 64-bit integer types.");
-            usage();
-            goto quit;
-        }
         if (!sparse_support) {
             HDputs("Test skipped because file system does not support holes.");
             usage();
@@ -738,9 +699,6 @@ error:
  *
  *            Failure:
  *
- * Programmer:    Robb Matzke
- *              Friday, April 10, 1998
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -759,10 +717,10 @@ main(int ac, char **av)
             ac--;
             av++;
             if (ac > 0) {
-                family_size_def = (hsize_t)HDstrtoull(*av, NULL, 0);
+                family_size_def = (hsize_t)strtoull(*av, NULL, 0);
             }
             else {
-                HDprintf("***Missing fsize value***\n");
+                printf("***Missing fsize value***\n");
                 usage();
                 return 1;
             }
@@ -795,7 +753,7 @@ main(int ac, char **av)
     seed = (unsigned long)HDtime(NULL);
 #if 0
     /* seed = (unsigned long)1155438845; */
-    HDfprintf(stderr, "Random # seed was: %lu\n", seed);
+    fprintf(stderr, "Random # seed was: %lu\n", seed);
 #endif
     HDsrandom((unsigned)seed);
 
