@@ -11,14 +11,11 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol
- *              Tuesday, May 13, 2003
- *
  * Purpose:    Test dangling IDs
  */
 #include "h5test.h"
 
-const char *FILENAME[] = {"dangle", NULL};
+static const char *FILENAME[] = {"dangle", NULL};
 
 #define MAX_DANGLE 1000
 
@@ -36,9 +33,6 @@ const char *FILENAME[] = {"dangle", NULL};
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -84,7 +78,7 @@ test_dangle_dataset(H5F_close_degree_t degree)
             0)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     if (H5Sclose(sid) < 0)
         TEST_ERROR;
@@ -100,7 +94,7 @@ test_dangle_dataset(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -133,9 +127,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -175,7 +166,7 @@ test_dangle_group(H5F_close_degree_t degree)
     {
         gid = H5Gcreate2(fid, GROUPNAME, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (gid >= 0)
         TEST_ERROR;
 
@@ -193,7 +184,7 @@ test_dangle_group(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -226,9 +217,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -274,7 +262,7 @@ test_dangle_datatype1(H5F_close_degree_t degree)
         if (H5Tcommit2(fid, TYPENAME, tid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT) >= 0)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (H5Tclose(tid) < 0)
         TEST_ERROR;
 
@@ -289,7 +277,7 @@ test_dangle_datatype1(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -322,9 +310,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Thursday, August 25, 2005
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -374,7 +359,7 @@ test_dangle_datatype2(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -407,9 +392,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Wednesday, June 18, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -462,7 +444,7 @@ test_dangle_attribute(H5F_close_degree_t degree)
         if ((aid = H5Acreate2(dsid, ATTRNAME, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT)) >= 0)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     if (H5Sclose(sid) < 0)
         TEST_ERROR;
@@ -481,7 +463,7 @@ test_dangle_attribute(H5F_close_degree_t degree)
             if (H5Fclose(fid) >= 0)
                 TEST_ERROR;
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     } /* end if */
     else if (H5Fclose(fid) < 0)
         TEST_ERROR;
@@ -514,9 +496,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Friday, October 29, 2010
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -598,7 +577,7 @@ test_dangle_force(void)
         TEST_ERROR;
 
     /* Allocate the array of object IDs */
-    if (NULL == (objs = (hid_t *)HDcalloc((size_t)count, sizeof(hid_t))))
+    if (NULL == (objs = (hid_t *)calloc((size_t)count, sizeof(hid_t))))
         TEST_ERROR;
 
     /* Get the list of open IDs */
@@ -620,14 +599,14 @@ test_dangle_force(void)
     HDremove(filename);
 
     /* Release object ID array */
-    HDfree(objs);
+    free(objs);
 
     PASSED();
     return 0;
 
 error:
     if (objs)
-        HDfree(objs);
+        free(objs);
     return 1;
 }
 
@@ -639,9 +618,6 @@ error:
  * Return:    Success:    zero
  *        Failure:    non-zero
  *
- * Programmer:    Quincey Koziol
- *              Tuesday, May 13, 2003
- *
  *-------------------------------------------------------------------------
  */
 int
