@@ -70,7 +70,7 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
                                        {25, 17, 10, 3, 4, 11, 19, 26, 33, 40, 48, 55, 62, 69, 4, 12, 19, 26}};
 
 #define UCOMPARE(TYPE, VAR1, VAR2, TOL)                                                                      \
-    {                                                                                                        \
+    do {                                                                                                     \
         size_t i, j;                                                                                         \
                                                                                                              \
         for (i = 0; i < ROWS; i++)                                                                           \
@@ -80,15 +80,15 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
                       (((VAR1)[i][j] <= (TYPE)((VAR2)[i][j])) &&                                             \
                        (((VAR1)[i][j] + (TOL)) > (TYPE)((VAR2)[i][j]))))) {                                  \
                     H5_FAILED();                                                                             \
-                    HDfprintf(stderr, "    ERROR: Conversion failed to match computed data\n");              \
+                    fprintf(stderr, "    ERROR: Conversion failed to match computed data\n");                \
                     goto error;                                                                              \
                 }                                                                                            \
             }                                                                                                \
         PASSED();                                                                                            \
-    }
+    } while (0)
 
 #define COMPARE(TYPE, VAR1, VAR2, TOL)                                                                       \
-    {                                                                                                        \
+    do {                                                                                                     \
         size_t i, j;                                                                                         \
                                                                                                              \
         for (i = 0; i < ROWS; i++)                                                                           \
@@ -96,29 +96,29 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
                 if (!(((VAR1)[i][j] <= ((TYPE)(VAR2)[i][j] + (TOL))) &&                                      \
                       ((VAR1)[i][j] >= ((TYPE)(VAR2)[i][j] - (TOL))))) {                                     \
                     H5_FAILED();                                                                             \
-                    HDfprintf(stderr, "    ERROR: Conversion failed to match computed data\n");              \
+                    fprintf(stderr, "    ERROR: Conversion failed to match computed data\n");                \
                     goto error;                                                                              \
                 }                                                                                            \
             }                                                                                                \
         PASSED();                                                                                            \
-    }
+    } while (0)
 
 #define COMPARE_INT(VAR1, VAR2)                                                                              \
-    {                                                                                                        \
+    do {                                                                                                     \
         size_t i, j;                                                                                         \
                                                                                                              \
         for (i = 0; i < ROWS; i++)                                                                           \
             for (j = 0; j < COLS; j++) {                                                                     \
                 if ((VAR1)[i][j] != (VAR2)[i][j]) {                                                          \
                     H5_FAILED();                                                                             \
-                    HDfprintf(stderr, "    ERROR: data  failed to match computed data\n");                   \
+                    fprintf(stderr, "    ERROR: data  failed to match computed data\n");                     \
                     goto error;                                                                              \
                 }                                                                                            \
             }                                                                                                \
-    }
+    } while (0)
 
 #define TEST_TYPE_CONTIG(XFORM, TYPE, HDF_TYPE, TEST_STR, COMPARE_DATA, SIGNED)                              \
-    {                                                                                                        \
+    do {                                                                                                     \
         struct {                                                                                             \
             TYPE arr[ROWS][COLS];                                                                            \
         } *array           = NULL;                                                                           \
@@ -131,7 +131,7 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
         hsize_t     dim[2] = {ROWS, COLS};                                                                   \
                                                                                                              \
         /* NOTE: If this macro encounters errors, this memory will leak */                                   \
-        if (NULL == (array = HDcalloc(1, sizeof(*array))))                                                   \
+        if (NULL == (array = calloc(1, sizeof(*array))))                                                     \
             TEST_ERROR;                                                                                      \
                                                                                                              \
         if ((dataspace = H5Screate_simple(2, dim, NULL)) < 0)                                                \
@@ -182,25 +182,25 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
         if (H5Dread(dset, HDF_TYPE, H5S_ALL, H5S_ALL, XFORM, array) < 0)                                     \
             TEST_ERROR;                                                                                      \
         if (SIGNED)                                                                                          \
-            COMPARE(TYPE, array->arr, COMPARE_DATA, 2)                                                       \
+            COMPARE(TYPE, array->arr, COMPARE_DATA, 2);                                                      \
         else                                                                                                 \
-            UCOMPARE(TYPE, array->arr, COMPARE_DATA, 4)                                                      \
+            UCOMPARE(TYPE, array->arr, COMPARE_DATA, 4);                                                     \
                                                                                                              \
         TESTING("contiguous, byte order conversion (" TEST_STR "->" TEST_STR ")");                           \
                                                                                                              \
         if (H5Dread(dset_nn, HDF_TYPE, H5S_ALL, H5S_ALL, XFORM, array) < 0)                                  \
             TEST_ERROR;                                                                                      \
         if (SIGNED)                                                                                          \
-            COMPARE(TYPE, array->arr, COMPARE_DATA, 2)                                                       \
+            COMPARE(TYPE, array->arr, COMPARE_DATA, 2);                                                      \
         else                                                                                                 \
-            UCOMPARE(TYPE, array->arr, COMPARE_DATA, 4)                                                      \
+            UCOMPARE(TYPE, array->arr, COMPARE_DATA, 4);                                                     \
                                                                                                              \
         if (SIGNED) {                                                                                        \
             TESTING("contiguous, with type conversion (float->" TEST_STR ")");                               \
                                                                                                              \
             if (H5Dread(dset_id_float, HDF_TYPE, H5S_ALL, H5S_ALL, XFORM, array) < 0)                        \
                 TEST_ERROR;                                                                                  \
-            COMPARE(TYPE, array->arr, COMPARE_DATA, 2)                                                       \
+            COMPARE(TYPE, array->arr, COMPARE_DATA, 2);                                                      \
         }                                                                                                    \
                                                                                                              \
         if (H5Dclose(dset_nn) < 0)                                                                           \
@@ -210,11 +210,11 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
         if (H5Sclose(dataspace) < 0)                                                                         \
             TEST_ERROR;                                                                                      \
                                                                                                              \
-        HDfree(array);                                                                                       \
-    }
+        free(array);                                                                                         \
+    } while (0)
 
 #define TEST_TYPE_CHUNK(XFORM, TYPE, HDF_TYPE, TEST_STR, COMPARE_DATA, SIGNED)                               \
-    {                                                                                                        \
+    do {                                                                                                     \
         struct {                                                                                             \
             TYPE arr[ROWS][COLS];                                                                            \
         } *array           = NULL;                                                                           \
@@ -227,7 +227,7 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
         hsize_t offset[2] = {0, 0};                                                                          \
                                                                                                              \
         /* NOTE: If this macro encounters errors, this memory will leak */                                   \
-        if (NULL == (array = HDcalloc(1, sizeof(*array))))                                                   \
+        if (NULL == (array = calloc(1, sizeof(*array))))                                                     \
             TEST_ERROR;                                                                                      \
                                                                                                              \
         if ((dataspace = H5Screate_simple(2, dim, NULL)) < 0)                                                \
@@ -276,16 +276,16 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
         if (H5Dread(dset_chunk, HDF_TYPE, memspace, filespace, XFORM, array) < 0)                            \
             TEST_ERROR;                                                                                      \
         if (SIGNED)                                                                                          \
-            COMPARE(TYPE, array->arr, COMPARE_DATA, 2)                                                       \
+            COMPARE(TYPE, array->arr, COMPARE_DATA, 2);                                                      \
         else                                                                                                 \
-            UCOMPARE(TYPE, array->arr, COMPARE_DATA, 4)                                                      \
+            UCOMPARE(TYPE, array->arr, COMPARE_DATA, 4);                                                     \
                                                                                                              \
         if (SIGNED) {                                                                                        \
             TESTING("chunked, with type conversion (float->" TEST_STR ")");                                  \
                                                                                                              \
             if (H5Dread(dset_id_float_chunk, HDF_TYPE, memspace, filespace, XFORM, array) < 0)               \
                 TEST_ERROR;                                                                                  \
-            COMPARE(TYPE, array->arr, COMPARE_DATA, 2)                                                       \
+            COMPARE(TYPE, array->arr, COMPARE_DATA, 2);                                                      \
         }                                                                                                    \
                                                                                                              \
         if (H5Pclose(cparms) < 0)                                                                            \
@@ -297,20 +297,20 @@ const int transformData[ROWS][COLS] = {{36, 31, 25, 19, 13, 7, 1, 5, 11, 16, 22,
         if (H5Sclose(memspace) < 0)                                                                          \
             TEST_ERROR;                                                                                      \
                                                                                                              \
-        HDfree(array);                                                                                       \
-    }
+        free(array);                                                                                         \
+    } while (0)
 
 #define INVALID_SET_TEST(TRANSFORM)                                                                          \
-    {                                                                                                        \
+    do {                                                                                                     \
         if (H5Pset_data_transform(dxpl_id, TRANSFORM) < 0) {                                                 \
             PASSED();                                                                                        \
         }                                                                                                    \
         else {                                                                                               \
             H5_FAILED();                                                                                     \
-            HDfprintf(stderr, "    ERROR: Data transform allowed invalid TRANSFORM transform to be set\n");  \
+            fprintf(stderr, "    ERROR: Data transform allowed invalid TRANSFORM transform to be set\n");    \
             goto error;                                                                                      \
         }                                                                                                    \
-    }
+    } while (0)
 
 int
 main(void)
@@ -558,7 +558,7 @@ test_poly(const hid_t dxpl_id_polynomial)
     if (H5Dread(dset_id_int, H5T_NATIVE_FLOAT, H5S_ALL, H5S_ALL, dxpl_id_polynomial, polyflread) < 0)
         TEST_ERROR;
 
-    COMPARE(float, polyflread, polyflres, 2.0F)
+    COMPARE(float, polyflread, polyflres, 2.0F);
 
     for (row = 0; row < ROWS; row++)
         for (col = 0; col < COLS; col++) {
@@ -570,7 +570,7 @@ test_poly(const hid_t dxpl_id_polynomial)
     if (H5Dread(dset_id_float, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, dxpl_id_polynomial, polyintread) < 0)
         TEST_ERROR;
 
-    COMPARE(int, polyintread, polyflres, 4)
+    COMPARE(int, polyintread, polyflres, 4);
 
     return 0;
 
@@ -620,7 +620,7 @@ test_specials(hid_t file)
     if (H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
         TEST_ERROR;
 
-    COMPARE_INT(read_buf, data_res)
+    COMPARE_INT(read_buf, data_res);
 
     if (H5Dclose(dset_id) < 0)
         TEST_ERROR;
@@ -643,7 +643,7 @@ test_specials(hid_t file)
     if (H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
         TEST_ERROR;
 
-    COMPARE_INT(read_buf, data_res)
+    COMPARE_INT(read_buf, data_res);
 
     if (H5Dclose(dset_id) < 0)
         TEST_ERROR;
@@ -666,7 +666,7 @@ test_specials(hid_t file)
     if (H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
         TEST_ERROR;
 
-    COMPARE_INT(read_buf, data_res)
+    COMPARE_INT(read_buf, data_res);
 
     if (H5Dclose(dset_id) < 0)
         TEST_ERROR;
@@ -689,7 +689,7 @@ test_specials(hid_t file)
     if (H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
         TEST_ERROR;
 
-    COMPARE_INT(read_buf, data_res)
+    COMPARE_INT(read_buf, data_res);
 
     if (H5Dclose(dset_id) < 0)
         TEST_ERROR;
@@ -712,7 +712,7 @@ test_specials(hid_t file)
     if (H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
         TEST_ERROR;
 
-    COMPARE_INT(read_buf, data_res)
+    COMPARE_INT(read_buf, data_res);
 
     if (H5Dclose(dset_id) < 0)
         TEST_ERROR;
@@ -735,7 +735,7 @@ test_specials(hid_t file)
     if (H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
         TEST_ERROR;
 
-    COMPARE_INT(read_buf, data_res)
+    COMPARE_INT(read_buf, data_res);
 
     if (H5Dclose(dset_id) < 0)
         TEST_ERROR;
@@ -761,7 +761,7 @@ test_specials(hid_t file)
     if (H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, read_buf) < 0)
         TEST_ERROR;
 
-    COMPARE_INT(read_buf, data_res)
+    COMPARE_INT(read_buf, data_res);
 
     if (H5Dclose(dset_id) < 0)
         TEST_ERROR;
@@ -797,13 +797,13 @@ test_copy(const hid_t dxpl_id_c_to_f_copy, const hid_t dxpl_id_polynomial_copy)
     if (H5Dread(dset_id_float, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, dxpl_id_c_to_f_copy, windchillFintread) < 0)
         TEST_ERROR;
 
-    COMPARE(int, windchillFintread, windchillFfloat, 2)
+    COMPARE(int, windchillFintread, windchillFfloat, 2);
 
     TESTING("data transform, polynomial transform w/ copied property");
     if (H5Dread(dset_id_float, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, dxpl_id_polynomial_copy, polyintread) < 0)
         TEST_ERROR;
 
-    COMPARE(int, polyintread, polyflres, 2)
+    COMPARE(int, polyintread, polyflres, 2);
 
     return 0;
 
@@ -857,7 +857,7 @@ test_getset(const hid_t dxpl_id_c_to_f)
 
     TESTING("H5Pget_data_transform");
 
-    if (NULL == (ptrgetTest = (char *)HDmalloc(HDstrlen(simple) + 1)))
+    if (NULL == (ptrgetTest = (char *)malloc(HDstrlen(simple) + 1)))
         TEST_ERROR;
 
     if (H5Pget_data_transform(dxpl_id_c_to_f, ptrgetTest, HDstrlen(c_to_f) + 1) < 0)
@@ -867,7 +867,7 @@ test_getset(const hid_t dxpl_id_c_to_f)
 
     PASSED();
 
-    HDfree(ptrgetTest);
+    free(ptrgetTest);
     ptrgetTest = NULL;
 
     TESTING("data transform, read after resetting of transform property");
@@ -888,7 +888,7 @@ test_getset(const hid_t dxpl_id_c_to_f)
 
     TESTING("H5Pget_data_transform, after resetting transform property");
 
-    if (NULL == (ptrgetTest = (char *)HDcalloc((size_t)1, HDstrlen(simple) + 1)))
+    if (NULL == (ptrgetTest = (char *)calloc((size_t)1, HDstrlen(simple) + 1)))
         TEST_ERROR;
     if (H5Pget_data_transform(dxpl_id_c_to_f, ptrgetTest, HDstrlen(simple) + 1) < 0)
         TEST_ERROR;
@@ -897,14 +897,14 @@ test_getset(const hid_t dxpl_id_c_to_f)
 
     PASSED();
 
-    HDfree(ptrgetTest);
+    free(ptrgetTest);
     ptrgetTest = NULL;
 
     return 0;
 
 error:
     if (ptrgetTest)
-        HDfree(ptrgetTest);
+        free(ptrgetTest);
 
     return -1;
 }
@@ -919,7 +919,7 @@ test_set(void)
 
     TESTING("H5Pget_data_transform (get before set)");
 
-    if (NULL == (ptrgetTest = (char *)HDmalloc(HDstrlen(str) + 1)))
+    if (NULL == (ptrgetTest = (char *)malloc(HDstrlen(str) + 1)))
         TEST_ERROR;
 
     if ((dxpl_id = H5Pcreate(H5P_DATASET_XFER)) < 0)
@@ -935,7 +935,7 @@ test_set(void)
     else
         FAIL_PUTS_ERROR("    ERROR: Data transform get before set succeeded (it shouldn't have)\n");
 
-    HDfree(ptrgetTest);
+    free(ptrgetTest);
     ptrgetTest = NULL;
 
     TESTING("H5Pset_data_transform (set with NULL transform)");
@@ -974,7 +974,7 @@ test_set(void)
 
 error:
     if (ptrgetTest)
-        HDfree(ptrgetTest);
+        free(ptrgetTest);
     H5E_BEGIN_TRY
     {
         H5Pclose(dxpl_id);
