@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:    Raymond Lu
- *              October 14, 2001
- *
  * Purpose:    Tests the error API routines.
  */
 #include "h5test.h"
@@ -23,36 +20,36 @@
 int
 main(void)
 {
-    HDfprintf(stderr, "Test skipped because backward compatibility with v1.6 is configured in\n");
+    fprintf(stderr, "Test skipped because backward compatibility with v1.6 is configured in\n");
     return 0;
 }
 #else /* H5_USE_16_API */
 
-const char *FILENAME[] = {"errors", NULL};
+static const char *FILENAME[] = {"errors", NULL};
 
 #define DATAFILE "filter_error"
 
 #define DIM0 100
 #define DIM1 200
 
-int **ipoints2      = NULL;
-int **icheck2       = NULL;
-int  *ipoints2_data = NULL;
-int  *icheck2_data  = NULL;
+static int **ipoints2      = NULL;
+static int **icheck2       = NULL;
+static int  *ipoints2_data = NULL;
+static int  *icheck2_data  = NULL;
 
-hid_t ERR_CLS;
-hid_t ERR_CLS2;
-hid_t ERR_STACK;
+static hid_t ERR_CLS;
+static hid_t ERR_CLS2;
+static hid_t ERR_STACK;
 
-hid_t ERR_MAJ_TEST;
-hid_t ERR_MAJ_IO;
-hid_t ERR_MAJ_API;
+static hid_t ERR_MAJ_TEST;
+static hid_t ERR_MAJ_IO;
+static hid_t ERR_MAJ_API;
 
-hid_t ERR_MIN_SUBROUTINE;
-hid_t ERR_MIN_ERRSTACK;
-hid_t ERR_MIN_CREATE;
-hid_t ERR_MIN_WRITE;
-hid_t ERR_MIN_GETNUM;
+static hid_t ERR_MIN_SUBROUTINE;
+static hid_t ERR_MIN_ERRSTACK;
+static hid_t ERR_MIN_CREATE;
+static hid_t ERR_MIN_WRITE;
+static hid_t ERR_MIN_GETNUM;
 
 #define DSET_NAME "a_dataset"
 #define FAKE_ID   (hid_t)0
@@ -100,7 +97,7 @@ test_error(hid_t file)
     H5E_auto2_t old_func;
     void       *old_data = NULL;
 
-    HDfprintf(stderr, "\nTesting error API based on data I/O\n");
+    fprintf(stderr, "\nTesting error API based on data I/O\n");
 
     /* Create the data space */
     dims[0] = DIM0;
@@ -113,7 +110,7 @@ test_error(hid_t file)
     {
         dataset = H5Dcreate2(FAKE_ID, DSET_NAME, H5T_STD_I32BE, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* Create the dataset */
     if ((dataset = H5Dcreate2(file, DSET_NAME, H5T_STD_I32BE, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) <
@@ -184,9 +181,9 @@ init_error(void)
     char      *msg      = NULL;
     H5E_type_t msg_type;
 
-    if (NULL == (cls_name = (char *)HDmalloc(HDstrlen(ERR_CLS_NAME) + 1)))
+    if (NULL == (cls_name = (char *)malloc(HDstrlen(ERR_CLS_NAME) + 1)))
         TEST_ERROR;
-    if (NULL == (msg = (char *)HDmalloc(HDstrlen(ERR_MIN_SUBROUTINE_MSG) + 1)))
+    if (NULL == (msg = (char *)malloc(HDstrlen(ERR_MIN_SUBROUTINE_MSG) + 1)))
         TEST_ERROR;
 
     if ((ERR_CLS = H5Eregister_class(ERR_CLS_NAME, PROG_NAME, PROG_VERS)) < 0)
@@ -226,16 +223,16 @@ init_error(void)
     if ((ERR_CLS2 = H5Eregister_class(ERR_CLS2_NAME, PROG2_NAME, PROG_VERS)) < 0)
         TEST_ERROR;
 
-    HDfree(cls_name);
-    HDfree(msg);
+    free(cls_name);
+    free(msg);
 
     return 0;
 
 error:
     if (cls_name)
-        HDfree(cls_name);
+        free(cls_name);
     if (msg)
-        HDfree(msg);
+        free(msg);
 
     return -1;
 } /* end init_error() */
@@ -329,9 +326,9 @@ test_long_desc(void)
     const char *test_FUNC = "test_long_desc";
 
     /* Allocate space for the error description info */
-    if (NULL == (long_desc = (char *)HDmalloc(LONG_DESC_SIZE)))
+    if (NULL == (long_desc = (char *)malloc(LONG_DESC_SIZE)))
         TEST_ERROR;
-    if (NULL == (full_desc = (char *)HDmalloc(LONG_DESC_SIZE + 128)))
+    if (NULL == (full_desc = (char *)malloc(LONG_DESC_SIZE + 128)))
         TEST_ERROR;
 
     /* Create the long part of the error description */
@@ -361,16 +358,16 @@ test_long_desc(void)
     if (H5Eclear2(H5E_DEFAULT) < 0)
         TEST_ERROR;
 
-    HDfree(long_desc);
-    HDfree(full_desc);
+    free(long_desc);
+    free(full_desc);
 
     return 0;
 
 error:
     if (long_desc)
-        HDfree(long_desc);
+        free(long_desc);
     if (full_desc)
-        HDfree(full_desc);
+        free(full_desc);
 
     return -1;
 } /* end test_long_desc() */
@@ -390,12 +387,12 @@ static herr_t
 dump_error(hid_t estack)
 {
     /* Print errors in library default way */
-    HDfprintf(stderr, "********* Print error stack in HDF5 default way *********\n");
+    fprintf(stderr, "********* Print error stack in HDF5 default way *********\n");
     if (H5Eprint2(estack, stderr) < 0)
         TEST_ERROR;
 
     /* Customized way to print errors */
-    HDfprintf(stderr, "\n********* Print error stack in customized way *********\n");
+    fprintf(stderr, "\n********* Print error stack in customized way *********\n");
     if (H5Ewalk2(estack, H5E_WALK_UPWARD, custom_print_cb, stderr) < 0)
         TEST_ERROR;
 
@@ -434,11 +431,11 @@ custom_print_cb(unsigned n, const H5E_error2_t *err_desc, void *client_data)
     if (H5Eget_msg(err_desc->min_num, NULL, min, MSG_SIZE) < 0)
         TEST_ERROR;
 
-    HDfprintf(stream, "%*serror #%03d: %s in %s(): line %u\n", indent, "", n, err_desc->file_name,
-              err_desc->func_name, err_desc->line);
-    HDfprintf(stream, "%*sclass: %s\n", indent * 2, "", cls);
-    HDfprintf(stream, "%*smajor: %s\n", indent * 2, "", maj);
-    HDfprintf(stream, "%*sminor: %s\n", indent * 2, "", min);
+    fprintf(stream, "%*serror #%03d: %s in %s(): line %u\n", indent, "", n, err_desc->file_name,
+            err_desc->func_name, err_desc->line);
+    fprintf(stream, "%*sclass: %s\n", indent * 2, "", cls);
+    fprintf(stream, "%*smajor: %s\n", indent * 2, "", maj);
+    fprintf(stream, "%*sminor: %s\n", indent * 2, "", min);
 
     return 0;
 
@@ -744,7 +741,7 @@ test_filter_error(const char *fname, hid_t fapl)
     hid_t       dataset  = -1;
     int         buf[20];
 
-    HDfprintf(stderr, "\nTesting error message during data reading when filter isn't registered\n");
+    fprintf(stderr, "\nTesting error message during data reading when filter isn't registered\n");
 
     /* Open the file */
     if ((file = H5Fopen(pathname, H5F_ACC_RDONLY, fapl)) < 0)
@@ -793,7 +790,7 @@ main(void)
     if (env_h5_drvr == NULL)
         env_h5_drvr = "nomatch";
 
-    HDfprintf(stderr, "   This program tests the Error API.  There're supposed to be some error messages\n");
+    fprintf(stderr, "   This program tests the Error API.  There're supposed to be some error messages\n");
 
     /* Initialize errors */
     if (init_error() < 0)
@@ -803,16 +800,16 @@ main(void)
         TEST_ERROR;
 
     /* Set up data arrays */
-    if (NULL == (ipoints2_data = (int *)HDcalloc(DIM0 * DIM1, sizeof(int))))
+    if (NULL == (ipoints2_data = (int *)calloc(DIM0 * DIM1, sizeof(int))))
         TEST_ERROR;
-    if (NULL == (ipoints2 = (int **)HDcalloc(DIM0, sizeof(ipoints2_data))))
+    if (NULL == (ipoints2 = (int **)calloc(DIM0, sizeof(ipoints2_data))))
         TEST_ERROR;
     for (i = 0; i < DIM0; i++)
         ipoints2[i] = ipoints2_data + (i * DIM1);
 
-    if (NULL == (icheck2_data = (int *)HDcalloc(DIM0 * DIM1, sizeof(int))))
+    if (NULL == (icheck2_data = (int *)calloc(DIM0 * DIM1, sizeof(int))))
         TEST_ERROR;
-    if (NULL == (icheck2 = (int **)HDcalloc(DIM0, sizeof(icheck2_data))))
+    if (NULL == (icheck2 = (int **)calloc(DIM0, sizeof(icheck2_data))))
         TEST_ERROR;
     for (i = 0; i < DIM0; i++)
         icheck2[i] = icheck2_data + (i * DIM1);
@@ -895,21 +892,21 @@ main(void)
 
     h5_clean_files(FILENAME, fapl);
 
-    HDfree(ipoints2);
-    HDfree(ipoints2_data);
-    HDfree(icheck2);
-    HDfree(icheck2_data);
+    free(ipoints2);
+    free(ipoints2_data);
+    free(icheck2);
+    free(icheck2_data);
 
-    HDfprintf(stderr, "\nAll error API tests passed.\n");
+    fprintf(stderr, "\nAll error API tests passed.\n");
     return 0;
 
 error:
-    HDfree(ipoints2);
-    HDfree(ipoints2_data);
-    HDfree(icheck2);
-    HDfree(icheck2_data);
+    free(ipoints2);
+    free(ipoints2_data);
+    free(icheck2);
+    free(icheck2_data);
 
-    HDfprintf(stderr, "\n***** ERROR TEST FAILED (real problem)! *****\n");
+    fprintf(stderr, "\n***** ERROR TEST FAILED (real problem)! *****\n");
     return 1;
 }
 #endif /* H5_USE_16_API */
