@@ -151,7 +151,7 @@ generate_eoc_test_file(hid_t fapl_id)
         TEST_ERROR;
 
     /* Create a data buffer for dataset writes */
-    if (NULL == (data = (int *)HDcalloc(NELEMENTS, sizeof(int))))
+    if (NULL == (data = (int *)calloc(NELEMENTS, sizeof(int))))
         TEST_ERROR;
 
     /* Create file */
@@ -183,7 +183,7 @@ generate_eoc_test_file(hid_t fapl_id)
         char subgroup_name[SUBGROUP_NAME_SIZE];
 
         /* Create the group name */
-        HDmemset(subgroup_name, '\0', SUBGROUP_NAME_SIZE);
+        memset(subgroup_name, '\0', SUBGROUP_NAME_SIZE);
         if (HDsnprintf(subgroup_name, (size_t)(SUBGROUP_NAME_SIZE - 1), "%d", i) < 0)
             TEST_ERROR;
 
@@ -278,7 +278,7 @@ generate_eoc_test_file(hid_t fapl_id)
         char subgroup_name[SUBGROUP_NAME_SIZE];
 
         /* Create the group name */
-        HDmemset(subgroup_name, '\0', SUBGROUP_NAME_SIZE);
+        memset(subgroup_name, '\0', SUBGROUP_NAME_SIZE);
         if (HDsnprintf(subgroup_name, (size_t)(SUBGROUP_NAME_SIZE - 1), "%d", i) < 0)
             TEST_ERROR;
 
@@ -546,7 +546,7 @@ generate_eoc_test_file(hid_t fapl_id)
     if (H5Pclose(fapl_copy_id) < 0)
         TEST_ERROR;
 
-    HDfree(data);
+    free(data);
 
     PASSED();
     return fid;
@@ -562,9 +562,9 @@ error:
         H5Pclose(dcpl_id);
         H5Pclose(fapl_copy_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
-    HDfree(data);
+    free(data);
 
     H5_FAILED();
     return -1;
@@ -601,10 +601,10 @@ check_group_layout(hid_t fid, const char *group_name)
     before = file_ptr->shared->cache->index_len;
 
 #ifdef EOC_MANUAL_INSPECTION
-    HDprintf("\nCACHE BEFORE GROUP OPEN:\n");
+    printf("\nCACHE BEFORE GROUP OPEN:\n");
     if (H5AC_dump_cache(file_ptr) < 0)
         TEST_ERROR;
-    HDprintf("NUMBER OF CACHE ENTRIES: %u\n", before);
+    printf("NUMBER OF CACHE ENTRIES: %u\n", before);
 #endif
 
     /* Open the main group and get its tag */
@@ -619,7 +619,7 @@ check_group_layout(hid_t fid, const char *group_name)
         char subgroup_name[SUBGROUP_NAME_SIZE];
 
         /* Create the group name */
-        HDmemset(subgroup_name, '\0', SUBGROUP_NAME_SIZE);
+        memset(subgroup_name, '\0', SUBGROUP_NAME_SIZE);
         if (HDsnprintf(subgroup_name, (size_t)(SUBGROUP_NAME_SIZE - 1), "%d", i) < 0)
             TEST_ERROR;
 
@@ -641,11 +641,11 @@ check_group_layout(hid_t fid, const char *group_name)
     during = file_ptr->shared->cache->index_len;
 
 #ifdef EOC_MANUAL_INSPECTION
-    HDprintf("\nCACHE AFTER OPENING GROUPS (WHILE OPEN):\n");
+    printf("\nCACHE AFTER OPENING GROUPS (WHILE OPEN):\n");
     if (H5AC_dump_cache(file_ptr) < 0)
         TEST_ERROR;
-    HDprintf("MAIN GROUP TAG: %#X\n", tag1);
-    HDprintf("NUMBER OF CACHE ENTRIES: %u\n", during);
+    printf("MAIN GROUP TAG: %#X\n", tag1);
+    printf("NUMBER OF CACHE ENTRIES: %u\n", during);
 #endif
 
     /* Close the main group */
@@ -656,10 +656,10 @@ check_group_layout(hid_t fid, const char *group_name)
     after = file_ptr->shared->cache->index_len;
 
 #ifdef EOC_MANUAL_INSPECTION
-    HDprintf("\nCACHE AFTER CLOSING GROUPS:\n");
+    printf("\nCACHE AFTER CLOSING GROUPS:\n");
     if (H5AC_dump_cache(file_ptr) < 0)
         TEST_ERROR;
-    HDprintf("NUMBER OF CACHE ENTRIES: %u\n", after);
+    printf("NUMBER OF CACHE ENTRIES: %u\n", after);
 #endif
 
     /* Ensure that the cache does not contain entries with the tag */
@@ -678,7 +678,7 @@ error:
         H5Gclose(gid1);
         H5Gclose(gid2);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     H5_FAILED();
     return FAIL;
@@ -712,17 +712,17 @@ check_dset_scheme(hid_t fid, const char *dset_name)
         TEST_ERROR;
 
     /* Create the data buffer */
-    if (NULL == (data = (int *)HDcalloc(NELEMENTS, sizeof(int))))
+    if (NULL == (data = (int *)calloc(NELEMENTS, sizeof(int))))
         TEST_ERROR;
 
     /* Record the number of cache entries */
     before = file_ptr->shared->cache->index_len;
 
 #ifdef EOC_MANUAL_INSPECTION
-    HDprintf("\nCACHE BEFORE DATASET OPEN:\n");
+    printf("\nCACHE BEFORE DATASET OPEN:\n");
     if (H5AC_dump_cache(file_ptr) < 0)
         TEST_ERROR;
-    HDprintf("NUMBER OF CACHE ENTRIES: %u\n", before);
+    printf("NUMBER OF CACHE ENTRIES: %u\n", before);
 #endif
 
     /* Open dataset and get the metadata tag */
@@ -742,11 +742,11 @@ check_dset_scheme(hid_t fid, const char *dset_name)
     during = file_ptr->shared->cache->index_len;
 
 #ifdef EOC_MANUAL_INSPECTION
-    HDprintf("\nCACHE AFTER DATA READ (WHILE OPEN):\n");
+    printf("\nCACHE AFTER DATA READ (WHILE OPEN):\n");
     if (H5AC_dump_cache(file_ptr) < 0)
         TEST_ERROR;
-    HDprintf("TAG: %#X\n", tag);
-    HDprintf("NUMBER OF CACHE ENTRIES: %u\n", during);
+    printf("TAG: %#X\n", tag);
+    printf("NUMBER OF CACHE ENTRIES: %u\n", during);
 #endif
 
     /* Close the dataset */
@@ -757,10 +757,10 @@ check_dset_scheme(hid_t fid, const char *dset_name)
     after = file_ptr->shared->cache->index_len;
 
 #ifdef EOC_MANUAL_INSPECTION
-    HDprintf("\nCACHE AFTER DATASET CLOSE:\n");
+    printf("\nCACHE AFTER DATASET CLOSE:\n");
     if (H5AC_dump_cache(file_ptr) < 0)
         TEST_ERROR;
-    HDprintf("NUMBER OF CACHE ENTRIES: %u\n", after);
+    printf("NUMBER OF CACHE ENTRIES: %u\n", after);
 #endif
 
     /* Ensure that the cache does not contain entries with the tag */
@@ -771,7 +771,7 @@ check_dset_scheme(hid_t fid, const char *dset_name)
     if (before != after || before == during)
         TEST_ERROR;
 
-    HDfree(data);
+    free(data);
 
     PASSED();
     return SUCCEED;
@@ -781,7 +781,7 @@ error:
     {
         H5Dclose(did);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     H5_FAILED();
     return FAIL;
@@ -847,7 +847,7 @@ check_evict_on_close_api(void)
     {
         status = H5Pset_evict_on_close(dapl_id, evict_on_close);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (status >= 0)
         FAIL_PUTS_ERROR("H5Pset_evict_on_close() accepted invalid access plist.");
 
@@ -856,7 +856,7 @@ check_evict_on_close_api(void)
     {
         status = H5Pget_evict_on_close(H5I_INVALID_HID, &evict_on_close);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (status >= 0)
         FAIL_PUTS_ERROR("H5Pget_evict_on_close() accepted invalid hid_t.");
 
@@ -887,7 +887,7 @@ main(void)
     hid_t    fid     = -1; /* file ID                              */
     unsigned nerrors = 0;  /* number of test errors                */
 
-    HDprintf("Testing evict-on-close cache behavior\n");
+    printf("Testing evict-on-close cache behavior\n");
 
     /* Initialize */
     h5_reset();
@@ -955,13 +955,13 @@ main(void)
     if (nerrors)
         goto error;
 
-    HDprintf("All evict-on-close tests passed.\n");
+    printf("All evict-on-close tests passed.\n");
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 
 error:
 
-    HDprintf("***** %u evict-on-close test%s FAILED! *****\n", nerrors, nerrors > 1 ? "S" : "");
+    printf("***** %u evict-on-close test%s FAILED! *****\n", nerrors, nerrors > 1 ? "S" : "");
 
     h5_delete_all_test_files(FILENAMES, fapl_id);
     H5E_BEGIN_TRY
@@ -969,9 +969,9 @@ error:
         H5Fclose(fid);
         H5Pclose(fapl_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
-    HDexit(EXIT_FAILURE);
+    exit(EXIT_FAILURE);
 
 } /* end main() */
 
@@ -1006,7 +1006,7 @@ check_evict_on_close_parallel_fail(void)
     {
         status = H5Pset_evict_on_close(fapl_id, evict_on_close);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (status >= 0)
         FAIL_PUTS_ERROR("H5Pset_evict_on_close() did not fail in parallel HDF5.");
 
@@ -1035,7 +1035,7 @@ main(void)
 {
     unsigned nerrors = 0; /* number of test errors                */
 
-    HDprintf("Testing evict-on-close cache behavior\n");
+    printf("Testing evict-on-close cache behavior\n");
 
     /* Initialize */
     h5_reset();
@@ -1046,16 +1046,16 @@ main(void)
     if (nerrors)
         goto error;
 
-    HDprintf("All evict-on-close tests passed.\n");
-    HDprintf("Note that EoC is not supported under parallel so most tests are skipped.\n");
+    printf("All evict-on-close tests passed.\n");
+    printf("Note that EoC is not supported under parallel so most tests are skipped.\n");
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 
 error:
 
-    HDprintf("***** %u evict-on-close test%s FAILED! *****\n", nerrors, nerrors > 1 ? "S" : "");
+    printf("***** %u evict-on-close test%s FAILED! *****\n", nerrors, nerrors > 1 ? "S" : "");
 
-    HDexit(EXIT_FAILURE);
+    exit(EXIT_FAILURE);
 
 } /* main() - parallel */
 
