@@ -43,19 +43,19 @@
 
 #define USERBLOCK_SIZE 512
 
-const char *FILENAME[] = {"file_image_core_test", NULL};
+static const char *FILENAME[] = {"file_image_core_test", NULL};
 
 /* need a second file name array, as the first file name array contains
  * files we don't want to delete on cleanup.
  */
-const char *FILENAME2[] = {"sec2_get_file_image_test",
-                           "stdio_get_file_image_test",
-                           "core_get_file_image_test",
-                           "family_get_file_image_test",
-                           "multi_get_file_image_test",
-                           "split_get_file_image_test",
-                           "get_file_image_error_rejection_test",
-                           NULL};
+static const char *FILENAME2[] = {"sec2_get_file_image_test",
+                                  "stdio_get_file_image_test",
+                                  "core_get_file_image_test",
+                                  "family_get_file_image_test",
+                                  "multi_get_file_image_test",
+                                  "split_get_file_image_test",
+                                  "get_file_image_error_rejection_test",
+                                  NULL};
 
 typedef struct {
     unsigned char        used_callbacks; /* Bitfield for tracking callbacks */
@@ -74,9 +74,6 @@ typedef struct {
  * Returns:     Success: 0
  *              Failure: 1
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static int
@@ -102,7 +99,7 @@ test_properties(void)
      * not be the case.
      */
     size = (size_t)count * sizeof(char);
-    if (NULL == (buffer = (char *)HDmalloc(size)))
+    if (NULL == (buffer = (char *)malloc(size)))
         TEST_ERROR;
     for (i = 0; i < count - 1; i++)
         buffer[i] = (char)(65 + i);
@@ -132,7 +129,7 @@ test_properties(void)
     VERIFY(temp != NULL, "temp is null!");
     VERIFY(temp_size == size, "Sizes of buffers don't match");
     VERIFY(temp != buffer, "Retrieved buffer is the same as original");
-    VERIFY(0 == HDmemcmp(temp, buffer, size), "Buffers contain different data");
+    VERIFY(0 == memcmp(temp, buffer, size), "Buffers contain different data");
 
     /* Copy the fapl */
     if ((fapl_2 = H5Pcopy(fapl_1)) < 0)
@@ -147,7 +144,7 @@ test_properties(void)
     VERIFY(temp2 != NULL, "Received buffer not set");
     VERIFY(temp2 != buffer, "Retrieved buffer is the same as original");
     VERIFY(temp2 != temp, "Retrieved buffer is the same as previously retrieved buffer");
-    VERIFY(0 == HDmemcmp(temp2, buffer, size), "Buffers contain different data");
+    VERIFY(0 == memcmp(temp2, buffer, size), "Buffers contain different data");
 
     retval = 0;
 
@@ -158,7 +155,7 @@ error:
         retval = 1;
     if (H5Pclose(fapl_2) < 0)
         retval = 1;
-    HDfree(buffer);
+    free(buffer);
     H5free_memory(temp);
     H5free_memory(temp2);
 
@@ -175,9 +172,6 @@ error:
  *
  * Returns:     The result of a standard malloc
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -187,7 +181,7 @@ malloc_cb(size_t size, H5FD_file_image_op_t op, void *udata)
 
     u->used_callbacks |= MALLOC;
     u->malloc_src = op;
-    return HDmalloc(size);
+    return malloc(size);
 }
 
 /******************************************************************************
@@ -197,9 +191,6 @@ malloc_cb(size_t size, H5FD_file_image_op_t op, void *udata)
  *
  * Returns:     The result of a standard memcpy
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -209,7 +200,7 @@ memcpy_cb(void *dest, const void *src, size_t size, H5FD_file_image_op_t op, voi
 
     u->used_callbacks |= MEMCPY;
     u->memcpy_src = op;
-    return HDmemcpy(dest, src, size);
+    return memcpy(dest, src, size);
 }
 
 /******************************************************************************
@@ -219,9 +210,6 @@ memcpy_cb(void *dest, const void *src, size_t size, H5FD_file_image_op_t op, voi
  *
  * Returns:     The result of a standard realloc
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -231,7 +219,7 @@ realloc_cb(void *ptr, size_t size, H5FD_file_image_op_t op, void *udata)
 
     u->used_callbacks |= REALLOC;
     u->realloc_src = op;
-    return HDrealloc(ptr, size);
+    return realloc(ptr, size);
 }
 
 /******************************************************************************
@@ -239,9 +227,6 @@ realloc_cb(void *ptr, size_t size, H5FD_file_image_op_t op, void *udata)
  *
  * Purpose:     This function allows calls to the free callback to be tracked.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static herr_t
@@ -251,7 +236,7 @@ free_cb(void *ptr, H5FD_file_image_op_t op, void *udata)
 
     u->used_callbacks |= FREE;
     u->free_src = op;
-    HDfree(ptr);
+    free(ptr);
     return (SUCCEED);
 }
 
@@ -264,9 +249,6 @@ free_cb(void *ptr, H5FD_file_image_op_t op, void *udata)
  *
  * Returns:     A pointer to the same udata that was passed in.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void *
@@ -287,9 +269,6 @@ udata_copy_cb(void *udata)
  *              udata_copy callback doesn't copy, only one instance of the udata
  *              is kept alive and such it must be freed explicitly at the end of the tests.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static herr_t
@@ -307,9 +286,6 @@ udata_free_cb(void *udata)
  * Purpose:     Resets the udata to default values. This facilitates storing only
  *              the results of a single operation in the udata.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static void
@@ -324,9 +300,6 @@ reset_udata(udata_t *u)
  *
  * Purpose:     Tests that callbacks are called properly in property list functions.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static int
@@ -349,7 +322,7 @@ test_callbacks(void)
     TESTING("Callback use in property list operations");
 
     /* Allocate and initialize udata */
-    udata = (udata_t *)HDmalloc(sizeof(udata_t));
+    udata = (udata_t *)malloc(sizeof(udata_t));
     VERIFY(udata != NULL, "udata malloc failed");
     reset_udata(udata);
 
@@ -358,7 +331,7 @@ test_callbacks(void)
 
     /* Allocate and initialize file image buffer */
     size       = (size_t)count * sizeof(char);
-    file_image = (char *)HDmalloc(size);
+    file_image = (char *)malloc(size);
     VERIFY(file_image != NULL, "file_image malloc failed");
     for (i = 0; i < count - 1; i++)
         file_image[i] = (char)(65 + i);
@@ -523,16 +496,16 @@ test_callbacks(void)
     /* Close stuff */
     if (H5Pclose(fapl_1) < 0)
         FAIL_STACK_ERROR;
-    HDfree(file_image);
-    HDfree(temp_file_image);
-    HDfree(udata);
+    free(file_image);
+    free(temp_file_image);
+    free(udata);
 
     PASSED();
     return 0;
 
 error:
-    HDfree(file_image);
-    HDfree(udata);
+    free(file_image);
+    free(udata);
 
     return 1;
 } /* test_callbacks() */
@@ -543,9 +516,6 @@ error:
  * Purpose:     Tests that callbacks are called properly in the core VFD and
  *              that the initial file image works properly.
  *
- * Programmer:  Jacob Gruber
- *              Monday, August 22, 2011
- *
  ******************************************************************************
  */
 static int
@@ -592,7 +562,7 @@ test_core(void)
     VERIFY(ret >= 0, "h5_make_local_copy");
 
     /* Allocate and initialize udata */
-    udata = (udata_t *)HDmalloc(sizeof(udata_t));
+    udata = (udata_t *)malloc(sizeof(udata_t));
     VERIFY(udata != NULL, "udata malloc failed");
 
     /* copy the address of the udata into the callbacks structure */
@@ -661,7 +631,7 @@ test_core(void)
     ret = HDfstat(fd, &sb);
     VERIFY(ret == 0, "fstat failed");
     size       = (size_t)sb.st_size;
-    file_image = (unsigned char *)HDmalloc(size);
+    file_image = (unsigned char *)malloc(size);
     if (HDread(fd, file_image, size) < 0)
         FAIL_PUTS_ERROR("unable to read from file descriptor");
     ret = HDclose(fd);
@@ -679,8 +649,8 @@ test_core(void)
 
     /* Release resources */
     h5_clean_files(FILENAME, fapl);
-    HDfree(udata);
-    HDfree(file_image);
+    free(udata);
+    free(file_image);
     HDremove(copied_filename);
 
     PASSED();
@@ -696,9 +666,6 @@ error:
  *
  * Purpose:     Test the H5Fget_file_image() call.
  *
- * Programmer:  John Mainzer
- *              Tuesday, November 15, 2011
- *
  ******************************************************************************
  */
 /* Disable warning for "format not a string literal" here -QAK */
@@ -785,8 +752,8 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
     VERIFY(image_size > 0, "H5Fget_file_image(1) failed.");
 
     /* allocate a buffer of the appropriate size */
-    image_ptr = HDmalloc((size_t)image_size);
-    VERIFY(image_ptr != NULL, "HDmalloc(1) failed.");
+    image_ptr = malloc((size_t)image_size);
+    VERIFY(image_ptr != NULL, "malloc(1) failed.");
 
     /* load the image of the file into the buffer */
     bytes_read = H5Fget_file_image(file_id, image_ptr, (size_t)image_size);
@@ -835,8 +802,8 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
         VERIFY(file_size >= image_size, "file size != image size.");
 
         /* allocate a buffer for the test file image */
-        file_image_ptr = HDmalloc((size_t)file_size);
-        VERIFY(file_image_ptr != NULL, "HDmalloc(2f) failed.");
+        file_image_ptr = malloc((size_t)file_size);
+        VERIFY(file_image_ptr != NULL, "malloc(2f) failed.");
 
         size_remaining = image_size;
         insertion_ptr  = file_image_ptr;
@@ -893,8 +860,8 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
         VERIFY(file_size == image_size, "file size != image size.");
 
         /* allocate a buffer for the test file image */
-        file_image_ptr = HDmalloc((size_t)file_size);
-        VERIFY(file_image_ptr != NULL, "HDmalloc(2) failed.");
+        file_image_ptr = malloc((size_t)file_size);
+        VERIFY(file_image_ptr != NULL, "malloc(2) failed.");
 
         /* open the test file using standard I/O calls */
         fd = HDopen(file_name, O_RDONLY);
@@ -958,11 +925,11 @@ test_get_file_image(const char *test_banner, const int file_name_num, hid_t fapl
 
     /* discard the image buffer if it exists */
     if (image_ptr != NULL)
-        HDfree(image_ptr);
+        free(image_ptr);
 
     /* discard the image buffer if it exists */
     if (file_image_ptr != NULL)
-        HDfree(file_image_ptr);
+        free(file_image_ptr);
 
     PASSED();
 
@@ -978,9 +945,6 @@ H5_GCC_CLANG_DIAG_ON("format-nonliteral")
  *
  * Purpose:     Verify that H5Fget_file_image() rejects invalid input.
  *
- * Programmer:  John Mainzer
- *              Tuesday, November 22, 2011
- *
  ******************************************************************************
  */
 
@@ -1061,15 +1025,15 @@ test_get_file_image_error_rejection(void)
     VERIFY(image_size > 0, "H5Fget_file_image(1 -- test 1) failed.");
 
     /* allocate a buffer of the appropriate size */
-    image_ptr = HDmalloc((size_t)image_size);
-    VERIFY(image_ptr != NULL, "HDmalloc(1) failed.");
+    image_ptr = malloc((size_t)image_size);
+    VERIFY(image_ptr != NULL, "malloc(1) failed.");
 
     /* load the image of the file into the buffer */
     H5E_BEGIN_TRY
     {
         bytes_read = H5Fget_file_image(file_id, image_ptr, (size_t)(image_size - 1));
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(bytes_read < 0, "H5Fget_file_image(2 -- test 1) succeeded.");
 
     /* Call H5Fget_file_image() with good buffer and buffer size,
@@ -1079,7 +1043,7 @@ test_get_file_image_error_rejection(void)
     {
         bytes_read = H5Fget_file_image((hid_t)0, image_ptr, (size_t)(image_size));
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(bytes_read < 0, "H5Fget_file_image(3 -- test 1) succeeded.");
 
     /* Call H5Fget_file_image() with good buffer and buffer size,
@@ -1089,7 +1053,7 @@ test_get_file_image_error_rejection(void)
     {
         bytes_read = H5Fget_file_image(dset_id, image_ptr, (size_t)(image_size));
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(bytes_read < 0, "H5Fget_file_image(4 -- test 1) succeeded.");
 
     /* Close dset and space */
@@ -1107,7 +1071,7 @@ test_get_file_image_error_rejection(void)
 
     /* discard the image buffer if it exists */
     if (image_ptr != NULL)
-        HDfree(image_ptr);
+        free(image_ptr);
 
     /************************** Test #2 **********************************/
     /* set up a multi file driver test file, and try to get its image
@@ -1193,7 +1157,7 @@ test_get_file_image_error_rejection(void)
     {
         image_size = H5Fget_file_image(file_id, NULL, (size_t)0);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(image_size == -1, "H5Fget_file_image(5) succeeded.");
 
     /* Close dset and space */
@@ -1255,7 +1219,7 @@ test_get_file_image_error_rejection(void)
     {
         image_size = H5Fget_file_image(file_id, NULL, (size_t)0);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(image_size == -1, "H5Fget_file_image(6) succeeded.");
 
     /* Close dset and space */
@@ -1315,7 +1279,7 @@ test_get_file_image_error_rejection(void)
     {
         image_size = H5Fget_file_image(file_id, NULL, (size_t)0);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(image_size == -1, "H5Fget_file_image(7) succeeded.");
 
     /* Close dset and space */
@@ -1349,7 +1313,7 @@ main(void)
 
     h5_reset();
 
-    HDprintf("Testing File Image Functionality.\n");
+    printf("Testing File Image Functionality.\n");
 
     errors += test_properties();
     errors += test_callbacks();
@@ -1412,10 +1376,10 @@ main(void)
     h5_restore_err();
 
     if (errors) {
-        HDprintf("***** %d File Image TEST%s FAILED! *****\n", errors, errors > 1 ? "S" : "");
+        printf("***** %d File Image TEST%s FAILED! *****\n", errors, errors > 1 ? "S" : "");
         return 1;
     }
 
-    HDprintf("All File Image tests passed.\n");
+    printf("All File Image tests passed.\n");
     return 0;
 }
