@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -12,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol <koziol@hdfgroup.org>
- *              Apr 17, 2007
- *
  * Purpose:     This program is run to generate an HDF5 data file with several
  *              datasets that have "bogus" messages in their object header.
  */
@@ -85,7 +81,15 @@ generate_datasets(hid_t loc_id, unsigned bogus_id)
         goto error;
 
     /* Set "fail if unknown always" message flag for bogus message */
-    /* There is no H5O_MSG_FLAG_FAIL_IF_UNKNOWN_ALWAYS, skip creating "Dataset3" */
+    bogus_flags = H5O_MSG_FLAG_FAIL_IF_UNKNOWN_ALWAYS;
+    if (H5Pset(dcpl, H5O_BOGUS_MSG_FLAGS_NAME, &bogus_flags) < 0)
+        goto error;
+
+    /* Create third dataset, with "fail if unknown always" message flag */
+    if ((did = H5Dcreate2(loc_id, "Dataset3", H5T_NATIVE_INT, sid, H5P_DEFAULT, dcpl, H5P_DEFAULT)) < 0)
+        goto error;
+    if (H5Dclose(did) < 0)
+        goto error;
 
     /* Set "mark if unknown" message flag for bogus message */
     bogus_flags = H5O_MSG_FLAG_MARK_IF_UNKNOWN;
@@ -126,7 +130,7 @@ error:
         H5Sclose(sid);
         H5Pclose(dcpl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 } /* generate_datasets() */
@@ -170,7 +174,7 @@ error:
         H5Gclose(gid);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 #else  /* H5O_ENABLE_BOGUS */
     HDputs("H5O_ENABLE_BOGUS compiler macro not defined!");
 #endif /* H5O_ENABLE_BOGUS */
