@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Raymond Lu
- *              Thursday, March 23, 2006
- *
  *  This program writes floating-point data to the HDF5 file.  It generates
  *  the file to be read by cross_read.c, to test reading data from cross-systems.
  *  Run it on an OpenVMS, a little-endian, and a big-endian machine.  Change the
@@ -85,9 +82,6 @@ int create_nbit_dsets_float(hid_t fid, hid_t fsid, hid_t msid);
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              Some time ago
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -176,7 +170,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -189,9 +183,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Neil Fortner
- *              27 January 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -264,7 +255,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -277,9 +268,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              21 January 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -352,7 +340,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -365,9 +353,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Neil Fortner
- *              27 January 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -448,7 +433,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -461,9 +446,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Neil Fortner
- *              27 January 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -544,7 +526,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -557,9 +539,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              21 January 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -640,7 +619,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -654,9 +633,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Neil Fortner
- *              27 January 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -737,7 +713,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -750,9 +726,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              29 March 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -825,7 +798,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -838,9 +811,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              29 March 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -921,7 +891,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 #endif /* H5_HAVE_FILTER_DEFLATE */
@@ -937,9 +907,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              29 March 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1012,7 +979,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -1026,9 +993,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              29 March 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1101,7 +1065,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -1114,9 +1078,6 @@ error:
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Raymond Lu
- *              29 March 2011
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1210,7 +1171,7 @@ error:
         H5Pclose(dcpl);
         H5Dclose(dataset);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -1222,8 +1183,6 @@ error:
  *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
- * Programmer:  Raymond Lu
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1258,8 +1217,8 @@ main(void)
 
     /* Create memory space.  This does not include the extra row for fill
      * values. */
-    HDassert(dimsf[0] == NX);
-    HDassert(dimsf[1] == NY);
+    assert(dimsf[0] == NX);
+    assert(dimsf[1] == NY);
     if ((memspace = H5Screate_simple(RANK, dimsf, NULL)) < 0)
         TEST_ERROR;
 
@@ -1325,8 +1284,8 @@ main(void)
     if (H5Fclose(file) < 0)
         TEST_ERROR;
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 
 error:
-    HDexit(EXIT_FAILURE);
+    exit(EXIT_FAILURE);
 } /* end main() */
