@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke
- *              Thursday, November 19, 1998
- *
  * Purpose:  Provides support functions for most of the hdf5 tests cases.
  *
  */
@@ -88,9 +85,6 @@ MPI_Info h5_io_info_g = MPI_INFO_NULL; /* MPI INFO object for IO */
  */
 static const char *multi_letters = "msbrglo";
 
-/* Length of multi-file VFD filename buffers */
-#define H5TEST_MULTI_FILENAME_LEN 1024
-
 /* Temporary file for sending signal messages */
 #define TMP_SIGNAL_FILE "tmp_signal_file"
 
@@ -135,9 +129,6 @@ static char  *h5_fixname_real(const char *base_name, hid_t fapl, const char *_su
  *
  *    Failure:  -1
  *
- * Programmer:  Robb Matzke
- *    Wednesday, March  4, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -156,9 +147,6 @@ h5_errors(hid_t estack, void H5_ATTR_UNUSED *client_data)
  *
  * Return:  void
  *
- * Programmer:  Neil Fortner
- *              June 1, 2015
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -186,9 +174,6 @@ h5_clean_files(const char *base_name[], hid_t fapl)
  *
  *              Since this is a cleanup file, we don't care if it fails.
  *
- * Programmer:  Dana Robinson
- *              February 2016
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -204,7 +189,7 @@ h5_delete_test_file(const char *base_name, hid_t fapl)
     {
         H5Fdelete(filename, fapl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
 } /* end h5_delete_test_file() */
 
@@ -223,9 +208,6 @@ h5_delete_test_file(const char *base_name, hid_t fapl)
  *
  *              Since this is a cleanup file, we don't care if it fails.
  *
- * Programmer:  Dana Robinson
- *              February 2016
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -248,9 +230,6 @@ h5_delete_all_test_files(const char *base_name[], hid_t fapl)
  *
  * Return:  Non-zero if cleanup actions were performed; zero otherwise.
  *
- * Programmer:  Albert Cheng
- *              May 28, 1998
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -284,9 +263,6 @@ h5_cleanup(const char *base_name[], hid_t fapl)
  *
  * Return:      void
  *
- * Programmer:  Dana Robinson
- *              February 2016
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -304,73 +280,36 @@ h5_test_shutdown(void)
  *
  * Return:      N/A
  *
- * Programmer:  Quincey Koziol
- *              Sept 10, 2015
- *
  *-------------------------------------------------------------------------
  */
 void
 h5_restore_err(void)
 {
     /* Restore the original error reporting routine */
-    HDassert(err_func != NULL);
+    assert(err_func != NULL);
     H5Eset_auto2(H5E_DEFAULT, err_func, NULL);
     err_func = NULL;
 }
 
 /*-------------------------------------------------------------------------
- * Function:  h5_reset
+ * Function:    h5_reset
  *
- * Purpose:  Reset the library by closing it.
- *
- * Return:  void
- *
- * Programmer:  Robb Matzke
- *              Friday, November 20, 1998
+ * Purpose:     Reset the library by closing it
  *
+ * Return:      void
  *-------------------------------------------------------------------------
  */
 void
 h5_reset(void)
 {
-    HDfflush(stdout);
-    HDfflush(stderr);
+    fflush(stdout);
+    fflush(stderr);
     H5close();
 
     /* Save current error stack reporting routine and redirect to our local one */
-    HDassert(err_func == NULL);
+    assert(err_func == NULL);
     H5Eget_auto2(H5E_DEFAULT, &err_func, NULL);
     H5Eset_auto2(H5E_DEFAULT, h5_errors, NULL);
-
-/*
- * I commented this chunk of code out because it's not clear what diagnostics
- *      were being output and under what circumstances, and creating this file
- *      is throwing off debugging some of the tests.  I can't see any _direct_
- *      harm in keeping this section of code, but I can't see any _direct_
- *      benefit right now either.  If we figure out under which circumstances
- *      diagnostics are being output, we should enable this behavior based on
- *      appropriate configure flags/macros.  QAK - 2007/12/20
- */
-#ifdef OLD_WAY
-    {
-        char filename[1024];
-
-        /*
-         * Cause the library to emit some diagnostics early so they don't
-         * interfere with other formatted output.
-         */
-        HDsnprintf(filename, sizeof(filename), "/tmp/h5emit-%05d.h5", HDgetpid());
-        H5E_BEGIN_TRY
-        {
-            hid_t file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
-            hid_t grp  = H5Gcreate2(file, "emit", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
-            H5Gclose(grp);
-            H5Fclose(file);
-            HDunlink(filename);
-        }
-        H5E_END_TRY;
-    }
-#endif /* OLD_WAY */
 }
 
 /*-------------------------------------------------------------------------
@@ -385,20 +324,17 @@ h5_reset(void)
  *
  * Return:      void
  *
- * Programmer:  Dana Robinson
- *              February 2016
- *
  *-------------------------------------------------------------------------
  */
 void
 h5_test_init(void)
 {
-    HDfflush(stdout);
-    HDfflush(stderr);
+    fflush(stdout);
+    fflush(stderr);
     H5close();
 
     /* Save current error stack reporting routine and redirect to our local one */
-    HDassert(err_func == NULL);
+    assert(err_func == NULL);
     H5Eget_auto2(H5E_DEFAULT, &err_func, NULL);
     H5Eset_auto2(H5E_DEFAULT, h5_errors, NULL);
 } /* end h5_test_init() */
@@ -420,9 +356,6 @@ h5_test_init(void)
  *        pointer or if FULLNAME isn't large enough for
  *        the result.
  *
- * Programmer:  Robb Matzke
- *              Thursday, November 19, 1998
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -445,9 +378,6 @@ h5_fixname(const char *base_name, hid_t fapl, char *fullname, size_t size)
  *                          pointer or if FULLNAME isn't large enough for
  *                          the result.
  *
- * Programmer:  Dana Robinson
- *              Spring 2019
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -489,9 +419,6 @@ h5_fixname_no_suffix(const char *base_name, hid_t fapl, char *fullname, size_t s
  *        pointer or if FULLNAME isn't large enough for
  *        the result.
  *
- * Programmer:  Neil Fortner
- *              Wednesday, July 15, 2015
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -517,9 +444,6 @@ h5_fixname_printf(const char *base_name, hid_t fapl, char *fullname, size_t size
  *        pointer or if FULLNAME isn't large enough for
  *        the result.
  *
- * Programmer:  Robb Matzke
- *              Thursday, November 19, 1998
- *
  *-------------------------------------------------------------------------
  */
 static char *
@@ -537,7 +461,7 @@ h5_fixname_real(const char *base_name, hid_t fapl, const char *_suffix, char *fu
     if (!base_name || !fullname || size < 1)
         return NULL;
 
-    HDmemset(fullname, 0, size);
+    memset(fullname, 0, size);
 
     /* Determine if driver is set by environment variable. If it is,
      * only generate a suffix if fixing the filename for the superblock
@@ -629,13 +553,13 @@ h5_fixname_real(const char *base_name, hid_t fapl, const char *_suffix, char *fu
             MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
 
             if (mpi_rank == 0)
-                HDprintf("*** Hint ***\n"
-                         "You can use environment variable HDF5_PARAPREFIX to "
-                         "run parallel test files in a\n"
-                         "different directory or to add file type prefix. e.g.,\n"
-                         "   HDF5_PARAPREFIX=pfs:/PFS/user/me\n"
-                         "   export HDF5_PARAPREFIX\n"
-                         "*** End of Hint ***\n");
+                printf("*** Hint ***\n"
+                       "You can use environment variable HDF5_PARAPREFIX to "
+                       "run parallel test files in a\n"
+                       "different directory or to add file type prefix. e.g.,\n"
+                       "   HDF5_PARAPREFIX=pfs:/PFS/user/me\n"
+                       "   export HDF5_PARAPREFIX\n"
+                       "*** End of Hint ***\n");
 
             explained = TRUE;
 #ifdef HDF5_PARAPREFIX
@@ -763,8 +687,6 @@ h5_fixname_real(const char *base_name, hid_t fapl, const char *_suffix, char *fu
  *
  * Return:  Success:  a pointer at the non-prefix part.
  *
- * Programmer:  Albert Cheng; Jun  1, 2006
- *
  *-------------------------------------------------------------------------
  */
 H5_ATTR_PURE const char *
@@ -790,9 +712,6 @@ h5_rmprefix(const char *filename)
  * Return:      Success:    A file access property list
  *              Failure:    H5I_INVALID_HID
  *
- * Programmer:  Robb Matzke
- *              Thursday, November 19, 1998
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -825,9 +744,6 @@ error:
  * Return:      Success:    A file access property list
  *              Failure:    H5I_INVALID_HID
  *
- * Programmer:  Robb Matzke
- *              Thursday, November 19, 1998
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -859,9 +775,6 @@ error:
  * Return:      Success:    0
  *              Failure:    -1
  *
- * Programmer:  Quincey Koziol
- *              November 2018
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -919,9 +832,6 @@ error:
  *
  * Return:  void
  *
- * Programmer:  Robb Matzke
- *              Friday, November 20, 1998
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -937,9 +847,6 @@ h5_no_hwconv(void)
  *
  * Return:  void
  *
- * Programmer:  Albert Cheng
- *              2002/04/22
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -961,13 +868,13 @@ h5_show_hostname(void)
 
         if (mpi_initialized && !mpi_finalized) {
             MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
-            HDprintf("MPI-process %d.", mpi_rank);
+            printf("MPI-process %d.", mpi_rank);
         }
         else
-            HDprintf("thread 0.");
+            printf("thread 0.");
     }
 #else
-    HDprintf("thread %" PRIu64 ".", H5TS_thread_id());
+    printf("thread %" PRIu64 ".", H5TS_thread_id());
 #endif
 #ifdef H5_HAVE_WIN32_API
 
@@ -991,12 +898,12 @@ h5_show_hostname(void)
 
 #endif
 #ifdef H5_HAVE_GETHOSTNAME
-    if (HDgethostname(hostname, (size_t)80) < 0)
-        HDprintf(" gethostname failed\n");
+    if (gethostname(hostname, (size_t)80) < 0)
+        printf(" gethostname failed\n");
     else
-        HDprintf(" hostname=%s\n", hostname);
+        printf(" hostname=%s\n", hostname);
 #else
-    HDprintf(" gethostname not supported\n");
+    printf(" gethostname not supported\n");
 #endif
 #ifdef H5_HAVE_WIN32_API
     WSACleanup();
@@ -1009,7 +916,6 @@ h5_show_hostname(void)
  * Purpose:     Process environment variables setting to set up MPI Info
  *              object.
  * Return:      0 if all is fine; otherwise non-zero.
- * Programmer:  Albert Cheng, 2002/05/21.
  */
 int
 h5_set_info_object(void)
@@ -1040,7 +946,7 @@ h5_set_info_object(void)
             /* copy key/value pair into temporary buffer */
             len  = HDstrcspn(valp, ";");
             next = &valp[len];
-            if (NULL == (key_val = (char *)HDcalloc(1, len + 1)))
+            if (NULL == (key_val = (char *)calloc(1, len + 1)))
                 return -1;
 
             /* increment the next pointer past the terminating semicolon */
@@ -1083,16 +989,16 @@ h5_set_info_object(void)
 
                 /* actually set the darned thing */
                 if (MPI_SUCCESS != MPI_Info_set(h5_io_info_g, namep, valp)) {
-                    HDprintf("MPI_Info_set failed\n");
+                    printf("MPI_Info_set failed\n");
                     ret_value = -1;
                 }
             }
 
             valp = next;
-            HDfree(key_val);
+            free(key_val);
         } while (next && *next);
 
-        HDfree(envp);
+        free(envp);
     }
 
     return ret_value;
@@ -1102,7 +1008,6 @@ h5_set_info_object(void)
  * Function:    h5_dump_info_object
  * Purpose:     Display content of an MPI Info object
  * Return:      void
- * Programmer:  Albert Cheng 2002/05/21
  */
 void
 h5_dump_info_object(MPI_Info info)
@@ -1112,17 +1017,17 @@ h5_dump_info_object(MPI_Info info)
     int  flag;
     int  i, nkeys;
 
-    HDprintf("Dumping MPI Info Object (up to %d bytes per item):\n", MPI_MAX_INFO_VAL);
+    printf("Dumping MPI Info Object (up to %d bytes per item):\n", MPI_MAX_INFO_VAL);
     if (info == MPI_INFO_NULL) {
-        HDprintf("object is MPI_INFO_NULL\n");
+        printf("object is MPI_INFO_NULL\n");
     }
     else {
         MPI_Info_get_nkeys(info, &nkeys);
-        HDprintf("object has %d items\n", nkeys);
+        printf("object has %d items\n", nkeys);
         for (i = 0; i < nkeys; i++) {
             MPI_Info_get_nthkey(info, i, key);
             MPI_Info_get(info, key, MPI_MAX_INFO_VAL, value, &flag);
-            HDprintf("%s=%s\n", key, value);
+            printf("%s=%s\n", key, value);
         }
     }
 }
@@ -1136,9 +1041,6 @@ h5_dump_info_object(MPI_Info info)
  * Return:  Success:  Size of file in bytes
  *    Failure:  -1
  *
- * Programmer:  Quincey Koziol
- *              Saturday, March 22, 2003
- *
  *-------------------------------------------------------------------------
  */
 /* Disable warning for "format not a string literal" here -QAK */
@@ -1211,7 +1113,7 @@ h5_get_file_size(const char *filename, hid_t fapl)
                 }     /* end for */
             }
             else {
-                HDassert(HDstrlen(multi_letters) == H5FD_MEM_NTYPES);
+                assert(HDstrlen(multi_letters) == H5FD_MEM_NTYPES);
                 for (mt = H5FD_MEM_DEFAULT; mt < H5FD_MEM_NTYPES; mt++) {
                     /* Create the filename to query */
                     HDsnprintf(temp, sizeof temp, "%s-%c.h5", filename, multi_letters[mt]);
@@ -1312,9 +1214,9 @@ print_func(const char *format, ...)
     va_list arglist;
     int     ret_value;
 
-    HDva_start(arglist, format);
+    va_start(arglist, format);
     ret_value = HDvprintf(format, arglist);
-    HDva_end(arglist);
+    va_end(arglist);
     return ret_value;
 }
 
@@ -1330,8 +1232,6 @@ print_func(const char *format, ...)
  *    0:  only decode is enabled
  *              -1: other
  *
- * Programmer:
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1379,9 +1279,6 @@ h5_szip_can_encode(void)
  * Return:  pointer to a string containing the value of the environment variable
  *     NULL if the variable doesn't exist in task 'root's environment.
  *
- * Programmer:  Leon Arber
- *              4/4/05
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -1391,7 +1288,7 @@ getenv_all(MPI_Comm comm, int root, const char *name)
     int          len;
     static char *env = NULL;
 
-    HDassert(name);
+    assert(name);
 
     MPI_Initialized(&mpi_initialized);
     MPI_Finalized(&mpi_finalized);
@@ -1399,7 +1296,7 @@ getenv_all(MPI_Comm comm, int root, const char *name)
     if (mpi_initialized && !mpi_finalized) {
         MPI_Comm_rank(comm, &mpi_rank);
         MPI_Comm_size(comm, &mpi_size);
-        HDassert(root < mpi_size);
+        assert(root < mpi_size);
 
         /* The root task does the getenv call
          * and sends the result to the other tasks */
@@ -1420,16 +1317,16 @@ getenv_all(MPI_Comm comm, int root, const char *name)
             MPI_Bcast(&len, 1, MPI_INT, root, comm);
             if (len >= 0) {
                 if (env == NULL)
-                    env = (char *)HDmalloc((size_t)len + 1);
+                    env = (char *)malloc((size_t)len + 1);
                 else if (HDstrlen(env) < (size_t)len)
-                    env = (char *)HDrealloc(env, (size_t)len + 1);
+                    env = (char *)realloc(env, (size_t)len + 1);
 
                 MPI_Bcast(env, len, MPI_CHAR, root, comm);
                 env[len] = '\0';
             }
             else {
                 if (env)
-                    HDfree(env);
+                    free(env);
                 env = NULL;
             }
         }
@@ -1440,7 +1337,7 @@ getenv_all(MPI_Comm comm, int root, const char *name)
     else {
         /* use original getenv */
         if (env)
-            HDfree(env);
+            free(env);
         env = HDgetenv(name);
     } /* end if */
 
@@ -1462,9 +1359,6 @@ getenv_all(MPI_Comm comm, int root, const char *name)
  *
  *              Failure:        -1
  *
- * Programmer:  Larry Knox
- *              Monday, October 13, 2009
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1479,7 +1373,7 @@ h5_make_local_copy(const char *origfilename, const char *local_copy_name)
         goto error;
 
     /* Allocate copy buffer */
-    if (NULL == (buf = HDcalloc((size_t)1, (size_t)READ_BUF_SIZE)))
+    if (NULL == (buf = calloc((size_t)1, (size_t)READ_BUF_SIZE)))
         goto error;
 
     /* Copy old file into temporary file */
@@ -1500,7 +1394,7 @@ h5_make_local_copy(const char *origfilename, const char *local_copy_name)
         goto error;
 
     /* Release memory */
-    HDfree(buf);
+    free(buf);
 
     return 0;
 
@@ -1510,7 +1404,7 @@ error:
         HDclose(fd_old);
     if (fd_new > 0)
         HDclose(fd_new);
-    HDfree(buf);
+    free(buf);
     return -1;
 } /* end h5_make_local_copy() */
 
@@ -1521,9 +1415,6 @@ error:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Neil Fortner
- *              Tuesday, April 12, 2011
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1549,9 +1440,6 @@ h5_verify_cached_stabs_cb(hid_t oid, const char H5_ATTR_UNUSED *name, const H5O_
  *
  *              Failure:        -1
  *
- * Programmer:  Neil Fortner
- *              Tuesday, April 12, 2011
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1593,7 +1481,7 @@ error:
     {
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return -1;
 }
@@ -1617,9 +1505,6 @@ error:
  *
  * Return:      void
  *
- * Programmer:  Mike McGreevy
- *              August 18, 2010
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -1628,23 +1513,23 @@ h5_send_message(const char *send, const char *arg1, const char *arg2)
     FILE *signalfile = NULL;
 
     /* Create signal file (which will send signal to some other process) */
-    signalfile = HDfopen(TMP_SIGNAL_FILE, "w+");
+    signalfile = fopen(TMP_SIGNAL_FILE, "w+");
 
     /* Write messages to signal file, if provided */
     if (arg2 != NULL) {
-        HDassert(arg1);
-        HDfprintf(signalfile, "%s\n%s\n", arg1, arg2);
+        assert(arg1);
+        fprintf(signalfile, "%s\n%s\n", arg1, arg2);
     } /* end if */
     else if (arg1 != NULL) {
-        HDassert(arg2 == NULL);
-        HDfprintf(signalfile, "%s\n", arg1);
+        assert(arg2 == NULL);
+        fprintf(signalfile, "%s\n", arg1);
     } /* end if */
     else {
-        HDassert(arg1 == NULL);
-        HDassert(arg2 == NULL);
+        assert(arg1 == NULL);
+        assert(arg2 == NULL);
     } /* end else */
 
-    HDfclose(signalfile);
+    fclose(signalfile);
 
     HDrename(TMP_SIGNAL_FILE, send);
 } /* h5_send_message() */
@@ -1671,9 +1556,6 @@ h5_send_message(const char *send, const char *arg1, const char *arg2)
  *
  * Return:      void
  *
- * Programmer:  Mike McGreevy
- *              August 18, 2010
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1688,7 +1570,7 @@ h5_wait_message(const char *waitfor)
     HDtime(&t0);
 
     /* Wait for return signal from some other process */
-    while ((returnfile = HDfopen(waitfor, "r")) == NULL) {
+    while ((returnfile = fopen(waitfor, "r")) == NULL) {
 
         /* make note of current time. */
         HDtime(&t1);
@@ -1697,12 +1579,12 @@ h5_wait_message(const char *waitfor)
             it was likely never sent and we should fail rather
             than loop infinitely */
         if (HDdifftime(t1, t0) > MESSAGE_TIMEOUT) {
-            HDfprintf(stdout, "Error communicating between processes. Make sure test script is running.\n");
+            fprintf(stdout, "Error communicating between processes. Make sure test script is running.\n");
             TEST_ERROR;
         } /* end if */
     }     /* end while */
 
-    HDfclose(returnfile);
+    fclose(returnfile);
     HDunlink(waitfor);
 
     return SUCCEED;
@@ -1841,17 +1723,17 @@ h5_get_dummy_vfd_class(void)
     H5FD_class_t *vfd_class = NULL; /* Dummy VFD that will be returned */
 
     /* Create the class and initialize everything to zero/NULL */
-    if (NULL == (vfd_class = (H5FD_class_t *)HDmalloc(sizeof(H5FD_class_t))))
+    if (NULL == (vfd_class = (H5FD_class_t *)malloc(sizeof(H5FD_class_t))))
         TEST_ERROR;
 
     /* Copy the dummy VFD */
-    HDmemcpy(vfd_class, &H5FD_dummy_g, sizeof(H5FD_class_t));
+    memcpy(vfd_class, &H5FD_dummy_g, sizeof(H5FD_class_t));
 
     return vfd_class;
 
 error:
     if (vfd_class)
-        HDfree(vfd_class);
+        free(vfd_class);
     return NULL;
 } /* h5_get_dummy_vfd_class */
 
@@ -1881,7 +1763,7 @@ h5_get_dummy_vol_class(void)
     H5VL_class_t *vol_class = NULL; /* Dummy VOL class that will be returned */
 
     /* Create the class and initialize everything to zero/NULL */
-    if (NULL == (vol_class = (H5VL_class_t *)HDcalloc((size_t)1, sizeof(H5VL_class_t))))
+    if (NULL == (vol_class = (H5VL_class_t *)calloc((size_t)1, sizeof(H5VL_class_t))))
         TEST_ERROR;
 
     /* Fill in the minimum parameters to make a VOL connector class that
@@ -1894,7 +1776,7 @@ h5_get_dummy_vol_class(void)
 
 error:
     if (vol_class)
-        HDfree(vol_class);
+        free(vol_class);
     return NULL;
 } /* h5_get_dummy_vol_class */
 
@@ -1921,8 +1803,6 @@ h5_get_version_string(H5F_libver_t libver)
  * Return:      Success:  0, if files are identical
  *              Failure: -1, if files differ
  *
- * Programmer:  Binh-Minh Ribler
- *              October, 2018
  *-------------------------------------------------------------------------
  */
 int
@@ -1938,15 +1818,15 @@ h5_compare_file_bytes(char *f1name, char *f2name)
     int   ret_value = 0; /* for error handling */
 
     /* Open files for reading */
-    f1ptr = HDfopen(f1name, "rb");
+    f1ptr = fopen(f1name, "rb");
     if (f1ptr == NULL) {
-        HDfprintf(stderr, "Unable to fopen() %s\n", f1name);
+        fprintf(stderr, "Unable to fopen() %s\n", f1name);
         ret_value = -1;
         goto done;
     }
-    f2ptr = HDfopen(f2name, "rb");
+    f2ptr = fopen(f2name, "rb");
     if (f2ptr == NULL) {
-        HDfprintf(stderr, "Unable to fopen() %s\n", f2name);
+        fprintf(stderr, "Unable to fopen() %s\n", f2name);
         ret_value = -1;
         goto done;
     }
@@ -1959,8 +1839,8 @@ h5_compare_file_bytes(char *f1name, char *f2name)
     f2size = HDftell(f2ptr);
 
     if (f1size != f2size) {
-        HDfprintf(stderr, "Files differ in size, %" PRIuHSIZE " vs. %" PRIuHSIZE "\n", (hsize_t)f1size,
-                  (hsize_t)f2size);
+        fprintf(stderr, "Files differ in size, %" PRIuHSIZE " vs. %" PRIuHSIZE "\n", (hsize_t)f1size,
+                (hsize_t)f2size);
         ret_value = -1;
         goto done;
     }
@@ -1969,16 +1849,16 @@ h5_compare_file_bytes(char *f1name, char *f2name)
     HDrewind(f1ptr);
     HDrewind(f2ptr);
     for (ii = 0; ii < f1size; ii++) {
-        if (HDfread(&f1char, 1, 1, f1ptr) != 1) {
+        if (fread(&f1char, 1, 1, f1ptr) != 1) {
             ret_value = -1;
             goto done;
         }
-        if (HDfread(&f2char, 1, 1, f2ptr) != 1) {
+        if (fread(&f2char, 1, 1, f2ptr) != 1) {
             ret_value = -1;
             goto done;
         }
         if (f1char != f2char) {
-            HDfprintf(stderr, "Mismatch @ 0x%" PRIXHSIZE ": 0x%X != 0x%X\n", (hsize_t)ii, f1char, f2char);
+            fprintf(stderr, "Mismatch @ 0x%" PRIXHSIZE ": 0x%X != 0x%X\n", (hsize_t)ii, f1char, f2char);
             ret_value = -1;
             goto done;
         }
@@ -1986,9 +1866,9 @@ h5_compare_file_bytes(char *f1name, char *f2name)
 
 done:
     if (f1ptr)
-        HDfclose(f1ptr);
+        fclose(f1ptr);
     if (f2ptr)
-        HDfclose(f2ptr);
+        fclose(f2ptr);
     return ret_value;
 } /* end h5_compare_file_bytes() */
 
@@ -2060,9 +1940,6 @@ H5_get_srcdir(void)
  * Return:      Success:  0, completed successfully
  *              Failure: -1
  *
- * Programmer:  Jake Smith
- *              24 June 2020
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -2078,7 +1955,7 @@ h5_duplicate_file_by_bytes(const char *orig, const char *dest)
 
     max_buf = 4096 * sizeof(char);
 
-    orig_ptr = HDfopen(orig, "rb");
+    orig_ptr = fopen(orig, "rb");
     if (NULL == orig_ptr) {
         ret_value = -1;
         goto done;
@@ -2088,36 +1965,36 @@ h5_duplicate_file_by_bytes(const char *orig, const char *dest)
     fsize = (hsize_t)HDftell(orig_ptr);
     HDrewind(orig_ptr);
 
-    dest_ptr = HDfopen(dest, "wb");
+    dest_ptr = fopen(dest, "wb");
     if (NULL == dest_ptr) {
         ret_value = -1;
         goto done;
     }
 
     read_size = MIN(fsize, max_buf);
-    dup_buf   = HDmalloc(read_size);
+    dup_buf   = malloc(read_size);
     if (NULL == dup_buf) {
         ret_value = -1;
         goto done;
     }
 
     while (read_size > 0) {
-        if (HDfread(dup_buf, read_size, 1, orig_ptr) != 1) {
+        if (fread(dup_buf, read_size, 1, orig_ptr) != 1) {
             ret_value = -1;
             goto done;
         }
-        HDfwrite(dup_buf, read_size, 1, dest_ptr);
+        fwrite(dup_buf, read_size, 1, dest_ptr);
         fsize -= read_size;
         read_size = MIN(fsize, max_buf);
     }
 
 done:
     if (orig_ptr != NULL)
-        HDfclose(orig_ptr);
+        fclose(orig_ptr);
     if (dest_ptr != NULL)
-        HDfclose(dest_ptr);
+        fclose(dest_ptr);
     if (dup_buf != NULL)
-        HDfree(dup_buf);
+        free(dup_buf);
     return ret_value;
 } /* end h5_duplicate_file_by_bytes() */
 
@@ -2195,7 +2072,7 @@ h5_using_default_driver(const char *drv_name)
 {
     hbool_t ret_val = TRUE;
 
-    HDassert(H5_DEFAULT_VFD == H5FD_SEC2);
+    assert(H5_DEFAULT_VFD == H5FD_SEC2);
 
     if (!drv_name)
         drv_name = HDgetenv(HDF5_DRIVER);
@@ -2227,8 +2104,8 @@ h5_using_parallel_driver(hid_t fapl_id, hbool_t *driver_is_parallel)
     hid_t         driver_id  = H5I_INVALID_HID;
     herr_t        ret_value  = SUCCEED;
 
-    HDassert(fapl_id >= 0);
-    HDassert(driver_is_parallel);
+    assert(fapl_id >= 0);
+    assert(driver_is_parallel);
 
     if (fapl_id == H5P_DEFAULT)
         fapl_id = H5P_FILE_ACCESS_DEFAULT;
@@ -2270,8 +2147,8 @@ h5_driver_is_default_vfd_compatible(hid_t fapl_id, hbool_t *default_vfd_compatib
     hid_t         driver_id  = H5I_INVALID_HID;
     herr_t        ret_value  = SUCCEED;
 
-    HDassert(fapl_id >= 0);
-    HDassert(default_vfd_compatible);
+    assert(fapl_id >= 0);
+    assert(default_vfd_compatible);
 
     if (fapl_id == H5P_DEFAULT)
         fapl_id = H5P_FILE_ACCESS_DEFAULT;
