@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke
- *              Friday, November 20, 1998
- *
  * Purpose:     Test support stuff.
  */
 #ifndef H5TEST_H
@@ -90,7 +87,7 @@ H5TEST_DLLVAR MPI_Info h5_io_info_g; /* MPI INFO object for IO */
  */
 #define AT()                                                                                                 \
     do {                                                                                                     \
-        HDprintf("   at %s:%d in %s()...\n", __FILE__, __LINE__, __func__);                                  \
+        printf("   at %s:%d in %s()...\n", __FILE__, __LINE__, __func__);                                    \
     } while (0)
 
 /*
@@ -104,37 +101,37 @@ H5TEST_DLLVAR MPI_Info h5_io_info_g; /* MPI INFO object for IO */
  */
 #define TESTING(WHAT)                                                                                        \
     do {                                                                                                     \
-        HDprintf("Testing %-62s", WHAT);                                                                     \
-        HDfflush(stdout);                                                                                    \
+        printf("Testing %-62s", WHAT);                                                                       \
+        fflush(stdout);                                                                                      \
         n_tests_run_g++;                                                                                     \
     } while (0)
 #define TESTING_2(WHAT)                                                                                      \
     do {                                                                                                     \
-        HDprintf("  Testing %-60s", WHAT);                                                                   \
-        HDfflush(stdout);                                                                                    \
+        printf("  Testing %-60s", WHAT);                                                                     \
+        fflush(stdout);                                                                                      \
         n_tests_run_g++;                                                                                     \
     } while (0)
 #define PASSED()                                                                                             \
     do {                                                                                                     \
         HDputs(" PASSED");                                                                                   \
-        HDfflush(stdout);                                                                                    \
+        fflush(stdout);                                                                                      \
         n_tests_passed_g++;                                                                                  \
     } while (0)
 #define H5_FAILED()                                                                                          \
     do {                                                                                                     \
         HDputs("*FAILED*");                                                                                  \
-        HDfflush(stdout);                                                                                    \
+        fflush(stdout);                                                                                      \
         n_tests_failed_g++;                                                                                  \
     } while (0)
 #define H5_WARNING()                                                                                         \
     do {                                                                                                     \
         HDputs("*WARNING*");                                                                                 \
-        HDfflush(stdout);                                                                                    \
+        fflush(stdout);                                                                                      \
     } while (0)
 #define SKIPPED()                                                                                            \
     do {                                                                                                     \
         HDputs(" -SKIP-");                                                                                   \
-        HDfflush(stdout);                                                                                    \
+        fflush(stdout);                                                                                      \
         n_tests_skipped_g++;                                                                                 \
     } while (0)
 #define PUTS_ERROR(s)                                                                                        \
@@ -174,9 +171,9 @@ H5TEST_DLLVAR MPI_Info h5_io_info_g; /* MPI INFO object for IO */
  */
 #define TESTING_MULTIPART(WHAT)                                                                              \
     do {                                                                                                     \
-        HDprintf("Testing %-62s", WHAT);                                                                     \
+        printf("Testing %-62s", WHAT);                                                                       \
         HDputs("");                                                                                          \
-        HDfflush(stdout);                                                                                    \
+        fflush(stdout);                                                                                      \
     } while (0)
 
 /*
@@ -266,7 +263,7 @@ extern "C" {
  * an equivalent non-const pointer around) is far messier.
  */
 #ifndef h5_free_const
-#define h5_free_const(mem) HDfree((void *)(uintptr_t)mem)
+#define h5_free_const(mem) free((void *)(uintptr_t)mem)
 #endif
 
 /* Generally useful testing routines */
