@@ -25,10 +25,10 @@
 #define TMPDIR        "tmp_links_env/"
 #define NAME_BUF_SIZE 1024
 
-const char *FILENAME[] = {"extlinks_env0",        /* 0: main file */
-                          "extlinks_env1",        /* 1: target file */
-                          TMPDIR "extlinks_env1", /* 2 */
-                          NULL};
+static const char *FILENAME[] = {"extlinks_env0",        /* 0: main file */
+                                 "extlinks_env1",        /* 1: target file */
+                                 TMPDIR "extlinks_env1", /* 2 */
+                                 NULL};
 
 static int external_link_env(hid_t fapl, hbool_t new_format);
 
@@ -45,9 +45,6 @@ static int external_link_env(hid_t fapl, hbool_t new_format);
  * Return:      Success:        0
  *              Failure:        -1
  *
- * Programmer:  Vailin Choi
- *              Feb. 20, 2008
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -107,7 +104,7 @@ external_link_env(hid_t fapl, hbool_t new_format)
     {
         gid = H5Gopen2(fid, "ext_link", H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* Should be able to find the target file from pathnames set via HDF5_EXT_PREFIX */
     if (gid < 0) {
@@ -131,7 +128,7 @@ error:
         H5Gclose(gid);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return -1;
 } /* end external_link_env() */
 
@@ -142,8 +139,6 @@ error:
  *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
- * Programmer:    Vailin Choi; Nov 2010
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -161,7 +156,7 @@ main(void)
     /* Splitter VFD has issues with external links */
     if (!HDstrcmp(env_h5_drvr, "splitter")) {
         HDputs(" -- SKIPPED for incompatible VFD --");
-        HDexit(EXIT_SUCCESS);
+        exit(EXIT_SUCCESS);
     }
 
     h5_reset();
@@ -182,18 +177,18 @@ main(void)
 
     /* Results */
     if (nerrors) {
-        HDprintf("***** %d External Link (HDF5_EXT_PREFIX) test%s FAILED! *****\n", nerrors,
-                 1 == nerrors ? "" : "s");
-        HDexit(EXIT_FAILURE);
+        printf("***** %d External Link (HDF5_EXT_PREFIX) test%s FAILED! *****\n", nerrors,
+               1 == nerrors ? "" : "s");
+        exit(EXIT_FAILURE);
     }
-    HDprintf("All external Link (HDF5_EXT_PREFIX) tests passed.\n");
+    printf("All external Link (HDF5_EXT_PREFIX) tests passed.\n");
 
     /* clean up tmp_links_env directory created by external link tests */
     HDrmdir(TMPDIR);
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 
 error:
     HDputs("*** TESTS FAILED ***");
-    HDexit(EXIT_FAILURE);
+    exit(EXIT_FAILURE);
 } /* end main() */
