@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -84,10 +83,10 @@ check_dataset(hid_t fid, unsigned verbose, const char *sym_name, symbol_t *recor
     hssize_t snpoints;                             /* Number of elements in dataset */
     hsize_t  start[2] = {0, 0}, count[2] = {1, 1}; /* Hyperslab selection values */
 
-    HDassert(fid >= 0);
-    HDassert(sym_name);
-    HDassert(record);
-    HDassert(rec_sid >= 0);
+    assert(fid >= 0);
+    assert(sym_name);
+    assert(record);
+    assert(rec_sid >= 0);
 
     /* Open dataset for symbol */
     if ((dsid = H5Dopen2(fid, sym_name, H5P_DEFAULT)) < 0)
@@ -103,7 +102,7 @@ check_dataset(hid_t fid, unsigned verbose, const char *sym_name, symbol_t *recor
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Symbol = '%s', # of records = %lld\n", sym_name, (long long)snpoints);
+        fprintf(stderr, "Symbol = '%s', # of records = %lld\n", sym_name, (long long)snpoints);
 
     /* Check if there are records for symbol */
     if (snpoints > 0) {
@@ -132,10 +131,10 @@ check_dataset(hid_t fid, unsigned verbose, const char *sym_name, symbol_t *recor
          * chunk may be deleted before the object header has the updated
          * dimensions */
         if (record->rec_id != start[1] && record->rec_id != (uint64_t)0) {
-            HDfprintf(stderr, "*** ERROR ***\n");
-            HDfprintf(stderr, "Incorrect record value!\n");
-            HDfprintf(stderr, "Symbol = '%s', # of records = %lld, record->rec_id = %llx\n", sym_name,
-                      (long long)snpoints, (unsigned long long)record->rec_id);
+            fprintf(stderr, "*** ERROR ***\n");
+            fprintf(stderr, "Incorrect record value!\n");
+            fprintf(stderr, "Symbol = '%s', # of records = %lld, record->rec_id = %llx\n", sym_name,
+                    (long long)snpoints, (unsigned long long)record->rec_id);
             return -1;
         } /* end if */
     }     /* end if */
@@ -200,22 +199,22 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
     symbol_t        record;          /* The record to add to the dataset */
     unsigned        v;               /* Local index variable */
 
-    HDassert(filename);
-    HDassert(nseconds != 0);
-    HDassert(poll_time != 0);
+    assert(filename);
+    assert(nseconds != 0);
+    assert(poll_time != 0);
 
     /* Reset the record */
     /* (record's 'info' field might need to change for each record written, also) */
-    HDmemset(&record, 0, sizeof(record));
+    memset(&record, 0, sizeof(record));
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Choosing datasets\n");
+        fprintf(stderr, "Choosing datasets\n");
 
     /* Allocate space for 'common' datasets, if any */
     if (ncommon > 0) {
         /* Allocate array to hold pointers to symbols for common datasets */
-        if (NULL == (sym_com = (symbol_info_t **)HDmalloc(sizeof(symbol_info_t *) * ncommon)))
+        if (NULL == (sym_com = (symbol_info_t **)malloc(sizeof(symbol_info_t *) * ncommon)))
             return -1;
 
         /* Open the common datasets */
@@ -229,14 +228,14 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
 
             /* Emit informational message */
             if (verbose)
-                HDfprintf(stderr, "Common symbol #%u = '%s'\n", v, symbol_info[0][offset].name);
+                fprintf(stderr, "Common symbol #%u = '%s'\n", v, symbol_info[0][offset].name);
         } /* end for */
     }     /* end if */
 
     /* Allocate space for 'random' datasets, if any */
     if (nrandom > 0) {
         /* Allocate array to hold pointers to symbols for random datasets */
-        if (NULL == (sym_rand = (symbol_info_t **)HDmalloc(sizeof(symbol_info_t *) * nrandom)))
+        if (NULL == (sym_rand = (symbol_info_t **)malloc(sizeof(symbol_info_t *) * nrandom)))
             return -1;
 
         /* Determine the random datasets */
@@ -250,7 +249,7 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
 
             /* Emit informational message */
             if (verbose)
-                HDfprintf(stderr, "Random symbol #%u = '%s'\n", v, sym->name);
+                fprintf(stderr, "Random symbol #%u = '%s'\n", v, sym->name);
         } /* end for */
     }     /* end if */
 
@@ -260,7 +259,7 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Reading records\n");
+        fprintf(stderr, "Reading records\n");
 
     /* Get the starting time */
     start_time = HDtime(NULL);
@@ -275,7 +274,7 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
 
         /* Emit informational message */
         if (verbose)
-            HDfprintf(stderr, "Opening file: %s\n", filename);
+            fprintf(stderr, "Opening file: %s\n", filename);
 
         /* Open the file */
         if ((fid = H5Fopen(filename, H5F_ACC_RDONLY | H5F_ACC_SWMR_READ, fapl)) < 0)
@@ -285,14 +284,14 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
         if (ncommon > 0) {
             /* Emit informational message */
             if (verbose)
-                HDfprintf(stderr, "Checking common symbols\n");
+                fprintf(stderr, "Checking common symbols\n");
 
             /* Iterate over common datasets */
             for (v = 0; v < ncommon; v++) {
                 /* Check common dataset */
                 if (check_dataset(fid, verbose, sym_com[v]->name, &record, mem_sid) < 0)
                     return -1;
-                HDmemset(&record, 0, sizeof(record));
+                memset(&record, 0, sizeof(record));
             } /* end for */
         }     /* end if */
 
@@ -300,20 +299,20 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
         if (nrandom > 0) {
             /* Emit informational message */
             if (verbose)
-                HDfprintf(stderr, "Checking random symbols\n");
+                fprintf(stderr, "Checking random symbols\n");
 
             /* Iterate over random datasets */
             for (v = 0; v < nrandom; v++) {
                 /* Check random dataset */
                 if (check_dataset(fid, verbose, sym_rand[v]->name, &record, mem_sid) < 0)
                     return -1;
-                HDmemset(&record, 0, sizeof(record));
+                memset(&record, 0, sizeof(record));
             } /* end for */
         }     /* end if */
 
         /* Emit informational message */
         if (verbose)
-            HDfprintf(stderr, "Closing file\n");
+            fprintf(stderr, "Closing file\n");
 
         /* Close the file */
         if (H5Fclose(fid) < 0)
@@ -336,18 +335,18 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Closing datasets\n");
+        fprintf(stderr, "Closing datasets\n");
 
     /* Close 'random' datasets, if any */
     if (nrandom > 0) {
         /* Release array holding dataset ID's for random datasets */
-        HDfree(sym_rand);
+        free(sym_rand);
     } /* end if */
 
     /* Close 'common' datasets, if any */
     if (ncommon > 0) {
         /* Release array holding dataset ID's for common datasets */
-        HDfree(sym_com);
+        free(sym_com);
     } /* end if */
 
     return 0;
@@ -356,18 +355,18 @@ read_records(const char *filename, unsigned verbose, unsigned long nseconds, uns
 static void
 usage(void)
 {
-    HDprintf("\n");
-    HDprintf("Usage error!\n");
-    HDprintf("\n");
-    HDprintf("Usage: swmr_remove_reader [-q] [-s <# of seconds to sleep between\n");
-    HDprintf("    polling>] [-h <# of common symbols to poll>] [-l <# of random symbols\n");
-    HDprintf("    to poll>] [-r <random seed>] <# of seconds to test>\n");
-    HDprintf("\n");
-    HDprintf("Defaults to verbose (no '-q' given), 1 second between polling ('-s 1'),\n");
-    HDprintf("5 common symbols to poll ('-h 5'), 10 random symbols to poll ('-l 10'),\n");
-    HDprintf("and will generate a random seed (no -r given).\n");
-    HDprintf("\n");
-    HDexit(EXIT_FAILURE);
+    printf("\n");
+    printf("Usage error!\n");
+    printf("\n");
+    printf("Usage: swmr_remove_reader [-q] [-s <# of seconds to sleep between\n");
+    printf("    polling>] [-h <# of common symbols to poll>] [-l <# of random symbols\n");
+    printf("    to poll>] [-r <random seed>] <# of seconds to test>\n");
+    printf("\n");
+    printf("Defaults to verbose (no '-q' given), 1 second between polling ('-s 1'),\n");
+    printf("5 common symbols to poll ('-h 5'), 10 random symbols to poll ('-l 10'),\n");
+    printf("and will generate a random seed (no -r given).\n");
+    printf("\n");
+    exit(EXIT_FAILURE);
 }
 
 int
@@ -393,7 +392,7 @@ main(int argc, char *argv[])
                 switch (argv[u][1]) {
                     /* # of common symbols to poll */
                     case 'h':
-                        ncommon = HDatoi(argv[u + 1]);
+                        ncommon = atoi(argv[u + 1]);
                         if (ncommon < 0)
                             usage();
                         u += 2;
@@ -401,7 +400,7 @@ main(int argc, char *argv[])
 
                     /* # of random symbols to poll */
                     case 'l':
-                        nrandom = HDatoi(argv[u + 1]);
+                        nrandom = atoi(argv[u + 1]);
                         if (nrandom < 0)
                             usage();
                         u += 2;
@@ -416,7 +415,7 @@ main(int argc, char *argv[])
                     /* Random # seed */
                     case 'r':
                         use_seed = 1;
-                        temp     = HDatoi(argv[u + 1]);
+                        temp     = atoi(argv[u + 1]);
                         if (temp < 0)
                             usage();
                         else
@@ -426,7 +425,7 @@ main(int argc, char *argv[])
 
                     /* # of seconds between polling */
                     case 's':
-                        poll_time = HDatoi(argv[u + 1]);
+                        poll_time = atoi(argv[u + 1]);
                         if (poll_time < 0)
                             usage();
                         u += 2;
@@ -439,7 +438,7 @@ main(int argc, char *argv[])
             }     /* end if */
             else {
                 /* Get the number of records to append */
-                nseconds = HDatol(argv[u]);
+                nseconds = atol(argv[u]);
                 if (nseconds <= 0)
                     usage();
 
@@ -454,11 +453,11 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose) {
-        HDfprintf(stderr, "Parameters:\n");
-        HDfprintf(stderr, "\t# of seconds between polling = %d\n", poll_time);
-        HDfprintf(stderr, "\t# of common symbols to poll = %d\n", ncommon);
-        HDfprintf(stderr, "\t# of random symbols to poll = %d\n", nrandom);
-        HDfprintf(stderr, "\t# of seconds to test = %ld\n", nseconds);
+        fprintf(stderr, "Parameters:\n");
+        fprintf(stderr, "\t# of seconds between polling = %d\n", poll_time);
+        fprintf(stderr, "\t# of common symbols to poll = %d\n", ncommon);
+        fprintf(stderr, "\t# of random symbols to poll = %d\n", nrandom);
+        fprintf(stderr, "\t# of seconds to test = %ld\n", nseconds);
     } /* end if */
 
     /* Set the random seed */
@@ -469,16 +468,16 @@ main(int argc, char *argv[])
     } /* end if */
     HDsrandom(random_seed);
     /* ALWAYS emit the random seed for possible debugging */
-    HDfprintf(stderr, "Using reader random seed: %u\n", random_seed);
+    fprintf(stderr, "Using reader random seed: %u\n", random_seed);
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Generating symbol names\n");
+        fprintf(stderr, "Generating symbol names\n");
 
     /* Generate dataset names */
     if (generate_symbols() < 0) {
-        HDfprintf(stderr, "Error generating symbol names!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error generating symbol names!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Create datatype for creating datasets */
@@ -488,28 +487,28 @@ main(int argc, char *argv[])
     /* Reading records from datasets */
     if (read_records(FILENAME, verbose, (unsigned long)nseconds, (unsigned)poll_time, (unsigned)ncommon,
                      (unsigned)nrandom) < 0) {
-        HDfprintf(stderr, "Error reading records from datasets!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error reading records from datasets!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Releasing symbols\n");
+        fprintf(stderr, "Releasing symbols\n");
 
     /* Clean up the symbols */
     if (shutdown_symbols() < 0) {
-        HDfprintf(stderr, "Error releasing symbols!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error releasing symbols!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Closing objects\n");
+        fprintf(stderr, "Closing objects\n");
 
     /* Close objects created */
     if (H5Tclose(symbol_tid) < 0) {
-        HDfprintf(stderr, "Error closing symbol datatype!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error closing symbol datatype!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     return 0;
