@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol
- *              Tuesday, January  6, 2004
- *
  * Purpose:    Provides support functions for the testing framework.
  *
  */
@@ -72,13 +69,13 @@ AddTest(const char *TheName, void (*TheCall)(void), void (*Cleanup)(void), const
 {
     /* Sanity checking */
     if (HDstrlen(TheDescr) >= MAXTESTDESC) {
-        HDprintf("Test description ('%s') too long, increase MAXTESTDESC(%d).\n", TheDescr, MAXTESTDESC);
-        HDexit(EXIT_FAILURE);
-    } /* end if */
+        printf("Test description ('%s') too long, increase MAXTESTDESC(%d).\n", TheDescr, MAXTESTDESC);
+        exit(EXIT_FAILURE);
+    }
     if (HDstrlen(TheName) >= MAXTESTNAME) {
-        HDprintf("Test name too long, increase MAXTESTNAME(%d).\n", MAXTESTNAME);
-        HDexit(EXIT_FAILURE);
-    } /* end if */
+        printf("Test name too long, increase MAXTESTNAME(%d).\n", MAXTESTNAME);
+        exit(EXIT_FAILURE);
+    }
 
     /* Check for increasing the Test array size */
     if (Index >= TestAlloc) {
@@ -86,16 +83,16 @@ AddTest(const char *TheName, void (*TheCall)(void), void (*Cleanup)(void), const
         unsigned    newAlloc = MAX(1, TestAlloc * 2); /* New array size */
 
         /* Reallocate array */
-        if (NULL == (newTest = (TestStruct *)HDrealloc(Test, newAlloc * sizeof(TestStruct)))) {
-            HDprintf("Out of memory for tests, Index = %u, TestAlloc = %u, newAlloc = %u\n", Index, TestAlloc,
-                     newAlloc);
-            HDexit(EXIT_FAILURE);
-        } /* end if */
+        if (NULL == (newTest = (TestStruct *)realloc(Test, newAlloc * sizeof(TestStruct)))) {
+            printf("Out of memory for tests, Index = %u, TestAlloc = %u, newAlloc = %u\n", Index, TestAlloc,
+                   newAlloc);
+            exit(EXIT_FAILURE);
+        }
 
         /* Update info */
         Test      = newTest;
         TestAlloc = newAlloc;
-    } /* end if */
+    }
 
     /* Set up test function */
     HDstrcpy(Test[Index].Description, TheDescr);
@@ -151,9 +148,6 @@ TestInit(const char *ProgName, void (*private_usage)(void), int (*private_parser
 /*
  * Print test usage.
  *    First print the common test options, then the extra options if provided.
- *
- * Modification:
- *     2004/08/18 Albert Cheng.  Add TestPrivateUsage feature.
  */
 void
 TestUsage(void)
@@ -211,9 +205,6 @@ TestInfo(const char *ProgName)
  *
  * Return: Void
  *    exit EXIT_FAILURE if error is encountered.
- *
- * Modification:
- *     2004/08/18 Albert Cheng.  Add extra_parse feature.
  */
 void
 TestParseCmdLine(int argc, char *argv[])
@@ -221,7 +212,7 @@ TestParseCmdLine(int argc, char *argv[])
     hbool_t skipped_all = FALSE;
     int     ret_code;
 
-    while (argv++, --argc > 0) {
+    while ((void)argv++, --argc > 0) {
         if ((HDstrcmp(*argv, "-verbose") == 0) || (HDstrcmp(*argv, "-v") == 0)) {
             if (argc > 0) {
                 --argc;
@@ -230,7 +221,7 @@ TestParseCmdLine(int argc, char *argv[])
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
         else if (((HDstrcmp(*argv, "-exclude") == 0) || (HDstrcmp(*argv, "-x") == 0))) {
@@ -241,7 +232,7 @@ TestParseCmdLine(int argc, char *argv[])
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
         else if (((HDstrcmp(*argv, "-begin") == 0) || (HDstrcmp(*argv, "-b") == 0))) {
@@ -252,7 +243,7 @@ TestParseCmdLine(int argc, char *argv[])
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
         else if (((HDstrcmp(*argv, "-only") == 0) || (HDstrcmp(*argv, "-o") == 0))) {
@@ -272,7 +263,7 @@ TestParseCmdLine(int argc, char *argv[])
             }
             else {
                 TestUsage();
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
         else if ((HDstrcmp(*argv, "-summary") == 0) || (HDstrcmp(*argv, "-s") == 0))
@@ -281,7 +272,7 @@ TestParseCmdLine(int argc, char *argv[])
             enable_error_stack = 1;
         else if ((HDstrcmp(*argv, "-help") == 0) || (HDstrcmp(*argv, "-h") == 0)) {
             TestUsage();
-            HDexit(EXIT_SUCCESS);
+            exit(EXIT_SUCCESS);
         }
         else if ((HDstrcmp(*argv, "-cleanoff") == 0) || (HDstrcmp(*argv, "-c") == 0))
             SetTestNoCleanup();
@@ -295,7 +286,7 @@ TestParseCmdLine(int argc, char *argv[])
     if (NULL != TestPrivateParser) {
         ret_code = TestPrivateParser(argc + 1, argv - 1);
         if (ret_code != 0)
-            HDexit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
     }
 }
 
@@ -325,7 +316,7 @@ PerformTests(void)
         }
 
     Test_parameters = NULL; /* clear it. */
-    MESSAGE(2, ("\n\n"))
+    MESSAGE(2, ("\n\n"));
 
     if (num_errs)
         print_func("!!! %d Error(s) were detected !!!\n\n", (int)num_errs);
@@ -378,7 +369,7 @@ void
 TestShutdown(void)
 {
     if (Test)
-        HDfree(Test);
+        free(Test);
 }
 
 /*
@@ -530,7 +521,7 @@ ParseTestVerbosity(char *argv)
     else if (*argv == 'h')
         SetTestVerbosity(VERBO_HI);
     else
-        SetTestVerbosity(HDatoi(argv));
+        SetTestVerbosity(atoi(argv));
 }
 
 /*
@@ -574,9 +565,9 @@ TestErrPrintf(const char *format, ...)
     num_errs++;
 
     /* Print the requested information */
-    HDva_start(arglist, format);
+    va_start(arglist, format);
     ret_value = HDvprintf(format, arglist);
-    HDva_end(arglist);
+    va_end(arglist);
 
     /* Return the length of the string produced (like printf() does) */
     return ret_value;
@@ -624,7 +615,7 @@ SetTest(const char *testname, int action)
             break;
         default:
             /* error */
-            HDprintf("*** ERROR: Unknown action (%d) for SetTest\n", action);
+            printf("*** ERROR: Unknown action (%d) for SetTest\n", action);
             break;
     }
 }
@@ -643,10 +634,10 @@ TestAlarmOn(void)
 
     /* Get the alarm value from the environment variable, if set */
     if (env_val != NULL)
-        alarm_sec = (unsigned)HDstrtoul(env_val, (char **)NULL, 10);
+        alarm_sec = (unsigned)strtoul(env_val, (char **)NULL, 10);
 
     /* Set the number of seconds before alarm goes off */
-    HDalarm((unsigned)alarm_sec);
+    alarm((unsigned)alarm_sec);
 #endif
 }
 
@@ -656,6 +647,6 @@ TestAlarmOff(void)
 {
 #ifdef H5_HAVE_ALARM
     /* Set the number of seconds to zero */
-    HDalarm(0);
+    alarm(0);
 #endif
 }
