@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke
- *              Friday, September 25, 1998
- *
  * Purpose:    Test unlinking operations.
  */
 
@@ -25,9 +22,9 @@
 #include "h5test.h"
 #include "H5Gpkg.h" /* Groups                */
 
-const char *FILENAME[] = {"unlink",          "new_move_a",     "new_move_b",    "lunlink",
-                          "filespace",       "slashes",        "resurrect_set", "resurrect_type",
-                          "resurrect_group", "unlink_chunked", "full_group",    NULL};
+static const char *FILENAME[] = {"unlink",          "new_move_a",     "new_move_b",    "lunlink",
+                                 "filespace",       "slashes",        "resurrect_set", "resurrect_type",
+                                 "resurrect_group", "unlink_chunked", "full_group",    NULL};
 
 /* Macros for test_create_unlink() & test_filespace */
 #define GROUPNAME                     "group"
@@ -75,9 +72,6 @@ const char *FILENAME[] = {"unlink",          "new_move_a",     "new_move_b",
  *
  *        Failure:    number of errors
  *
- * Programmer:    Robb Matzke
- *              Friday, September 25, 1998
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -118,7 +112,7 @@ test_one(hid_t file)
     {
         status = H5Ldelete(grp, ".", H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (status >= 0)
         FAIL_PUTS_ERROR("    Unlinking object w/o a name should have failed.");
     if (H5Gclose(grp) < 0)
@@ -137,7 +131,7 @@ error:
         H5Gclose(work);
         H5Gclose(grp);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_one() */
 
@@ -150,9 +144,6 @@ error:
  *
  *        Failure:    number of errors
  *
- * Programmer:    Robb Matzke
- *              Friday, September 25, 1998
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -244,7 +235,7 @@ error:
         H5Gclose(work);
         H5Gclose(grp);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -257,9 +248,6 @@ error:
  *
  *        Failure:    number of errors
  *
- * Programmer:    Robb Matzke
- *              Friday, September 25, 1998
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -289,7 +277,7 @@ error:
     {
         H5Gclose(work);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_symlink() */
 
@@ -302,9 +290,6 @@ error:
  *
  *        Failure:    number of errors
  *
- * Programmer:    Robb Matzke
- *              Friday, September 25, 1998
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -353,7 +338,7 @@ error:
         H5Gclose(foo);
         H5Gclose(inner);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_rename() */
 
@@ -366,9 +351,6 @@ error:
  *
  *              Failure:        number of errors
  *
- * Programmer:  Raymond Lu
- *              Thursday, April 25, 2002
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -410,7 +392,7 @@ test_new_move(hid_t fapl)
             FAIL)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* Move a group across files.  Should fail. */
     H5E_BEGIN_TRY
@@ -418,7 +400,7 @@ test_new_move(hid_t fapl)
         if (H5Lmove(grp_1, "group_move", file_b, "group_new_name", H5P_DEFAULT, H5P_DEFAULT) != FAIL)
             TEST_ERROR;
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* Move a group across groups in the same file. */
     if (H5Lmove(grp_1, "group_move", grp_2, "group_new_name", H5P_DEFAULT, H5P_DEFAULT) < 0)
@@ -454,7 +436,7 @@ error:
         H5Fclose(file_a);
         H5Fclose(file_b);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -467,9 +449,6 @@ error:
  *
  *              Failure:        number of errors
  *
- * Programmer:  Raymond Lu
- *              Thursday, April 25, 2002
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -527,9 +506,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Saturday, March 22, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -649,7 +625,7 @@ test_filespace(hid_t fapl)
         TEST_ERROR;
 
     /* Create buffer for writing dataset */
-    if (NULL == (data = (int *)HDmalloc(sizeof(int) * FILESPACE_DIM0 * FILESPACE_DIM1 * FILESPACE_DIM2)))
+    if (NULL == (data = (int *)malloc(sizeof(int) * FILESPACE_DIM0 * FILESPACE_DIM1 * FILESPACE_DIM2)))
         TEST_ERROR;
 
     /* Create single dataset (with contiguous storage & late allocation), remove it & verify file size */
@@ -1243,7 +1219,7 @@ test_filespace(hid_t fapl)
     {
         dataset = H5Dcreate2(file, DATASETNAME, H5T_NATIVE_INT, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (dataset >= 0) {
         H5Dclose(dataset);
         TEST_ERROR;
@@ -1285,7 +1261,7 @@ test_filespace(hid_t fapl)
     {
         group = H5Gcreate2(file, GROUPNAME, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (group >= 0) {
         H5Gclose(group);
         TEST_ERROR;
@@ -1335,7 +1311,7 @@ test_filespace(hid_t fapl)
     {
         status = H5Tcommit2(file, TYPENAME, type, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (status >= 0)
         TEST_ERROR;
     if (H5Tclose(type) < 0)
@@ -1390,7 +1366,7 @@ test_filespace(hid_t fapl)
     {
         attr = H5Acreate2(dataset, ATTRNAME, H5T_NATIVE_INT, attr_space, H5P_DEFAULT, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     if (attr >= 0) {
         H5Aclose(attr);
         TEST_ERROR;
@@ -1425,7 +1401,7 @@ test_filespace(hid_t fapl)
     /* Cleanup common objects */
 
     /* Release dataset buffer */
-    HDfree(data);
+    free(data);
 
     /* Close property lists */
     if (H5Pclose(fapl_nocache) < 0)
@@ -1452,7 +1428,7 @@ test_filespace(hid_t fapl)
 error:
     /* Release dataset buffer */
     if (data)
-        HDfree(data);
+        free(data);
 
     return 1;
 } /* end test_filespace() */
@@ -1465,9 +1441,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Friday, April 11, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1490,12 +1463,12 @@ test_create_unlink(const char *msg, hid_t fapl)
         HDsnprintf(groupname, sizeof(groupname), "%s %u", GROUPNAME, u);
         if ((group = H5Gcreate2(file, groupname, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
             H5_FAILED();
-            HDprintf("group %s creation failed\n", groupname);
+            printf("group %s creation failed\n", groupname);
             goto error;
         } /* end if */
         if (H5Gclose(group) < 0) {
             H5_FAILED();
-            HDprintf("closing group %s failed\n", groupname);
+            printf("closing group %s failed\n", groupname);
             goto error;
         } /* end if */
     }     /* end for */
@@ -1505,7 +1478,7 @@ test_create_unlink(const char *msg, hid_t fapl)
         HDsnprintf(groupname, sizeof(groupname), "%s %u", GROUPNAME, u);
         if (H5Ldelete(file, groupname, H5P_DEFAULT) < 0) {
             H5_FAILED();
-            HDprintf("Unlinking group %s failed\n", groupname);
+            printf("Unlinking group %s failed\n", groupname);
             goto error;
         } /* end if */
     }     /* end for */
@@ -1529,9 +1502,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Saturday, August 16, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1608,9 +1578,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Saturday, August 16, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1719,9 +1686,6 @@ delete_node(hid_t pid, hid_t id)
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Monday, January 19, 2004
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1736,7 +1700,7 @@ test_unlink_rightleaf(hid_t fid)
     TESTING("deleting right-most child in non-leaf B-tree node");
 
     /* Allocate space for the group IDs */
-    if (NULL == (gids = (hid_t *)HDcalloc((size_t)ngroups, sizeof(hid_t))))
+    if (NULL == (gids = (hid_t *)calloc((size_t)ngroups, sizeof(hid_t))))
         TEST_ERROR;
 
     if ((rootid = H5Gopen2(fid, "/", H5P_DEFAULT)) < 0)
@@ -1770,7 +1734,7 @@ test_unlink_rightleaf(hid_t fid)
         TEST_ERROR;
 
     /* Free memory */
-    HDfree(gids);
+    free(gids);
 
     PASSED();
     return 0;
@@ -1784,15 +1748,15 @@ error:
                 {
                     H5Gclose(gids[n]);
                 }
-                H5E_END_TRY;
+                H5E_END_TRY
             } /* end if */
-        HDfree(gids);
+        free(gids);
     } /* end if */
     H5E_BEGIN_TRY
     {
         H5Gclose(rootid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_unlink_rightleaf() */
@@ -1806,9 +1770,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Monday, January 19, 2004
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1823,7 +1784,7 @@ test_unlink_rightnode(hid_t fid)
     TESTING("deleting right-most child in non-leaf B-tree node");
 
     /* Allocate space for the group IDs */
-    if (NULL == (gids = (hid_t *)HDcalloc((size_t)ngroups, sizeof(hid_t))))
+    if (NULL == (gids = (hid_t *)calloc((size_t)ngroups, sizeof(hid_t))))
         TEST_ERROR;
 
     if ((rootid = H5Gopen2(fid, "/", H5P_DEFAULT)) < 0)
@@ -1860,7 +1821,7 @@ test_unlink_rightnode(hid_t fid)
         FAIL_STACK_ERROR;
 
     /* Free memory */
-    HDfree(gids);
+    free(gids);
 
     PASSED();
     return 0;
@@ -1874,15 +1835,15 @@ error:
                 {
                     H5Gclose(gids[n]);
                 }
-                H5E_END_TRY;
+                H5E_END_TRY
             } /* end if */
-        HDfree(gids);
+        free(gids);
     } /* end if */
     H5E_BEGIN_TRY
     {
         H5Gclose(rootid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_unlink_rightnode() */
@@ -1896,9 +1857,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Monday, January 19, 2004
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -1913,7 +1871,7 @@ test_unlink_middlenode(hid_t fid)
     TESTING("deleting right-most child in non-leaf B-tree node");
 
     /* Allocate space for the group IDs */
-    if (NULL == (gids = (hid_t *)HDcalloc((size_t)ngroups, sizeof(hid_t))))
+    if (NULL == (gids = (hid_t *)calloc((size_t)ngroups, sizeof(hid_t))))
         TEST_ERROR;
 
     if ((rootid = H5Gopen2(fid, "/", H5P_DEFAULT)) < 0)
@@ -2236,7 +2194,7 @@ test_unlink_middlenode(hid_t fid)
         FAIL_STACK_ERROR;
 
     /* Free memory */
-    HDfree(gids);
+    free(gids);
 
     PASSED();
     return 0;
@@ -2250,15 +2208,15 @@ error:
                 {
                     H5Gclose(gids[n]);
                 }
-                H5E_END_TRY;
+                H5E_END_TRY
             } /* end if */
-        HDfree(gids);
+        free(gids);
     } /* end if */
     H5E_BEGIN_TRY
     {
         H5Gclose(rootid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return 1;
 } /* end test_unlink_middlenode() */
@@ -2272,9 +2230,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Wednesday, July 14, 2004
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -2342,7 +2297,7 @@ error:
         H5Dclose(d);
         H5Fclose(f);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_resurrect_dataset() */
 
@@ -2355,9 +2310,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  James Laird
- *              Wednesday, July 28, 2004
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -2422,7 +2374,7 @@ error:
         H5Tclose(type);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_resurrect_datatype() */
 
@@ -2435,9 +2387,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  James Laird
- *              Wednesday, July 28, 2004
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -2500,7 +2449,7 @@ error:
         H5Gclose(group);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_resurrect_group() */
 
@@ -2512,9 +2461,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Monday, September 27, 2004
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -2598,7 +2544,7 @@ error:
         H5Dclose(dset_id);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_unlink_chunked_dataset() */
 
@@ -2610,9 +2556,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Wednesday, January 18, 2006
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -2759,7 +2702,7 @@ error:
         H5Gclose(gid);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_full_group_compact() */
 
@@ -2771,9 +2714,6 @@ error:
  * Return:      Success:        0
  *              Failure:        number of errors
  *
- * Programmer:  Quincey Koziol
- *              Wednesday, January 18, 2006
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -2937,7 +2877,7 @@ error:
         H5Pclose(gcpl);
         H5Fclose(file_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* end test_full_group_dense() */
 
@@ -2948,9 +2888,6 @@ error:
  *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
- * Programmer:    Robb Matzke
- *              Friday, September 25, 1998
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -3022,12 +2959,12 @@ main(void)
 
             /* Get FAPL cache settings */
             if (H5Pget_cache(fapl_small_mdc, &mdc_nelmts, &rdcc_nelmts, &rdcc_nbytes, &rdcc_w0) < 0)
-                HDprintf("H5Pget_cache failed\n");
+                printf("H5Pget_cache failed\n");
 
             /* Change FAPL cache settings */
             mdc_nelmts = 1;
             if (H5Pset_cache(fapl_small_mdc, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0) < 0)
-                HDprintf("H5Pset_cache failed\n");
+                printf("H5Pset_cache failed\n");
 
             /* Test creating & unlinking lots of objects with a 1-element metadata cache FAPL */
             nerrors += test_create_unlink("create and unlink large number of objects with small cache",
@@ -3075,16 +3012,16 @@ main(void)
     nerrors += (h5_verify_cached_stabs(FILENAME, fapl) < 0 ? 1 : 0);
 
     if (nerrors) {
-        HDprintf("***** %d FAILURE%s! *****\n", nerrors, 1 == nerrors ? "" : "S");
-        HDexit(EXIT_FAILURE);
+        printf("***** %d FAILURE%s! *****\n", nerrors, 1 == nerrors ? "" : "S");
+        exit(EXIT_FAILURE);
     }
 
     HDputs("All unlink tests passed.");
 
     h5_cleanup(FILENAME, fapl);
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 
 error:
-    HDexit(EXIT_FAILURE);
+    exit(EXIT_FAILURE);
 } /* end main() */
