@@ -1,3 +1,14 @@
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include "hdf5.h"
 #include "testphdf5.h"
@@ -133,16 +144,16 @@ point_set(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[], s
                     }
 
     if (VERBOSE_MED) {
-        HDprintf("start[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "count[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "stride[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "block[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "total datapoints=%" PRIuHSIZE "\n",
-                 start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1],
-                 block[0] * block[1] * count[0] * count[1]);
+        printf("start[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "count[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "stride[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "block[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "total datapoints=%" PRIuHSIZE "\n",
+               start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1],
+               block[0] * block[1] * count[0] * count[1]);
         k = 0;
         for (i = 0; i < num_points; i++) {
-            HDprintf("(%d, %d)\n", (int)coords[k], (int)coords[k + 1]);
+            printf("(%d, %d)\n", (int)coords[k], (int)coords[k + 1]);
             k += 2;
         }
     }
@@ -158,19 +169,19 @@ dataset_print(hsize_t start[], hsize_t block[], B_DATATYPE *dataset)
     hsize_t     i, j;
 
     /* print the column heading */
-    HDprintf("%-8s", "Cols:");
+    printf("%-8s", "Cols:");
     for (j = 0; j < block[1]; j++) {
-        HDprintf("%3" PRIuHSIZE " ", start[1] + j);
+        printf("%3" PRIuHSIZE " ", start[1] + j);
     }
-    HDprintf("\n");
+    printf("\n");
 
     /* print the slab data */
     for (i = 0; i < block[0]; i++) {
-        HDprintf("Row %2" PRIuHSIZE ": ", i + start[0]);
+        printf("Row %2" PRIuHSIZE ": ", i + start[0]);
         for (j = 0; j < block[1]; j++) {
-            HDprintf("%" PRIuHSIZE " ", *dataptr++);
+            printf("%" PRIuHSIZE " ", *dataptr++);
         }
-        HDprintf("\n");
+        printf("\n");
     }
 }
 
@@ -186,15 +197,15 @@ verify_data(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[],
 
     /* print it if VERBOSE_MED */
     if (VERBOSE_MED) {
-        HDprintf("verify_data dumping:::\n");
-        HDprintf("start(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "count(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "stride(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "block(%" PRIuHSIZE ", %" PRIuHSIZE ")\n",
-                 start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1]);
-        HDprintf("original values:\n");
+        printf("verify_data dumping:::\n");
+        printf("start(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "count(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "stride(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "block(%" PRIuHSIZE ", %" PRIuHSIZE ")\n",
+               start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1]);
+        printf("original values:\n");
         dataset_print(start, block, original);
-        HDprintf("compared values:\n");
+        printf("compared values:\n");
         dataset_print(start, block, dataset);
     }
 
@@ -203,10 +214,10 @@ verify_data(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[],
         for (j = 0; j < block[1]; j++) {
             if (*dataset != *original) {
                 if (vrfyerrs++ < MAX_ERR_REPORT || VERBOSE_MED) {
-                    HDprintf("Dataset Verify failed at [%" PRIuHSIZE "][%" PRIuHSIZE "]"
-                             "(row %" PRIuHSIZE ", col %" PRIuHSIZE "): "
-                             "expect %" PRIuHSIZE ", got %" PRIuHSIZE "\n",
-                             i, j, i + start[0], j + start[1], *(original), *(dataset));
+                    printf("Dataset Verify failed at [%" PRIuHSIZE "][%" PRIuHSIZE "]"
+                           "(row %" PRIuHSIZE ", col %" PRIuHSIZE "): "
+                           "expect %" PRIuHSIZE ", got %" PRIuHSIZE "\n",
+                           i, j, i + start[0], j + start[1], *(original), *(dataset));
                 }
                 dataset++;
                 original++;
@@ -214,9 +225,9 @@ verify_data(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[],
         }
     }
     if (vrfyerrs > MAX_ERR_REPORT && !VERBOSE_MED)
-        HDprintf("[more errors ...]\n");
+        printf("[more errors ...]\n");
     if (vrfyerrs)
-        HDprintf("%d errors found in verify_data\n", vrfyerrs);
+        printf("%d errors found in verify_data\n", vrfyerrs);
     return (vrfyerrs);
 }
 
@@ -314,12 +325,12 @@ ccslab_set(int mpi_rank, int mpi_size, hsize_t start[], hsize_t count[], hsize_t
             break;
     }
     if (VERBOSE_MED) {
-        HDprintf("start[]=(%lu,%lu), count[]=(%lu,%lu), stride[]=(%lu,%lu), block[]=(%lu,%lu), total "
-                 "datapoints=%lu\n",
-                 (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
-                 (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
-                 (unsigned long)block[0], (unsigned long)block[1],
-                 (unsigned long)(block[0] * block[1] * count[0] * count[1]));
+        printf("start[]=(%lu,%lu), count[]=(%lu,%lu), stride[]=(%lu,%lu), block[]=(%lu,%lu), total "
+               "datapoints=%lu\n",
+               (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
+               (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
+               (unsigned long)block[0], (unsigned long)block[1],
+               (unsigned long)(block[0] * block[1] * count[0] * count[1]));
     }
 }
 
@@ -372,20 +383,20 @@ ccdataset_print(hsize_t start[], hsize_t block[], DATATYPE *dataset)
     hsize_t   i, j;
 
     /* print the column heading */
-    HDprintf("Print only the first block of the dataset\n");
-    HDprintf("%-8s", "Cols:");
+    printf("Print only the first block of the dataset\n");
+    printf("%-8s", "Cols:");
     for (j = 0; j < block[1]; j++) {
-        HDprintf("%3lu ", (unsigned long)(start[1] + j));
+        printf("%3lu ", (unsigned long)(start[1] + j));
     }
-    HDprintf("\n");
+    printf("\n");
 
     /* print the slab data */
     for (i = 0; i < block[0]; i++) {
-        HDprintf("Row %2lu: ", (unsigned long)(i + start[0]));
+        printf("Row %2lu: ", (unsigned long)(i + start[0]));
         for (j = 0; j < block[1]; j++) {
-            HDprintf("%03d ", *dataptr++);
+            printf("%03d ", *dataptr++);
         }
-        HDprintf("\n");
+        printf("\n");
     }
 }
 
@@ -402,14 +413,14 @@ ccdataset_vrfy(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block
 
     /* print it if VERBOSE_MED */
     if (VERBOSE_MED) {
-        HDprintf("dataset_vrfy dumping:::\n");
-        HDprintf("start(%lu, %lu), count(%lu, %lu), stride(%lu, %lu), block(%lu, %lu)\n",
-                 (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
-                 (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
-                 (unsigned long)block[0], (unsigned long)block[1]);
-        HDprintf("original values:\n");
+        printf("dataset_vrfy dumping:::\n");
+        printf("start(%lu, %lu), count(%lu, %lu), stride(%lu, %lu), block(%lu, %lu)\n",
+               (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
+               (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
+               (unsigned long)block[0], (unsigned long)block[1]);
+        printf("original values:\n");
         ccdataset_print(start, block, original);
-        HDprintf("compared values:\n");
+        printf("compared values:\n");
         ccdataset_print(start, block, dataset);
     }
 
@@ -432,8 +443,8 @@ ccdataset_vrfy(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block
                     }
                     if (*dataptr != *oriptr) {
                         if (vrfyerrs++ < MAX_ERR_REPORT || VERBOSE_MED) {
-                            HDprintf("Dataset Verify failed at [%lu][%lu]: expect %d, got %d\n",
-                                     (unsigned long)i, (unsigned long)j, *(oriptr), *(dataptr));
+                            printf("Dataset Verify failed at [%lu][%lu]: expect %d, got %d\n",
+                                   (unsigned long)i, (unsigned long)j, *(oriptr), *(dataptr));
                         }
                     }
                 }
@@ -441,9 +452,9 @@ ccdataset_vrfy(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block
         }
     }
     if (vrfyerrs > MAX_ERR_REPORT && !VERBOSE_MED)
-        HDprintf("[more errors ...]\n");
+        printf("[more errors ...]\n");
     if (vrfyerrs)
-        HDprintf("%d errors found in ccdataset_vrfy\n", vrfyerrs);
+        printf("%d errors found in ccdataset_vrfy\n", vrfyerrs);
     return (vrfyerrs);
 }
 
@@ -477,7 +488,7 @@ dataset_big_write(void)
     B_DATATYPE *wdata;
 
     /* allocate memory for data buffer */
-    wdata = (B_DATATYPE *)HDmalloc(bigcount * sizeof(B_DATATYPE));
+    wdata = (B_DATATYPE *)malloc(bigcount * sizeof(B_DATATYPE));
     VRFY_G((wdata != NULL), "wdata malloc succeeded");
 
     /* setup file access template */
@@ -495,7 +506,7 @@ dataset_big_write(void)
 
     /* Each process takes a slabs of rows. */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset1 write by ROW\n");
+        printf("\nTesting Dataset1 write by ROW\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = (hsize_t)mpi_size_g;
@@ -556,7 +567,7 @@ dataset_big_write(void)
 
     /* Each process takes a slabs of cols. */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset2 write by COL\n");
+        printf("\nTesting Dataset2 write by COL\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = (hsize_t)mpi_size_g;
@@ -617,7 +628,7 @@ dataset_big_write(void)
 
     /* ALL selection */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset3 write select ALL proc 0, NONE others\n");
+        printf("\nTesting Dataset3 write select ALL proc 0, NONE others\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = 1;
@@ -678,7 +689,7 @@ dataset_big_write(void)
 
     /* Point selection */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset4 write point selection\n");
+        printf("\nTesting Dataset4 write point selection\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = (hsize_t)(mpi_size_g * 4);
@@ -700,7 +711,7 @@ dataset_big_write(void)
 
     num_points = bigcount;
 
-    coords = (hsize_t *)HDmalloc(num_points * RANK * sizeof(hsize_t));
+    coords = (hsize_t *)malloc(num_points * RANK * sizeof(hsize_t));
     VRFY_G((coords != NULL), "coords malloc succeeded");
 
     set_coords(start, count, stride, block, num_points, coords, IN_ORDER);
@@ -749,7 +760,7 @@ dataset_big_write(void)
     ret = H5Dclose(dataset);
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
-    HDfree(wdata);
+    free(wdata);
     H5Fclose(fid);
 }
 
@@ -782,12 +793,12 @@ dataset_big_read(void)
     herr_t      ret; /* Generic return value */
 
     /* allocate memory for data buffer */
-    rdata = (B_DATATYPE *)HDmalloc(bigcount * sizeof(B_DATATYPE));
+    rdata = (B_DATATYPE *)malloc(bigcount * sizeof(B_DATATYPE));
     VRFY_G((rdata != NULL), "rdata malloc succeeded");
-    wdata = (B_DATATYPE *)HDmalloc(bigcount * sizeof(B_DATATYPE));
+    wdata = (B_DATATYPE *)malloc(bigcount * sizeof(B_DATATYPE));
     VRFY_G((wdata != NULL), "wdata malloc succeeded");
 
-    HDmemset(rdata, 0, bigcount * sizeof(B_DATATYPE));
+    memset(rdata, 0, bigcount * sizeof(B_DATATYPE));
 
     /* setup file access template */
     acc_tpl = H5Pcreate(H5P_FILE_ACCESS);
@@ -803,7 +814,7 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset1 by COL\n");
+        printf("\nRead Testing Dataset1 by COL\n");
 
     dataset = H5Dopen2(fid, DATASET1, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
@@ -854,7 +865,7 @@ dataset_big_read(void)
     /* verify the read data with original expected data */
     ret = verify_data(start, count, stride, block, rdata, wdata);
     if (ret) {
-        HDfprintf(stderr, "verify failed\n");
+        fprintf(stderr, "verify failed\n");
         exit(1);
     }
 
@@ -866,8 +877,8 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset2 by ROW\n");
-    HDmemset(rdata, 0, bigcount * sizeof(B_DATATYPE));
+        printf("\nRead Testing Dataset2 by ROW\n");
+    memset(rdata, 0, bigcount * sizeof(B_DATATYPE));
     dataset = H5Dopen2(fid, DATASET2, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
 
@@ -917,7 +928,7 @@ dataset_big_read(void)
     /* verify the read data with original expected data */
     ret = verify_data(start, count, stride, block, rdata, wdata);
     if (ret) {
-        HDfprintf(stderr, "verify failed\n");
+        fprintf(stderr, "verify failed\n");
         exit(1);
     }
 
@@ -929,8 +940,8 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset3 read select ALL proc 0, NONE others\n");
-    HDmemset(rdata, 0, bigcount * sizeof(B_DATATYPE));
+        printf("\nRead Testing Dataset3 read select ALL proc 0, NONE others\n");
+    memset(rdata, 0, bigcount * sizeof(B_DATATYPE));
     dataset = H5Dopen2(fid, DATASET3, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
 
@@ -982,7 +993,7 @@ dataset_big_read(void)
         /* verify the read data with original expected data */
         ret = verify_data(start, count, stride, block, rdata, wdata);
         if (ret) {
-            HDfprintf(stderr, "verify failed\n");
+            fprintf(stderr, "verify failed\n");
             exit(1);
         }
     }
@@ -995,7 +1006,7 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset4 with Point selection\n");
+        printf("\nRead Testing Dataset4 with Point selection\n");
     dataset = H5Dopen2(fid, DATASET4, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
 
@@ -1020,7 +1031,7 @@ dataset_big_read(void)
 
     num_points = bigcount;
 
-    coords = (hsize_t *)HDmalloc(num_points * RANK * sizeof(hsize_t));
+    coords = (hsize_t *)malloc(num_points * RANK * sizeof(hsize_t));
     VRFY_G((coords != NULL), "coords malloc succeeded");
 
     set_coords(start, count, stride, block, num_points, coords, IN_ORDER);
@@ -1031,7 +1042,7 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Sselect_elements succeeded");
 
     if (coords)
-        HDfree(coords);
+        free(coords);
 
     /* create a memory dataspace */
     /* Warning: H5Screate_simple requires an array of hsize_t elements
@@ -1057,7 +1068,7 @@ dataset_big_read(void)
 
     ret = verify_data(start, count, stride, block, rdata, wdata);
     if (ret) {
-        HDfprintf(stderr, "verify failed\n");
+        fprintf(stderr, "verify failed\n");
         exit(1);
     }
 
@@ -1068,8 +1079,8 @@ dataset_big_read(void)
     ret = H5Dclose(dataset);
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
-    HDfree(wdata);
-    HDfree(rdata);
+    free(wdata);
+    free(rdata);
 
     wdata = NULL;
     rdata = NULL;
@@ -1096,9 +1107,9 @@ dataset_big_read(void)
 
     /* release data buffers */
     if (rdata)
-        HDfree(rdata);
+        free(rdata);
     if (wdata)
-        HDfree(wdata);
+        free(wdata);
 
 } /* dataset_large_readAll */
 
@@ -1106,7 +1117,7 @@ static void
 single_rank_independent_io(void)
 {
     if (mpi_rank_g == 0)
-        HDprintf("single_rank_independent_io\n");
+        printf("single_rank_independent_io\n");
 
     if (MAIN_PROCESS) {
         hsize_t  dims[1];
@@ -1153,7 +1164,7 @@ single_rank_independent_io(void)
         VRFY_G((ret >= 0), "H5Dwrite succeeded");
 
         /* Wipe buffer */
-        HDmemset(data, 0, dims[0] * sizeof(int));
+        memset(data, 0, dims[0] * sizeof(int));
 
         /* Read data back */
         ret = H5Dread(dset_id, H5T_NATIVE_INT, H5S_BLOCK, fspace_id, H5P_DEFAULT, data);
@@ -1162,7 +1173,7 @@ single_rank_independent_io(void)
         /* Verify data */
         for (i = 0; i < dims[0]; i++)
             if (data[i] != (int)(i % (uint64_t)DXFER_BIGCOUNT)) {
-                HDfprintf(stderr, "verify failed\n");
+                fprintf(stderr, "verify failed\n");
                 exit(1);
             }
 
@@ -1241,9 +1252,6 @@ create_faccess_plist(MPI_Comm comm, MPI_Info info, int l_facc_type)
  *
  *        Failure:    -1
  *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1269,7 +1277,7 @@ coll_chunk1(void)
 {
     const char *filename = FILENAME[0];
     if (mpi_rank_g == 0)
-        HDprintf("coll_chunk1\n");
+        printf("coll_chunk1\n");
 
     coll_chunktest(filename, 1, BYROW_CONT, API_NONE, HYPER, HYPER, OUT_OF_ORDER);
     coll_chunktest(filename, 1, BYROW_CONT, API_NONE, HYPER, POINT, OUT_OF_ORDER);
@@ -1291,12 +1299,6 @@ coll_chunk1(void)
  * Return:    Success:    0
  *
  *        Failure:    -1
- *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1322,7 +1324,7 @@ coll_chunk2(void)
 {
     const char *filename = FILENAME[0];
     if (mpi_rank_g == 0)
-        HDprintf("coll_chunk2\n");
+        printf("coll_chunk2\n");
 
     coll_chunktest(filename, 1, BYROW_DISCONT, API_NONE, HYPER, HYPER, OUT_OF_ORDER);
     coll_chunktest(filename, 1, BYROW_DISCONT, API_NONE, HYPER, POINT, OUT_OF_ORDER);
@@ -1345,9 +1347,6 @@ coll_chunk2(void)
  *
  *        Failure:    -1
  *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1374,7 +1373,7 @@ coll_chunk3(void)
 {
     const char *filename = FILENAME[0];
     if (mpi_rank_g == 0)
-        HDprintf("coll_chunk3\n");
+        printf("coll_chunk3\n");
 
     coll_chunktest(filename, mpi_size_g, BYROW_CONT, API_NONE, HYPER, HYPER, OUT_OF_ORDER);
     coll_chunktest(filename, mpi_size_g, BYROW_CONT, API_NONE, HYPER, POINT, OUT_OF_ORDER);
@@ -1402,9 +1401,6 @@ coll_chunk3(void)
  *
  *        Failure:    -1
  *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1448,7 +1444,7 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
     dims[1] = space_dim2;
 
     /* allocate memory for data buffer */
-    data_array1 = (int *)HDmalloc(dims[0] * dims[1] * sizeof(int));
+    data_array1 = (int *)malloc(dims[0] * dims[1] * sizeof(int));
     VRFY_G((data_array1 != NULL), "data_array1 malloc succeeded");
 
     /* set up dimensions of the slab this process accesses */
@@ -1456,7 +1452,7 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
 
     /* set up the coords array selection */
     num_points = block[0] * block[1] * count[0] * count[1];
-    coords     = (hsize_t *)HDmalloc(num_points * RANK * sizeof(hsize_t));
+    coords     = (hsize_t *)malloc(num_points * RANK * sizeof(hsize_t));
     VRFY_G((coords != NULL), "coords malloc succeeded");
     point_set(start, count, stride, block, num_points, coords, mode);
 
@@ -1715,16 +1711,16 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
     VRFY_G((status >= 0), "");
 
     if (data_array1)
-        HDfree(data_array1);
+        free(data_array1);
 
     /* Use collective read to verify the correctness of collective write. */
 
     /* allocate memory for data buffer */
-    data_array1 = (int *)HDmalloc(dims[0] * dims[1] * sizeof(int));
+    data_array1 = (int *)malloc(dims[0] * dims[1] * sizeof(int));
     VRFY_G((data_array1 != NULL), "data_array1 malloc succeeded");
 
     /* allocate memory for data buffer */
-    data_origin1 = (int *)HDmalloc(dims[0] * dims[1] * sizeof(int));
+    data_origin1 = (int *)malloc(dims[0] * dims[1] * sizeof(int));
     VRFY_G((data_origin1 != NULL), "data_origin1 malloc succeeded");
 
     acc_plist = create_faccess_plist(comm, info, facc_type);
@@ -1847,11 +1843,11 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
 
     /* release data buffers */
     if (coords)
-        HDfree(coords);
+        free(coords);
     if (data_array1)
-        HDfree(data_array1);
+        free(data_array1);
     if (data_origin1)
-        HDfree(data_origin1);
+        free(data_origin1);
 }
 
 int
@@ -1865,11 +1861,11 @@ main(int argc, char **argv)
 
     /* Attempt to turn off atexit post processing so that in case errors
      * happen during the test and the process is aborted, it will not get
-     * hang in the atexit post processing in which it may try to make MPI
+     * hung in the atexit post processing in which it may try to make MPI
      * calls.  By then, MPI calls may not work.
      */
     if (H5dont_atexit() < 0)
-        HDprintf("Failed to turn off atexit processing. Continue.\n");
+        printf("Failed to turn off atexit processing. Continue.\n");
 
     /* set alarm. */
     /* TestAlarmOn(); */
@@ -1879,7 +1875,7 @@ main(int argc, char **argv)
     /* Get the capability flag of the VOL connector being used */
     if (H5Pget_vol_cap_flags(acc_plist, &vol_cap_flags_g) < 0) {
         if (MAIN_PROCESS)
-            HDprintf("Failed to get the capability flag of the VOL connector being used\n");
+            printf("Failed to get the capability flag of the VOL connector being used\n");
 
         MPI_Finalize();
         return 0;
@@ -1891,7 +1887,7 @@ main(int argc, char **argv)
     if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
         !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_MORE)) {
         if (MAIN_PROCESS)
-            HDprintf(
+            printf(
                 "API functions for basic file, dataset basic or more aren't supported with this connector\n");
 
         MPI_Finalize();
@@ -1926,7 +1922,7 @@ main(int argc, char **argv)
             H5Fdelete(FILENAME[0], fapl_id);
             H5Fdelete(FILENAME[1], fapl_id);
         }
-        H5E_END_TRY;
+        H5E_END_TRY
 
         H5Pclose(fapl_id);
     }
