@@ -185,8 +185,8 @@ multiple_dset_write(void)
         return;
     }
 
-    outme = HDmalloc((size_t)size * (size_t)size * sizeof(double));
-    VRFY((outme != NULL), "HDmalloc succeeded for outme");
+    outme = malloc((size_t)size * (size_t)size * sizeof(double));
+    VRFY((outme != NULL), "malloc succeeded for outme");
 
     plist = create_faccess_plist(MPI_COMM_WORLD, MPI_INFO_NULL, facc_type);
     VRFY((plist >= 0), "create_faccess_plist succeeded");
@@ -225,7 +225,7 @@ multiple_dset_write(void)
         H5Dclose(dataset);
 #ifdef BARRIER_CHECKS
         if (!((n + 1) % 10)) {
-            HDprintf("created %d datasets\n", n + 1);
+            printf("created %d datasets\n", n + 1);
             MPI_Barrier(MPI_COMM_WORLD);
         }
 #endif /* BARRIER_CHECKS */
@@ -236,7 +236,7 @@ multiple_dset_write(void)
     H5Pclose(dcpl);
     H5Fclose(iof);
 
-    HDfree(outme);
+    free(outme);
 }
 
 /* Example of using PHDF5 to create, write, and read compact dataset.
@@ -275,11 +275,11 @@ compact_dataset(void)
         return;
     }
 
-    outme = HDmalloc((size_t)((size_t)size * (size_t)size * sizeof(double)));
-    VRFY((outme != NULL), "HDmalloc succeeded for outme");
+    outme = malloc((size_t)((size_t)size * (size_t)size * sizeof(double)));
+    VRFY((outme != NULL), "malloc succeeded for outme");
 
-    inme = HDmalloc((size_t)size * (size_t)size * sizeof(double));
-    VRFY((outme != NULL), "HDmalloc succeeded for inme");
+    inme = malloc((size_t)size * (size_t)size * sizeof(double));
+    VRFY((outme != NULL), "malloc succeeded for inme");
 
     filename = PARATESTFILE /* GetTestParameters() */;
     VRFY((mpi_size <= size), "mpi_size <= size");
@@ -366,15 +366,15 @@ compact_dataset(void)
         for (j = 0; j < size; j++)
             if (!H5_DBL_ABS_EQUAL(inme[(i * size) + j], outme[(i * size) + j]))
                 if (err_num++ < MAX_ERR_REPORT || VERBOSE_MED)
-                    HDprintf("Dataset Verify failed at [%d][%d]: expect %f, got %f\n", i, j,
-                             outme[(i * size) + j], inme[(i * size) + j]);
+                    printf("Dataset Verify failed at [%d][%d]: expect %f, got %f\n", i, j,
+                           outme[(i * size) + j], inme[(i * size) + j]);
 
     H5Pclose(plist);
     H5Pclose(dxpl);
     H5Dclose(dataset);
     H5Fclose(iof);
-    HDfree(inme);
-    HDfree(outme);
+    free(inme);
+    free(outme);
 }
 
 /*
@@ -683,10 +683,10 @@ dataset_fillvalue(void)
     dset_size    = dset_dims[0] * dset_dims[1] * dset_dims[2] * dset_dims[3];
 
     /* Allocate space for the buffers */
-    rdata = HDmalloc((size_t)(dset_size * sizeof(int)));
-    VRFY((rdata != NULL), "HDcalloc succeeded for read buffer");
-    wdata = HDmalloc((size_t)(dset_size * sizeof(int)));
-    VRFY((wdata != NULL), "HDmalloc succeeded for write buffer");
+    rdata = malloc((size_t)(dset_size * sizeof(int)));
+    VRFY((rdata != NULL), "calloc succeeded for read buffer");
+    wdata = malloc((size_t)(dset_size * sizeof(int)));
+    VRFY((wdata != NULL), "malloc succeeded for write buffer");
 
     fapl = create_faccess_plist(MPI_COMM_WORLD, MPI_INFO_NULL, facc_type);
     VRFY((fapl >= 0), "create_faccess_plist succeeded");
@@ -730,7 +730,7 @@ dataset_fillvalue(void)
         VRFY((ret >= 0), "H5Pset_dxpl_mpio succeeded");
 
         /* set entire read buffer with the constant 2 */
-        HDmemset(rdata, 2, (size_t)(dset_size * sizeof(int)));
+        memset(rdata, 2, (size_t)(dset_size * sizeof(int)));
 
         /* Read the entire dataset back */
         ret = H5Dread(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, dxpl, rdata);
@@ -755,13 +755,13 @@ dataset_fillvalue(void)
                     for (l = 0; l < (int)dset_dims[3]; l++, trdata++)
                         if (*trdata != 0)
                             if (err_num++ < MAX_ERR_REPORT || VERBOSE_MED)
-                                HDprintf(
+                                printf(
                                     "Rank %d: Dataset Verify failed at [%d][%d][%d][%d]: expect 0, got %d\n",
                                     mpi_rank, i, j, k, l, *trdata);
         if (err_num > MAX_ERR_REPORT && !VERBOSE_MED)
-            HDprintf("Rank %d: [more errors ...]\n", mpi_rank);
+            printf("Rank %d: [more errors ...]\n", mpi_rank);
         if (err_num) {
-            HDprintf("Rank %d: %d errors found in check_value\n", mpi_rank, err_num);
+            printf("Rank %d: %d errors found in check_value\n", mpi_rank, err_num);
             nerrors++;
         }
     }
@@ -820,7 +820,7 @@ dataset_fillvalue(void)
         VRFY((ret >= 0), "H5Pset_dxpl_mpio succeeded");
 
         /* set entire read buffer with the constant 2 */
-        HDmemset(rdata, 2, (size_t)(dset_size * sizeof(int)));
+        memset(rdata, 2, (size_t)(dset_size * sizeof(int)));
 
         /* Read the entire dataset back */
         ret = H5Dread(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, dxpl, rdata);
@@ -847,19 +847,19 @@ dataset_fillvalue(void)
                         if (i < mpi_size) {
                             if (*twdata != *trdata)
                                 if (err_num++ < MAX_ERR_REPORT || VERBOSE_MED)
-                                    HDprintf("Dataset Verify failed at [%d][%d][%d][%d]: expect %d, got %d\n",
-                                             i, j, k, l, *twdata, *trdata);
+                                    printf("Dataset Verify failed at [%d][%d][%d][%d]: expect %d, got %d\n",
+                                           i, j, k, l, *twdata, *trdata);
                         } /* end if */
                         else {
                             if (*trdata != 0)
                                 if (err_num++ < MAX_ERR_REPORT || VERBOSE_MED)
-                                    HDprintf("Dataset Verify failed at [%d][%d][%d][%d]: expect 0, got %d\n",
-                                             i, j, k, l, *trdata);
+                                    printf("Dataset Verify failed at [%d][%d][%d][%d]: expect 0, got %d\n", i,
+                                           j, k, l, *trdata);
                         } /* end else */
         if (err_num > MAX_ERR_REPORT && !VERBOSE_MED)
-            HDprintf("[more errors ...]\n");
+            printf("[more errors ...]\n");
         if (err_num) {
-            HDprintf("%d errors found in check_value\n", err_num);
+            printf("%d errors found in check_value\n", err_num);
             nerrors++;
         }
     }
@@ -885,8 +885,8 @@ dataset_fillvalue(void)
     VRFY((ret >= 0), "H5Pclose succeeded");
 
     /* free the buffers */
-    HDfree(rdata);
-    HDfree(wdata);
+    free(rdata);
+    free(wdata);
 }
 
 /* combined cngrpw and ingrpr tests because ingrpr reads file created by cngrpw. */
@@ -945,8 +945,8 @@ collective_group_write(void)
     chunk_size[0] = (hsize_t)(size / 2);
     chunk_size[1] = (hsize_t)(size / 2);
 
-    outme = HDmalloc((size_t)size * (size_t)size * sizeof(DATATYPE));
-    VRFY((outme != NULL), "HDmalloc succeeded for outme");
+    outme = malloc((size_t)size * (size_t)size * sizeof(DATATYPE));
+    VRFY((outme != NULL), "malloc succeeded for outme");
 
     plist = create_faccess_plist(MPI_COMM_WORLD, MPI_INFO_NULL, facc_type);
     fid   = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, plist);
@@ -998,7 +998,7 @@ collective_group_write(void)
 
 #ifdef BARRIER_CHECKS
         if (!((m + 1) % 10)) {
-            HDprintf("created %d groups\n", m + 1);
+            printf("created %d groups\n", m + 1);
             MPI_Barrier(MPI_COMM_WORLD);
         }
 #endif /* BARRIER_CHECKS */
@@ -1011,7 +1011,7 @@ collective_group_write(void)
     ret1 = H5Fclose(fid);
     VRFY((ret1 == 0), "H5Fclose");
 
-    HDfree(outme);
+    free(outme);
 }
 
 /* Let two sets of processes open and read different groups and chunked
@@ -1037,6 +1037,19 @@ independent_group_read(void)
 
     MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
 
+    /* Make sure the connector supports the API functions being tested */
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC)) {
+        if (MAINPROCESS) {
+            puts("SKIPPED");
+            printf(
+                "    API functions for basic file, group, or dataset aren't supported with this connector\n");
+            fflush(stdout);
+        }
+
+        return;
+    }
+
     plist = create_faccess_plist(MPI_COMM_WORLD, MPI_INFO_NULL, facc_type);
     H5Pset_all_coll_metadata_ops(plist, FALSE);
 
@@ -1073,11 +1086,11 @@ group_dataset_read(hid_t fid, int mpi_rank, int m)
 
     size = get_size();
 
-    indata = (DATATYPE *)HDmalloc((size_t)size * (size_t)size * sizeof(DATATYPE));
-    VRFY((indata != NULL), "HDmalloc succeeded for indata");
+    indata = (DATATYPE *)malloc((size_t)size * (size_t)size * sizeof(DATATYPE));
+    VRFY((indata != NULL), "malloc succeeded for indata");
 
-    outdata = (DATATYPE *)HDmalloc((size_t)size * (size_t)size * sizeof(DATATYPE));
-    VRFY((outdata != NULL), "HDmalloc succeeded for outdata");
+    outdata = (DATATYPE *)malloc((size_t)size * (size_t)size * sizeof(DATATYPE));
+    VRFY((outdata != NULL), "malloc succeeded for outdata");
 
     /* open every group under root group. */
     HDsnprintf(gname, sizeof(gname), "group%d", m);
@@ -1105,8 +1118,8 @@ group_dataset_read(hid_t fid, int mpi_rank, int m)
     ret = H5Gclose(gid);
     VRFY((ret == 0), "H5Gclose");
 
-    HDfree(indata);
-    HDfree(outdata);
+    free(indata);
+    free(outdata);
 }
 
 /*
@@ -1212,7 +1225,7 @@ multiple_group_write(void)
 
 #ifdef BARRIER_CHECKS
         if (!((m + 1) % 10)) {
-            HDprintf("created %d groups\n", m + 1);
+            printf("created %d groups\n", m + 1);
             MPI_Barrier(MPI_COMM_WORLD);
         }
 #endif /* BARRIER_CHECKS */
@@ -1250,8 +1263,8 @@ write_dataset(hid_t memspace, hid_t filespace, hid_t gid)
 
     size = get_size();
 
-    outme = HDmalloc((size_t)size * (size_t)size * sizeof(double));
-    VRFY((outme != NULL), "HDmalloc succeeded for outme");
+    outme = malloc((size_t)size * (size_t)size * sizeof(double));
+    VRFY((outme != NULL), "malloc succeeded for outme");
 
     for (n = 0; n < NDATASET; n++) {
         HDsnprintf(dname, sizeof(dname), "dataset%d", n);
@@ -1269,7 +1282,7 @@ write_dataset(hid_t memspace, hid_t filespace, hid_t gid)
 
         H5Dclose(did);
     }
-    HDfree(outme);
+    free(outme);
 }
 
 /*
@@ -1287,7 +1300,7 @@ create_group_recursive(hid_t memspace, hid_t filespace, hid_t gid, int counter)
 
 #ifdef BARRIER_CHECKS
     if (!((counter + 1) % 10)) {
-        HDprintf("created %dth child groups\n", counter + 1);
+        printf("created %dth child groups\n", counter + 1);
         MPI_Barrier(MPI_COMM_WORLD);
     }
 #endif /* BARRIER_CHECKS */
@@ -1413,11 +1426,11 @@ read_dataset(hid_t memspace, hid_t filespace, hid_t gid)
 
     size = get_size();
 
-    indata = (DATATYPE *)HDmalloc((size_t)size * (size_t)size * sizeof(DATATYPE));
-    VRFY((indata != NULL), "HDmalloc succeeded for indata");
+    indata = (DATATYPE *)malloc((size_t)size * (size_t)size * sizeof(DATATYPE));
+    VRFY((indata != NULL), "malloc succeeded for indata");
 
-    outdata = (DATATYPE *)HDmalloc((size_t)size * (size_t)size * sizeof(DATATYPE));
-    VRFY((outdata != NULL), "HDmalloc succeeded for outdata");
+    outdata = (DATATYPE *)malloc((size_t)size * (size_t)size * sizeof(DATATYPE));
+    VRFY((outdata != NULL), "malloc succeeded for outdata");
 
     for (n = 0; n < NDATASET; n++) {
         HDsnprintf(dname, sizeof(dname), "dataset%d", n);
@@ -1444,8 +1457,8 @@ read_dataset(hid_t memspace, hid_t filespace, hid_t gid)
         H5Dclose(did);
     }
 
-    HDfree(indata);
-    HDfree(outdata);
+    free(indata);
+    free(outdata);
 
     return vrfy_errors;
 }
@@ -1565,14 +1578,14 @@ check_value(DATATYPE *indata, DATATYPE *outdata, int size)
         for (j = chunk_origin[1]; j < (chunk_origin[1] + chunk_dims[1]); j++) {
             if (*indata != *outdata)
                 if (err_num++ < MAX_ERR_REPORT || VERBOSE_MED)
-                    HDprintf("Dataset Verify failed at [%lu][%lu](row %lu, col%lu): expect %d, got %d\n",
-                             (unsigned long)i, (unsigned long)j, (unsigned long)i, (unsigned long)j, *outdata,
-                             *indata);
+                    printf("Dataset Verify failed at [%lu][%lu](row %lu, col%lu): expect %d, got %d\n",
+                           (unsigned long)i, (unsigned long)j, (unsigned long)i, (unsigned long)j, *outdata,
+                           *indata);
         }
     if (err_num > MAX_ERR_REPORT && !VERBOSE_MED)
-        HDprintf("[more errors ...]\n");
+        printf("[more errors ...]\n");
     if (err_num)
-        HDprintf("%d errors found in check_value\n", err_num);
+        printf("%d errors found in check_value\n", err_num);
     return err_num;
 }
 
@@ -1684,7 +1697,7 @@ io_mode_confusion(void)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Setting up property list.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Setting up property list.\n", mpi_rank, fcn_name);
 
     plist_id = H5Pcreate(H5P_FILE_ACCESS);
     VRFY((plist_id != -1), "H5Pcreate() failed");
@@ -1697,7 +1710,7 @@ io_mode_confusion(void)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Creating new file.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Creating new file.\n", mpi_rank, fcn_name);
 
     file_id = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, plist_id);
     VRFY((file_id >= 0), "H5Fcreate() failed");
@@ -1710,7 +1723,7 @@ io_mode_confusion(void)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Creating the dataspace for the dataset.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Creating the dataspace for the dataset.\n", mpi_rank, fcn_name);
 
     dimsf[0]  = N;
     filespace = H5Screate_simple(rank, dimsf, NULL);
@@ -1721,7 +1734,7 @@ io_mode_confusion(void)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Creating the dataset, and closing filespace.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Creating the dataset, and closing filespace.\n", mpi_rank, fcn_name);
 
     dset_id =
         H5Dcreate2(file_id, dataset_name, H5T_NATIVE_INT, filespace, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
@@ -1731,33 +1744,33 @@ io_mode_confusion(void)
     VRFY((status >= 0), "H5Sclose() failed");
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Calling H5Screate_simple().\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Calling H5Screate_simple().\n", mpi_rank, fcn_name);
 
     memspace = H5Screate_simple(rank, dimsf, NULL);
     VRFY((memspace >= 0), "H5Screate_simple() failed.");
 
     if (mpi_rank == 0) {
         if (verbose)
-            HDfprintf(stdout, "%0d:%s: Calling H5Sselect_all(memspace).\n", mpi_rank, fcn_name);
+            fprintf(stdout, "%0d:%s: Calling H5Sselect_all(memspace).\n", mpi_rank, fcn_name);
 
         status = H5Sselect_all(memspace);
         VRFY((status >= 0), "H5Sselect_all() failed");
     }
     else {
         if (verbose)
-            HDfprintf(stdout, "%0d:%s: Calling H5Sselect_none(memspace).\n", mpi_rank, fcn_name);
+            fprintf(stdout, "%0d:%s: Calling H5Sselect_none(memspace).\n", mpi_rank, fcn_name);
 
         status = H5Sselect_none(memspace);
         VRFY((status >= 0), "H5Sselect_none() failed");
     }
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Calling MPI_Barrier().\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Calling MPI_Barrier().\n", mpi_rank, fcn_name);
 
     MPI_Barrier(MPI_COMM_WORLD);
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Calling H5Dget_space().\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Calling H5Dget_space().\n", mpi_rank, fcn_name);
 
     filespace = H5Dget_space(dset_id);
     VRFY((filespace >= 0), "H5Dget_space() failed");
@@ -1765,32 +1778,32 @@ io_mode_confusion(void)
     /* select all */
     if (mpi_rank == 0) {
         if (verbose)
-            HDfprintf(stdout, "%0d:%s: Calling H5Sselect_elements() -- set up hang?\n", mpi_rank, fcn_name);
+            fprintf(stdout, "%0d:%s: Calling H5Sselect_elements() -- set up hang?\n", mpi_rank, fcn_name);
 
         status = H5Sselect_elements(filespace, H5S_SELECT_SET, N, (const hsize_t *)&coord);
         VRFY((status >= 0), "H5Sselect_elements() failed");
     }
     else { /* select nothing */
         if (verbose)
-            HDfprintf(stdout, "%0d:%s: Calling H5Sselect_none().\n", mpi_rank, fcn_name);
+            fprintf(stdout, "%0d:%s: Calling H5Sselect_none().\n", mpi_rank, fcn_name);
 
         status = H5Sselect_none(filespace);
         VRFY((status >= 0), "H5Sselect_none() failed");
     }
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Calling MPI_Barrier().\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Calling MPI_Barrier().\n", mpi_rank, fcn_name);
 
     MPI_Barrier(MPI_COMM_WORLD);
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Calling H5Pcreate().\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Calling H5Pcreate().\n", mpi_rank, fcn_name);
 
     plist_id = H5Pcreate(H5P_DATASET_XFER);
     VRFY((plist_id != -1), "H5Pcreate() failed");
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Calling H5Pset_dxpl_mpio().\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Calling H5Pset_dxpl_mpio().\n", mpi_rank, fcn_name);
 
     status = H5Pset_dxpl_mpio(plist_id, H5FD_MPIO_COLLECTIVE);
     VRFY((status >= 0), "H5Pset_dxpl_mpio() failed");
@@ -1800,12 +1813,12 @@ io_mode_confusion(void)
     }
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Calling H5Dwrite() -- hang here?.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Calling H5Dwrite() -- hang here?.\n", mpi_rank, fcn_name);
 
     status = H5Dwrite(dset_id, H5T_NATIVE_INT, memspace, filespace, plist_id, data);
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Returned from H5Dwrite(), status=%d.\n", mpi_rank, fcn_name, status);
+        fprintf(stdout, "%0d:%s: Returned from H5Dwrite(), status=%d.\n", mpi_rank, fcn_name, status);
     VRFY((status >= 0), "H5Dwrite() failed");
 
     /*
@@ -1813,7 +1826,7 @@ io_mode_confusion(void)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Cleaning up from test.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Cleaning up from test.\n", mpi_rank, fcn_name);
 
     status = H5Dclose(dset_id);
     VRFY((status >= 0), "H5Dclose() failed");
@@ -1831,7 +1844,7 @@ io_mode_confusion(void)
     VRFY((status >= 0), "H5Fclose() failed");
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
 
     return;
 
@@ -1942,7 +1955,7 @@ rr_obj_hdr_flush_confusion(void)
         return;
     }
 
-    HDassert(mpi_size > 2);
+    assert(mpi_size > 2);
 
     is_reader = mpi_rank % 2;
     mrc       = MPI_Comm_split(MPI_COMM_WORLD, is_reader, mpi_rank, &comm);
@@ -1962,7 +1975,7 @@ rr_obj_hdr_flush_confusion(void)
 
     MPI_Comm_free(&comm);
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
 
     return;
 
@@ -2035,7 +2048,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Setting up property list.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Setting up property list.\n", mpi_rank, fcn_name);
 
     fapl_id = H5Pcreate(H5P_FILE_ACCESS);
     VRFY((fapl_id != -1), "H5Pcreate(H5P_FILE_ACCESS) failed");
@@ -2048,7 +2061,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Creating new file \"%s\".\n", mpi_rank, fcn_name, filename);
+        fprintf(stdout, "%0d:%s: Creating new file \"%s\".\n", mpi_rank, fcn_name, filename);
 
     file_id = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
     VRFY((file_id >= 0), "H5Fcreate() failed");
@@ -2061,7 +2074,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Creating the datasets.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Creating the datasets.\n", mpi_rank, fcn_name);
 
     disk_size[0] = (hsize_t)(LOCAL_DATA_SIZE * mpi_size);
     mem_size[0]  = (hsize_t)(LOCAL_DATA_SIZE);
@@ -2082,7 +2095,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Setting up dxpl.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Setting up dxpl.\n", mpi_rank, fcn_name);
 
     dxpl_id = H5Pcreate(H5P_DATASET_XFER);
     VRFY((dxpl_id != -1), "H5Pcreate(H5P_DATASET_XFER) failed.\n");
@@ -2095,7 +2108,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Writing datasets.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Writing datasets.\n", mpi_rank, fcn_name);
 
     disk_count[0] = (hsize_t)(LOCAL_DATA_SIZE);
     disk_start[0] = (hsize_t)(LOCAL_DATA_SIZE * mpi_rank);
@@ -2124,7 +2137,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: closing dataspaces.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: closing dataspaces.\n", mpi_rank, fcn_name);
 
     for (i = 0; i < NUM_DATA_SETS; i++) {
         err = H5Sclose(disk_space[i]);
@@ -2140,7 +2153,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
     err = H5Fflush(file_id, H5F_SCOPE_GLOBAL);
     VRFY((err >= 0), "H5Fflush(1) failed.\n");
 
@@ -2154,7 +2167,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: writing attributes.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: writing attributes.\n", mpi_rank, fcn_name);
 
     att_size[0] = (hsize_t)(LOCAL_DATA_SIZE);
     for (j = 0; j < LOCAL_DATA_SIZE; j++) {
@@ -2179,7 +2192,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: closing attr ids and spaces .\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: closing attr ids and spaces .\n", mpi_rank, fcn_name);
 
     for (i = 0; i < NUM_DATA_SETS; i++) {
         err = H5Sclose(att_space[i]);
@@ -2195,7 +2208,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
     err = H5Fflush(file_id, H5F_SCOPE_GLOBAL);
     VRFY((err >= 0), "H5Fflush(2) failed.\n");
 
@@ -2209,7 +2222,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: writing large attributes.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: writing large attributes.\n", mpi_rank, fcn_name);
 
     lg_att_size[0] = (hsize_t)(LARGE_ATTR_SIZE);
 
@@ -2243,7 +2256,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
     err = H5Fflush(file_id, H5F_SCOPE_GLOBAL);
     VRFY((err >= 0), "H5Fflush(3) failed.\n");
 
@@ -2257,7 +2270,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: writing different large attributes.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: writing different large attributes.\n", mpi_rank, fcn_name);
 
     for (j = 0; j < LARGE_ATTR_SIZE; j++) {
         lg_att[j] = (double)(j + 2);
@@ -2277,7 +2290,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      * flush the metadata cache again
      */
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: flushing metadata cache.\n", mpi_rank, fcn_name);
     err = H5Fflush(file_id, H5F_SCOPE_GLOBAL);
     VRFY((err >= 0), "H5Fflush(3) failed.\n");
 
@@ -2293,7 +2306,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: closing large attr ids and spaces .\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: closing large attr ids and spaces .\n", mpi_rank, fcn_name);
 
     for (i = 0; i < NUM_DATA_SETS; i++) {
 
@@ -2308,7 +2321,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: closing datasets .\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: closing datasets .\n", mpi_rank, fcn_name);
 
     for (i = 0; i < NUM_DATA_SETS; i++) {
         err = H5Dclose(dataset[i]);
@@ -2320,7 +2333,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: closing dxpl .\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: closing dxpl .\n", mpi_rank, fcn_name);
 
     err = H5Pclose(dxpl_id);
     VRFY((err >= 0), "H5Pclose(dxpl_id) failed.\n");
@@ -2330,7 +2343,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
      */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: closing file.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: closing file.\n", mpi_rank, fcn_name);
 
     err = H5Fclose(file_id);
     VRFY((err >= 0), "H5Fclose(1) failed");
@@ -2347,7 +2360,7 @@ rr_obj_hdr_flush_confusion_writer(MPI_Comm comm)
     VRFY((MPI_SUCCESS == mrc), "Reader_check failed");
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
 
     return;
 
@@ -2426,7 +2439,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
              */
 
             if (verbose)
-                HDfprintf(stdout, "%0d:%s: Setting up property list.\n", mpi_rank, fcn_name);
+                fprintf(stdout, "%0d:%s: Setting up property list.\n", mpi_rank, fcn_name);
 
             fapl_id = H5Pcreate(H5P_FILE_ACCESS);
             VRFY((fapl_id != -1), "H5Pcreate(H5P_FILE_ACCESS) failed");
@@ -2438,7 +2451,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
              */
 
             if (verbose)
-                HDfprintf(stdout, "%0d:%s: Re-open file \"%s\".\n", mpi_rank, fcn_name, filename);
+                fprintf(stdout, "%0d:%s: Re-open file \"%s\".\n", mpi_rank, fcn_name, filename);
 
             file_id = H5Fopen(filename, H5F_ACC_RDONLY, fapl_id);
             VRFY((file_id >= 0), "H5Fopen() failed");
@@ -2452,7 +2465,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                  *=====================================================*/
 
                 if (verbose)
-                    HDfprintf(stdout, "%0d:%s: opening the datasets.\n", mpi_rank, fcn_name);
+                    fprintf(stdout, "%0d:%s: opening the datasets.\n", mpi_rank, fcn_name);
 
                 for (i = 0; i < NUM_DATA_SETS; i++) {
                     dataset[i] = -1;
@@ -2470,7 +2483,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                  */
 
                 if (verbose)
-                    HDfprintf(stdout, "%0d:%s: Setting up dxpl.\n", mpi_rank, fcn_name);
+                    fprintf(stdout, "%0d:%s: Setting up dxpl.\n", mpi_rank, fcn_name);
 
                 dxpl_id = H5Pcreate(H5P_DATASET_XFER);
                 VRFY((dxpl_id != -1), "H5Pcreate(H5P_DATASET_XFER) failed.\n");
@@ -2482,7 +2495,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                  */
 
                 if (verbose)
-                    HDfprintf(stdout, "%0d:%s: Reading datasets.\n", mpi_rank, fcn_name);
+                    fprintf(stdout, "%0d:%s: Reading datasets.\n", mpi_rank, fcn_name);
 
                 disk_count[0] = (hsize_t)(LOCAL_DATA_SIZE);
                 disk_start[0] = (hsize_t)(LOCAL_DATA_SIZE * mpi_rank);
@@ -2512,10 +2525,10 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                     /* compare read data with expected data */
                     for (j = 0; j < LOCAL_DATA_SIZE; j++)
                         if (!H5_DBL_ABS_EQUAL(data_read[j], data[j])) {
-                            HDfprintf(stdout,
-                                      "%0d:%s: Reading datasets value failed in "
-                                      "Dataset %d, at position %d: expect %f, got %f.\n",
-                                      mpi_rank, fcn_name, i, j, data[j], data_read[j]);
+                            fprintf(stdout,
+                                    "%0d:%s: Reading datasets value failed in "
+                                    "Dataset %d, at position %d: expect %f, got %f.\n",
+                                    mpi_rank, fcn_name, i, j, data[j], data_read[j]);
                             nerrors++;
                         }
                     for (j = 0; j < LOCAL_DATA_SIZE; j++)
@@ -2527,7 +2540,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                  */
 
                 if (verbose)
-                    HDfprintf(stdout, "%0d:%s: closing dataspaces.\n", mpi_rank, fcn_name);
+                    fprintf(stdout, "%0d:%s: closing dataspaces.\n", mpi_rank, fcn_name);
 
                 for (i = 0; i < NUM_DATA_SETS; i++) {
                     err = H5Sclose(disk_space[i]);
@@ -2547,7 +2560,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
 
             if (steps >= 2) {
                 if (verbose)
-                    HDfprintf(stdout, "%0d:%s: reading attributes.\n", mpi_rank, fcn_name);
+                    fprintf(stdout, "%0d:%s: reading attributes.\n", mpi_rank, fcn_name);
 
                 for (j = 0; j < LOCAL_DATA_SIZE; j++) {
                     att[j] = (double)(j + 1);
@@ -2563,8 +2576,8 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                     tri_err = H5Tequal(att_type, H5T_NATIVE_DOUBLE);
                     VRFY((tri_err >= 0), "H5Tequal failed.\n");
                     if (tri_err == 0) {
-                        HDfprintf(stdout, "%0d:%s: Mismatched Attribute type of Dataset %d.\n", mpi_rank,
-                                  fcn_name, i);
+                        fprintf(stdout, "%0d:%s: Mismatched Attribute type of Dataset %d.\n", mpi_rank,
+                                fcn_name, i);
                         nerrors++;
                     }
                     else {
@@ -2574,10 +2587,10 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                         /* compare read attribute data with expected data */
                         for (j = 0; j < LOCAL_DATA_SIZE; j++)
                             if (!H5_DBL_ABS_EQUAL(att_read[j], att[j])) {
-                                HDfprintf(stdout,
-                                          "%0d:%s: Mismatched attribute data read in Dataset %d, at position "
-                                          "%d: expect %f, got %f.\n",
-                                          mpi_rank, fcn_name, i, j, att[j], att_read[j]);
+                                fprintf(stdout,
+                                        "%0d:%s: Mismatched attribute data read in Dataset %d, at position "
+                                        "%d: expect %f, got %f.\n",
+                                        mpi_rank, fcn_name, i, j, att[j], att_read[j]);
                                 nerrors++;
                             }
                         for (j = 0; j < LOCAL_DATA_SIZE; j++) {
@@ -2600,7 +2613,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
 
             if (steps >= 3) {
                 if (verbose)
-                    HDfprintf(stdout, "%0d:%s: reading large attributes.\n", mpi_rank, fcn_name);
+                    fprintf(stdout, "%0d:%s: reading large attributes.\n", mpi_rank, fcn_name);
 
                 for (j = 0; j < LARGE_ATTR_SIZE; j++) {
                     lg_att[j] = (steps == 3) ? (double)(j + 1) : (double)(j + 2);
@@ -2614,8 +2627,8 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                     tri_err = H5Tequal(lg_att_type[i], H5T_NATIVE_DOUBLE);
                     VRFY((tri_err >= 0), "H5Tequal failed.\n");
                     if (tri_err == 0) {
-                        HDfprintf(stdout, "%0d:%s: Mismatched Large attribute type of Dataset %d.\n",
-                                  mpi_rank, fcn_name, i);
+                        fprintf(stdout, "%0d:%s: Mismatched Large attribute type of Dataset %d.\n", mpi_rank,
+                                fcn_name, i);
                         nerrors++;
                     }
                     else {
@@ -2625,10 +2638,10 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
                         /* compare read attribute data with expected data */
                         for (j = 0; j < LARGE_ATTR_SIZE; j++)
                             if (!H5_DBL_ABS_EQUAL(lg_att_read[j], lg_att[j])) {
-                                HDfprintf(stdout,
-                                          "%0d:%s: Mismatched large attribute data read in Dataset %d, at "
-                                          "position %d: expect %f, got %f.\n",
-                                          mpi_rank, fcn_name, i, j, lg_att[j], lg_att_read[j]);
+                                fprintf(stdout,
+                                        "%0d:%s: Mismatched large attribute data read in Dataset %d, at "
+                                        "position %d: expect %f, got %f.\n",
+                                        mpi_rank, fcn_name, i, j, lg_att[j], lg_att_read[j]);
                                 nerrors++;
                             }
                         for (j = 0; j < LARGE_ATTR_SIZE; j++) {
@@ -2662,7 +2675,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
              */
 
             if (verbose)
-                HDfprintf(stdout, "%0d:%s: closing datasets again.\n", mpi_rank, fcn_name);
+                fprintf(stdout, "%0d:%s: closing datasets again.\n", mpi_rank, fcn_name);
 
             for (i = 0; i < NUM_DATA_SETS; i++) {
                 if (dataset[i] >= 0) {
@@ -2676,7 +2689,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
              */
 
             if (verbose)
-                HDfprintf(stdout, "%0d:%s: closing dxpl .\n", mpi_rank, fcn_name);
+                fprintf(stdout, "%0d:%s: closing dxpl .\n", mpi_rank, fcn_name);
 
             err = H5Pclose(dxpl_id);
             VRFY((err >= 0), "H5Pclose(dxpl_id) failed.\n");
@@ -2685,7 +2698,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
              * Close the file
              */
             if (verbose)
-                HDfprintf(stdout, "%0d:%s: closing file again.\n", mpi_rank, fcn_name);
+                fprintf(stdout, "%0d:%s: closing file again.\n", mpi_rank, fcn_name);
             err = H5Fclose(file_id);
             VRFY((err >= 0), "H5Fclose(1) failed");
 
@@ -2694,7 +2707,7 @@ rr_obj_hdr_flush_confusion_reader(MPI_Comm comm)
     } /* end while(1) */
 
     if (verbose)
-        HDfprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
+        fprintf(stdout, "%0d:%s: Done.\n", mpi_rank, fcn_name);
 
     return;
 } /* rr_obj_hdr_flush_confusion_reader() */
@@ -2768,7 +2781,7 @@ chunk_align_bug_1(void)
 #endif
 
     /* Set aggregator size and alignment, disable metadata aggregator */
-    HDassert(AGGR_SIZE > CHUNK_SIZE);
+    assert(AGGR_SIZE > CHUNK_SIZE);
     ret = H5Pset_small_data_block_size(fapl_id, AGGR_SIZE);
     VRFY((ret >= 0), "H5Pset_small_data_block_size succeeded");
     ret = H5Pset_meta_block_size(fapl_id, 0);
