@@ -130,16 +130,16 @@ point_set(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[], s
                     }
 
     if (VERBOSE_MED) {
-        HDprintf("start[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "count[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "stride[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "block[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "total datapoints=%" PRIuHSIZE "\n",
-                 start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1],
-                 block[0] * block[1] * count[0] * count[1]);
+        printf("start[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "count[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "stride[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "block[]=(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "total datapoints=%" PRIuHSIZE "\n",
+               start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1],
+               block[0] * block[1] * count[0] * count[1]);
         k = 0;
         for (i = 0; i < num_points; i++) {
-            HDprintf("(%d, %d)\n", (int)coords[k], (int)coords[k + 1]);
+            printf("(%d, %d)\n", (int)coords[k], (int)coords[k + 1]);
             k += 2;
         }
     }
@@ -155,19 +155,19 @@ dataset_print(hsize_t start[], hsize_t block[], B_DATATYPE *dataset)
     hsize_t     i, j;
 
     /* print the column heading */
-    HDprintf("%-8s", "Cols:");
+    printf("%-8s", "Cols:");
     for (j = 0; j < block[1]; j++) {
-        HDprintf("%3" PRIuHSIZE " ", start[1] + j);
+        printf("%3" PRIuHSIZE " ", start[1] + j);
     }
-    HDprintf("\n");
+    printf("\n");
 
     /* print the slab data */
     for (i = 0; i < block[0]; i++) {
-        HDprintf("Row %2" PRIuHSIZE ": ", i + start[0]);
+        printf("Row %2" PRIuHSIZE ": ", i + start[0]);
         for (j = 0; j < block[1]; j++) {
-            HDprintf("%" PRIuHSIZE " ", *dataptr++);
+            printf("%" PRIuHSIZE " ", *dataptr++);
         }
-        HDprintf("\n");
+        printf("\n");
     }
 }
 
@@ -183,15 +183,15 @@ verify_data(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[],
 
     /* print it if VERBOSE_MED */
     if (VERBOSE_MED) {
-        HDprintf("verify_data dumping:::\n");
-        HDprintf("start(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "count(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "stride(%" PRIuHSIZE ", %" PRIuHSIZE "), "
-                 "block(%" PRIuHSIZE ", %" PRIuHSIZE ")\n",
-                 start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1]);
-        HDprintf("original values:\n");
+        printf("verify_data dumping:::\n");
+        printf("start(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "count(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "stride(%" PRIuHSIZE ", %" PRIuHSIZE "), "
+               "block(%" PRIuHSIZE ", %" PRIuHSIZE ")\n",
+               start[0], start[1], count[0], count[1], stride[0], stride[1], block[0], block[1]);
+        printf("original values:\n");
         dataset_print(start, block, original);
-        HDprintf("compared values:\n");
+        printf("compared values:\n");
         dataset_print(start, block, dataset);
     }
 
@@ -200,10 +200,10 @@ verify_data(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[],
         for (j = 0; j < block[1]; j++) {
             if (*dataset != *original) {
                 if (vrfyerrs++ < MAX_ERR_REPORT || VERBOSE_MED) {
-                    HDprintf("Dataset Verify failed at [%" PRIuHSIZE "][%" PRIuHSIZE "]"
-                             "(row %" PRIuHSIZE ", col %" PRIuHSIZE "): "
-                             "expect %" PRIuHSIZE ", got %" PRIuHSIZE "\n",
-                             i, j, i + start[0], j + start[1], *(original), *(dataset));
+                    printf("Dataset Verify failed at [%" PRIuHSIZE "][%" PRIuHSIZE "]"
+                           "(row %" PRIuHSIZE ", col %" PRIuHSIZE "): "
+                           "expect %" PRIuHSIZE ", got %" PRIuHSIZE "\n",
+                           i, j, i + start[0], j + start[1], *(original), *(dataset));
                 }
                 dataset++;
                 original++;
@@ -211,9 +211,9 @@ verify_data(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block[],
         }
     }
     if (vrfyerrs > MAX_ERR_REPORT && !VERBOSE_MED)
-        HDprintf("[more errors ...]\n");
+        printf("[more errors ...]\n");
     if (vrfyerrs)
-        HDprintf("%d errors found in verify_data\n", vrfyerrs);
+        printf("%d errors found in verify_data\n", vrfyerrs);
     return (vrfyerrs);
 }
 
@@ -311,12 +311,12 @@ ccslab_set(int mpi_rank, int mpi_size, hsize_t start[], hsize_t count[], hsize_t
             break;
     }
     if (VERBOSE_MED) {
-        HDprintf("start[]=(%lu,%lu), count[]=(%lu,%lu), stride[]=(%lu,%lu), block[]=(%lu,%lu), total "
-                 "datapoints=%lu\n",
-                 (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
-                 (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
-                 (unsigned long)block[0], (unsigned long)block[1],
-                 (unsigned long)(block[0] * block[1] * count[0] * count[1]));
+        printf("start[]=(%lu,%lu), count[]=(%lu,%lu), stride[]=(%lu,%lu), block[]=(%lu,%lu), total "
+               "datapoints=%lu\n",
+               (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
+               (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
+               (unsigned long)block[0], (unsigned long)block[1],
+               (unsigned long)(block[0] * block[1] * count[0] * count[1]));
     }
 }
 
@@ -369,20 +369,20 @@ ccdataset_print(hsize_t start[], hsize_t block[], DATATYPE *dataset)
     hsize_t   i, j;
 
     /* print the column heading */
-    HDprintf("Print only the first block of the dataset\n");
-    HDprintf("%-8s", "Cols:");
+    printf("Print only the first block of the dataset\n");
+    printf("%-8s", "Cols:");
     for (j = 0; j < block[1]; j++) {
-        HDprintf("%3lu ", (unsigned long)(start[1] + j));
+        printf("%3lu ", (unsigned long)(start[1] + j));
     }
-    HDprintf("\n");
+    printf("\n");
 
     /* print the slab data */
     for (i = 0; i < block[0]; i++) {
-        HDprintf("Row %2lu: ", (unsigned long)(i + start[0]));
+        printf("Row %2lu: ", (unsigned long)(i + start[0]));
         for (j = 0; j < block[1]; j++) {
-            HDprintf("%03d ", *dataptr++);
+            printf("%03d ", *dataptr++);
         }
-        HDprintf("\n");
+        printf("\n");
     }
 }
 
@@ -399,14 +399,14 @@ ccdataset_vrfy(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block
 
     /* print it if VERBOSE_MED */
     if (VERBOSE_MED) {
-        HDprintf("dataset_vrfy dumping:::\n");
-        HDprintf("start(%lu, %lu), count(%lu, %lu), stride(%lu, %lu), block(%lu, %lu)\n",
-                 (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
-                 (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
-                 (unsigned long)block[0], (unsigned long)block[1]);
-        HDprintf("original values:\n");
+        printf("dataset_vrfy dumping:::\n");
+        printf("start(%lu, %lu), count(%lu, %lu), stride(%lu, %lu), block(%lu, %lu)\n",
+               (unsigned long)start[0], (unsigned long)start[1], (unsigned long)count[0],
+               (unsigned long)count[1], (unsigned long)stride[0], (unsigned long)stride[1],
+               (unsigned long)block[0], (unsigned long)block[1]);
+        printf("original values:\n");
         ccdataset_print(start, block, original);
-        HDprintf("compared values:\n");
+        printf("compared values:\n");
         ccdataset_print(start, block, dataset);
     }
 
@@ -429,8 +429,8 @@ ccdataset_vrfy(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block
                     }
                     if (*dataptr != *oriptr) {
                         if (vrfyerrs++ < MAX_ERR_REPORT || VERBOSE_MED) {
-                            HDprintf("Dataset Verify failed at [%lu][%lu]: expect %d, got %d\n",
-                                     (unsigned long)i, (unsigned long)j, *(oriptr), *(dataptr));
+                            printf("Dataset Verify failed at [%lu][%lu]: expect %d, got %d\n",
+                                   (unsigned long)i, (unsigned long)j, *(oriptr), *(dataptr));
                         }
                     }
                 }
@@ -438,9 +438,9 @@ ccdataset_vrfy(hsize_t start[], hsize_t count[], hsize_t stride[], hsize_t block
         }
     }
     if (vrfyerrs > MAX_ERR_REPORT && !VERBOSE_MED)
-        HDprintf("[more errors ...]\n");
+        printf("[more errors ...]\n");
     if (vrfyerrs)
-        HDprintf("%d errors found in ccdataset_vrfy\n", vrfyerrs);
+        printf("%d errors found in ccdataset_vrfy\n", vrfyerrs);
     return (vrfyerrs);
 }
 
@@ -474,7 +474,7 @@ dataset_big_write(void)
     B_DATATYPE *wdata;
 
     /* allocate memory for data buffer */
-    wdata = (B_DATATYPE *)HDmalloc(bigcount * sizeof(B_DATATYPE));
+    wdata = (B_DATATYPE *)malloc(bigcount * sizeof(B_DATATYPE));
     VRFY_G((wdata != NULL), "wdata malloc succeeded");
 
     /* setup file access template */
@@ -492,7 +492,7 @@ dataset_big_write(void)
 
     /* Each process takes a slabs of rows. */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset1 write by ROW\n");
+        printf("\nTesting Dataset1 write by ROW\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = (hsize_t)mpi_size_g;
@@ -553,7 +553,7 @@ dataset_big_write(void)
 
     /* Each process takes a slabs of cols. */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset2 write by COL\n");
+        printf("\nTesting Dataset2 write by COL\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = (hsize_t)mpi_size_g;
@@ -614,7 +614,7 @@ dataset_big_write(void)
 
     /* ALL selection */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset3 write select ALL proc 0, NONE others\n");
+        printf("\nTesting Dataset3 write select ALL proc 0, NONE others\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = 1;
@@ -675,7 +675,7 @@ dataset_big_write(void)
 
     /* Point selection */
     if (mpi_rank_g == 0)
-        HDprintf("\nTesting Dataset4 write point selection\n");
+        printf("\nTesting Dataset4 write point selection\n");
     /* Create a large dataset */
     dims[0] = bigcount;
     dims[1] = (hsize_t)(mpi_size_g * 4);
@@ -697,7 +697,7 @@ dataset_big_write(void)
 
     num_points = bigcount;
 
-    coords = (hsize_t *)HDmalloc(num_points * RANK * sizeof(hsize_t));
+    coords = (hsize_t *)malloc(num_points * RANK * sizeof(hsize_t));
     VRFY_G((coords != NULL), "coords malloc succeeded");
 
     set_coords(start, count, stride, block, num_points, coords, IN_ORDER);
@@ -746,7 +746,7 @@ dataset_big_write(void)
     ret = H5Dclose(dataset);
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
-    HDfree(wdata);
+    free(wdata);
     H5Fclose(fid);
 }
 
@@ -779,12 +779,12 @@ dataset_big_read(void)
     herr_t      ret; /* Generic return value */
 
     /* allocate memory for data buffer */
-    rdata = (B_DATATYPE *)HDmalloc(bigcount * sizeof(B_DATATYPE));
+    rdata = (B_DATATYPE *)malloc(bigcount * sizeof(B_DATATYPE));
     VRFY_G((rdata != NULL), "rdata malloc succeeded");
-    wdata = (B_DATATYPE *)HDmalloc(bigcount * sizeof(B_DATATYPE));
+    wdata = (B_DATATYPE *)malloc(bigcount * sizeof(B_DATATYPE));
     VRFY_G((wdata != NULL), "wdata malloc succeeded");
 
-    HDmemset(rdata, 0, bigcount * sizeof(B_DATATYPE));
+    memset(rdata, 0, bigcount * sizeof(B_DATATYPE));
 
     /* setup file access template */
     acc_tpl = H5Pcreate(H5P_FILE_ACCESS);
@@ -800,7 +800,7 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset1 by COL\n");
+        printf("\nRead Testing Dataset1 by COL\n");
 
     dataset = H5Dopen2(fid, DATASET1, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
@@ -851,7 +851,7 @@ dataset_big_read(void)
     /* verify the read data with original expected data */
     ret = verify_data(start, count, stride, block, rdata, wdata);
     if (ret) {
-        HDfprintf(stderr, "verify failed\n");
+        fprintf(stderr, "verify failed\n");
         exit(1);
     }
 
@@ -863,8 +863,8 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset2 by ROW\n");
-    HDmemset(rdata, 0, bigcount * sizeof(B_DATATYPE));
+        printf("\nRead Testing Dataset2 by ROW\n");
+    memset(rdata, 0, bigcount * sizeof(B_DATATYPE));
     dataset = H5Dopen2(fid, DATASET2, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
 
@@ -914,7 +914,7 @@ dataset_big_read(void)
     /* verify the read data with original expected data */
     ret = verify_data(start, count, stride, block, rdata, wdata);
     if (ret) {
-        HDfprintf(stderr, "verify failed\n");
+        fprintf(stderr, "verify failed\n");
         exit(1);
     }
 
@@ -926,8 +926,8 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset3 read select ALL proc 0, NONE others\n");
-    HDmemset(rdata, 0, bigcount * sizeof(B_DATATYPE));
+        printf("\nRead Testing Dataset3 read select ALL proc 0, NONE others\n");
+    memset(rdata, 0, bigcount * sizeof(B_DATATYPE));
     dataset = H5Dopen2(fid, DATASET3, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
 
@@ -979,7 +979,7 @@ dataset_big_read(void)
         /* verify the read data with original expected data */
         ret = verify_data(start, count, stride, block, rdata, wdata);
         if (ret) {
-            HDfprintf(stderr, "verify failed\n");
+            fprintf(stderr, "verify failed\n");
             exit(1);
         }
     }
@@ -992,7 +992,7 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
     if (mpi_rank_g == 0)
-        HDprintf("\nRead Testing Dataset4 with Point selection\n");
+        printf("\nRead Testing Dataset4 with Point selection\n");
     dataset = H5Dopen2(fid, DATASET4, H5P_DEFAULT);
     VRFY_G((dataset >= 0), "H5Dopen2 succeeded");
 
@@ -1017,7 +1017,7 @@ dataset_big_read(void)
 
     num_points = bigcount;
 
-    coords = (hsize_t *)HDmalloc(num_points * RANK * sizeof(hsize_t));
+    coords = (hsize_t *)malloc(num_points * RANK * sizeof(hsize_t));
     VRFY_G((coords != NULL), "coords malloc succeeded");
 
     set_coords(start, count, stride, block, num_points, coords, IN_ORDER);
@@ -1028,7 +1028,7 @@ dataset_big_read(void)
     VRFY_G((ret >= 0), "H5Sselect_elements succeeded");
 
     if (coords)
-        HDfree(coords);
+        free(coords);
 
     /* create a memory dataspace */
     /* Warning: H5Screate_simple requires an array of hsize_t elements
@@ -1054,7 +1054,7 @@ dataset_big_read(void)
 
     ret = verify_data(start, count, stride, block, rdata, wdata);
     if (ret) {
-        HDfprintf(stderr, "verify failed\n");
+        fprintf(stderr, "verify failed\n");
         exit(1);
     }
 
@@ -1065,8 +1065,8 @@ dataset_big_read(void)
     ret = H5Dclose(dataset);
     VRFY_G((ret >= 0), "H5Dclose1 succeeded");
 
-    HDfree(wdata);
-    HDfree(rdata);
+    free(wdata);
+    free(rdata);
 
     wdata = NULL;
     rdata = NULL;
@@ -1093,9 +1093,9 @@ dataset_big_read(void)
 
     /* release data buffers */
     if (rdata)
-        HDfree(rdata);
+        free(rdata);
     if (wdata)
-        HDfree(wdata);
+        free(wdata);
 
 } /* dataset_large_readAll */
 
@@ -1103,7 +1103,7 @@ static void
 single_rank_independent_io(void)
 {
     if (mpi_rank_g == 0)
-        HDprintf("\nSingle Rank Independent I/O\n");
+        printf("\nSingle Rank Independent I/O\n");
 
     if (MAIN_PROCESS) {
         hsize_t  dims[1];
@@ -1150,7 +1150,7 @@ single_rank_independent_io(void)
         VRFY_G((ret >= 0), "H5Dwrite succeeded");
 
         /* Wipe buffer */
-        HDmemset(data, 0, dims[0] * sizeof(int));
+        memset(data, 0, dims[0] * sizeof(int));
 
         /* Read data back */
         ret = H5Dread(dset_id, H5T_NATIVE_INT, H5S_BLOCK, fspace_id, H5P_DEFAULT, data);
@@ -1159,7 +1159,7 @@ single_rank_independent_io(void)
         /* Verify data */
         for (i = 0; i < dims[0]; i++)
             if (data[i] != (int)(i % (uint64_t)DXFER_BIGCOUNT)) {
-                HDfprintf(stderr, "verify failed\n");
+                fprintf(stderr, "verify failed\n");
                 exit(1);
             }
 
@@ -1168,11 +1168,7 @@ single_rank_independent_io(void)
         H5Dclose(dset_id);
         H5Fclose(file_id);
 
-        H5E_BEGIN_TRY
-        {
-            H5Fdelete(FILENAME[1], fapl_id);
-        }
-        H5E_END_TRY;
+        H5Fdelete(FILENAME[1], fapl_id);
 
         H5Pclose(fapl_id);
     }
@@ -1242,9 +1238,6 @@ create_faccess_plist(MPI_Comm comm, MPI_Info info, int l_facc_type)
  *
  *        Failure:    -1
  *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1270,7 +1263,7 @@ coll_chunk1(void)
 {
     const char *filename = FILENAME[0];
     if (mpi_rank_g == 0)
-        HDprintf("\nCollective chunk I/O Test #1\n");
+        printf("\nCollective chunk I/O Test #1\n");
 
     coll_chunktest(filename, 1, BYROW_CONT, API_NONE, HYPER, HYPER, OUT_OF_ORDER);
     coll_chunktest(filename, 1, BYROW_CONT, API_NONE, HYPER, POINT, OUT_OF_ORDER);
@@ -1293,9 +1286,6 @@ coll_chunk1(void)
  *
  *        Failure:    -1
  *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1321,7 +1311,7 @@ coll_chunk2(void)
 {
     const char *filename = FILENAME[0];
     if (mpi_rank_g == 0)
-        HDprintf("\nCollective chunk I/O Test #2\n");
+        printf("\nCollective chunk I/O Test #2\n");
 
     coll_chunktest(filename, 1, BYROW_DISCONT, API_NONE, HYPER, HYPER, OUT_OF_ORDER);
     coll_chunktest(filename, 1, BYROW_DISCONT, API_NONE, HYPER, POINT, OUT_OF_ORDER);
@@ -1344,9 +1334,6 @@ coll_chunk2(void)
  *
  *        Failure:    -1
  *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1373,7 +1360,7 @@ coll_chunk3(void)
 {
     const char *filename = FILENAME[0];
     if (mpi_rank_g == 0)
-        HDprintf("\nCollective chunk I/O Test #3\n");
+        printf("\nCollective chunk I/O Test #3\n");
 
     coll_chunktest(filename, mpi_size_g, BYROW_CONT, API_NONE, HYPER, HYPER, OUT_OF_ORDER);
     coll_chunktest(filename, mpi_size_g, BYROW_CONT, API_NONE, HYPER, POINT, OUT_OF_ORDER);
@@ -1401,9 +1388,6 @@ coll_chunk3(void)
  *
  *        Failure:    -1
  *
- * Programmer:    Unknown
- *        July 12th, 2004
- *
  *-------------------------------------------------------------------------
  */
 
@@ -1447,7 +1431,7 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
     dims[1] = space_dim2;
 
     /* allocate memory for data buffer */
-    data_array1 = (int *)HDmalloc(dims[0] * dims[1] * sizeof(int));
+    data_array1 = (int *)malloc(dims[0] * dims[1] * sizeof(int));
     VRFY_G((data_array1 != NULL), "data_array1 malloc succeeded");
 
     /* set up dimensions of the slab this process accesses */
@@ -1455,7 +1439,7 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
 
     /* set up the coords array selection */
     num_points = block[0] * block[1] * count[0] * count[1];
-    coords     = (hsize_t *)HDmalloc(num_points * RANK * sizeof(hsize_t));
+    coords     = (hsize_t *)malloc(num_points * RANK * sizeof(hsize_t));
     VRFY_G((coords != NULL), "coords malloc succeeded");
     point_set(start, count, stride, block, num_points, coords, mode);
 
@@ -1521,6 +1505,9 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
             status = H5Sselect_all(file_dataspace);
             VRFY_G((status >= 0), "H5Sselect_all succeeded");
             break;
+
+        default:
+            break;
     }
 
     switch (mem_selection) {
@@ -1544,6 +1531,9 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
             status = H5Sselect_all(mem_dataspace);
             VRFY_G((status >= 0), "H5Sselect_all succeeded");
             break;
+
+        default:
+            break;
     }
 
     /* set up the collective transfer property list */
@@ -1714,16 +1704,16 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
     VRFY_G((status >= 0), "");
 
     if (data_array1)
-        HDfree(data_array1);
+        free(data_array1);
 
     /* Use collective read to verify the correctness of collective write. */
 
     /* allocate memory for data buffer */
-    data_array1 = (int *)HDmalloc(dims[0] * dims[1] * sizeof(int));
+    data_array1 = (int *)malloc(dims[0] * dims[1] * sizeof(int));
     VRFY_G((data_array1 != NULL), "data_array1 malloc succeeded");
 
     /* allocate memory for data buffer */
-    data_origin1 = (int *)HDmalloc(dims[0] * dims[1] * sizeof(int));
+    data_origin1 = (int *)malloc(dims[0] * dims[1] * sizeof(int));
     VRFY_G((data_origin1 != NULL), "data_origin1 malloc succeeded");
 
     acc_plist = create_faccess_plist(comm, info, facc_type);
@@ -1781,6 +1771,9 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
             status = H5Sselect_all(file_dataspace);
             VRFY_G((status >= 0), "H5Sselect_all succeeded");
             break;
+
+        default:
+            break;
     }
 
     switch (mem_selection) {
@@ -1804,6 +1797,9 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
             status = H5Sselect_all(mem_dataspace);
             VRFY_G((status >= 0), "H5Sselect_all succeeded");
             break;
+
+        default:
+            break;
     }
 
     /* fill dataset with test data */
@@ -1846,11 +1842,11 @@ coll_chunktest(const char *filename, int chunk_factor, int select_factor, int ap
 
     /* release data buffers */
     if (coords)
-        HDfree(coords);
+        free(coords);
     if (data_array1)
-        HDfree(data_array1);
+        free(data_array1);
     if (data_origin1)
-        HDfree(data_origin1);
+        free(data_origin1);
 }
 
 int
@@ -1874,11 +1870,11 @@ main(int argc, char **argv)
 
     /* Attempt to turn off atexit post processing so that in case errors
      * happen during the test and the process is aborted, it will not get
-     * hang in the atexit post processing in which it may try to make MPI
+     * hung in the atexit post processing in which it may try to make MPI
      * calls.  By then, MPI calls may not work.
      */
     if (H5dont_atexit() < 0)
-        HDprintf("Failed to turn off atexit processing. Continue.\n");
+        printf("Failed to turn off atexit processing. Continue.\n");
 
     /* set alarm. */
     TestAlarmOn();
@@ -1912,20 +1908,30 @@ main(int argc, char **argv)
 
         H5Pset_fapl_mpio(fapl_id, MPI_COMM_SELF, MPI_INFO_NULL);
 
-        H5E_BEGIN_TRY
-        {
-            H5Fdelete(FILENAME[0], fapl_id);
-            H5Fdelete(FILENAME[1], fapl_id);
-        }
-        H5E_END_TRY;
+        if (H5Fdelete(FILENAME[0], fapl_id) < 0)
+            nerrors++;
 
         H5Pclose(fapl_id);
     }
 
+    /* Gather errors from all ranks */
+    MPI_Allreduce(MPI_IN_PLACE, &nerrors, 1, MPI_INT, MPI_MAX, MPI_COMM_WORLD);
+
+    if (mpi_rank_g == 0) {
+        printf("\n==================================================\n");
+        if (nerrors)
+            printf("***Parallel big IO tests detected %d errors***\n", nerrors);
+        else
+            printf("Parallel big IO tests finished with no errors\n");
+        printf("==================================================\n");
+    }
+
     /* close HDF5 library */
     H5close();
 
+    /* MPI_Finalize must be called AFTER H5close which may use MPI calls */
     MPI_Finalize();
 
-    return 0;
+    /* cannot just return (nerrors) because exit code is limited to 1 byte */
+    return (nerrors != 0);
 }
