@@ -66,7 +66,7 @@ test_split_comm_access(void)
 
     filename = (const char *)GetTestParameters();
     if (VERBOSE_MED)
-        HDprintf("Split Communicator access test on file %s\n", filename);
+        printf("Split Communicator access test on file %s\n", filename);
 
     /* set up MPI parameters */
     MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
@@ -104,7 +104,7 @@ test_split_comm_access(void)
         {
             ret = H5Fdelete(filename, acc_tpl);
         }
-        H5E_END_TRY;
+        H5E_END_TRY
         VRFY((ret >= 0), "H5Fdelete succeeded");
 
         /* Release file-access template */
@@ -137,7 +137,7 @@ test_page_buffer_access(void)
     filename = (const char *)GetTestParameters();
 
     if (VERBOSE_MED)
-        HDprintf("Page Buffer Usage in Parallel %s\n", filename);
+        printf("Page Buffer Usage in Parallel %s\n", filename);
 
     fapl = create_faccess_plist(MPI_COMM_WORLD, MPI_INFO_NULL, facc_type);
     VRFY((fapl >= 0), "create_faccess_plist succeeded");
@@ -156,7 +156,7 @@ test_page_buffer_access(void)
     {
         file_id = H5Fcreate(filename, H5F_ACC_TRUNC, fcpl, fapl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VRFY((file_id < 0), "H5Fcreate failed");
 
     /* disable collective metadata writes for page buffering to work */
@@ -178,7 +178,7 @@ test_page_buffer_access(void)
     ret = H5Pset_file_space_page_size(fcpl, sizeof(int) * 100);
     VRFY((ret == 0), "");
 
-    data = (int *)HDmalloc(sizeof(int) * (size_t)num_elements);
+    data = (int *)malloc(sizeof(int) * (size_t)num_elements);
 
     /* initialize all the elements to have a value of -1 */
     for (i = 0; i < num_elements; i++)
@@ -427,7 +427,7 @@ test_page_buffer_access(void)
         api_ctx_pushed = FALSE;
     }
 
-    HDfree(data);
+    free(data);
     data = NULL;
     MPI_Barrier(MPI_COMM_WORLD);
 }
@@ -467,7 +467,6 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
     VRFY((f != NULL), "");
 
     cache_ptr = f->shared->cache;
-    VRFY((cache_ptr->magic == H5C__H5C_T_MAGIC), "");
 
     cache_ptr->ignore_tags = TRUE;
     H5C_stats__reset(cache_ptr);
@@ -501,8 +500,8 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
 
     num_elements = block[0] * block[1];
     /* allocate memory for data buffer */
-    data_array = (DATATYPE *)HDmalloc(num_elements * sizeof(DATATYPE));
-    VRFY((data_array != NULL), "data_array HDmalloc succeeded");
+    data_array = (DATATYPE *)malloc(num_elements * sizeof(DATATYPE));
+    VRFY((data_array != NULL), "data_array malloc succeeded");
     /* put some trivial data in the data_array */
     for (i = 0; i < num_elements; i++)
         data_array[i] = mpi_rank + 1;
@@ -543,7 +542,7 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
         ret = H5Dclose(dset_id);
         VRFY((ret == 0), "");
 
-        HDmemset(data_array, 0, num_elements * sizeof(DATATYPE));
+        memset(data_array, 0, num_elements * sizeof(DATATYPE));
         dset_id = H5Dopen2(grp_id, dset_name, H5P_DEFAULT);
         VRFY((dset_id >= 0), "");
 
@@ -584,7 +583,7 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
     }
 
     MPI_Barrier(MPI_COMM_WORLD);
-    HDfree(data_array);
+    free(data_array);
     return 0;
 } /* create_file */
 
@@ -634,7 +633,6 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
     VRFY((f != NULL), "");
 
     cache_ptr = f->shared->cache;
-    VRFY((cache_ptr->magic == H5C__H5C_T_MAGIC), "");
 
     MPI_Barrier(MPI_COMM_WORLD);
 
@@ -660,8 +658,8 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
 
     num_elements = block[0] * block[1];
     /* allocate memory for data buffer */
-    data_array = (DATATYPE *)HDmalloc(num_elements * sizeof(DATATYPE));
-    VRFY((data_array != NULL), "data_array HDmalloc succeeded");
+    data_array = (DATATYPE *)malloc(num_elements * sizeof(DATATYPE));
+    VRFY((data_array != NULL), "data_array malloc succeeded");
 
     /* create a memory dataspace independently */
     mem_dataspace = H5Screate_simple(1, &num_elements, NULL);
@@ -713,8 +711,7 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
         entry_ptr = cache_ptr->index[i];
 
         while (entry_ptr != NULL) {
-            HDassert(entry_ptr->magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-            HDassert(entry_ptr->is_dirty == FALSE);
+            assert(entry_ptr->is_dirty == FALSE);
 
             if (!entry_ptr->is_pinned && !entry_ptr->is_protected) {
                 ret = H5AC_expunge_entry(f, entry_ptr->type, entry_ptr->addr, 0);
@@ -747,7 +744,7 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
         api_ctx_pushed = FALSE;
     }
 
-    HDfree(data_array);
+    free(data_array);
 
     return nerrors;
 }
@@ -953,13 +950,13 @@ test_file_properties(void)
 void
 test_delete(void)
 {
-    hid_t       fid      = H5I_INVALID_HID; /* HDF5 file ID */
-    hid_t       fapl_id  = H5I_INVALID_HID; /* File access plist */
-    const char *filename = NULL;
-    MPI_Comm    comm     = MPI_COMM_WORLD;
-    MPI_Info    info     = MPI_INFO_NULL;
-    htri_t      is_hdf5  = FAIL; /* Whether a file is an HDF5 file */
-    herr_t      ret;             /* Generic return value */
+    hid_t       fid           = H5I_INVALID_HID; /* HDF5 file ID */
+    hid_t       fapl_id       = H5I_INVALID_HID; /* File access plist */
+    const char *filename      = NULL;
+    MPI_Comm    comm          = MPI_COMM_WORLD;
+    MPI_Info    info          = MPI_INFO_NULL;
+    htri_t      is_accessible = FAIL; /* Whether a file is accessible */
+    herr_t      ret;                  /* Generic return value */
 
     filename = (const char *)GetTestParameters();
 
@@ -982,21 +979,30 @@ test_delete(void)
     VRFY((SUCCEED == ret), "H5Fclose");
 
     /* Verify that the file is an HDF5 file */
-    is_hdf5 = H5Fis_accessible(filename, fapl_id);
-    VRFY((TRUE == is_hdf5), "H5Fis_accessible");
+    is_accessible = H5Fis_accessible(filename, fapl_id);
+    VRFY((TRUE == is_accessible), "H5Fis_accessible");
 
     /* Delete the file */
     ret = H5Fdelete(filename, fapl_id);
     VRFY((SUCCEED == ret), "H5Fdelete");
 
+    /*
+     * Work around a Cray MPICH bug that causes
+     * H5Fis_accessible to re-create the just-deleted
+     * file as a 0-byte file with strange Unix
+     * permissions, causing the routine to return
+     * false here instead of FAIL.
+     */
+    H5Pset_fapl_mpio(fapl_id, comm, info);
+
     /* Verify that the file is NO LONGER an HDF5 file */
     /* This should fail since there is no file */
     H5E_BEGIN_TRY
     {
-        is_hdf5 = H5Fis_accessible(filename, fapl_id);
+        is_accessible = H5Fis_accessible(filename, fapl_id);
     }
-    H5E_END_TRY;
-    VRFY((is_hdf5 != SUCCEED), "H5Fis_accessible");
+    H5E_END_TRY
+    VRFY((FAIL == is_accessible), "H5Fis_accessible failed as expected");
 
     /* Release file-access plist */
     ret = H5Pclose(fapl_id);
