@@ -10,10 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- * Author: Christian Chilan, April 2008
- */
-
 #include "hdf5.h"
 
 #include <errno.h>
@@ -38,14 +34,14 @@
 #define ELMT_H5_TYPE H5T_NATIVE_UCHAR
 
 #define GOTOERROR(errcode)                                                                                   \
-    {                                                                                                        \
+    do {                                                                                                     \
         ret_code = errcode;                                                                                  \
         goto done;                                                                                           \
-    }
+    } while (0)
 #define ERRMSG(mesg)                                                                                         \
-    {                                                                                                        \
-        HDfprintf(stderr, "*** Assertion failed (%s) at line %4d in %s\n", mesg, (int)__LINE__, __FILE__);   \
-    }
+    do {                                                                                                     \
+        fprintf(stderr, "*** Assertion failed (%s) at line %4d in %s\n", mesg, (int)__LINE__, __FILE__);     \
+    } while (0)
 
 /* verify: if val is false (0), print mesg. */
 #define VRFY(val, mesg)                                                                                      \
@@ -122,7 +118,6 @@ static hid_t    h5dxpl          = H5I_INVALID_HID; /* Dataset transfer property
  * Function:        do_sio
  * Purpose:         SIO Engine where IO are executed.
  * Return:          results
- * Programmer:      Christian Chilan, April, 2008
  */
 void
 do_sio(parameters param, results *res)
@@ -144,7 +139,7 @@ do_sio(parameters param, results *res)
     /* IO type */
     iot = param.io_type;
 
-    if (NULL == (fname = HDcalloc(FILENAME_MAX, sizeof(char))))
+    if (NULL == (fname = calloc(FILENAME_MAX, sizeof(char))))
         GOTOERROR(FAIL);
 
     switch (iot) {
@@ -158,7 +153,7 @@ do_sio(parameters param, results *res)
             break;
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
             GOTOERROR(FAIL);
     }
 
@@ -173,29 +168,29 @@ do_sio(parameters param, results *res)
 
         /* Validate transfer buffer size */
         if (param.buf_size[i] <= 0) {
-            HDfprintf(stderr, "Transfer buffer size[%d] (%zu) must be > 0\n", i, buf_size[i]);
+            fprintf(stderr, "Transfer buffer size[%d] (%zu) must be > 0\n", i, buf_size[i]);
             GOTOERROR(FAIL);
         }
 
         if ((param.dset_size[i] % param.buf_size[i]) != 0) {
-            HDfprintf(stderr,
-                      "Dataset size[%d] (%lld) must be a multiple of the "
-                      "transfer buffer size[%d] (%zu)\n",
-                      param.rank, (long long)param.dset_size[i], param.rank, param.buf_size[i]);
+            fprintf(stderr,
+                    "Dataset size[%d] (%lld) must be a multiple of the "
+                    "transfer buffer size[%d] (%zu)\n",
+                    param.rank, (long long)param.dset_size[i], param.rank, param.buf_size[i]);
             GOTOERROR(FAIL);
         }
     }
 
     /* Allocate transfer buffer */
     if ((buffer = (char *)malloc(linear_buf_size)) == NULL) {
-        HDfprintf(stderr, "malloc for transfer buffer size (%zu) failed\n", linear_buf_size);
+        fprintf(stderr, "malloc for transfer buffer size (%zu) failed\n", linear_buf_size);
         GOTOERROR(FAIL);
     }
 
     if (sio_debug_level >= 4)
 
         /* output all of the times for all iterations */
-        HDfprintf(output, "Timer details:\n");
+        fprintf(output, "Timer details:\n");
 
     /*
      * Write performance measurement
@@ -206,7 +201,7 @@ do_sio(parameters param, results *res)
     sio_create_filename(iot, base_name, fname, FILENAME_MAX, &param);
 
     if (sio_debug_level > 0)
-        HDfprintf(output, "data filename=%s\n", fname);
+        fprintf(output, "data filename=%s\n", fname);
 
     io_time_set(res->timers, HDF5_GROSS_WRITE_FIXED_DIMS, TSTART);
     hrc = do_fopen(&param, fname, &fd, SIO_CREATE | SIO_WRITE);
@@ -263,13 +258,13 @@ done:
             break;
         default:
             /* unknown request */
-            HDassert(0 && "Unknown IO type");
+            assert(0 && "Unknown IO type");
             break;
     }
 
     /* release generic resources */
-    HDfree(buffer);
-    HDfree(fname);
+    free(buffer);
+    free(fname);
 
     res->ret_code = ret_code;
 }
@@ -281,7 +276,6 @@ done:
  *              doing. Also, place in the /tmp/{$USER,$LOGIN} directory if
  *              USER or LOGIN are specified in the environment.
  * Return:      Pointer to filename or NULL
- * Programmer:  Bill Wendling, 21. November 2001
  */
 static char *
 sio_create_filename(iotype iot, const char *base_name, char *fullname, size_t size, parameters *param)
@@ -310,8 +304,8 @@ sio_create_filename(iotype iot, const char *base_name, char *fullname, size_t si
             break;
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
-            HDassert(0 && "Unknown IO type");
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
+            assert(0 && "Unknown IO type");
             break;
     }
 
@@ -401,7 +395,6 @@ sio_create_filename(iotype iot, const char *base_name, char *fullname, size_t si
  * Function:        do_write
  * Purpose:         Write the required amount of data to the file.
  * Return:          SUCCESS or FAIL
- * Programmer:      Christian Chilan, April, 2008
  */
 static herr_t
 do_write(results *res, file_descr *fd, parameters *parms, void *buffer)
@@ -486,14 +479,14 @@ do_write(results *res, file_descr *fd, parameters *parms, void *buffer)
             /* Create the dataset transfer property list */
             h5dxpl = H5Pcreate(H5P_DATASET_XFER);
             if (h5dxpl < 0) {
-                HDfprintf(stderr, "HDF5 Property List Create failed\n");
+                fprintf(stderr, "HDF5 Property List Create failed\n");
                 GOTOERROR(FAIL);
             }
 
             break;
 
         default:
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
             GOTOERROR(FAIL);
             break;
     } /* end switch */
@@ -507,7 +500,7 @@ do_write(results *res, file_descr *fd, parameters *parms, void *buffer)
             h5dcpl = H5Pcreate(H5P_DATASET_CREATE);
 
             if (h5dcpl < 0) {
-                HDfprintf(stderr, "HDF5 Property List Create failed\n");
+                fprintf(stderr, "HDF5 Property List Create failed\n");
                 GOTOERROR(FAIL);
             }
 
@@ -515,7 +508,7 @@ do_write(results *res, file_descr *fd, parameters *parms, void *buffer)
                 /* Set the chunk size to be the same as the buffer size */
                 hrc = H5Pset_chunk(h5dcpl, rank, h5chunk);
                 if (hrc < 0) {
-                    HDfprintf(stderr, "HDF5 Property List Set failed\n");
+                    fprintf(stderr, "HDF5 Property List Set failed\n");
                     GOTOERROR(FAIL);
                 } /* end if */
             }     /* end if */
@@ -525,21 +518,21 @@ do_write(results *res, file_descr *fd, parameters *parms, void *buffer)
                 H5Dcreate2(fd->h5fd, dname, ELMT_H5_TYPE, h5dset_space_id, H5P_DEFAULT, h5dcpl, H5P_DEFAULT);
 
             if (h5ds_id < 0) {
-                HDfprintf(stderr, "HDF5 Dataset Create failed\n");
+                fprintf(stderr, "HDF5 Dataset Create failed\n");
                 GOTOERROR(FAIL);
             }
 
             hrc = H5Pclose(h5dcpl);
             /* verifying the close of the dcpl */
             if (hrc < 0) {
-                HDfprintf(stderr, "HDF5 Property List Close failed\n");
+                fprintf(stderr, "HDF5 Property List Close failed\n");
                 GOTOERROR(FAIL);
             }
             break;
 
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
             GOTOERROR(FAIL);
             break;
     }
@@ -551,7 +544,7 @@ do_write(results *res, file_descr *fd, parameters *parms, void *buffer)
     hrc = dset_write(rank - 1, fd, parms, buffer);
 
     if (hrc < 0) {
-        HDfprintf(stderr, "Error in dataset write\n");
+        fprintf(stderr, "Error in dataset write\n");
         GOTOERROR(FAIL);
     }
 
@@ -565,7 +558,7 @@ do_write(results *res, file_descr *fd, parameters *parms, void *buffer)
         hrc = H5Dclose(h5ds_id);
 
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Dataset Close failed\n");
+            fprintf(stderr, "HDF5 Dataset Close failed\n");
             GOTOERROR(FAIL);
         }
 
@@ -578,7 +571,7 @@ done:
     if (h5dset_space_id != -1) {
         hrc = H5Sclose(h5dset_space_id);
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Dataset Space Close failed\n");
+            fprintf(stderr, "HDF5 Dataset Space Close failed\n");
             ret_code = FAIL;
         }
         else {
@@ -589,7 +582,7 @@ done:
     if (h5mem_space_id != -1) {
         hrc = H5Sclose(h5mem_space_id);
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Memory Space Close failed\n");
+            fprintf(stderr, "HDF5 Memory Space Close failed\n");
             ret_code = FAIL;
         }
         else {
@@ -600,7 +593,7 @@ done:
     if (h5dxpl != -1) {
         hrc = H5Pclose(h5dxpl);
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Dataset Transfer Property List Close failed\n");
+            fprintf(stderr, "HDF5 Dataset Transfer Property List Close failed\n");
             ret_code = FAIL;
         }
         else {
@@ -615,7 +608,6 @@ done:
  * Function:        dset_write
  * Purpose:         Write buffer into the dataset.
  * Return:          SUCCESS or FAIL
- * Programmer:      Christian Chilan, April, 2008
  */
 static herr_t
 dset_write(int local_dim, file_descr *fd, parameters *parms, void *buffer)
@@ -660,7 +652,7 @@ dset_write(int local_dim, file_descr *fd, parameters *parms, void *buffer)
 
                         for (k = 0; k < parms->rank; k++) {
 
-                            HDassert(h5offset[k] >= 0);
+                            assert(h5offset[k] >= 0);
                             if (dims[k] <= (hsize_t)h5offset[k]) {
                                 dims[k] = dims[k] + h5count[k];
                                 hrc     = H5Sset_extent_simple(h5dset_space_id, parms->rank, dims, maxdims);
@@ -683,8 +675,8 @@ dset_write(int local_dim, file_descr *fd, parameters *parms, void *buffer)
 
                 default:
                     /* unknown request */
-                    HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
-                    HDassert(0 && "Unknown IO type");
+                    fprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
+                    assert(0 && "Unknown IO type");
                     break;
             } /* switch (parms->io_type) */
         }
@@ -697,7 +689,6 @@ done:
  * Function:        posix_buffer_write
  * Purpose:         Write buffer into the POSIX file considering contiguity.
  * Return:          SUCCESS or FAIL
- * Programmer:      Christian Chilan, April, 2008
  */
 
 static herr_t
@@ -757,7 +748,6 @@ done:
  * Function:        do_read
  * Purpose:         Read the required amount of data to the file.
  * Return:          SUCCESS or FAIL
- * Programmer:      Christian Chilan, April, 2008
  */
 static herr_t
 do_read(results *res, file_descr *fd, parameters *parms, void *buffer)
@@ -777,7 +767,7 @@ do_read(results *res, file_descr *fd, parameters *parms, void *buffer)
 
     /* Allocate data verification buffer */
     if (NULL == (buffer2 = (char *)malloc(linear_buf_size))) {
-        HDfprintf(stderr, "malloc for data verification buffer size (%zu) failed\n", linear_buf_size);
+        fprintf(stderr, "malloc for data verification buffer size (%zu) failed\n", linear_buf_size);
         GOTOERROR(FAIL);
     } /* end if */
 
@@ -828,14 +818,14 @@ do_read(results *res, file_descr *fd, parameters *parms, void *buffer)
             /* Create the dataset transfer property list */
             h5dxpl = H5Pcreate(H5P_DATASET_XFER);
             if (h5dxpl < 0) {
-                HDfprintf(stderr, "HDF5 Property List Create failed\n");
+                fprintf(stderr, "HDF5 Property List Create failed\n");
                 GOTOERROR(FAIL);
             }
             break;
 
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
             GOTOERROR(FAIL);
             break;
     } /* end switch */
@@ -849,14 +839,14 @@ do_read(results *res, file_descr *fd, parameters *parms, void *buffer)
             HDsnprintf(dname, sizeof(dname), "Dataset_%ld", (long)parms->num_bytes);
             h5ds_id = H5Dopen2(fd->h5fd, dname, H5P_DEFAULT);
             if (h5ds_id < 0) {
-                HDfprintf(stderr, "HDF5 Dataset open failed\n");
+                fprintf(stderr, "HDF5 Dataset open failed\n");
                 GOTOERROR(FAIL);
             }
             break;
 
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
             GOTOERROR(FAIL);
             break;
     } /* end switch */
@@ -866,7 +856,7 @@ do_read(results *res, file_descr *fd, parameters *parms, void *buffer)
     hrc = dset_read(rank - 1, fd, parms, buffer, buffer2);
 
     if (hrc < 0) {
-        HDfprintf(stderr, "Error in dataset read\n");
+        fprintf(stderr, "Error in dataset read\n");
         GOTOERROR(FAIL);
     }
 
@@ -880,7 +870,7 @@ do_read(results *res, file_descr *fd, parameters *parms, void *buffer)
         hrc = H5Dclose(h5ds_id);
 
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Dataset Close failed\n");
+            fprintf(stderr, "HDF5 Dataset Close failed\n");
             GOTOERROR(FAIL);
         }
 
@@ -893,7 +883,7 @@ done:
     if (h5dset_space_id != -1) {
         hrc = H5Sclose(h5dset_space_id);
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Dataset Space Close failed\n");
+            fprintf(stderr, "HDF5 Dataset Space Close failed\n");
             ret_code = FAIL;
         }
         else {
@@ -904,7 +894,7 @@ done:
     if (h5mem_space_id != -1) {
         hrc = H5Sclose(h5mem_space_id);
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Memory Space Close failed\n");
+            fprintf(stderr, "HDF5 Memory Space Close failed\n");
             ret_code = FAIL;
         }
         else {
@@ -915,7 +905,7 @@ done:
     if (h5dxpl != -1) {
         hrc = H5Pclose(h5dxpl);
         if (hrc < 0) {
-            HDfprintf(stderr, "HDF5 Dataset Transfer Property List Close failed\n");
+            fprintf(stderr, "HDF5 Dataset Transfer Property List Close failed\n");
             ret_code = FAIL;
         }
         else {
@@ -934,7 +924,6 @@ done:
  * Function:        dset_read
  * Purpose:         Read buffer into the dataset.
  * Return:          SUCCESS or FAIL
- * Programmer:      Christian Chilan, April, 2008
  */
 
 static herr_t
@@ -981,8 +970,8 @@ dset_read(int local_dim, file_descr *fd, parameters *parms, void *buffer, const
 
                 default:
                     /* unknown request */
-                    HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
-                    HDassert(0 && "Unknown IO type");
+                    fprintf(stderr, "Unknown IO type request (%d)\n", (int)parms->io_type);
+                    assert(0 && "Unknown IO type");
                     break;
             } /* switch (parms->io_type) */
         }
@@ -995,7 +984,6 @@ done:
  * Function:        posix_buffer_read
  * Purpose:         Read buffer into the POSIX file considering contiguity.
  * Return:          SUCCESS or FAIL
- * Programmer:      Christian Chilan, April, 2008
  */
 
 static herr_t
@@ -1049,7 +1037,6 @@ done:
  * Function:    do_fopen
  * Purpose:     Open the specified file.
  * Return:      SUCCESS or FAIL
- * Programmer:  Albert Cheng, Bill Wendling, 2001/12/13
  */
 static herr_t
 do_fopen(parameters *param, char *fname, file_descr *fd /*out*/, int flags)
@@ -1065,7 +1052,7 @@ do_fopen(parameters *param, char *fname, file_descr *fd /*out*/, int flags)
                 fd->posixfd = POSIXOPEN(fname, O_RDONLY);
 
             if (fd->posixfd < 0) {
-                HDfprintf(stderr, "POSIX File Open failed(%s)\n", fname);
+                fprintf(stderr, "POSIX File Open failed(%s)\n", fname);
                 GOTOERROR(FAIL);
             }
 
@@ -1076,7 +1063,7 @@ do_fopen(parameters *param, char *fname, file_descr *fd /*out*/, int flags)
             fapl = set_vfd(param);
 
             if (fapl < 0) {
-                HDfprintf(stderr, "HDF5 Property List Create failed\n");
+                fprintf(stderr, "HDF5 Property List Create failed\n");
                 GOTOERROR(FAIL);
             }
 
@@ -1097,14 +1084,14 @@ do_fopen(parameters *param, char *fname, file_descr *fd /*out*/, int flags)
             }
 
             if (fd->h5fd < 0) {
-                HDfprintf(stderr, "HDF5 File Create failed(%s)\n", fname);
+                fprintf(stderr, "HDF5 File Create failed(%s)\n", fname);
                 GOTOERROR(FAIL);
             }
             break;
 
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)param->io_type);
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)param->io_type);
             GOTOERROR(FAIL);
             break;
     }
@@ -1117,7 +1104,6 @@ done:
  * Function:    set_vfd
  * Purpose:     Sets file driver.
  * Return:      SUCCESS or FAIL
- * Programmer:  Christian Chilan, April, 2008
  */
 
 hid_t
@@ -1162,14 +1148,14 @@ set_vfd(parameters *param)
             char arr[H5FD_MEM_NTYPES][1024];
         } *sv = NULL;
 
-        HDmemset(memb_map, 0, sizeof memb_map);
-        HDmemset(memb_fapl, 0, sizeof memb_fapl);
-        HDmemset(memb_name, 0, sizeof memb_name);
-        HDmemset(memb_addr, 0, sizeof memb_addr);
+        memset(memb_map, 0, sizeof memb_map);
+        memset(memb_fapl, 0, sizeof memb_fapl);
+        memset(memb_name, 0, sizeof memb_name);
+        memset(memb_addr, 0, sizeof memb_addr);
 
-        HDassert(HDstrlen(multi_letters) == H5FD_MEM_NTYPES);
+        assert(HDstrlen(multi_letters) == H5FD_MEM_NTYPES);
 
-        if (NULL == (sv = HDcalloc(1, sizeof(*sv))))
+        if (NULL == (sv = calloc(1, sizeof(*sv))))
             return -1;
         for (mt = H5FD_MEM_DEFAULT; mt < H5FD_MEM_NTYPES; mt++) {
             memb_fapl[mt] = H5P_DEFAULT;
@@ -1179,18 +1165,18 @@ set_vfd(parameters *param)
         }
 
         if (H5Pset_fapl_multi(my_fapl, memb_map, memb_fapl, memb_name, memb_addr, FALSE) < 0) {
-            HDfree(sv);
+            free(sv);
             return -1;
         }
 
-        HDfree(sv);
+        free(sv);
     }
     else if (vfd == family) {
         hsize_t fam_size = 1 * 1024 * 1024; /*100 MB*/
 
         /* Family of files, each 1MB and using the default driver */
         /* if ((val=HDstrtok(NULL, " \t\n\r")))
-            fam_size = (hsize_t)(HDstrtod(val, NULL) * 1024*1024); */
+            fam_size = (hsize_t)(strtod(val, NULL) * 1024*1024); */
         if (H5Pset_fapl_family(my_fapl, fam_size, H5P_DEFAULT) < 0)
             return -1;
     }
@@ -1214,7 +1200,6 @@ set_vfd(parameters *param)
  * Function:    do_fclose
  * Purpose:     Close the specified file descriptor.
  * Return:      SUCCESS or FAIL
- * Programmer:  Albert Cheng, Bill Wendling, 2001/12/13
  */
 static herr_t
 do_fclose(iotype iot, file_descr *fd /*out*/)
@@ -1227,7 +1212,7 @@ do_fclose(iotype iot, file_descr *fd /*out*/)
             rc = POSIXCLOSE(fd->posixfd);
 
             if (rc != 0) {
-                HDfprintf(stderr, "POSIX File Close failed\n");
+                fprintf(stderr, "POSIX File Close failed\n");
                 GOTOERROR(FAIL);
             }
 
@@ -1238,7 +1223,7 @@ do_fclose(iotype iot, file_descr *fd /*out*/)
             hrc = H5Fclose(fd->h5fd);
 
             if (hrc < 0) {
-                HDfprintf(stderr, "HDF5 File Close failed\n");
+                fprintf(stderr, "HDF5 File Close failed\n");
                 GOTOERROR(FAIL);
             }
 
@@ -1247,7 +1232,7 @@ do_fclose(iotype iot, file_descr *fd /*out*/)
 
         default:
             /* unknown request */
-            HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
+            fprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
             GOTOERROR(FAIL);
             break;
     }
@@ -1260,7 +1245,6 @@ done:
  * Function:    do_cleanupfile
  * Purpose:     Cleanup temporary file unless HDF5_NOCLEANUP is set.
  * Return:      void
- * Programmer:  Albert Cheng 2001/12/12
  */
 static void
 do_cleanupfile(iotype iot, char *filename)
@@ -1271,7 +1255,7 @@ do_cleanupfile(iotype iot, char *filename)
     hid_t  driver;
 
     temp_sz = (4096 + sizeof("-?.h5")) * sizeof(char);
-    if (NULL == (temp = HDcalloc(1, temp_sz)))
+    if (NULL == (temp = calloc(1, temp_sz)))
         goto done;
 
     if (clean_file_g == -1)
@@ -1310,7 +1294,7 @@ do_cleanupfile(iotype iot, char *filename)
                 }
                 else if (driver == H5FD_MULTI) {
                     H5FD_mem_t mt;
-                    HDassert(HDstrlen(multi_letters) == H5FD_MEM_NTYPES);
+                    assert(HDstrlen(multi_letters) == H5FD_MEM_NTYPES);
 
                     for (mt = H5FD_MEM_DEFAULT; mt < H5FD_MEM_NTYPES; mt++) {
                         HDsnprintf(temp, temp_sz, "%s-%c.h5", filename, multi_letters[mt]);
@@ -1325,12 +1309,12 @@ do_cleanupfile(iotype iot, char *filename)
 
             default:
                 /* unknown request */
-                HDfprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
-                HDassert(0 && "Unknown IO type");
+                fprintf(stderr, "Unknown IO type request (%d)\n", (int)iot);
+                assert(0 && "Unknown IO type");
                 break;
         }
     }
 
 done:
-    HDfree(temp);
+    free(temp);
 }
