@@ -299,7 +299,7 @@ copy_objects(const char *fnamein, const char *fnameout, pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
     if (options->verbose > 0)
-        HDprintf("Making new file ...\n");
+        printf("Making new file ...\n");
 
     if ((fidout = H5Fcreate(fnameout, H5F_ACC_TRUNC, fcpl, options->fout_fapl)) < 0)
         H5TOOLS_GOTO_ERROR((-1), "H5Fcreate could not create file <%s>:", fnameout);
@@ -390,7 +390,7 @@ done:
             H5Fclose(fidout);
             H5Fclose(fidin);
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     }
     if (travt)
         trav_table_free(travt);
@@ -653,12 +653,13 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
     int                ifil;
     int                is_ref = 0;
     htri_t             is_named;
+    htri_t             is_vlen = 0;
     hbool_t            limit_maxdims;
     hsize_t            size_dset;
     int                ret_value = 0;
 
     /* init linkinfo struct */
-    HDmemset(&linkinfo, 0, sizeof(h5tool_link_info_t));
+    memset(&linkinfo, 0, sizeof(h5tool_link_info_t));
 
     /*-------------------------------------------------------------------------
      * copy the supplied object list
@@ -667,14 +668,14 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
     if (options->verbose > 0) {
         if (options->verbose == 2) {
-            HDprintf("-----------------------------------------------------------------\n");
-            HDprintf(" Type     Filter (Compression)        Timing read/write    Name\n");
-            HDprintf("-----------------------------------------------------------------\n");
+            printf("-----------------------------------------------------------------\n");
+            printf(" Type     Filter (Compression)        Timing read/write    Name\n");
+            printf("-----------------------------------------------------------------\n");
         }
         else {
-            HDprintf("-----------------------------------------\n");
-            HDprintf(" Type     Filter (Compression)     Name\n");
-            HDprintf("-----------------------------------------\n");
+            printf("-----------------------------------------\n");
+            printf(" Type     Filter (Compression)     Name\n");
+            printf("-----------------------------------------\n");
         }
     }
 
@@ -695,9 +696,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                 case H5TRAV_TYPE_GROUP:
                     if (options->verbose > 0) {
                         if (options->verbose == 2)
-                            HDprintf(FORMAT_OBJ_NOTIME, "group", travt->objs[i].name);
+                            printf(FORMAT_OBJ_NOTIME, "group", travt->objs[i].name);
                         else
-                            HDprintf(FORMAT_OBJ, "group", travt->objs[i].name);
+                            printf(FORMAT_OBJ, "group", travt->objs[i].name);
                     }
 
                     /* open input group */
@@ -806,6 +807,10 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                     if (H5T_REFERENCE == H5Tget_class(ftype_id))
                         is_ref = 1;
 
+                    /* early detection of variable-length types */
+                    if ((is_vlen = H5Tdetect_class(ftype_id, H5T_VLEN)) < 0)
+                        H5TOOLS_GOTO_ERROR((-1), "H5Tdetect_class failed");
+
                     /* Check if the datatype is committed */
                     if ((is_named = H5Tcommitted(ftype_id)) < 0)
                         H5TOOLS_GOTO_ERROR((-1), "H5Tcommitted failed");
@@ -823,10 +828,16 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                      * check if we should use H5Ocopy or not
                      * if there is a request for filters/layout, we read/write the object
                      * otherwise we do a copy using H5Ocopy
+                     *
+                     * Note that H5Ocopy is currently unsafe to use for objects that reside in
+                     * or interact with global heaps, such as variable-length datatypes. This
+                     * appears to be due to H5Ocopy not correctly translating in the case where
+                     * these objects move to different global heap addresses in the repacked
+                     * file.
                      *-------------------------------------------------------------------------
                      */
                     use_h5ocopy = !(options->op_tbl->nelems || options->all_filter == 1 ||
-                                    options->all_layout == 1 || is_ref || is_named);
+                                    options->all_layout == 1 || is_ref || is_vlen || is_named);
 
                     /*
                      * Check if we are using different source and destination VOL connectors.
@@ -877,7 +888,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                             H5TOOLS_GOTO_ERROR((-1), "H5Dget_create_plist failed");
                         if ((rank = H5Sget_simple_extent_ndims(f_space_id)) < 0)
                             H5TOOLS_GOTO_ERROR((-1), "H5Sget_simple_extent_ndims failed");
-                        HDmemset(dims, 0, sizeof dims);
+                        memset(dims, 0, sizeof dims);
                         if (H5Sget_simple_extent_dims(f_space_id, dims, NULL) < 0)
                             H5TOOLS_GOTO_ERROR((-1), "H5Sget_simple_extent_dims failed");
                         if (H5Dget_space_status(dset_in, &space_status) < 0)
@@ -991,9 +1002,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                 if (dset_out == H5I_INVALID_HID) {
                                     H5TOOLS_INFO("H5Dcreate2 failed");
                                     if (options->verbose > 0)
-                                        HDprintf(" warning: could not create dataset <%s>. Applying original "
-                                                 "settings\n",
-                                                 travt->objs[i].name);
+                                        printf(" warning: could not create dataset <%s>. Applying original "
+                                               "settings\n",
+                                               travt->objs[i].name);
 
                                     if ((dset_out =
                                              H5Dcreate2(fidout, travt->objs[i].name, wtype_id, f_space_id,
@@ -1012,7 +1023,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                     /* have to read the whole dataset if there is only one element in the
                                      * dataset */
                                     if (need < H5TOOLS_MALLOCSIZE)
-                                        buf = HDmalloc(need);
+                                        buf = malloc(need);
 
                                     /* Set up collective write if using filters in parallel */
                                     {
@@ -1061,7 +1072,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                                         if (buf != NULL) { /* TODO: is buf potentially released by
                                                               H5Dvlen_reclaim()? */
-                                            HDfree(buf);
+                                            free(buf);
                                             buf = NULL;
                                         }
                                     }
@@ -1108,7 +1119,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                                           &hslab_nbytes) < 0)
                                             H5TOOLS_GOTO_ERROR((-1), "get_hyperslab failed");
 
-                                        hslab_buf = HDmalloc((size_t)hslab_nbytes);
+                                        hslab_buf = malloc((size_t)hslab_nbytes);
                                         if (hslab_buf == NULL)
                                             H5TOOLS_GOTO_ERROR((-1), "can't allocate space for hyperslab");
 
@@ -1116,8 +1127,8 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                         hslab_space  = H5Screate_simple(1, &hslab_nelmts, NULL);
 
                                         /* the hyperslab selection loop */
-                                        HDmemset(hs_sel_offset, 0, sizeof hs_sel_offset);
-                                        HDmemset(zero, 0, sizeof zero);
+                                        memset(hs_sel_offset, 0, sizeof hs_sel_offset);
+                                        memset(zero, 0, sizeof zero);
 
                                         for (elmtno = 0; elmtno < p_nelmts; elmtno += hs_select_nelmts) {
                                             if (rank > 0) {
@@ -1189,7 +1200,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                                         H5Sclose(hslab_space);
                                         if (hslab_buf != NULL) {
-                                            HDfree(hslab_buf);
+                                            free(hslab_buf);
                                             hslab_buf = NULL;
                                         }
                                     } /* end if reading/writing by hyperslab */
@@ -1221,13 +1232,13 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                      * (in case there was a filter)
                                      */
                                     if (has_filter && apply_s == 0)
-                                        HDprintf(" <warning: filter not applied to %s. dataset smaller than "
-                                                 "%d bytes>\n",
-                                                 travt->objs[i].name, (int)options->min_comp);
+                                        printf(" <warning: filter not applied to %s. dataset smaller than "
+                                               "%d bytes>\n",
+                                               travt->objs[i].name, (int)options->min_comp);
 
                                     if (has_filter && apply_f == 0)
-                                        HDprintf(" <warning: could not apply the filter to %s>\n",
-                                                 travt->objs[i].name);
+                                        printf(" <warning: could not apply the filter to %s>\n",
+                                               travt->objs[i].name);
                                 } /* end if verbose (print compression) */
 
                                 /*-------------------------------------------------------------------------
@@ -1310,9 +1321,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                         if (options->verbose > 0) {
                             if (options->verbose == 2)
-                                HDprintf(FORMAT_OBJ_TIME, "dset", 0.0, write_time, travt->objs[i].name);
+                                printf(FORMAT_OBJ_TIME, "dset", 0.0, write_time, travt->objs[i].name);
                             else
-                                HDprintf(FORMAT_OBJ, "dset", travt->objs[i].name);
+                                printf(FORMAT_OBJ, "dset", travt->objs[i].name);
                         }
 
                     } /* end whether we have request for filter/chunking */
@@ -1327,9 +1338,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                 case H5TRAV_TYPE_NAMED_DATATYPE:
                     if (options->verbose > 0) {
                         if (options->verbose == 2)
-                            HDprintf(FORMAT_OBJ_NOTIME, "type", travt->objs[i].name);
+                            printf(FORMAT_OBJ_NOTIME, "type", travt->objs[i].name);
                         else
-                            HDprintf(FORMAT_OBJ, "type", travt->objs[i].name);
+                            printf(FORMAT_OBJ, "type", travt->objs[i].name);
                     }
 
                     if ((type_in = H5Topen2(fidin, travt->objs[i].name, H5P_DEFAULT)) < 0)
@@ -1371,9 +1382,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                 case H5TRAV_TYPE_UDLINK:
                     if (options->verbose > 0) {
                         if (options->verbose == 2)
-                            HDprintf(FORMAT_OBJ_NOTIME, "link", travt->objs[i].name);
+                            printf(FORMAT_OBJ_NOTIME, "link", travt->objs[i].name);
                         else
-                            HDprintf(FORMAT_OBJ, "link", travt->objs[i].name);
+                            printf(FORMAT_OBJ, "link", travt->objs[i].name);
                     }
 
                     /* Check -X option. */
@@ -1381,7 +1392,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                         if (H5tools_get_symlink_info(fidin, travt->objs[i].name, &linkinfo, 1) == 0) {
                             /* dangling link */
                             if (options->prune) {
-                                HDprintf("Pruned %s.\n", travt->objs[i].name);
+                                printf("Pruned %s.\n", travt->objs[i].name);
                             }
                             else {
                                 if (H5Lcopy(fidin, travt->objs[i].name, fidout, travt->objs[i].name,
@@ -1421,12 +1432,12 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                         /* free link info path */
                         if (linkinfo.trg_path)
-                            HDfree(linkinfo.trg_path);
+                            free(linkinfo.trg_path);
                         linkinfo.trg_path = NULL;
                     } /* options->merge */
                     else {
                         if (options->prune) {
-                            HDprintf("Pruned %s.\n", travt->objs[i].name);
+                            printf("Pruned %s.\n", travt->objs[i].name);
                         }
                         else {
                             if (H5Lcopy(fidin, travt->objs[i].name, fidout, travt->objs[i].name, H5P_DEFAULT,
@@ -1455,12 +1466,12 @@ done:
         {
             named_datatype_free(&named_dt_head, 1);
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     }
 
     /* free link info path */
     if (linkinfo.trg_path)
-        HDfree(linkinfo.trg_path);
+        free(linkinfo.trg_path);
 
     H5E_BEGIN_TRY
     {
@@ -1480,13 +1491,13 @@ done:
         H5Tclose(type_in);
         H5Tclose(type_out);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* free */
     if (buf != NULL)
-        HDfree(buf);
+        free(buf);
     if (hslab_buf != NULL)
-        HDfree(hslab_buf);
+        free(hslab_buf);
 
     return ret_value;
 } /* end do_copy_objects() */
@@ -1589,9 +1600,9 @@ print_dataset_info(hid_t dcpl_id, char *objname, double ratio, int pr, pack_opt_
 
     if (!pr)
         if (options->verbose == 2)
-            HDprintf(FORMAT_OBJ_TIME, "dset", read_time, write_time, objname);
+            printf(FORMAT_OBJ_TIME, "dset", read_time, write_time, objname);
         else
-            HDprintf(FORMAT_OBJ, "dset", objname);
+            printf(FORMAT_OBJ, "dset", objname);
     else {
         char str[512], temp[512];
 
@@ -1600,9 +1611,9 @@ print_dataset_info(hid_t dcpl_id, char *objname, double ratio, int pr, pack_opt_
         HDsnprintf(temp, sizeof(temp), "  (%.3f:1)", ratio);
         HDstrcat(str, temp);
         if (options->verbose == 2)
-            HDprintf(FORMAT_OBJ_TIME, str, read_time, write_time, objname);
+            printf(FORMAT_OBJ_TIME, str, read_time, write_time, objname);
         else
-            HDprintf(FORMAT_OBJ, str, objname);
+            printf(FORMAT_OBJ, str, objname);
     }
 } /* end print_dataset_info() */
 
@@ -1654,13 +1665,13 @@ copy_user_block(const char *infile, const char *outfile, hsize_t size)
             } while (-1 == nwritten && EINTR == errno);
             if (-1 == nwritten) /* error */
                 H5TOOLS_GOTO_ERROR((-1), "HDwrite failed");
-            HDassert(nwritten > 0);
-            HDassert(nwritten <= nbytes);
+            assert(nwritten > 0);
+            assert(nwritten <= nbytes);
 
             /* Update # of bytes left & offset in buffer */
             nbytes -= nwritten;
             wbuf += nwritten;
-            HDassert(nbytes == 0 || wbuf < (rbuf + USERBLOCK_XFER_SIZE));
+            assert(nbytes == 0 || wbuf < (rbuf + USERBLOCK_XFER_SIZE));
         } /* end while */
 
         /* Update size of userblock left to transfer */
@@ -1728,9 +1739,9 @@ print_user_block(const char *filename, hid_t fid)
 
         for (i = 0; i < nread; i++) {
 
-            HDprintf("%c ", rbuf[i]);
+            printf("%c ", rbuf[i]);
         }
-        HDprintf("\n");
+        printf("\n");
 
         if (nread < 0) {
             H5TOOLS_GOTO_ERROR((-1), "nread < 0");
