@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -28,15 +27,15 @@
 #define EDGE_V3_FILE   "h5fc_edge_v3.h5"
 #define ERR_LEVEL_FILE "h5fc_err_level.h5"
 
-const char *FILENAME[] = {"h5fc_ext1_i.h5",   /* 0 */
-                          "h5fc_ext1_s.h5",   /* 1 */
-                          "h5fc_ext1_f.h5",   /* 2 */
-                          "h5fc_ext2_is.h5",  /* 3 */
-                          "h5fc_ext2_if.h5",  /* 4 */
-                          "h5fc_ext2_sf.h5",  /* 5 */
-                          "h5fc_ext3_isf.h5", /* 6 */
-                          "h5fc_ext_none.h5", /* 7 */
-                          NULL};
+static const char *FILENAME[] = {"h5fc_ext1_i.h5",   /* 0 */
+                                 "h5fc_ext1_s.h5",   /* 1 */
+                                 "h5fc_ext1_f.h5",   /* 2 */
+                                 "h5fc_ext2_is.h5",  /* 3 */
+                                 "h5fc_ext2_if.h5",  /* 4 */
+                                 "h5fc_ext2_sf.h5",  /* 5 */
+                                 "h5fc_ext3_isf.h5", /* 6 */
+                                 "h5fc_ext_none.h5", /* 7 */
+                                 NULL};
 
 #define GROUP "GROUP"
 
@@ -63,7 +62,7 @@ const char *FILENAME[] = {"h5fc_ext1_i.h5",   /* 0 */
 /*
  * Function: gen_non()
  *
- * Create a file with SWMR write+non-latest-format--this will result in v3 superbock+latest version support:
+ * Create a file with SWMR write+non-latest-format--this will result in v3 superblock+latest version support:
  *    1) 1 chunked dataset with extensible array chunk indexing type (without data)
  *    2) 1 chunked dataset with version 2 B-tree chunk indexing type (with data)
  * Re-open the file with write+non-latest-format and create:
@@ -294,7 +293,7 @@ error:
         H5Fclose(fcpl);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
 } /* gen_non() */
 
@@ -374,7 +373,7 @@ error:
         H5Fclose(fid);
         H5Pclose(fapl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
 } /* gen_edge() */
 
@@ -424,8 +423,8 @@ gen_err_level(const char *fname)
         goto error;
 
     /* Initialize data buffer */
-    buf = (unsigned char *)HDmalloc(NUM * sizeof(unsigned char *));
-    HDmemset(buf, 42, NUM * sizeof(unsigned char));
+    buf = (unsigned char *)malloc(NUM * sizeof(unsigned char *));
+    memset(buf, 42, NUM * sizeof(unsigned char));
 
     /* Create the test file */
     if ((fid = H5Fcreate(fname, H5F_ACC_TRUNC, fcpl, fapl)) < 0)
@@ -519,7 +518,7 @@ error:
         H5Pclose(fapl);
         H5Pclose(fcpl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
 } /* gen_err_level() */
 
@@ -775,7 +774,7 @@ error:
         H5Pclose(fapl);
         H5Pclose(fcpl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
 } /* end gen_ext() */
 
@@ -798,7 +797,7 @@ main(void)
         for (i = 0; i < 8; i++) {
             char filename[50];
 
-            HDmemset(filename, 0, sizeof(filename));
+            memset(filename, 0, sizeof(filename));
             if (!new_format)
                 HDstrcat(filename, "old_");
             HDstrcat(filename, FILENAME[i]);
