@@ -13,7 +13,7 @@
 #include "h5test.h"
 
 /* The HDF5 test files */
-const char *FILENAME[] = {
+static const char *FILENAME[] = {
     "h5clear_sec2_v3.h5", /* 0 -- sec2 file with superblock version 3 */
     "h5clear_log_v3.h5",  /* 1 -- log file with superblock version 3 */
     "h5clear_sec2_v0.h5", /* 2 -- sec2 file with superblock version 0 */
@@ -48,8 +48,6 @@ const char *FILENAME_ENHANCE[] = {
  * Return:      Success:    0
  *              Failure:    1
  *
- * Programmer:    Vailin Choi; March 2017
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -124,7 +122,7 @@ gen_cache_image_file(const char *fname)
     if (H5Fclose(fid) < 0)
         goto error;
 
-    HDfree(buf);
+    free(buf);
 
     return 0;
 
@@ -138,9 +136,9 @@ error:
         H5Pclose(fapl);
         H5Pclose(dcpl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
-    HDfree(buf);
+    free(buf);
 
     return 1;
 } /* gen_cache_image_file() */
@@ -167,8 +165,6 @@ error:
  * Return:      Success:    0
  *              Failure:    1
  *
- * Programmer:    Vailin Choi; March 2017
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -313,7 +309,7 @@ error:
         H5Fclose(fid);
         H5Pclose(fcpl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* gen_enhance_files() */
 
@@ -366,8 +362,6 @@ error:
  * Return:    Success:    0
  *            Failure:    1
  *
- * Programmer:    Vailin Choi; July 2013
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -600,10 +594,10 @@ main(void)
     fflush(stderr);
 
     /* Not going through library closing by calling _exit(0) with success */
-    HD_exit(0);
+    _exit(0);
 
 error:
 
     /* Exit with failure */
-    HD_exit(1);
+    _exit(1);
 }
