@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2004
- *
  * Purpose:	Tests performance of metadata
  */
 
@@ -28,25 +25,25 @@
 #define FACC_MPIO    0x1 /* MPIO */
 
 /* Which test to run */
-int RUN_TEST = 0x0; /* all tests as default */
-int TEST_1   = 0x1; /* Test 1 */
-int TEST_2   = 0x2; /* Test 2 */
-int TEST_3   = 0x4; /* Test 3 */
+static int RUN_TEST = 0x0; /* all tests as default */
+static int TEST_1   = 0x1; /* Test 1 */
+static int TEST_2   = 0x2; /* Test 2 */
+static int TEST_3   = 0x4; /* Test 3 */
 
-const char *FILENAME[] = {"meta_perf_1", "meta_perf_2", "meta_perf_3", NULL};
+static const char *FILENAME[] = {"meta_perf_1", "meta_perf_2", "meta_perf_3", NULL};
 
 /* Default values for performance. Can be changed through command line options */
-int     NUM_DSETS   = 16;
-int     NUM_ATTRS   = 8;
-int     BATCH_ATTRS = 2;
-hbool_t flush_dset  = FALSE;
-hbool_t flush_attr  = FALSE;
-int     nerrors     = 0; /* errors count */
-hid_t   fapl;
+static int     NUM_DSETS   = 16;
+static int     NUM_ATTRS   = 8;
+static int     BATCH_ATTRS = 2;
+static hbool_t flush_dset  = FALSE;
+static hbool_t flush_attr  = FALSE;
+static int     nerrors     = 0; /* errors count */
+static hid_t   fapl;
 
 /* Data space IDs */
-hid_t space;
-hid_t small_space;
+static hid_t space;
+static hid_t small_space;
 
 /* Performance data */
 typedef struct p_time {
@@ -59,7 +56,7 @@ typedef struct p_time {
 } p_time;
 
 /*Test file access type for parallel.  MPIO as default */
-int facc_type = FACC_DEFAULT;
+static int facc_type = FACC_DEFAULT;
 
 double retrieve_time(void);
 void   perf(p_time *perf_t, double start_t, double end_t);
@@ -70,9 +67,6 @@ void   print_perf(p_time, p_time, p_time);
  *
  * Purpose:	Parse command line options
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -188,9 +182,6 @@ parse_options(int argc, char **argv)
  *
  * Purpose:	Prints help page
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -241,9 +232,6 @@ usage(void)
  *
  *		Failure:	-1
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -279,9 +267,6 @@ error:
  *
  *		Failure:	-1
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -319,9 +304,6 @@ error:
  *
  *		Failure:	-1
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -399,8 +381,7 @@ create_attrs_1(void)
             attr_t.avg = attr_t.total / (NUM_ATTRS * NUM_DSETS);
 
         /* Print out the performance result */
-        HDfprintf(stderr, "1.  Create %d attributes for each of %d existing datasets\n", NUM_ATTRS,
-                  NUM_DSETS);
+        fprintf(stderr, "1.  Create %d attributes for each of %d existing datasets\n", NUM_ATTRS, NUM_DSETS);
         print_perf(open_t, close_t, attr_t);
     }
 
@@ -422,9 +403,6 @@ error:
  *
  *		Failure:	-1
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -500,7 +478,7 @@ create_attrs_2(void)
             attr_t.avg = attr_t.total / (NUM_ATTRS * NUM_DSETS);
 
         /* Print out the performance result */
-        HDfprintf(stderr, "2.  Create %d attributes for each of %d new datasets\n", NUM_ATTRS, NUM_DSETS);
+        fprintf(stderr, "2.  Create %d attributes for each of %d new datasets\n", NUM_ATTRS, NUM_DSETS);
         print_perf(create_t, close_t, attr_t);
     }
 
@@ -523,9 +501,6 @@ error:
  *
  *		Failure:	-1
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -608,8 +583,8 @@ create_attrs_3(void)
         attr_t.avg  = attr_t.total / (NUM_ATTRS * NUM_DSETS);
 
         /* Print out the performance result */
-        HDfprintf(stderr, "3.  Create %d attributes for each of %d existing datasets for %d times\n",
-                  BATCH_ATTRS, NUM_DSETS, loop_num);
+        fprintf(stderr, "3.  Create %d attributes for each of %d existing datasets for %d times\n",
+                BATCH_ATTRS, NUM_DSETS, loop_num);
         print_perf(open_t, close_t, attr_t);
     }
 
@@ -627,9 +602,6 @@ error:
  *
  * Purpose:     Returns time in seconds, in a double number.
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 double
@@ -655,9 +627,6 @@ retrieve_time(void)
  * Purpose:	Calculate total time, maximal and minimal time of
  *              performance.
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -707,21 +676,18 @@ perf(p_time *perf_t, double start_t, double end_t)
  *
  * Purpose:	Print out performance data.
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 void
 print_perf(p_time open_t, p_time close_t, p_time attr_t)
 {
-    HDfprintf(stderr, "\t%s:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n", open_t.func, open_t.avg, open_t.max,
-              open_t.min);
-    HDfprintf(stderr, "\tH5Dclose:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n", close_t.avg, close_t.max,
-              close_t.min);
+    fprintf(stderr, "\t%s:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n", open_t.func, open_t.avg, open_t.max,
+            open_t.min);
+    fprintf(stderr, "\tH5Dclose:\t\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n", close_t.avg, close_t.max,
+            close_t.min);
     if (NUM_ATTRS)
-        HDfprintf(stderr, "\tH5A(create & close):\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n", attr_t.avg,
-                  attr_t.max, attr_t.min);
+        fprintf(stderr, "\tH5A(create & close):\tavg=%.6fs;\tmax=%.6fs;\tmin=%.6fs\n", attr_t.avg, attr_t.max,
+                attr_t.min);
 }
 
 /*-------------------------------------------------------------------------
@@ -733,9 +699,6 @@ print_perf(p_time open_t, p_time close_t, p_time attr_t)
  *
  *		Failure:	exit(1)
  *
- * Programmer:	Raymond Lu
- *		Friday, Oct 3, 2003
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -761,7 +724,7 @@ main(int argc, char **argv)
 #ifdef H5_HAVE_PARALLEL
     if (facc_type == FACC_DEFAULT || (facc_type != FACC_DEFAULT && MAINPROCESS))
 #endif /*H5_HAVE_PARALLEL*/
-        HDfprintf(stderr, "\t\tPerformance result of metadata for datasets and attributes\n\n");
+        fprintf(stderr, "\t\tPerformance result of metadata for datasets and attributes\n\n");
 
     fapl = H5Pcreate(H5P_FILE_ACCESS);
 #ifdef H5_HAVE_PARALLEL
